#line 2 "scan.c"
/*-------------------------------------------------------------------------
 *
 * scan.l
 *	  lexical scanner for PostgreSQL
 *
 * NOTE NOTE NOTE:
 *
 * The rules in this file must be kept in sync with src/fe_utils/psqlscan.l
 * and src/interfaces/ecpg/preproc/pgc.l!
 *
 * The rules are designed so that the scanner never has to backtrack,
 * in the sense that there is always a rule that can match the input
 * consumed so far (the rule action may internally throw back some input
 * with yyless(), however).  As explained in the flex manual, this makes
 * for a useful speed increase --- several percent faster when measuring
 * raw parsing (Flex + Bison).  The extra complexity is mostly in the rules
 * for handling float numbers and continued string literals.  If you change
 * the lexical rules, verify that you haven't broken the no-backtrack
 * property by running flex with the "-b" option and checking that the
 * resulting "lex.backup" file says that no backing up is needed.  (As of
 * Postgres 9.2, this check is made automatically by the Makefile.)
 *
 *
 * Portions Copyright (c) 1996-2024, PostgreSQL Global Development Group
 * Portions Copyright (c) 1994, Regents of the University of California
 *
 * IDENTIFICATION
 *	  src/backend/parser/scan.l
 *
 *-------------------------------------------------------------------------
 */
#include "postgres.h"

#include <ctype.h>
#include <unistd.h>

#include "common/string.h"
#include "gramparse.h"
#include "nodes/miscnodes.h"
#include "parser/parser.h"		/* only needed for GUC variables */
#include "parser/scansup.h"
#include "port/pg_bitutils.h"
#include "mb/pg_wchar.h"
#include "utils/builtins.h"

#line 48 "scan.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 1
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* An opaque pointer. */
#ifndef YY_TYPEDEF_YY_SCANNER_T
#define YY_TYPEDEF_YY_SCANNER_T
typedef void* yyscan_t;
#endif

/* For convenience, these vars (plus the bison vars far below)
   are macros in the reentrant scanner. */
#define yyin yyg->yyin_r
#define yyout yyg->yyout_r
#define yyextra yyg->yyextra_r
#define yyleng yyg->yyleng_r
#define yytext yyg->yytext_r
#define yylineno (YY_CURRENT_BUFFER_LVALUE->yy_bs_lineno)
#define yycolumn (YY_CURRENT_BUFFER_LVALUE->yy_bs_column)
#define yy_flex_debug yyg->yy_flex_debug_r

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN yyg->yy_start = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START ((yyg->yy_start - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE core_yyrestart(yyin ,yyscanner )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        yy_size_t yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = yyg->yy_hold_char; \
		YY_RESTORE_YY_MORE_OFFSET \
		yyg->yy_c_buf_p = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, yyg->yytext_ptr , yyscanner )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via core_yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( yyg->yy_buffer_stack \
                          ? yyg->yy_buffer_stack[yyg->yy_buffer_stack_top] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE yyg->yy_buffer_stack[yyg->yy_buffer_stack_top]

void core_yyrestart (FILE *input_file ,yyscan_t yyscanner );
void core_yy_switch_to_buffer (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
YY_BUFFER_STATE core_yy_create_buffer (FILE *file,int size ,yyscan_t yyscanner );
void core_yy_delete_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void core_yy_flush_buffer (YY_BUFFER_STATE b ,yyscan_t yyscanner );
void core_yypush_buffer_state (YY_BUFFER_STATE new_buffer ,yyscan_t yyscanner );
void core_yypop_buffer_state (yyscan_t yyscanner );

static void core_yyensure_buffer_stack (yyscan_t yyscanner );
static void core_yy_load_buffer_state (yyscan_t yyscanner );
static void core_yy_init_buffer (YY_BUFFER_STATE b,FILE *file ,yyscan_t yyscanner );

#define YY_FLUSH_BUFFER core_yy_flush_buffer(YY_CURRENT_BUFFER ,yyscanner)

YY_BUFFER_STATE core_yy_scan_buffer (char *base,yy_size_t size ,yyscan_t yyscanner );
YY_BUFFER_STATE core_yy_scan_string (yyconst char *yy_str ,yyscan_t yyscanner );
YY_BUFFER_STATE core_yy_scan_bytes (yyconst char *bytes,int len ,yyscan_t yyscanner );

void *core_yyalloc (yy_size_t ,yyscan_t yyscanner );
void *core_yyrealloc (void *,yy_size_t ,yyscan_t yyscanner );
void core_yyfree (void * ,yyscan_t yyscanner );

#define yy_new_buffer core_yy_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        core_yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            core_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        core_yyensure_buffer_stack (yyscanner); \
		YY_CURRENT_BUFFER_LVALUE =    \
            core_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define core_yywrap(yyscanner) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

typedef yyconst struct yy_trans_info *yy_state_type;

#define yytext_ptr yytext_r

static yy_state_type yy_get_previous_state (yyscan_t yyscanner );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  ,yyscan_t yyscanner);
static int yy_get_next_buffer (yyscan_t yyscanner );
static void yynoreturn yy_fatal_error (yyconst char* msg ,yyscan_t yyscanner );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	yyg->yytext_ptr = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	yyg->yy_hold_char = *yy_cp; \
	*yy_cp = '\0'; \
	yyg->yy_c_buf_p = yy_cp;

#define YY_NUM_RULES 76
#define YY_END_OF_BUFFER 77
struct yy_trans_info
	{
	flex_int16_t yy_verify;
	flex_int16_t yy_nxt;
	};
static yyconst struct yy_trans_info yy_transition[25101] =
    {
 {   0,   0 }, {   0,24845 }, {   0,   0 }, {   0,24843 }, {   1,6192 },
 {   2,6192 }, {   3,6192 }, {   4,6192 }, {   5,6192 }, {   6,6192 },
 {   7,6192 }, {   8,6192 }, {   9,6194 }, {  10,6199 }, {  11,6194 },
 {  12,6194 }, {  13,6194 }, {  14,6192 }, {  15,6192 }, {  16,6192 },
 {  17,6192 }, {  18,6192 }, {  19,6192 }, {  20,6192 }, {  21,6192 },
 {  22,6192 }, {  23,6192 }, {  24,6192 }, {  25,6192 }, {  26,6192 },
 {  27,6192 }, {  28,6192 }, {  29,6192 }, {  30,6192 }, {  31,6192 },
 {  32,6194 }, {  33,6201 }, {  34,6196 }, {  35,6241 }, {  36,6307 },
 {  37,6564 }, {  38,6241 }, {  39,6214 }, {  40,6216 }, {  41,6216 },
 {  42,6564 }, {  43,6564 }, {  44,6216 }, {  45,6575 }, {  46,6594 },

 {  47,6665 }, {  48,6697 }, {  49,6954 }, {  50,6954 }, {  51,6954 },
 {  52,6954 }, {  53,6954 }, {  54,6954 }, {  55,6954 }, {  56,6954 },
 {  57,6954 }, {  58,6219 }, {  59,6216 }, {  60,7211 }, {  61,7222 },
 {  62,7289 }, {  63,6241 }, {  64,6241 }, {  65,7321 }, {  66,7578 },
 {  67,7321 }, {  68,7321 }, {  69,7835 }, {  70,7321 }, {  71,7321 },
 {  72,7321 }, {  73,7321 }, {  74,7321 }, {  75,7321 }, {  76,7321 },
 {  77,7321 }, {  78,8092 }, {  79,7321 }, {  80,7321 }, {  81,7321 },
 {  82,7321 }, {  83,7321 }, {  84,7321 }, {  85,8349 }, {  86,7321 },
 {  87,7321 }, {  88,8606 }, {  89,7321 }, {  90,7321 }, {  91,6216 },
 {  92,6192 }, {  93,6216 }, {  94,6564 }, {  95,7321 }, {  96,6241 },

 {  97,7321 }, {  98,7578 }, {  99,7321 }, { 100,7321 }, { 101,7835 },
 { 102,7321 }, { 103,7321 }, { 104,7321 }, { 105,7321 }, { 106,7321 },
 { 107,7321 }, { 108,7321 }, { 109,7321 }, { 110,8092 }, { 111,7321 },
 { 112,7321 }, { 113,7321 }, { 114,7321 }, { 115,7321 }, { 116,7321 },
 { 117,8349 }, { 118,7321 }, { 119,7321 }, { 120,8606 }, { 121,7321 },
 { 122,7321 }, { 123,6192 }, { 124,6241 }, { 125,6192 }, { 126,6241 },
 { 127,6192 }, { 128,7321 }, { 129,7321 }, { 130,7321 }, { 131,7321 },
 { 132,7321 }, { 133,7321 }, { 134,7321 }, { 135,7321 }, { 136,7321 },
 { 137,7321 }, { 138,7321 }, { 139,7321 }, { 140,7321 }, { 141,7321 },
 { 142,7321 }, { 143,7321 }, { 144,7321 }, { 145,7321 }, { 146,7321 },

 { 147,7321 }, { 148,7321 }, { 149,7321 }, { 150,7321 }, { 151,7321 },
 { 152,7321 }, { 153,7321 }, { 154,7321 }, { 155,7321 }, { 156,7321 },
 { 157,7321 }, { 158,7321 }, { 159,7321 }, { 160,7321 }, { 161,7321 },
 { 162,7321 }, { 163,7321 }, { 164,7321 }, { 165,7321 }, { 166,7321 },
 { 167,7321 }, { 168,7321 }, { 169,7321 }, { 170,7321 }, { 171,7321 },
 { 172,7321 }, { 173,7321 }, { 174,7321 }, { 175,7321 }, { 176,7321 },
 { 177,7321 }, { 178,7321 }, { 179,7321 }, { 180,7321 }, { 181,7321 },
 { 182,7321 }, { 183,7321 }, { 184,7321 }, { 185,7321 }, { 186,7321 },
 { 187,7321 }, { 188,7321 }, { 189,7321 }, { 190,7321 }, { 191,7321 },
 { 192,7321 }, { 193,7321 }, { 194,7321 }, { 195,7321 }, { 196,7321 },

 { 197,7321 }, { 198,7321 }, { 199,7321 }, { 200,7321 }, { 201,7321 },
 { 202,7321 }, { 203,7321 }, { 204,7321 }, { 205,7321 }, { 206,7321 },
 { 207,7321 }, { 208,7321 }, { 209,7321 }, { 210,7321 }, { 211,7321 },
 { 212,7321 }, { 213,7321 }, { 214,7321 }, { 215,7321 }, { 216,7321 },
 { 217,7321 }, { 218,7321 }, { 219,7321 }, { 220,7321 }, { 221,7321 },
 { 222,7321 }, { 223,7321 }, { 224,7321 }, { 225,7321 }, { 226,7321 },
 { 227,7321 }, { 228,7321 }, { 229,7321 }, { 230,7321 }, { 231,7321 },
 { 232,7321 }, { 233,7321 }, { 234,7321 }, { 235,7321 }, { 236,7321 },
 { 237,7321 }, { 238,7321 }, { 239,7321 }, { 240,7321 }, { 241,7321 },
 { 242,7321 }, { 243,7321 }, { 244,7321 }, { 245,7321 }, { 246,7321 },

 { 247,7321 }, { 248,7321 }, { 249,7321 }, { 250,7321 }, { 251,7321 },
 { 252,7321 }, { 253,7321 }, { 254,7321 }, { 255,7321 }, { 256,6192 },
 {   0,   0 }, {   0,24585 }, {   1,5934 }, {   2,5934 }, {   3,5934 },
 {   4,5934 }, {   5,5934 }, {   6,5934 }, {   7,5934 }, {   8,5934 },
 {   9,5936 }, {  10,5941 }, {  11,5936 }, {  12,5936 }, {  13,5936 },
 {  14,5934 }, {  15,5934 }, {  16,5934 }, {  17,5934 }, {  18,5934 },
 {  19,5934 }, {  20,5934 }, {  21,5934 }, {  22,5934 }, {  23,5934 },
 {  24,5934 }, {  25,5934 }, {  26,5934 }, {  27,5934 }, {  28,5934 },
 {  29,5934 }, {  30,5934 }, {  31,5934 }, {  32,5936 }, {  33,5943 },
 {  34,5938 }, {  35,5983 }, {  36,6049 }, {  37,6306 }, {  38,5983 },

 {  39,5956 }, {  40,5958 }, {  41,5958 }, {  42,6306 }, {  43,6306 },
 {  44,5958 }, {  45,6317 }, {  46,6336 }, {  47,6407 }, {  48,6439 },
 {  49,6696 }, {  50,6696 }, {  51,6696 }, {  52,6696 }, {  53,6696 },
 {  54,6696 }, {  55,6696 }, {  56,6696 }, {  57,6696 }, {  58,5961 },
 {  59,5958 }, {  60,6953 }, {  61,6964 }, {  62,7031 }, {  63,5983 },
 {  64,5983 }, {  65,7063 }, {  66,7320 }, {  67,7063 }, {  68,7063 },
 {  69,7577 }, {  70,7063 }, {  71,7063 }, {  72,7063 }, {  73,7063 },
 {  74,7063 }, {  75,7063 }, {  76,7063 }, {  77,7063 }, {  78,7834 },
 {  79,7063 }, {  80,7063 }, {  81,7063 }, {  82,7063 }, {  83,7063 },
 {  84,7063 }, {  85,8091 }, {  86,7063 }, {  87,7063 }, {  88,8348 },

 {  89,7063 }, {  90,7063 }, {  91,5958 }, {  92,5934 }, {  93,5958 },
 {  94,6306 }, {  95,7063 }, {  96,5983 }, {  97,7063 }, {  98,7320 },
 {  99,7063 }, { 100,7063 }, { 101,7577 }, { 102,7063 }, { 103,7063 },
 { 104,7063 }, { 105,7063 }, { 106,7063 }, { 107,7063 }, { 108,7063 },
 { 109,7063 }, { 110,7834 }, { 111,7063 }, { 112,7063 }, { 113,7063 },
 { 114,7063 }, { 115,7063 }, { 116,7063 }, { 117,8091 }, { 118,7063 },
 { 119,7063 }, { 120,8348 }, { 121,7063 }, { 122,7063 }, { 123,5934 },
 { 124,5983 }, { 125,5934 }, { 126,5983 }, { 127,5934 }, { 128,7063 },
 { 129,7063 }, { 130,7063 }, { 131,7063 }, { 132,7063 }, { 133,7063 },
 { 134,7063 }, { 135,7063 }, { 136,7063 }, { 137,7063 }, { 138,7063 },

 { 139,7063 }, { 140,7063 }, { 141,7063 }, { 142,7063 }, { 143,7063 },
 { 144,7063 }, { 145,7063 }, { 146,7063 }, { 147,7063 }, { 148,7063 },
 { 149,7063 }, { 150,7063 }, { 151,7063 }, { 152,7063 }, { 153,7063 },
 { 154,7063 }, { 155,7063 }, { 156,7063 }, { 157,7063 }, { 158,7063 },
 { 159,7063 }, { 160,7063 }, { 161,7063 }, { 162,7063 }, { 163,7063 },
 { 164,7063 }, { 165,7063 }, { 166,7063 }, { 167,7063 }, { 168,7063 },
 { 169,7063 }, { 170,7063 }, { 171,7063 }, { 172,7063 }, { 173,7063 },
 { 174,7063 }, { 175,7063 }, { 176,7063 }, { 177,7063 }, { 178,7063 },
 { 179,7063 }, { 180,7063 }, { 181,7063 }, { 182,7063 }, { 183,7063 },
 { 184,7063 }, { 185,7063 }, { 186,7063 }, { 187,7063 }, { 188,7063 },

 { 189,7063 }, { 190,7063 }, { 191,7063 }, { 192,7063 }, { 193,7063 },
 { 194,7063 }, { 195,7063 }, { 196,7063 }, { 197,7063 }, { 198,7063 },
 { 199,7063 }, { 200,7063 }, { 201,7063 }, { 202,7063 }, { 203,7063 },
 { 204,7063 }, { 205,7063 }, { 206,7063 }, { 207,7063 }, { 208,7063 },
 { 209,7063 }, { 210,7063 }, { 211,7063 }, { 212,7063 }, { 213,7063 },
 { 214,7063 }, { 215,7063 }, { 216,7063 }, { 217,7063 }, { 218,7063 },
 { 219,7063 }, { 220,7063 }, { 221,7063 }, { 222,7063 }, { 223,7063 },
 { 224,7063 }, { 225,7063 }, { 226,7063 }, { 227,7063 }, { 228,7063 },
 { 229,7063 }, { 230,7063 }, { 231,7063 }, { 232,7063 }, { 233,7063 },
 { 234,7063 }, { 235,7063 }, { 236,7063 }, { 237,7063 }, { 238,7063 },

 { 239,7063 }, { 240,7063 }, { 241,7063 }, { 242,7063 }, { 243,7063 },
 { 244,7063 }, { 245,7063 }, { 246,7063 }, { 247,7063 }, { 248,7063 },
 { 249,7063 }, { 250,7063 }, { 251,7063 }, { 252,7063 }, { 253,7063 },
 { 254,7063 }, { 255,7063 }, { 256,5934 }, {   0,  10 }, {   0,24327 },
 {   1,8347 }, {   2,8347 }, {   3,8347 }, {   4,8347 }, {   5,8347 },
 {   6,8347 }, {   7,8347 }, {   8,8347 }, {   9,8347 }, {  10,8347 },
 {  11,8347 }, {  12,8347 }, {  13,8347 }, {  14,8347 }, {  15,8347 },
 {  16,8347 }, {  17,8347 }, {  18,8347 }, {  19,8347 }, {  20,8347 },
 {  21,8347 }, {  22,8347 }, {  23,8347 }, {  24,8347 }, {  25,8347 },
 {  26,8347 }, {  27,8347 }, {  28,8347 }, {  29,8347 }, {  30,8347 },

 {  31,8347 }, {  32,8347 }, {  33,8347 }, {  34,8347 }, {  35,8347 },
 {  36,8347 }, {  37,8347 }, {  38,8347 }, {  39,5705 }, {  40,8347 },
 {  41,8347 }, {  42,8347 }, {  43,8347 }, {  44,8347 }, {  45,8347 },
 {  46,8347 }, {  47,8347 }, {  48,8347 }, {  49,8347 }, {  50,8347 },
 {  51,8347 }, {  52,8347 }, {  53,8347 }, {  54,8347 }, {  55,8347 },
 {  56,8347 }, {  57,8347 }, {  58,8347 }, {  59,8347 }, {  60,8347 },
 {  61,8347 }, {  62,8347 }, {  63,8347 }, {  64,8347 }, {  65,8347 },
 {  66,8347 }, {  67,8347 }, {  68,8347 }, {  69,8347 }, {  70,8347 },
 {  71,8347 }, {  72,8347 }, {  73,8347 }, {  74,8347 }, {  75,8347 },
 {  76,8347 }, {  77,8347 }, {  78,8347 }, {  79,8347 }, {  80,8347 },

 {  81,8347 }, {  82,8347 }, {  83,8347 }, {  84,8347 }, {  85,8347 },
 {  86,8347 }, {  87,8347 }, {  88,8347 }, {  89,8347 }, {  90,8347 },
 {  91,8347 }, {  92,8347 }, {  93,8347 }, {  94,8347 }, {  95,8347 },
 {  96,8347 }, {  97,8347 }, {  98,8347 }, {  99,8347 }, { 100,8347 },
 { 101,8347 }, { 102,8347 }, { 103,8347 }, { 104,8347 }, { 105,8347 },
 { 106,8347 }, { 107,8347 }, { 108,8347 }, { 109,8347 }, { 110,8347 },
 { 111,8347 }, { 112,8347 }, { 113,8347 }, { 114,8347 }, { 115,8347 },
 { 116,8347 }, { 117,8347 }, { 118,8347 }, { 119,8347 }, { 120,8347 },
 { 121,8347 }, { 122,8347 }, { 123,8347 }, { 124,8347 }, { 125,8347 },
 { 126,8347 }, { 127,8347 }, { 128,8347 }, { 129,8347 }, { 130,8347 },

 { 131,8347 }, { 132,8347 }, { 133,8347 }, { 134,8347 }, { 135,8347 },
 { 136,8347 }, { 137,8347 }, { 138,8347 }, { 139,8347 }, { 140,8347 },
 { 141,8347 }, { 142,8347 }, { 143,8347 }, { 144,8347 }, { 145,8347 },
 { 146,8347 }, { 147,8347 }, { 148,8347 }, { 149,8347 }, { 150,8347 },
 { 151,8347 }, { 152,8347 }, { 153,8347 }, { 154,8347 }, { 155,8347 },
 { 156,8347 }, { 157,8347 }, { 158,8347 }, { 159,8347 }, { 160,8347 },
 { 161,8347 }, { 162,8347 }, { 163,8347 }, { 164,8347 }, { 165,8347 },
 { 166,8347 }, { 167,8347 }, { 168,8347 }, { 169,8347 }, { 170,8347 },
 { 171,8347 }, { 172,8347 }, { 173,8347 }, { 174,8347 }, { 175,8347 },
 { 176,8347 }, { 177,8347 }, { 178,8347 }, { 179,8347 }, { 180,8347 },

 { 181,8347 }, { 182,8347 }, { 183,8347 }, { 184,8347 }, { 185,8347 },
 { 186,8347 }, { 187,8347 }, { 188,8347 }, { 189,8347 }, { 190,8347 },
 { 191,8347 }, { 192,8347 }, { 193,8347 }, { 194,8347 }, { 195,8347 },
 { 196,8347 }, { 197,8347 }, { 198,8347 }, { 199,8347 }, { 200,8347 },
 { 201,8347 }, { 202,8347 }, { 203,8347 }, { 204,8347 }, { 205,8347 },
 { 206,8347 }, { 207,8347 }, { 208,8347 }, { 209,8347 }, { 210,8347 },
 { 211,8347 }, { 212,8347 }, { 213,8347 }, { 214,8347 }, { 215,8347 },
 { 216,8347 }, { 217,8347 }, { 218,8347 }, { 219,8347 }, { 220,8347 },
 { 221,8347 }, { 222,8347 }, { 223,8347 }, { 224,8347 }, { 225,8347 },
 { 226,8347 }, { 227,8347 }, { 228,8347 }, { 229,8347 }, { 230,8347 },

 { 231,8347 }, { 232,8347 }, { 233,8347 }, { 234,8347 }, { 235,8347 },
 { 236,8347 }, { 237,8347 }, { 238,8347 }, { 239,8347 }, { 240,8347 },
 { 241,8347 }, { 242,8347 }, { 243,8347 }, { 244,8347 }, { 245,8347 },
 { 246,8347 }, { 247,8347 }, { 248,8347 }, { 249,8347 }, { 250,8347 },
 { 251,8347 }, { 252,8347 }, { 253,8347 }, { 254,8347 }, { 255,8347 },
 { 256,8347 }, {   0,  10 }, {   0,24069 }, {   1,8089 }, {   2,8089 },
 {   3,8089 }, {   4,8089 }, {   5,8089 }, {   6,8089 }, {   7,8089 },
 {   8,8089 }, {   9,8089 }, {  10,8089 }, {  11,8089 }, {  12,8089 },
 {  13,8089 }, {  14,8089 }, {  15,8089 }, {  16,8089 }, {  17,8089 },
 {  18,8089 }, {  19,8089 }, {  20,8089 }, {  21,8089 }, {  22,8089 },

 {  23,8089 }, {  24,8089 }, {  25,8089 }, {  26,8089 }, {  27,8089 },
 {  28,8089 }, {  29,8089 }, {  30,8089 }, {  31,8089 }, {  32,8089 },
 {  33,8089 }, {  34,8089 }, {  35,8089 }, {  36,8089 }, {  37,8089 },
 {  38,8089 }, {  39,5447 }, {  40,8089 }, {  41,8089 }, {  42,8089 },
 {  43,8089 }, {  44,8089 }, {  45,8089 }, {  46,8089 }, {  47,8089 },
 {  48,8089 }, {  49,8089 }, {  50,8089 }, {  51,8089 }, {  52,8089 },
 {  53,8089 }, {  54,8089 }, {  55,8089 }, {  56,8089 }, {  57,8089 },
 {  58,8089 }, {  59,8089 }, {  60,8089 }, {  61,8089 }, {  62,8089 },
 {  63,8089 }, {  64,8089 }, {  65,8089 }, {  66,8089 }, {  67,8089 },
 {  68,8089 }, {  69,8089 }, {  70,8089 }, {  71,8089 }, {  72,8089 },

 {  73,8089 }, {  74,8089 }, {  75,8089 }, {  76,8089 }, {  77,8089 },
 {  78,8089 }, {  79,8089 }, {  80,8089 }, {  81,8089 }, {  82,8089 },
 {  83,8089 }, {  84,8089 }, {  85,8089 }, {  86,8089 }, {  87,8089 },
 {  88,8089 }, {  89,8089 }, {  90,8089 }, {  91,8089 }, {  92,8089 },
 {  93,8089 }, {  94,8089 }, {  95,8089 }, {  96,8089 }, {  97,8089 },
 {  98,8089 }, {  99,8089 }, { 100,8089 }, { 101,8089 }, { 102,8089 },
 { 103,8089 }, { 104,8089 }, { 105,8089 }, { 106,8089 }, { 107,8089 },
 { 108,8089 }, { 109,8089 }, { 110,8089 }, { 111,8089 }, { 112,8089 },
 { 113,8089 }, { 114,8089 }, { 115,8089 }, { 116,8089 }, { 117,8089 },
 { 118,8089 }, { 119,8089 }, { 120,8089 }, { 121,8089 }, { 122,8089 },

 { 123,8089 }, { 124,8089 }, { 125,8089 }, { 126,8089 }, { 127,8089 },
 { 128,8089 }, { 129,8089 }, { 130,8089 }, { 131,8089 }, { 132,8089 },
 { 133,8089 }, { 134,8089 }, { 135,8089 }, { 136,8089 }, { 137,8089 },
 { 138,8089 }, { 139,8089 }, { 140,8089 }, { 141,8089 }, { 142,8089 },
 { 143,8089 }, { 144,8089 }, { 145,8089 }, { 146,8089 }, { 147,8089 },
 { 148,8089 }, { 149,8089 }, { 150,8089 }, { 151,8089 }, { 152,8089 },
 { 153,8089 }, { 154,8089 }, { 155,8089 }, { 156,8089 }, { 157,8089 },
 { 158,8089 }, { 159,8089 }, { 160,8089 }, { 161,8089 }, { 162,8089 },
 { 163,8089 }, { 164,8089 }, { 165,8089 }, { 166,8089 }, { 167,8089 },
 { 168,8089 }, { 169,8089 }, { 170,8089 }, { 171,8089 }, { 172,8089 },

 { 173,8089 }, { 174,8089 }, { 175,8089 }, { 176,8089 }, { 177,8089 },
 { 178,8089 }, { 179,8089 }, { 180,8089 }, { 181,8089 }, { 182,8089 },
 { 183,8089 }, { 184,8089 }, { 185,8089 }, { 186,8089 }, { 187,8089 },
 { 188,8089 }, { 189,8089 }, { 190,8089 }, { 191,8089 }, { 192,8089 },
 { 193,8089 }, { 194,8089 }, { 195,8089 }, { 196,8089 }, { 197,8089 },
 { 198,8089 }, { 199,8089 }, { 200,8089 }, { 201,8089 }, { 202,8089 },
 { 203,8089 }, { 204,8089 }, { 205,8089 }, { 206,8089 }, { 207,8089 },
 { 208,8089 }, { 209,8089 }, { 210,8089 }, { 211,8089 }, { 212,8089 },
 { 213,8089 }, { 214,8089 }, { 215,8089 }, { 216,8089 }, { 217,8089 },
 { 218,8089 }, { 219,8089 }, { 220,8089 }, { 221,8089 }, { 222,8089 },

 { 223,8089 }, { 224,8089 }, { 225,8089 }, { 226,8089 }, { 227,8089 },
 { 228,8089 }, { 229,8089 }, { 230,8089 }, { 231,8089 }, { 232,8089 },
 { 233,8089 }, { 234,8089 }, { 235,8089 }, { 236,8089 }, { 237,8089 },
 { 238,8089 }, { 239,8089 }, { 240,8089 }, { 241,8089 }, { 242,8089 },
 { 243,8089 }, { 244,8089 }, { 245,8089 }, { 246,8089 }, { 247,8089 },
 { 248,8089 }, { 249,8089 }, { 250,8089 }, { 251,8089 }, { 252,8089 },
 { 253,8089 }, { 254,8089 }, { 255,8089 }, { 256,8089 }, {   0,   0 },
 {   0,23811 }, {   1,8089 }, {   2,8089 }, {   3,8089 }, {   4,8089 },
 {   5,8089 }, {   6,8089 }, {   7,8089 }, {   8,8089 }, {   9,8089 },
 {  10,8089 }, {  11,8089 }, {  12,8089 }, {  13,8089 }, {  14,8089 },

 {  15,8089 }, {  16,8089 }, {  17,8089 }, {  18,8089 }, {  19,8089 },
 {  20,8089 }, {  21,8089 }, {  22,8089 }, {  23,8089 }, {  24,8089 },
 {  25,8089 }, {  26,8089 }, {  27,8089 }, {  28,8089 }, {  29,8089 },
 {  30,8089 }, {  31,8089 }, {  32,8089 }, {  33,8347 }, {  34,8089 },
 {  35,8347 }, {  36,8089 }, {  37,8347 }, {  38,8347 }, {  39,8089 },
 {  40,8089 }, {  41,8089 }, {  42,5192 }, {  43,8347 }, {  44,8089 },
 {  45,8347 }, {  46,8089 }, {  47,5196 }, {  48,8089 }, {  49,8089 },
 {  50,8089 }, {  51,8089 }, {  52,8089 }, {  53,8089 }, {  54,8089 },
 {  55,8089 }, {  56,8089 }, {  57,8089 }, {  58,8089 }, {  59,8089 },
 {  60,8347 }, {  61,8347 }, {  62,8347 }, {  63,8347 }, {  64,8347 },

 {  65,8089 }, {  66,8089 }, {  67,8089 }, {  68,8089 }, {  69,8089 },
 {  70,8089 }, {  71,8089 }, {  72,8089 }, {  73,8089 }, {  74,8089 },
 {  75,8089 }, {  76,8089 }, {  77,8089 }, {  78,8089 }, {  79,8089 },
 {  80,8089 }, {  81,8089 }, {  82,8089 }, {  83,8089 }, {  84,8089 },
 {  85,8089 }, {  86,8089 }, {  87,8089 }, {  88,8089 }, {  89,8089 },
 {  90,8089 }, {  91,8089 }, {  92,8089 }, {  93,8089 }, {  94,8347 },
 {  95,8089 }, {  96,8347 }, {  97,8089 }, {  98,8089 }, {  99,8089 },
 { 100,8089 }, { 101,8089 }, { 102,8089 }, { 103,8089 }, { 104,8089 },
 { 105,8089 }, { 106,8089 }, { 107,8089 }, { 108,8089 }, { 109,8089 },
 { 110,8089 }, { 111,8089 }, { 112,8089 }, { 113,8089 }, { 114,8089 },

 { 115,8089 }, { 116,8089 }, { 117,8089 }, { 118,8089 }, { 119,8089 },
 { 120,8089 }, { 121,8089 }, { 122,8089 }, { 123,8089 }, { 124,8347 },
 { 125,8089 }, { 126,8347 }, { 127,8089 }, { 128,8089 }, { 129,8089 },
 { 130,8089 }, { 131,8089 }, { 132,8089 }, { 133,8089 }, { 134,8089 },
 { 135,8089 }, { 136,8089 }, { 137,8089 }, { 138,8089 }, { 139,8089 },
 { 140,8089 }, { 141,8089 }, { 142,8089 }, { 143,8089 }, { 144,8089 },
 { 145,8089 }, { 146,8089 }, { 147,8089 }, { 148,8089 }, { 149,8089 },
 { 150,8089 }, { 151,8089 }, { 152,8089 }, { 153,8089 }, { 154,8089 },
 { 155,8089 }, { 156,8089 }, { 157,8089 }, { 158,8089 }, { 159,8089 },
 { 160,8089 }, { 161,8089 }, { 162,8089 }, { 163,8089 }, { 164,8089 },

 { 165,8089 }, { 166,8089 }, { 167,8089 }, { 168,8089 }, { 169,8089 },
 { 170,8089 }, { 171,8089 }, { 172,8089 }, { 173,8089 }, { 174,8089 },
 { 175,8089 }, { 176,8089 }, { 177,8089 }, { 178,8089 }, { 179,8089 },
 { 180,8089 }, { 181,8089 }, { 182,8089 }, { 183,8089 }, { 184,8089 },
 { 185,8089 }, { 186,8089 }, { 187,8089 }, { 188,8089 }, { 189,8089 },
 { 190,8089 }, { 191,8089 }, { 192,8089 }, { 193,8089 }, { 194,8089 },
 { 195,8089 }, { 196,8089 }, { 197,8089 }, { 198,8089 }, { 199,8089 },
 { 200,8089 }, { 201,8089 }, { 202,8089 }, { 203,8089 }, { 204,8089 },
 { 205,8089 }, { 206,8089 }, { 207,8089 }, { 208,8089 }, { 209,8089 },
 { 210,8089 }, { 211,8089 }, { 212,8089 }, { 213,8089 }, { 214,8089 },

 { 215,8089 }, { 216,8089 }, { 217,8089 }, { 218,8089 }, { 219,8089 },
 { 220,8089 }, { 221,8089 }, { 222,8089 }, { 223,8089 }, { 224,8089 },
 { 225,8089 }, { 226,8089 }, { 227,8089 }, { 228,8089 }, { 229,8089 },
 { 230,8089 }, { 231,8089 }, { 232,8089 }, { 233,8089 }, { 234,8089 },
 { 235,8089 }, { 236,8089 }, { 237,8089 }, { 238,8089 }, { 239,8089 },
 { 240,8089 }, { 241,8089 }, { 242,8089 }, { 243,8089 }, { 244,8089 },
 { 245,8089 }, { 246,8089 }, { 247,8089 }, { 248,8089 }, { 249,8089 },
 { 250,8089 }, { 251,8089 }, { 252,8089 }, { 253,8089 }, { 254,8089 },
 { 255,8089 }, { 256,8089 }, {   0,   0 }, {   0,23553 }, {   1,7831 },
 {   2,7831 }, {   3,7831 }, {   4,7831 }, {   5,7831 }, {   6,7831 },

 {   7,7831 }, {   8,7831 }, {   9,7831 }, {  10,7831 }, {  11,7831 },
 {  12,7831 }, {  13,7831 }, {  14,7831 }, {  15,7831 }, {  16,7831 },
 {  17,7831 }, {  18,7831 }, {  19,7831 }, {  20,7831 }, {  21,7831 },
 {  22,7831 }, {  23,7831 }, {  24,7831 }, {  25,7831 }, {  26,7831 },
 {  27,7831 }, {  28,7831 }, {  29,7831 }, {  30,7831 }, {  31,7831 },
 {  32,7831 }, {  33,8089 }, {  34,7831 }, {  35,8089 }, {  36,7831 },
 {  37,8089 }, {  38,8089 }, {  39,7831 }, {  40,7831 }, {  41,7831 },
 {  42,4934 }, {  43,8089 }, {  44,7831 }, {  45,8089 }, {  46,7831 },
 {  47,4938 }, {  48,7831 }, {  49,7831 }, {  50,7831 }, {  51,7831 },
 {  52,7831 }, {  53,7831 }, {  54,7831 }, {  55,7831 }, {  56,7831 },

 {  57,7831 }, {  58,7831 }, {  59,7831 }, {  60,8089 }, {  61,8089 },
 {  62,8089 }, {  63,8089 }, {  64,8089 }, {  65,7831 }, {  66,7831 },
 {  67,7831 }, {  68,7831 }, {  69,7831 }, {  70,7831 }, {  71,7831 },
 {  72,7831 }, {  73,7831 }, {  74,7831 }, {  75,7831 }, {  76,7831 },
 {  77,7831 }, {  78,7831 }, {  79,7831 }, {  80,7831 }, {  81,7831 },
 {  82,7831 }, {  83,7831 }, {  84,7831 }, {  85,7831 }, {  86,7831 },
 {  87,7831 }, {  88,7831 }, {  89,7831 }, {  90,7831 }, {  91,7831 },
 {  92,7831 }, {  93,7831 }, {  94,8089 }, {  95,7831 }, {  96,8089 },
 {  97,7831 }, {  98,7831 }, {  99,7831 }, { 100,7831 }, { 101,7831 },
 { 102,7831 }, { 103,7831 }, { 104,7831 }, { 105,7831 }, { 106,7831 },

 { 107,7831 }, { 108,7831 }, { 109,7831 }, { 110,7831 }, { 111,7831 },
 { 112,7831 }, { 113,7831 }, { 114,7831 }, { 115,7831 }, { 116,7831 },
 { 117,7831 }, { 118,7831 }, { 119,7831 }, { 120,7831 }, { 121,7831 },
 { 122,7831 }, { 123,7831 }, { 124,8089 }, { 125,7831 }, { 126,8089 },
 { 127,7831 }, { 128,7831 }, { 129,7831 }, { 130,7831 }, { 131,7831 },
 { 132,7831 }, { 133,7831 }, { 134,7831 }, { 135,7831 }, { 136,7831 },
 { 137,7831 }, { 138,7831 }, { 139,7831 }, { 140,7831 }, { 141,7831 },
 { 142,7831 }, { 143,7831 }, { 144,7831 }, { 145,7831 }, { 146,7831 },
 { 147,7831 }, { 148,7831 }, { 149,7831 }, { 150,7831 }, { 151,7831 },
 { 152,7831 }, { 153,7831 }, { 154,7831 }, { 155,7831 }, { 156,7831 },

 { 157,7831 }, { 158,7831 }, { 159,7831 }, { 160,7831 }, { 161,7831 },
 { 162,7831 }, { 163,7831 }, { 164,7831 }, { 165,7831 }, { 166,7831 },
 { 167,7831 }, { 168,7831 }, { 169,7831 }, { 170,7831 }, { 171,7831 },
 { 172,7831 }, { 173,7831 }, { 174,7831 }, { 175,7831 }, { 176,7831 },
 { 177,7831 }, { 178,7831 }, { 179,7831 }, { 180,7831 }, { 181,7831 },
 { 182,7831 }, { 183,7831 }, { 184,7831 }, { 185,7831 }, { 186,7831 },
 { 187,7831 }, { 188,7831 }, { 189,7831 }, { 190,7831 }, { 191,7831 },
 { 192,7831 }, { 193,7831 }, { 194,7831 }, { 195,7831 }, { 196,7831 },
 { 197,7831 }, { 198,7831 }, { 199,7831 }, { 200,7831 }, { 201,7831 },
 { 202,7831 }, { 203,7831 }, { 204,7831 }, { 205,7831 }, { 206,7831 },

 { 207,7831 }, { 208,7831 }, { 209,7831 }, { 210,7831 }, { 211,7831 },
 { 212,7831 }, { 213,7831 }, { 214,7831 }, { 215,7831 }, { 216,7831 },
 { 217,7831 }, { 218,7831 }, { 219,7831 }, { 220,7831 }, { 221,7831 },
 { 222,7831 }, { 223,7831 }, { 224,7831 }, { 225,7831 }, { 226,7831 },
 { 227,7831 }, { 228,7831 }, { 229,7831 }, { 230,7831 }, { 231,7831 },
 { 232,7831 }, { 233,7831 }, { 234,7831 }, { 235,7831 }, { 236,7831 },
 { 237,7831 }, { 238,7831 }, { 239,7831 }, { 240,7831 }, { 241,7831 },
 { 242,7831 }, { 243,7831 }, { 244,7831 }, { 245,7831 }, { 246,7831 },
 { 247,7831 }, { 248,7831 }, { 249,7831 }, { 250,7831 }, { 251,7831 },
 { 252,7831 }, { 253,7831 }, { 254,7831 }, { 255,7831 }, { 256,7831 },

 {   0,   0 }, {   0,23295 }, {   1,8089 }, {   2,8089 }, {   3,8089 },
 {   4,8089 }, {   5,8089 }, {   6,8089 }, {   7,8089 }, {   8,8089 },
 {   9,8089 }, {  10,8089 }, {  11,8089 }, {  12,8089 }, {  13,8089 },
 {  14,8089 }, {  15,8089 }, {  16,8089 }, {  17,8089 }, {  18,8089 },
 {  19,8089 }, {  20,8089 }, {  21,8089 }, {  22,8089 }, {  23,8089 },
 {  24,8089 }, {  25,8089 }, {  26,8089 }, {  27,8089 }, {  28,8089 },
 {  29,8089 }, {  30,8089 }, {  31,8089 }, {  32,8089 }, {  33,8089 },
 {  34,4685 }, {  35,8089 }, {  36,8089 }, {  37,8089 }, {  38,8089 },
 {  39,8089 }, {  40,8089 }, {  41,8089 }, {  42,8089 }, {  43,8089 },
 {  44,8089 }, {  45,8089 }, {  46,8089 }, {  47,8089 }, {  48,8089 },

 {  49,8089 }, {  50,8089 }, {  51,8089 }, {  52,8089 }, {  53,8089 },
 {  54,8089 }, {  55,8089 }, {  56,8089 }, {  57,8089 }, {  58,8089 },
 {  59,8089 }, {  60,8089 }, {  61,8089 }, {  62,8089 }, {  63,8089 },
 {  64,8089 }, {  65,8089 }, {  66,8089 }, {  67,8089 }, {  68,8089 },
 {  69,8089 }, {  70,8089 }, {  71,8089 }, {  72,8089 }, {  73,8089 },
 {  74,8089 }, {  75,8089 }, {  76,8089 }, {  77,8089 }, {  78,8089 },
 {  79,8089 }, {  80,8089 }, {  81,8089 }, {  82,8089 }, {  83,8089 },
 {  84,8089 }, {  85,8089 }, {  86,8089 }, {  87,8089 }, {  88,8089 },
 {  89,8089 }, {  90,8089 }, {  91,8089 }, {  92,8089 }, {  93,8089 },
 {  94,8089 }, {  95,8089 }, {  96,8089 }, {  97,8089 }, {  98,8089 },

 {  99,8089 }, { 100,8089 }, { 101,8089 }, { 102,8089 }, { 103,8089 },
 { 104,8089 }, { 105,8089 }, { 106,8089 }, { 107,8089 }, { 108,8089 },
 { 109,8089 }, { 110,8089 }, { 111,8089 }, { 112,8089 }, { 113,8089 },
 { 114,8089 }, { 115,8089 }, { 116,8089 }, { 117,8089 }, { 118,8089 },
 { 119,8089 }, { 120,8089 }, { 121,8089 }, { 122,8089 }, { 123,8089 },
 { 124,8089 }, { 125,8089 }, { 126,8089 }, { 127,8089 }, { 128,8089 },
 { 129,8089 }, { 130,8089 }, { 131,8089 }, { 132,8089 }, { 133,8089 },
 { 134,8089 }, { 135,8089 }, { 136,8089 }, { 137,8089 }, { 138,8089 },
 { 139,8089 }, { 140,8089 }, { 141,8089 }, { 142,8089 }, { 143,8089 },
 { 144,8089 }, { 145,8089 }, { 146,8089 }, { 147,8089 }, { 148,8089 },

 { 149,8089 }, { 150,8089 }, { 151,8089 }, { 152,8089 }, { 153,8089 },
 { 154,8089 }, { 155,8089 }, { 156,8089 }, { 157,8089 }, { 158,8089 },
 { 159,8089 }, { 160,8089 }, { 161,8089 }, { 162,8089 }, { 163,8089 },
 { 164,8089 }, { 165,8089 }, { 166,8089 }, { 167,8089 }, { 168,8089 },
 { 169,8089 }, { 170,8089 }, { 171,8089 }, { 172,8089 }, { 173,8089 },
 { 174,8089 }, { 175,8089 }, { 176,8089 }, { 177,8089 }, { 178,8089 },
 { 179,8089 }, { 180,8089 }, { 181,8089 }, { 182,8089 }, { 183,8089 },
 { 184,8089 }, { 185,8089 }, { 186,8089 }, { 187,8089 }, { 188,8089 },
 { 189,8089 }, { 190,8089 }, { 191,8089 }, { 192,8089 }, { 193,8089 },
 { 194,8089 }, { 195,8089 }, { 196,8089 }, { 197,8089 }, { 198,8089 },

 { 199,8089 }, { 200,8089 }, { 201,8089 }, { 202,8089 }, { 203,8089 },
 { 204,8089 }, { 205,8089 }, { 206,8089 }, { 207,8089 }, { 208,8089 },
 { 209,8089 }, { 210,8089 }, { 211,8089 }, { 212,8089 }, { 213,8089 },
 { 214,8089 }, { 215,8089 }, { 216,8089 }, { 217,8089 }, { 218,8089 },
 { 219,8089 }, { 220,8089 }, { 221,8089 }, { 222,8089 }, { 223,8089 },
 { 224,8089 }, { 225,8089 }, { 226,8089 }, { 227,8089 }, { 228,8089 },
 { 229,8089 }, { 230,8089 }, { 231,8089 }, { 232,8089 }, { 233,8089 },
 { 234,8089 }, { 235,8089 }, { 236,8089 }, { 237,8089 }, { 238,8089 },
 { 239,8089 }, { 240,8089 }, { 241,8089 }, { 242,8089 }, { 243,8089 },
 { 244,8089 }, { 245,8089 }, { 246,8089 }, { 247,8089 }, { 248,8089 },

 { 249,8089 }, { 250,8089 }, { 251,8089 }, { 252,8089 }, { 253,8089 },
 { 254,8089 }, { 255,8089 }, { 256,8089 }, {   0,   0 }, {   0,23037 },
 {   1,7831 }, {   2,7831 }, {   3,7831 }, {   4,7831 }, {   5,7831 },
 {   6,7831 }, {   7,7831 }, {   8,7831 }, {   9,7831 }, {  10,7831 },
 {  11,7831 }, {  12,7831 }, {  13,7831 }, {  14,7831 }, {  15,7831 },
 {  16,7831 }, {  17,7831 }, {  18,7831 }, {  19,7831 }, {  20,7831 },
 {  21,7831 }, {  22,7831 }, {  23,7831 }, {  24,7831 }, {  25,7831 },
 {  26,7831 }, {  27,7831 }, {  28,7831 }, {  29,7831 }, {  30,7831 },
 {  31,7831 }, {  32,7831 }, {  33,7831 }, {  34,4427 }, {  35,7831 },
 {  36,7831 }, {  37,7831 }, {  38,7831 }, {  39,7831 }, {  40,7831 },

 {  41,7831 }, {  42,7831 }, {  43,7831 }, {  44,7831 }, {  45,7831 },
 {  46,7831 }, {  47,7831 }, {  48,7831 }, {  49,7831 }, {  50,7831 },
 {  51,7831 }, {  52,7831 }, {  53,7831 }, {  54,7831 }, {  55,7831 },
 {  56,7831 }, {  57,7831 }, {  58,7831 }, {  59,7831 }, {  60,7831 },
 {  61,7831 }, {  62,7831 }, {  63,7831 }, {  64,7831 }, {  65,7831 },
 {  66,7831 }, {  67,7831 }, {  68,7831 }, {  69,7831 }, {  70,7831 },
 {  71,7831 }, {  72,7831 }, {  73,7831 }, {  74,7831 }, {  75,7831 },
 {  76,7831 }, {  77,7831 }, {  78,7831 }, {  79,7831 }, {  80,7831 },
 {  81,7831 }, {  82,7831 }, {  83,7831 }, {  84,7831 }, {  85,7831 },
 {  86,7831 }, {  87,7831 }, {  88,7831 }, {  89,7831 }, {  90,7831 },

 {  91,7831 }, {  92,7831 }, {  93,7831 }, {  94,7831 }, {  95,7831 },
 {  96,7831 }, {  97,7831 }, {  98,7831 }, {  99,7831 }, { 100,7831 },
 { 101,7831 }, { 102,7831 }, { 103,7831 }, { 104,7831 }, { 105,7831 },
 { 106,7831 }, { 107,7831 }, { 108,7831 }, { 109,7831 }, { 110,7831 },
 { 111,7831 }, { 112,7831 }, { 113,7831 }, { 114,7831 }, { 115,7831 },
 { 116,7831 }, { 117,7831 }, { 118,7831 }, { 119,7831 }, { 120,7831 },
 { 121,7831 }, { 122,7831 }, { 123,7831 }, { 124,7831 }, { 125,7831 },
 { 126,7831 }, { 127,7831 }, { 128,7831 }, { 129,7831 }, { 130,7831 },
 { 131,7831 }, { 132,7831 }, { 133,7831 }, { 134,7831 }, { 135,7831 },
 { 136,7831 }, { 137,7831 }, { 138,7831 }, { 139,7831 }, { 140,7831 },

 { 141,7831 }, { 142,7831 }, { 143,7831 }, { 144,7831 }, { 145,7831 },
 { 146,7831 }, { 147,7831 }, { 148,7831 }, { 149,7831 }, { 150,7831 },
 { 151,7831 }, { 152,7831 }, { 153,7831 }, { 154,7831 }, { 155,7831 },
 { 156,7831 }, { 157,7831 }, { 158,7831 }, { 159,7831 }, { 160,7831 },
 { 161,7831 }, { 162,7831 }, { 163,7831 }, { 164,7831 }, { 165,7831 },
 { 166,7831 }, { 167,7831 }, { 168,7831 }, { 169,7831 }, { 170,7831 },
 { 171,7831 }, { 172,7831 }, { 173,7831 }, { 174,7831 }, { 175,7831 },
 { 176,7831 }, { 177,7831 }, { 178,7831 }, { 179,7831 }, { 180,7831 },
 { 181,7831 }, { 182,7831 }, { 183,7831 }, { 184,7831 }, { 185,7831 },
 { 186,7831 }, { 187,7831 }, { 188,7831 }, { 189,7831 }, { 190,7831 },

 { 191,7831 }, { 192,7831 }, { 193,7831 }, { 194,7831 }, { 195,7831 },
 { 196,7831 }, { 197,7831 }, { 198,7831 }, { 199,7831 }, { 200,7831 },
 { 201,7831 }, { 202,7831 }, { 203,7831 }, { 204,7831 }, { 205,7831 },
 { 206,7831 }, { 207,7831 }, { 208,7831 }, { 209,7831 }, { 210,7831 },
 { 211,7831 }, { 212,7831 }, { 213,7831 }, { 214,7831 }, { 215,7831 },
 { 216,7831 }, { 217,7831 }, { 218,7831 }, { 219,7831 }, { 220,7831 },
 { 221,7831 }, { 222,7831 }, { 223,7831 }, { 224,7831 }, { 225,7831 },
 { 226,7831 }, { 227,7831 }, { 228,7831 }, { 229,7831 }, { 230,7831 },
 { 231,7831 }, { 232,7831 }, { 233,7831 }, { 234,7831 }, { 235,7831 },
 { 236,7831 }, { 237,7831 }, { 238,7831 }, { 239,7831 }, { 240,7831 },

 { 241,7831 }, { 242,7831 }, { 243,7831 }, { 244,7831 }, { 245,7831 },
 { 246,7831 }, { 247,7831 }, { 248,7831 }, { 249,7831 }, { 250,7831 },
 { 251,7831 }, { 252,7831 }, { 253,7831 }, { 254,7831 }, { 255,7831 },
 { 256,7831 }, {   0,   9 }, {   0,22779 }, {   1,7831 }, {   2,7831 },
 {   3,7831 }, {   4,7831 }, {   5,7831 }, {   6,7831 }, {   7,7831 },
 {   8,7831 }, {   9,7831 }, {  10,7831 }, {  11,7831 }, {  12,7831 },
 {  13,7831 }, {  14,7831 }, {  15,7831 }, {  16,7831 }, {  17,7831 },
 {  18,7831 }, {  19,7831 }, {  20,7831 }, {  21,7831 }, {  22,7831 },
 {  23,7831 }, {  24,7831 }, {  25,7831 }, {  26,7831 }, {  27,7831 },
 {  28,7831 }, {  29,7831 }, {  30,7831 }, {  31,7831 }, {  32,7831 },

 {  33,7831 }, {  34,7831 }, {  35,7831 }, {  36,7831 }, {  37,7831 },
 {  38,7831 }, {  39,4157 }, {  40,7831 }, {  41,7831 }, {  42,7831 },
 {  43,7831 }, {  44,7831 }, {  45,7831 }, {  46,7831 }, {  47,7831 },
 {  48,7831 }, {  49,7831 }, {  50,7831 }, {  51,7831 }, {  52,7831 },
 {  53,7831 }, {  54,7831 }, {  55,7831 }, {  56,7831 }, {  57,7831 },
 {  58,7831 }, {  59,7831 }, {  60,7831 }, {  61,7831 }, {  62,7831 },
 {  63,7831 }, {  64,7831 }, {  65,7831 }, {  66,7831 }, {  67,7831 },
 {  68,7831 }, {  69,7831 }, {  70,7831 }, {  71,7831 }, {  72,7831 },
 {  73,7831 }, {  74,7831 }, {  75,7831 }, {  76,7831 }, {  77,7831 },
 {  78,7831 }, {  79,7831 }, {  80,7831 }, {  81,7831 }, {  82,7831 },

 {  83,7831 }, {  84,7831 }, {  85,7831 }, {  86,7831 }, {  87,7831 },
 {  88,7831 }, {  89,7831 }, {  90,7831 }, {  91,7831 }, {  92,7831 },
 {  93,7831 }, {  94,7831 }, {  95,7831 }, {  96,7831 }, {  97,7831 },
 {  98,7831 }, {  99,7831 }, { 100,7831 }, { 101,7831 }, { 102,7831 },
 { 103,7831 }, { 104,7831 }, { 105,7831 }, { 106,7831 }, { 107,7831 },
 { 108,7831 }, { 109,7831 }, { 110,7831 }, { 111,7831 }, { 112,7831 },
 { 113,7831 }, { 114,7831 }, { 115,7831 }, { 116,7831 }, { 117,7831 },
 { 118,7831 }, { 119,7831 }, { 120,7831 }, { 121,7831 }, { 122,7831 },
 { 123,7831 }, { 124,7831 }, { 125,7831 }, { 126,7831 }, { 127,7831 },
 { 128,7831 }, { 129,7831 }, { 130,7831 }, { 131,7831 }, { 132,7831 },

 { 133,7831 }, { 134,7831 }, { 135,7831 }, { 136,7831 }, { 137,7831 },
 { 138,7831 }, { 139,7831 }, { 140,7831 }, { 141,7831 }, { 142,7831 },
 { 143,7831 }, { 144,7831 }, { 145,7831 }, { 146,7831 }, { 147,7831 },
 { 148,7831 }, { 149,7831 }, { 150,7831 }, { 151,7831 }, { 152,7831 },
 { 153,7831 }, { 154,7831 }, { 155,7831 }, { 156,7831 }, { 157,7831 },
 { 158,7831 }, { 159,7831 }, { 160,7831 }, { 161,7831 }, { 162,7831 },
 { 163,7831 }, { 164,7831 }, { 165,7831 }, { 166,7831 }, { 167,7831 },
 { 168,7831 }, { 169,7831 }, { 170,7831 }, { 171,7831 }, { 172,7831 },
 { 173,7831 }, { 174,7831 }, { 175,7831 }, { 176,7831 }, { 177,7831 },
 { 178,7831 }, { 179,7831 }, { 180,7831 }, { 181,7831 }, { 182,7831 },

 { 183,7831 }, { 184,7831 }, { 185,7831 }, { 186,7831 }, { 187,7831 },
 { 188,7831 }, { 189,7831 }, { 190,7831 }, { 191,7831 }, { 192,7831 },
 { 193,7831 }, { 194,7831 }, { 195,7831 }, { 196,7831 }, { 197,7831 },
 { 198,7831 }, { 199,7831 }, { 200,7831 }, { 201,7831 }, { 202,7831 },
 { 203,7831 }, { 204,7831 }, { 205,7831 }, { 206,7831 }, { 207,7831 },
 { 208,7831 }, { 209,7831 }, { 210,7831 }, { 211,7831 }, { 212,7831 },
 { 213,7831 }, { 214,7831 }, { 215,7831 }, { 216,7831 }, { 217,7831 },
 { 218,7831 }, { 219,7831 }, { 220,7831 }, { 221,7831 }, { 222,7831 },
 { 223,7831 }, { 224,7831 }, { 225,7831 }, { 226,7831 }, { 227,7831 },
 { 228,7831 }, { 229,7831 }, { 230,7831 }, { 231,7831 }, { 232,7831 },

 { 233,7831 }, { 234,7831 }, { 235,7831 }, { 236,7831 }, { 237,7831 },
 { 238,7831 }, { 239,7831 }, { 240,7831 }, { 241,7831 }, { 242,7831 },
 { 243,7831 }, { 244,7831 }, { 245,7831 }, { 246,7831 }, { 247,7831 },
 { 248,7831 }, { 249,7831 }, { 250,7831 }, { 251,7831 }, { 252,7831 },
 { 253,7831 }, { 254,7831 }, { 255,7831 }, { 256,7831 }, {   0,   9 },
 {   0,22521 }, {   1,7573 }, {   2,7573 }, {   3,7573 }, {   4,7573 },
 {   5,7573 }, {   6,7573 }, {   7,7573 }, {   8,7573 }, {   9,7573 },
 {  10,7573 }, {  11,7573 }, {  12,7573 }, {  13,7573 }, {  14,7573 },
 {  15,7573 }, {  16,7573 }, {  17,7573 }, {  18,7573 }, {  19,7573 },
 {  20,7573 }, {  21,7573 }, {  22,7573 }, {  23,7573 }, {  24,7573 },

 {  25,7573 }, {  26,7573 }, {  27,7573 }, {  28,7573 }, {  29,7573 },
 {  30,7573 }, {  31,7573 }, {  32,7573 }, {  33,7573 }, {  34,7573 },
 {  35,7573 }, {  36,7573 }, {  37,7573 }, {  38,7573 }, {  39,3899 },
 {  40,7573 }, {  41,7573 }, {  42,7573 }, {  43,7573 }, {  44,7573 },
 {  45,7573 }, {  46,7573 }, {  47,7573 }, {  48,7573 }, {  49,7573 },
 {  50,7573 }, {  51,7573 }, {  52,7573 }, {  53,7573 }, {  54,7573 },
 {  55,7573 }, {  56,7573 }, {  57,7573 }, {  58,7573 }, {  59,7573 },
 {  60,7573 }, {  61,7573 }, {  62,7573 }, {  63,7573 }, {  64,7573 },
 {  65,7573 }, {  66,7573 }, {  67,7573 }, {  68,7573 }, {  69,7573 },
 {  70,7573 }, {  71,7573 }, {  72,7573 }, {  73,7573 }, {  74,7573 },

 {  75,7573 }, {  76,7573 }, {  77,7573 }, {  78,7573 }, {  79,7573 },
 {  80,7573 }, {  81,7573 }, {  82,7573 }, {  83,7573 }, {  84,7573 },
 {  85,7573 }, {  86,7573 }, {  87,7573 }, {  88,7573 }, {  89,7573 },
 {  90,7573 }, {  91,7573 }, {  92,7573 }, {  93,7573 }, {  94,7573 },
 {  95,7573 }, {  96,7573 }, {  97,7573 }, {  98,7573 }, {  99,7573 },
 { 100,7573 }, { 101,7573 }, { 102,7573 }, { 103,7573 }, { 104,7573 },
 { 105,7573 }, { 106,7573 }, { 107,7573 }, { 108,7573 }, { 109,7573 },
 { 110,7573 }, { 111,7573 }, { 112,7573 }, { 113,7573 }, { 114,7573 },
 { 115,7573 }, { 116,7573 }, { 117,7573 }, { 118,7573 }, { 119,7573 },
 { 120,7573 }, { 121,7573 }, { 122,7573 }, { 123,7573 }, { 124,7573 },

 { 125,7573 }, { 126,7573 }, { 127,7573 }, { 128,7573 }, { 129,7573 },
 { 130,7573 }, { 131,7573 }, { 132,7573 }, { 133,7573 }, { 134,7573 },
 { 135,7573 }, { 136,7573 }, { 137,7573 }, { 138,7573 }, { 139,7573 },
 { 140,7573 }, { 141,7573 }, { 142,7573 }, { 143,7573 }, { 144,7573 },
 { 145,7573 }, { 146,7573 }, { 147,7573 }, { 148,7573 }, { 149,7573 },
 { 150,7573 }, { 151,7573 }, { 152,7573 }, { 153,7573 }, { 154,7573 },
 { 155,7573 }, { 156,7573 }, { 157,7573 }, { 158,7573 }, { 159,7573 },
 { 160,7573 }, { 161,7573 }, { 162,7573 }, { 163,7573 }, { 164,7573 },
 { 165,7573 }, { 166,7573 }, { 167,7573 }, { 168,7573 }, { 169,7573 },
 { 170,7573 }, { 171,7573 }, { 172,7573 }, { 173,7573 }, { 174,7573 },

 { 175,7573 }, { 176,7573 }, { 177,7573 }, { 178,7573 }, { 179,7573 },
 { 180,7573 }, { 181,7573 }, { 182,7573 }, { 183,7573 }, { 184,7573 },
 { 185,7573 }, { 186,7573 }, { 187,7573 }, { 188,7573 }, { 189,7573 },
 { 190,7573 }, { 191,7573 }, { 192,7573 }, { 193,7573 }, { 194,7573 },
 { 195,7573 }, { 196,7573 }, { 197,7573 }, { 198,7573 }, { 199,7573 },
 { 200,7573 }, { 201,7573 }, { 202,7573 }, { 203,7573 }, { 204,7573 },
 { 205,7573 }, { 206,7573 }, { 207,7573 }, { 208,7573 }, { 209,7573 },
 { 210,7573 }, { 211,7573 }, { 212,7573 }, { 213,7573 }, { 214,7573 },
 { 215,7573 }, { 216,7573 }, { 217,7573 }, { 218,7573 }, { 219,7573 },
 { 220,7573 }, { 221,7573 }, { 222,7573 }, { 223,7573 }, { 224,7573 },

 { 225,7573 }, { 226,7573 }, { 227,7573 }, { 228,7573 }, { 229,7573 },
 { 230,7573 }, { 231,7573 }, { 232,7573 }, { 233,7573 }, { 234,7573 },
 { 235,7573 }, { 236,7573 }, { 237,7573 }, { 238,7573 }, { 239,7573 },
 { 240,7573 }, { 241,7573 }, { 242,7573 }, { 243,7573 }, { 244,7573 },
 { 245,7573 }, { 246,7573 }, { 247,7573 }, { 248,7573 }, { 249,7573 },
 { 250,7573 }, { 251,7573 }, { 252,7573 }, { 253,7573 }, { 254,7573 },
 { 255,7573 }, { 256,7573 }, {   0,   0 }, {   0,22263 }, {   1,7573 },
 {   2,7573 }, {   3,7573 }, {   4,7573 }, {   5,7573 }, {   6,7573 },
 {   7,7573 }, {   8,7573 }, {   9,7573 }, {  10,7573 }, {  11,7573 },
 {  12,7573 }, {  13,7573 }, {  14,7573 }, {  15,7573 }, {  16,7573 },

 {  17,7573 }, {  18,7573 }, {  19,7573 }, {  20,7573 }, {  21,7573 },
 {  22,7573 }, {  23,7573 }, {  24,7573 }, {  25,7573 }, {  26,7573 },
 {  27,7573 }, {  28,7573 }, {  29,7573 }, {  30,7573 }, {  31,7573 },
 {  32,7573 }, {  33,7573 }, {  34,7573 }, {  35,7573 }, {  36,7573 },
 {  37,7573 }, {  38,7573 }, {  39,3670 }, {  40,7573 }, {  41,7573 },
 {  42,7573 }, {  43,7573 }, {  44,7573 }, {  45,7573 }, {  46,7573 },
 {  47,7573 }, {  48,7573 }, {  49,7573 }, {  50,7573 }, {  51,7573 },
 {  52,7573 }, {  53,7573 }, {  54,7573 }, {  55,7573 }, {  56,7573 },
 {  57,7573 }, {  58,7573 }, {  59,7573 }, {  60,7573 }, {  61,7573 },
 {  62,7573 }, {  63,7573 }, {  64,7573 }, {  65,7573 }, {  66,7573 },

 {  67,7573 }, {  68,7573 }, {  69,7573 }, {  70,7573 }, {  71,7573 },
 {  72,7573 }, {  73,7573 }, {  74,7573 }, {  75,7573 }, {  76,7573 },
 {  77,7573 }, {  78,7573 }, {  79,7573 }, {  80,7573 }, {  81,7573 },
 {  82,7573 }, {  83,7573 }, {  84,7573 }, {  85,7573 }, {  86,7573 },
 {  87,7573 }, {  88,7573 }, {  89,7573 }, {  90,7573 }, {  91,7573 },
 {  92,7573 }, {  93,7573 }, {  94,7573 }, {  95,7573 }, {  96,7573 },
 {  97,7573 }, {  98,7573 }, {  99,7573 }, { 100,7573 }, { 101,7573 },
 { 102,7573 }, { 103,7573 }, { 104,7573 }, { 105,7573 }, { 106,7573 },
 { 107,7573 }, { 108,7573 }, { 109,7573 }, { 110,7573 }, { 111,7573 },
 { 112,7573 }, { 113,7573 }, { 114,7573 }, { 115,7573 }, { 116,7573 },

 { 117,7573 }, { 118,7573 }, { 119,7573 }, { 120,7573 }, { 121,7573 },
 { 122,7573 }, { 123,7573 }, { 124,7573 }, { 125,7573 }, { 126,7573 },
 { 127,7573 }, { 128,7573 }, { 129,7573 }, { 130,7573 }, { 131,7573 },
 { 132,7573 }, { 133,7573 }, { 134,7573 }, { 135,7573 }, { 136,7573 },
 { 137,7573 }, { 138,7573 }, { 139,7573 }, { 140,7573 }, { 141,7573 },
 { 142,7573 }, { 143,7573 }, { 144,7573 }, { 145,7573 }, { 146,7573 },
 { 147,7573 }, { 148,7573 }, { 149,7573 }, { 150,7573 }, { 151,7573 },
 { 152,7573 }, { 153,7573 }, { 154,7573 }, { 155,7573 }, { 156,7573 },
 { 157,7573 }, { 158,7573 }, { 159,7573 }, { 160,7573 }, { 161,7573 },
 { 162,7573 }, { 163,7573 }, { 164,7573 }, { 165,7573 }, { 166,7573 },

 { 167,7573 }, { 168,7573 }, { 169,7573 }, { 170,7573 }, { 171,7573 },
 { 172,7573 }, { 173,7573 }, { 174,7573 }, { 175,7573 }, { 176,7573 },
 { 177,7573 }, { 178,7573 }, { 179,7573 }, { 180,7573 }, { 181,7573 },
 { 182,7573 }, { 183,7573 }, { 184,7573 }, { 185,7573 }, { 186,7573 },
 { 187,7573 }, { 188,7573 }, { 189,7573 }, { 190,7573 }, { 191,7573 },
 { 192,7573 }, { 193,7573 }, { 194,7573 }, { 195,7573 }, { 196,7573 },
 { 197,7573 }, { 198,7573 }, { 199,7573 }, { 200,7573 }, { 201,7573 },
 { 202,7573 }, { 203,7573 }, { 204,7573 }, { 205,7573 }, { 206,7573 },
 { 207,7573 }, { 208,7573 }, { 209,7573 }, { 210,7573 }, { 211,7573 },
 { 212,7573 }, { 213,7573 }, { 214,7573 }, { 215,7573 }, { 216,7573 },

 { 217,7573 }, { 218,7573 }, { 219,7573 }, { 220,7573 }, { 221,7573 },
 { 222,7573 }, { 223,7573 }, { 224,7573 }, { 225,7573 }, { 226,7573 },
 { 227,7573 }, { 228,7573 }, { 229,7573 }, { 230,7573 }, { 231,7573 },
 { 232,7573 }, { 233,7573 }, { 234,7573 }, { 235,7573 }, { 236,7573 },
 { 237,7573 }, { 238,7573 }, { 239,7573 }, { 240,7573 }, { 241,7573 },
 { 242,7573 }, { 243,7573 }, { 244,7573 }, { 245,7573 }, { 246,7573 },
 { 247,7573 }, { 248,7573 }, { 249,7573 }, { 250,7573 }, { 251,7573 },
 { 252,7573 }, { 253,7573 }, { 254,7573 }, { 255,7573 }, { 256,7573 },
 {   0,   0 }, {   0,22005 }, {   1,7315 }, {   2,7315 }, {   3,7315 },
 {   4,7315 }, {   5,7315 }, {   6,7315 }, {   7,7315 }, {   8,7315 },

 {   9,7315 }, {  10,7315 }, {  11,7315 }, {  12,7315 }, {  13,7315 },
 {  14,7315 }, {  15,7315 }, {  16,7315 }, {  17,7315 }, {  18,7315 },
 {  19,7315 }, {  20,7315 }, {  21,7315 }, {  22,7315 }, {  23,7315 },
 {  24,7315 }, {  25,7315 }, {  26,7315 }, {  27,7315 }, {  28,7315 },
 {  29,7315 }, {  30,7315 }, {  31,7315 }, {  32,7315 }, {  33,7315 },
 {  34,7315 }, {  35,7315 }, {  36,7315 }, {  37,7315 }, {  38,7315 },
 {  39,3412 }, {  40,7315 }, {  41,7315 }, {  42,7315 }, {  43,7315 },
 {  44,7315 }, {  45,7315 }, {  46,7315 }, {  47,7315 }, {  48,7315 },
 {  49,7315 }, {  50,7315 }, {  51,7315 }, {  52,7315 }, {  53,7315 },
 {  54,7315 }, {  55,7315 }, {  56,7315 }, {  57,7315 }, {  58,7315 },

 {  59,7315 }, {  60,7315 }, {  61,7315 }, {  62,7315 }, {  63,7315 },
 {  64,7315 }, {  65,7315 }, {  66,7315 }, {  67,7315 }, {  68,7315 },
 {  69,7315 }, {  70,7315 }, {  71,7315 }, {  72,7315 }, {  73,7315 },
 {  74,7315 }, {  75,7315 }, {  76,7315 }, {  77,7315 }, {  78,7315 },
 {  79,7315 }, {  80,7315 }, {  81,7315 }, {  82,7315 }, {  83,7315 },
 {  84,7315 }, {  85,7315 }, {  86,7315 }, {  87,7315 }, {  88,7315 },
 {  89,7315 }, {  90,7315 }, {  91,7315 }, {  92,7315 }, {  93,7315 },
 {  94,7315 }, {  95,7315 }, {  96,7315 }, {  97,7315 }, {  98,7315 },
 {  99,7315 }, { 100,7315 }, { 101,7315 }, { 102,7315 }, { 103,7315 },
 { 104,7315 }, { 105,7315 }, { 106,7315 }, { 107,7315 }, { 108,7315 },

 { 109,7315 }, { 110,7315 }, { 111,7315 }, { 112,7315 }, { 113,7315 },
 { 114,7315 }, { 115,7315 }, { 116,7315 }, { 117,7315 }, { 118,7315 },
 { 119,7315 }, { 120,7315 }, { 121,7315 }, { 122,7315 }, { 123,7315 },
 { 124,7315 }, { 125,7315 }, { 126,7315 }, { 127,7315 }, { 128,7315 },
 { 129,7315 }, { 130,7315 }, { 131,7315 }, { 132,7315 }, { 133,7315 },
 { 134,7315 }, { 135,7315 }, { 136,7315 }, { 137,7315 }, { 138,7315 },
 { 139,7315 }, { 140,7315 }, { 141,7315 }, { 142,7315 }, { 143,7315 },
 { 144,7315 }, { 145,7315 }, { 146,7315 }, { 147,7315 }, { 148,7315 },
 { 149,7315 }, { 150,7315 }, { 151,7315 }, { 152,7315 }, { 153,7315 },
 { 154,7315 }, { 155,7315 }, { 156,7315 }, { 157,7315 }, { 158,7315 },

 { 159,7315 }, { 160,7315 }, { 161,7315 }, { 162,7315 }, { 163,7315 },
 { 164,7315 }, { 165,7315 }, { 166,7315 }, { 167,7315 }, { 168,7315 },
 { 169,7315 }, { 170,7315 }, { 171,7315 }, { 172,7315 }, { 173,7315 },
 { 174,7315 }, { 175,7315 }, { 176,7315 }, { 177,7315 }, { 178,7315 },
 { 179,7315 }, { 180,7315 }, { 181,7315 }, { 182,7315 }, { 183,7315 },
 { 184,7315 }, { 185,7315 }, { 186,7315 }, { 187,7315 }, { 188,7315 },
 { 189,7315 }, { 190,7315 }, { 191,7315 }, { 192,7315 }, { 193,7315 },
 { 194,7315 }, { 195,7315 }, { 196,7315 }, { 197,7315 }, { 198,7315 },
 { 199,7315 }, { 200,7315 }, { 201,7315 }, { 202,7315 }, { 203,7315 },
 { 204,7315 }, { 205,7315 }, { 206,7315 }, { 207,7315 }, { 208,7315 },

 { 209,7315 }, { 210,7315 }, { 211,7315 }, { 212,7315 }, { 213,7315 },
 { 214,7315 }, { 215,7315 }, { 216,7315 }, { 217,7315 }, { 218,7315 },
 { 219,7315 }, { 220,7315 }, { 221,7315 }, { 222,7315 }, { 223,7315 },
 { 224,7315 }, { 225,7315 }, { 226,7315 }, { 227,7315 }, { 228,7315 },
 { 229,7315 }, { 230,7315 }, { 231,7315 }, { 232,7315 }, { 233,7315 },
 { 234,7315 }, { 235,7315 }, { 236,7315 }, { 237,7315 }, { 238,7315 },
 { 239,7315 }, { 240,7315 }, { 241,7315 }, { 242,7315 }, { 243,7315 },
 { 244,7315 }, { 245,7315 }, { 246,7315 }, { 247,7315 }, { 248,7315 },
 { 249,7315 }, { 250,7315 }, { 251,7315 }, { 252,7315 }, { 253,7315 },
 { 254,7315 }, { 255,7315 }, { 256,7315 }, {   0,  18 }, {   0,21747 },

 {   1,3156 }, {   2,3156 }, {   3,3156 }, {   4,3156 }, {   5,3156 },
 {   6,3156 }, {   7,3156 }, {   8,3156 }, {   9,7315 }, {  10,7320 },
 {  11,7315 }, {  12,7315 }, {  13,7344 }, {  14,3156 }, {  15,3156 },
 {  16,3156 }, {  17,3156 }, {  18,3156 }, {  19,3156 }, {  20,3156 },
 {  21,3156 }, {  22,3156 }, {  23,3156 }, {  24,3156 }, {  25,3156 },
 {  26,3156 }, {  27,3156 }, {  28,3156 }, {  29,3156 }, {  30,3156 },
 {  31,3156 }, {  32,7315 }, {  33,3156 }, {  34,3156 }, {  35,3156 },
 {  36,3156 }, {  37,3156 }, {  38,3156 }, {  39,3156 }, {  40,3156 },
 {  41,3156 }, {  42,3156 }, {  43,3156 }, {  44,3156 }, {  45,3158 },
 {  46,3156 }, {  47,3156 }, {  48,3156 }, {  49,3156 }, {  50,3156 },

 {  51,3156 }, {  52,3156 }, {  53,3156 }, {  54,3156 }, {  55,3156 },
 {  56,3156 }, {  57,3156 }, {  58,3156 }, {  59,3156 }, {  60,3156 },
 {  61,3156 }, {  62,3156 }, {  63,3156 }, {  64,3156 }, {  65,3156 },
 {  66,3156 }, {  67,3156 }, {  68,3156 }, {  69,3156 }, {  70,3156 },
 {  71,3156 }, {  72,3156 }, {  73,3156 }, {  74,3156 }, {  75,3156 },
 {  76,3156 }, {  77,3156 }, {  78,3156 }, {  79,3156 }, {  80,3156 },
 {  81,3156 }, {  82,3156 }, {  83,3156 }, {  84,3156 }, {  85,3156 },
 {  86,3156 }, {  87,3156 }, {  88,3156 }, {  89,3156 }, {  90,3156 },
 {  91,3156 }, {  92,3156 }, {  93,3156 }, {  94,3156 }, {  95,3156 },
 {  96,3156 }, {  97,3156 }, {  98,3156 }, {  99,3156 }, { 100,3156 },

 { 101,3156 }, { 102,3156 }, { 103,3156 }, { 104,3156 }, { 105,3156 },
 { 106,3156 }, { 107,3156 }, { 108,3156 }, { 109,3156 }, { 110,3156 },
 { 111,3156 }, { 112,3156 }, { 113,3156 }, { 114,3156 }, { 115,3156 },
 { 116,3156 }, { 117,3156 }, { 118,3156 }, { 119,3156 }, { 120,3156 },
 { 121,3156 }, { 122,3156 }, { 123,3156 }, { 124,3156 }, { 125,3156 },
 { 126,3156 }, { 127,3156 }, { 128,3156 }, { 129,3156 }, { 130,3156 },
 { 131,3156 }, { 132,3156 }, { 133,3156 }, { 134,3156 }, { 135,3156 },
 { 136,3156 }, { 137,3156 }, { 138,3156 }, { 139,3156 }, { 140,3156 },
 { 141,3156 }, { 142,3156 }, { 143,3156 }, { 144,3156 }, { 145,3156 },
 { 146,3156 }, { 147,3156 }, { 148,3156 }, { 149,3156 }, { 150,3156 },

 { 151,3156 }, { 152,3156 }, { 153,3156 }, { 154,3156 }, { 155,3156 },
 { 156,3156 }, { 157,3156 }, { 158,3156 }, { 159,3156 }, { 160,3156 },
 { 161,3156 }, { 162,3156 }, { 163,3156 }, { 164,3156 }, { 165,3156 },
 { 166,3156 }, { 167,3156 }, { 168,3156 }, { 169,3156 }, { 170,3156 },
 { 171,3156 }, { 172,3156 }, { 173,3156 }, { 174,3156 }, { 175,3156 },
 { 176,3156 }, { 177,3156 }, { 178,3156 }, { 179,3156 }, { 180,3156 },
 { 181,3156 }, { 182,3156 }, { 183,3156 }, { 184,3156 }, { 185,3156 },
 { 186,3156 }, { 187,3156 }, { 188,3156 }, { 189,3156 }, { 190,3156 },
 { 191,3156 }, { 192,3156 }, { 193,3156 }, { 194,3156 }, { 195,3156 },
 { 196,3156 }, { 197,3156 }, { 198,3156 }, { 199,3156 }, { 200,3156 },

 { 201,3156 }, { 202,3156 }, { 203,3156 }, { 204,3156 }, { 205,3156 },
 { 206,3156 }, { 207,3156 }, { 208,3156 }, { 209,3156 }, { 210,3156 },
 { 211,3156 }, { 212,3156 }, { 213,3156 }, { 214,3156 }, { 215,3156 },
 { 216,3156 }, { 217,3156 }, { 218,3156 }, { 219,3156 }, { 220,3156 },
 { 221,3156 }, { 222,3156 }, { 223,3156 }, { 224,3156 }, { 225,3156 },
 { 226,3156 }, { 227,3156 }, { 228,3156 }, { 229,3156 }, { 230,3156 },
 { 231,3156 }, { 232,3156 }, { 233,3156 }, { 234,3156 }, { 235,3156 },
 { 236,3156 }, { 237,3156 }, { 238,3156 }, { 239,3156 }, { 240,3156 },
 { 241,3156 }, { 242,3156 }, { 243,3156 }, { 244,3156 }, { 245,3156 },
 { 246,3156 }, { 247,3156 }, { 248,3156 }, { 249,3156 }, { 250,3156 },

 { 251,3156 }, { 252,3156 }, { 253,3156 }, { 254,3156 }, { 255,3156 },
 { 256,3156 }, {   0,  18 }, {   0,21489 }, {   1,2898 }, {   2,2898 },
 {   3,2898 }, {   4,2898 }, {   5,2898 }, {   6,2898 }, {   7,2898 },
 {   8,2898 }, {   9,7057 }, {  10,7062 }, {  11,7057 }, {  12,7057 },
 {  13,7086 }, {  14,2898 }, {  15,2898 }, {  16,2898 }, {  17,2898 },
 {  18,2898 }, {  19,2898 }, {  20,2898 }, {  21,2898 }, {  22,2898 },
 {  23,2898 }, {  24,2898 }, {  25,2898 }, {  26,2898 }, {  27,2898 },
 {  28,2898 }, {  29,2898 }, {  30,2898 }, {  31,2898 }, {  32,7057 },
 {  33,2898 }, {  34,2898 }, {  35,2898 }, {  36,2898 }, {  37,2898 },
 {  38,2898 }, {  39,2898 }, {  40,2898 }, {  41,2898 }, {  42,2898 },

 {  43,2898 }, {  44,2898 }, {  45,2900 }, {  46,2898 }, {  47,2898 },
 {  48,2898 }, {  49,2898 }, {  50,2898 }, {  51,2898 }, {  52,2898 },
 {  53,2898 }, {  54,2898 }, {  55,2898 }, {  56,2898 }, {  57,2898 },
 {  58,2898 }, {  59,2898 }, {  60,2898 }, {  61,2898 }, {  62,2898 },
 {  63,2898 }, {  64,2898 }, {  65,2898 }, {  66,2898 }, {  67,2898 },
 {  68,2898 }, {  69,2898 }, {  70,2898 }, {  71,2898 }, {  72,2898 },
 {  73,2898 }, {  74,2898 }, {  75,2898 }, {  76,2898 }, {  77,2898 },
 {  78,2898 }, {  79,2898 }, {  80,2898 }, {  81,2898 }, {  82,2898 },
 {  83,2898 }, {  84,2898 }, {  85,2898 }, {  86,2898 }, {  87,2898 },
 {  88,2898 }, {  89,2898 }, {  90,2898 }, {  91,2898 }, {  92,2898 },

 {  93,2898 }, {  94,2898 }, {  95,2898 }, {  96,2898 }, {  97,2898 },
 {  98,2898 }, {  99,2898 }, { 100,2898 }, { 101,2898 }, { 102,2898 },
 { 103,2898 }, { 104,2898 }, { 105,2898 }, { 106,2898 }, { 107,2898 },
 { 108,2898 }, { 109,2898 }, { 110,2898 }, { 111,2898 }, { 112,2898 },
 { 113,2898 }, { 114,2898 }, { 115,2898 }, { 116,2898 }, { 117,2898 },
 { 118,2898 }, { 119,2898 }, { 120,2898 }, { 121,2898 }, { 122,2898 },
 { 123,2898 }, { 124,2898 }, { 125,2898 }, { 126,2898 }, { 127,2898 },
 { 128,2898 }, { 129,2898 }, { 130,2898 }, { 131,2898 }, { 132,2898 },
 { 133,2898 }, { 134,2898 }, { 135,2898 }, { 136,2898 }, { 137,2898 },
 { 138,2898 }, { 139,2898 }, { 140,2898 }, { 141,2898 }, { 142,2898 },

 { 143,2898 }, { 144,2898 }, { 145,2898 }, { 146,2898 }, { 147,2898 },
 { 148,2898 }, { 149,2898 }, { 150,2898 }, { 151,2898 }, { 152,2898 },
 { 153,2898 }, { 154,2898 }, { 155,2898 }, { 156,2898 }, { 157,2898 },
 { 158,2898 }, { 159,2898 }, { 160,2898 }, { 161,2898 }, { 162,2898 },
 { 163,2898 }, { 164,2898 }, { 165,2898 }, { 166,2898 }, { 167,2898 },
 { 168,2898 }, { 169,2898 }, { 170,2898 }, { 171,2898 }, { 172,2898 },
 { 173,2898 }, { 174,2898 }, { 175,2898 }, { 176,2898 }, { 177,2898 },
 { 178,2898 }, { 179,2898 }, { 180,2898 }, { 181,2898 }, { 182,2898 },
 { 183,2898 }, { 184,2898 }, { 185,2898 }, { 186,2898 }, { 187,2898 },
 { 188,2898 }, { 189,2898 }, { 190,2898 }, { 191,2898 }, { 192,2898 },

 { 193,2898 }, { 194,2898 }, { 195,2898 }, { 196,2898 }, { 197,2898 },
 { 198,2898 }, { 199,2898 }, { 200,2898 }, { 201,2898 }, { 202,2898 },
 { 203,2898 }, { 204,2898 }, { 205,2898 }, { 206,2898 }, { 207,2898 },
 { 208,2898 }, { 209,2898 }, { 210,2898 }, { 211,2898 }, { 212,2898 },
 { 213,2898 }, { 214,2898 }, { 215,2898 }, { 216,2898 }, { 217,2898 },
 { 218,2898 }, { 219,2898 }, { 220,2898 }, { 221,2898 }, { 222,2898 },
 { 223,2898 }, { 224,2898 }, { 225,2898 }, { 226,2898 }, { 227,2898 },
 { 228,2898 }, { 229,2898 }, { 230,2898 }, { 231,2898 }, { 232,2898 },
 { 233,2898 }, { 234,2898 }, { 235,2898 }, { 236,2898 }, { 237,2898 },
 { 238,2898 }, { 239,2898 }, { 240,2898 }, { 241,2898 }, { 242,2898 },

 { 243,2898 }, { 244,2898 }, { 245,2898 }, { 246,2898 }, { 247,2898 },
 { 248,2898 }, { 249,2898 }, { 250,2898 }, { 251,2898 }, { 252,2898 },
 { 253,2898 }, { 254,2898 }, { 255,2898 }, { 256,2898 }, {   0,   0 },
 {   0,21231 }, {   1,6875 }, {   2,6875 }, {   3,6875 }, {   4,6875 },
 {   5,6875 }, {   6,6875 }, {   7,6875 }, {   8,6875 }, {   9,6875 },
 {  10,7133 }, {  11,6875 }, {  12,6875 }, {  13,6875 }, {  14,6875 },
 {  15,6875 }, {  16,6875 }, {  17,6875 }, {  18,6875 }, {  19,6875 },
 {  20,6875 }, {  21,6875 }, {  22,6875 }, {  23,6875 }, {  24,6875 },
 {  25,6875 }, {  26,6875 }, {  27,6875 }, {  28,6875 }, {  29,6875 },
 {  30,6875 }, {  31,6875 }, {  32,6875 }, {  33,6875 }, {  34,6875 },

 {  35,6875 }, {  36,6875 }, {  37,6875 }, {  38,6875 }, {  39,2645 },
 {  40,6875 }, {  41,6875 }, {  42,6875 }, {  43,6875 }, {  44,6875 },
 {  45,6875 }, {  46,6875 }, {  47,6875 }, {  48,6875 }, {  49,6875 },
 {  50,6875 }, {  51,6875 }, {  52,6875 }, {  53,6875 }, {  54,6875 },
 {  55,6875 }, {  56,6875 }, {  57,6875 }, {  58,6875 }, {  59,6875 },
 {  60,6875 }, {  61,6875 }, {  62,6875 }, {  63,6875 }, {  64,6875 },
 {  65,6875 }, {  66,6875 }, {  67,6875 }, {  68,6875 }, {  69,6875 },
 {  70,6875 }, {  71,6875 }, {  72,6875 }, {  73,6875 }, {  74,6875 },
 {  75,6875 }, {  76,6875 }, {  77,6875 }, {  78,6875 }, {  79,6875 },
 {  80,6875 }, {  81,6875 }, {  82,6875 }, {  83,6875 }, {  84,6875 },

 {  85,6875 }, {  86,6875 }, {  87,6875 }, {  88,6875 }, {  89,6875 },
 {  90,6875 }, {  91,6875 }, {  92,7391 }, {  93,6875 }, {  94,6875 },
 {  95,6875 }, {  96,6875 }, {  97,6875 }, {  98,6875 }, {  99,6875 },
 { 100,6875 }, { 101,6875 }, { 102,6875 }, { 103,6875 }, { 104,6875 },
 { 105,6875 }, { 106,6875 }, { 107,6875 }, { 108,6875 }, { 109,6875 },
 { 110,6875 }, { 111,6875 }, { 112,6875 }, { 113,6875 }, { 114,6875 },
 { 115,6875 }, { 116,6875 }, { 117,6875 }, { 118,6875 }, { 119,6875 },
 { 120,6875 }, { 121,6875 }, { 122,6875 }, { 123,6875 }, { 124,6875 },
 { 125,6875 }, { 126,6875 }, { 127,6875 }, { 128,6875 }, { 129,6875 },
 { 130,6875 }, { 131,6875 }, { 132,6875 }, { 133,6875 }, { 134,6875 },

 { 135,6875 }, { 136,6875 }, { 137,6875 }, { 138,6875 }, { 139,6875 },
 { 140,6875 }, { 141,6875 }, { 142,6875 }, { 143,6875 }, { 144,6875 },
 { 145,6875 }, { 146,6875 }, { 147,6875 }, { 148,6875 }, { 149,6875 },
 { 150,6875 }, { 151,6875 }, { 152,6875 }, { 153,6875 }, { 154,6875 },
 { 155,6875 }, { 156,6875 }, { 157,6875 }, { 158,6875 }, { 159,6875 },
 { 160,6875 }, { 161,6875 }, { 162,6875 }, { 163,6875 }, { 164,6875 },
 { 165,6875 }, { 166,6875 }, { 167,6875 }, { 168,6875 }, { 169,6875 },
 { 170,6875 }, { 171,6875 }, { 172,6875 }, { 173,6875 }, { 174,6875 },
 { 175,6875 }, { 176,6875 }, { 177,6875 }, { 178,6875 }, { 179,6875 },
 { 180,6875 }, { 181,6875 }, { 182,6875 }, { 183,6875 }, { 184,6875 },

 { 185,6875 }, { 186,6875 }, { 187,6875 }, { 188,6875 }, { 189,6875 },
 { 190,6875 }, { 191,6875 }, { 192,6875 }, { 193,6875 }, { 194,6875 },
 { 195,6875 }, { 196,6875 }, { 197,6875 }, { 198,6875 }, { 199,6875 },
 { 200,6875 }, { 201,6875 }, { 202,6875 }, { 203,6875 }, { 204,6875 },
 { 205,6875 }, { 206,6875 }, { 207,6875 }, { 208,6875 }, { 209,6875 },
 { 210,6875 }, { 211,6875 }, { 212,6875 }, { 213,6875 }, { 214,6875 },
 { 215,6875 }, { 216,6875 }, { 217,6875 }, { 218,6875 }, { 219,6875 },
 { 220,6875 }, { 221,6875 }, { 222,6875 }, { 223,6875 }, { 224,6875 },
 { 225,6875 }, { 226,6875 }, { 227,6875 }, { 228,6875 }, { 229,6875 },
 { 230,6875 }, { 231,6875 }, { 232,6875 }, { 233,6875 }, { 234,6875 },

 { 235,6875 }, { 236,6875 }, { 237,6875 }, { 238,6875 }, { 239,6875 },
 { 240,6875 }, { 241,6875 }, { 242,6875 }, { 243,6875 }, { 244,6875 },
 { 245,6875 }, { 246,6875 }, { 247,6875 }, { 248,6875 }, { 249,6875 },
 { 250,6875 }, { 251,6875 }, { 252,6875 }, { 253,6875 }, { 254,6875 },
 { 255,6875 }, { 256,6875 }, {   0,   0 }, {   0,20973 }, {   1,6617 },
 {   2,6617 }, {   3,6617 }, {   4,6617 }, {   5,6617 }, {   6,6617 },
 {   7,6617 }, {   8,6617 }, {   9,6617 }, {  10,6875 }, {  11,6617 },
 {  12,6617 }, {  13,6617 }, {  14,6617 }, {  15,6617 }, {  16,6617 },
 {  17,6617 }, {  18,6617 }, {  19,6617 }, {  20,6617 }, {  21,6617 },
 {  22,6617 }, {  23,6617 }, {  24,6617 }, {  25,6617 }, {  26,6617 },

 {  27,6617 }, {  28,6617 }, {  29,6617 }, {  30,6617 }, {  31,6617 },
 {  32,6617 }, {  33,6617 }, {  34,6617 }, {  35,6617 }, {  36,6617 },
 {  37,6617 }, {  38,6617 }, {  39,2387 }, {  40,6617 }, {  41,6617 },
 {  42,6617 }, {  43,6617 }, {  44,6617 }, {  45,6617 }, {  46,6617 },
 {  47,6617 }, {  48,6617 }, {  49,6617 }, {  50,6617 }, {  51,6617 },
 {  52,6617 }, {  53,6617 }, {  54,6617 }, {  55,6617 }, {  56,6617 },
 {  57,6617 }, {  58,6617 }, {  59,6617 }, {  60,6617 }, {  61,6617 },
 {  62,6617 }, {  63,6617 }, {  64,6617 }, {  65,6617 }, {  66,6617 },
 {  67,6617 }, {  68,6617 }, {  69,6617 }, {  70,6617 }, {  71,6617 },
 {  72,6617 }, {  73,6617 }, {  74,6617 }, {  75,6617 }, {  76,6617 },

 {  77,6617 }, {  78,6617 }, {  79,6617 }, {  80,6617 }, {  81,6617 },
 {  82,6617 }, {  83,6617 }, {  84,6617 }, {  85,6617 }, {  86,6617 },
 {  87,6617 }, {  88,6617 }, {  89,6617 }, {  90,6617 }, {  91,6617 },
 {  92,7133 }, {  93,6617 }, {  94,6617 }, {  95,6617 }, {  96,6617 },
 {  97,6617 }, {  98,6617 }, {  99,6617 }, { 100,6617 }, { 101,6617 },
 { 102,6617 }, { 103,6617 }, { 104,6617 }, { 105,6617 }, { 106,6617 },
 { 107,6617 }, { 108,6617 }, { 109,6617 }, { 110,6617 }, { 111,6617 },
 { 112,6617 }, { 113,6617 }, { 114,6617 }, { 115,6617 }, { 116,6617 },
 { 117,6617 }, { 118,6617 }, { 119,6617 }, { 120,6617 }, { 121,6617 },
 { 122,6617 }, { 123,6617 }, { 124,6617 }, { 125,6617 }, { 126,6617 },

 { 127,6617 }, { 128,6617 }, { 129,6617 }, { 130,6617 }, { 131,6617 },
 { 132,6617 }, { 133,6617 }, { 134,6617 }, { 135,6617 }, { 136,6617 },
 { 137,6617 }, { 138,6617 }, { 139,6617 }, { 140,6617 }, { 141,6617 },
 { 142,6617 }, { 143,6617 }, { 144,6617 }, { 145,6617 }, { 146,6617 },
 { 147,6617 }, { 148,6617 }, { 149,6617 }, { 150,6617 }, { 151,6617 },
 { 152,6617 }, { 153,6617 }, { 154,6617 }, { 155,6617 }, { 156,6617 },
 { 157,6617 }, { 158,6617 }, { 159,6617 }, { 160,6617 }, { 161,6617 },
 { 162,6617 }, { 163,6617 }, { 164,6617 }, { 165,6617 }, { 166,6617 },
 { 167,6617 }, { 168,6617 }, { 169,6617 }, { 170,6617 }, { 171,6617 },
 { 172,6617 }, { 173,6617 }, { 174,6617 }, { 175,6617 }, { 176,6617 },

 { 177,6617 }, { 178,6617 }, { 179,6617 }, { 180,6617 }, { 181,6617 },
 { 182,6617 }, { 183,6617 }, { 184,6617 }, { 185,6617 }, { 186,6617 },
 { 187,6617 }, { 188,6617 }, { 189,6617 }, { 190,6617 }, { 191,6617 },
 { 192,6617 }, { 193,6617 }, { 194,6617 }, { 195,6617 }, { 196,6617 },
 { 197,6617 }, { 198,6617 }, { 199,6617 }, { 200,6617 }, { 201,6617 },
 { 202,6617 }, { 203,6617 }, { 204,6617 }, { 205,6617 }, { 206,6617 },
 { 207,6617 }, { 208,6617 }, { 209,6617 }, { 210,6617 }, { 211,6617 },
 { 212,6617 }, { 213,6617 }, { 214,6617 }, { 215,6617 }, { 216,6617 },
 { 217,6617 }, { 218,6617 }, { 219,6617 }, { 220,6617 }, { 221,6617 },
 { 222,6617 }, { 223,6617 }, { 224,6617 }, { 225,6617 }, { 226,6617 },

 { 227,6617 }, { 228,6617 }, { 229,6617 }, { 230,6617 }, { 231,6617 },
 { 232,6617 }, { 233,6617 }, { 234,6617 }, { 235,6617 }, { 236,6617 },
 { 237,6617 }, { 238,6617 }, { 239,6617 }, { 240,6617 }, { 241,6617 },
 { 242,6617 }, { 243,6617 }, { 244,6617 }, { 245,6617 }, { 246,6617 },
 { 247,6617 }, { 248,6617 }, { 249,6617 }, { 250,6617 }, { 251,6617 },
 { 252,6617 }, { 253,6617 }, { 254,6617 }, { 255,6617 }, { 256,6617 },
 {   0,   0 }, {   0,20715 }, {   1,7133 }, {   2,7133 }, {   3,7133 },
 {   4,7133 }, {   5,7133 }, {   6,7133 }, {   7,7133 }, {   8,7133 },
 {   9,7133 }, {  10,7391 }, {  11,7133 }, {  12,7133 }, {  13,7133 },
 {  14,7133 }, {  15,7133 }, {  16,7133 }, {  17,7133 }, {  18,7133 },

 {  19,7133 }, {  20,7133 }, {  21,7133 }, {  22,7133 }, {  23,7133 },
 {  24,7133 }, {  25,7133 }, {  26,7133 }, {  27,7133 }, {  28,7133 },
 {  29,7133 }, {  30,7133 }, {  31,7133 }, {  32,7133 }, {  33,7133 },
 {  34,7133 }, {  35,7133 }, {  36,7649 }, {  37,7133 }, {  38,7133 },
 {  39,7133 }, {  40,7133 }, {  41,7133 }, {  42,7133 }, {  43,7133 },
 {  44,7133 }, {  45,7133 }, {  46,7133 }, {  47,7133 }, {  48,7133 },
 {  49,7133 }, {  50,7133 }, {  51,7133 }, {  52,7133 }, {  53,7133 },
 {  54,7133 }, {  55,7133 }, {  56,7133 }, {  57,7133 }, {  58,7133 },
 {  59,7133 }, {  60,7133 }, {  61,7133 }, {  62,7133 }, {  63,7133 },
 {  64,7133 }, {  65,7133 }, {  66,7133 }, {  67,7133 }, {  68,7133 },

 {  69,7133 }, {  70,7133 }, {  71,7133 }, {  72,7133 }, {  73,7133 },
 {  74,7133 }, {  75,7133 }, {  76,7133 }, {  77,7133 }, {  78,7133 },
 {  79,7133 }, {  80,7133 }, {  81,7133 }, {  82,7133 }, {  83,7133 },
 {  84,7133 }, {  85,7133 }, {  86,7133 }, {  87,7133 }, {  88,7133 },
 {  89,7133 }, {  90,7133 }, {  91,7133 }, {  92,7133 }, {  93,7133 },
 {  94,7133 }, {  95,7133 }, {  96,7133 }, {  97,7133 }, {  98,7133 },
 {  99,7133 }, { 100,7133 }, { 101,7133 }, { 102,7133 }, { 103,7133 },
 { 104,7133 }, { 105,7133 }, { 106,7133 }, { 107,7133 }, { 108,7133 },
 { 109,7133 }, { 110,7133 }, { 111,7133 }, { 112,7133 }, { 113,7133 },
 { 114,7133 }, { 115,7133 }, { 116,7133 }, { 117,7133 }, { 118,7133 },

 { 119,7133 }, { 120,7133 }, { 121,7133 }, { 122,7133 }, { 123,7133 },
 { 124,7133 }, { 125,7133 }, { 126,7133 }, { 127,7133 }, { 128,7133 },
 { 129,7133 }, { 130,7133 }, { 131,7133 }, { 132,7133 }, { 133,7133 },
 { 134,7133 }, { 135,7133 }, { 136,7133 }, { 137,7133 }, { 138,7133 },
 { 139,7133 }, { 140,7133 }, { 141,7133 }, { 142,7133 }, { 143,7133 },
 { 144,7133 }, { 145,7133 }, { 146,7133 }, { 147,7133 }, { 148,7133 },
 { 149,7133 }, { 150,7133 }, { 151,7133 }, { 152,7133 }, { 153,7133 },
 { 154,7133 }, { 155,7133 }, { 156,7133 }, { 157,7133 }, { 158,7133 },
 { 159,7133 }, { 160,7133 }, { 161,7133 }, { 162,7133 }, { 163,7133 },
 { 164,7133 }, { 165,7133 }, { 166,7133 }, { 167,7133 }, { 168,7133 },

 { 169,7133 }, { 170,7133 }, { 171,7133 }, { 172,7133 }, { 173,7133 },
 { 174,7133 }, { 175,7133 }, { 176,7133 }, { 177,7133 }, { 178,7133 },
 { 179,7133 }, { 180,7133 }, { 181,7133 }, { 182,7133 }, { 183,7133 },
 { 184,7133 }, { 185,7133 }, { 186,7133 }, { 187,7133 }, { 188,7133 },
 { 189,7133 }, { 190,7133 }, { 191,7133 }, { 192,7133 }, { 193,7133 },
 { 194,7133 }, { 195,7133 }, { 196,7133 }, { 197,7133 }, { 198,7133 },
 { 199,7133 }, { 200,7133 }, { 201,7133 }, { 202,7133 }, { 203,7133 },
 { 204,7133 }, { 205,7133 }, { 206,7133 }, { 207,7133 }, { 208,7133 },
 { 209,7133 }, { 210,7133 }, { 211,7133 }, { 212,7133 }, { 213,7133 },
 { 214,7133 }, { 215,7133 }, { 216,7133 }, { 217,7133 }, { 218,7133 },

 { 219,7133 }, { 220,7133 }, { 221,7133 }, { 222,7133 }, { 223,7133 },
 { 224,7133 }, { 225,7133 }, { 226,7133 }, { 227,7133 }, { 228,7133 },
 { 229,7133 }, { 230,7133 }, { 231,7133 }, { 232,7133 }, { 233,7133 },
 { 234,7133 }, { 235,7133 }, { 236,7133 }, { 237,7133 }, { 238,7133 },
 { 239,7133 }, { 240,7133 }, { 241,7133 }, { 242,7133 }, { 243,7133 },
 { 244,7133 }, { 245,7133 }, { 246,7133 }, { 247,7133 }, { 248,7133 },
 { 249,7133 }, { 250,7133 }, { 251,7133 }, { 252,7133 }, { 253,7133 },
 { 254,7133 }, { 255,7133 }, { 256,7133 }, {   0,   0 }, {   0,20457 },
 {   1,6875 }, {   2,6875 }, {   3,6875 }, {   4,6875 }, {   5,6875 },
 {   6,6875 }, {   7,6875 }, {   8,6875 }, {   9,6875 }, {  10,7133 },

 {  11,6875 }, {  12,6875 }, {  13,6875 }, {  14,6875 }, {  15,6875 },
 {  16,6875 }, {  17,6875 }, {  18,6875 }, {  19,6875 }, {  20,6875 },
 {  21,6875 }, {  22,6875 }, {  23,6875 }, {  24,6875 }, {  25,6875 },
 {  26,6875 }, {  27,6875 }, {  28,6875 }, {  29,6875 }, {  30,6875 },
 {  31,6875 }, {  32,6875 }, {  33,6875 }, {  34,6875 }, {  35,6875 },
 {  36,7391 }, {  37,6875 }, {  38,6875 }, {  39,6875 }, {  40,6875 },
 {  41,6875 }, {  42,6875 }, {  43,6875 }, {  44,6875 }, {  45,6875 },
 {  46,6875 }, {  47,6875 }, {  48,6875 }, {  49,6875 }, {  50,6875 },
 {  51,6875 }, {  52,6875 }, {  53,6875 }, {  54,6875 }, {  55,6875 },
 {  56,6875 }, {  57,6875 }, {  58,6875 }, {  59,6875 }, {  60,6875 },

 {  61,6875 }, {  62,6875 }, {  63,6875 }, {  64,6875 }, {  65,6875 },
 {  66,6875 }, {  67,6875 }, {  68,6875 }, {  69,6875 }, {  70,6875 },
 {  71,6875 }, {  72,6875 }, {  73,6875 }, {  74,6875 }, {  75,6875 },
 {  76,6875 }, {  77,6875 }, {  78,6875 }, {  79,6875 }, {  80,6875 },
 {  81,6875 }, {  82,6875 }, {  83,6875 }, {  84,6875 }, {  85,6875 },
 {  86,6875 }, {  87,6875 }, {  88,6875 }, {  89,6875 }, {  90,6875 },
 {  91,6875 }, {  92,6875 }, {  93,6875 }, {  94,6875 }, {  95,6875 },
 {  96,6875 }, {  97,6875 }, {  98,6875 }, {  99,6875 }, { 100,6875 },
 { 101,6875 }, { 102,6875 }, { 103,6875 }, { 104,6875 }, { 105,6875 },
 { 106,6875 }, { 107,6875 }, { 108,6875 }, { 109,6875 }, { 110,6875 },

 { 111,6875 }, { 112,6875 }, { 113,6875 }, { 114,6875 }, { 115,6875 },
 { 116,6875 }, { 117,6875 }, { 118,6875 }, { 119,6875 }, { 120,6875 },
 { 121,6875 }, { 122,6875 }, { 123,6875 }, { 124,6875 }, { 125,6875 },
 { 126,6875 }, { 127,6875 }, { 128,6875 }, { 129,6875 }, { 130,6875 },
 { 131,6875 }, { 132,6875 }, { 133,6875 }, { 134,6875 }, { 135,6875 },
 { 136,6875 }, { 137,6875 }, { 138,6875 }, { 139,6875 }, { 140,6875 },
 { 141,6875 }, { 142,6875 }, { 143,6875 }, { 144,6875 }, { 145,6875 },
 { 146,6875 }, { 147,6875 }, { 148,6875 }, { 149,6875 }, { 150,6875 },
 { 151,6875 }, { 152,6875 }, { 153,6875 }, { 154,6875 }, { 155,6875 },
 { 156,6875 }, { 157,6875 }, { 158,6875 }, { 159,6875 }, { 160,6875 },

 { 161,6875 }, { 162,6875 }, { 163,6875 }, { 164,6875 }, { 165,6875 },
 { 166,6875 }, { 167,6875 }, { 168,6875 }, { 169,6875 }, { 170,6875 },
 { 171,6875 }, { 172,6875 }, { 173,6875 }, { 174,6875 }, { 175,6875 },
 { 176,6875 }, { 177,6875 }, { 178,6875 }, { 179,6875 }, { 180,6875 },
 { 181,6875 }, { 182,6875 }, { 183,6875 }, { 184,6875 }, { 185,6875 },
 { 186,6875 }, { 187,6875 }, { 188,6875 }, { 189,6875 }, { 190,6875 },
 { 191,6875 }, { 192,6875 }, { 193,6875 }, { 194,6875 }, { 195,6875 },
 { 196,6875 }, { 197,6875 }, { 198,6875 }, { 199,6875 }, { 200,6875 },
 { 201,6875 }, { 202,6875 }, { 203,6875 }, { 204,6875 }, { 205,6875 },
 { 206,6875 }, { 207,6875 }, { 208,6875 }, { 209,6875 }, { 210,6875 },

 { 211,6875 }, { 212,6875 }, { 213,6875 }, { 214,6875 }, { 215,6875 },
 { 216,6875 }, { 217,6875 }, { 218,6875 }, { 219,6875 }, { 220,6875 },
 { 221,6875 }, { 222,6875 }, { 223,6875 }, { 224,6875 }, { 225,6875 },
 { 226,6875 }, { 227,6875 }, { 228,6875 }, { 229,6875 }, { 230,6875 },
 { 231,6875 }, { 232,6875 }, { 233,6875 }, { 234,6875 }, { 235,6875 },
 { 236,6875 }, { 237,6875 }, { 238,6875 }, { 239,6875 }, { 240,6875 },
 { 241,6875 }, { 242,6875 }, { 243,6875 }, { 244,6875 }, { 245,6875 },
 { 246,6875 }, { 247,6875 }, { 248,6875 }, { 249,6875 }, { 250,6875 },
 { 251,6875 }, { 252,6875 }, { 253,6875 }, { 254,6875 }, { 255,6875 },
 { 256,6875 }, {   0,   0 }, {   0,20199 }, {   1,4993 }, {   2,4993 },

 {   3,4993 }, {   4,4993 }, {   5,4993 }, {   6,4993 }, {   7,4993 },
 {   8,4993 }, {   9,4993 }, {  10,4993 }, {  11,4993 }, {  12,4993 },
 {  13,4993 }, {  14,4993 }, {  15,4993 }, {  16,4993 }, {  17,4993 },
 {  18,4993 }, {  19,4993 }, {  20,4993 }, {  21,4993 }, {  22,4993 },
 {  23,4993 }, {  24,4993 }, {  25,4993 }, {  26,4993 }, {  27,4993 },
 {  28,4993 }, {  29,4993 }, {  30,4993 }, {  31,4993 }, {  32,4993 },
 {  33,4993 }, {  34,1615 }, {  35,4993 }, {  36,4993 }, {  37,4993 },
 {  38,4993 }, {  39,4993 }, {  40,4993 }, {  41,4993 }, {  42,4993 },
 {  43,4993 }, {  44,4993 }, {  45,4993 }, {  46,4993 }, {  47,4993 },
 {  48,4993 }, {  49,4993 }, {  50,4993 }, {  51,4993 }, {  52,4993 },

 {  53,4993 }, {  54,4993 }, {  55,4993 }, {  56,4993 }, {  57,4993 },
 {  58,4993 }, {  59,4993 }, {  60,4993 }, {  61,4993 }, {  62,4993 },
 {  63,4993 }, {  64,4993 }, {  65,4993 }, {  66,4993 }, {  67,4993 },
 {  68,4993 }, {  69,4993 }, {  70,4993 }, {  71,4993 }, {  72,4993 },
 {  73,4993 }, {  74,4993 }, {  75,4993 }, {  76,4993 }, {  77,4993 },
 {  78,4993 }, {  79,4993 }, {  80,4993 }, {  81,4993 }, {  82,4993 },
 {  83,4993 }, {  84,4993 }, {  85,4993 }, {  86,4993 }, {  87,4993 },
 {  88,4993 }, {  89,4993 }, {  90,4993 }, {  91,4993 }, {  92,4993 },
 {  93,4993 }, {  94,4993 }, {  95,4993 }, {  96,4993 }, {  97,4993 },
 {  98,4993 }, {  99,4993 }, { 100,4993 }, { 101,4993 }, { 102,4993 },

 { 103,4993 }, { 104,4993 }, { 105,4993 }, { 106,4993 }, { 107,4993 },
 { 108,4993 }, { 109,4993 }, { 110,4993 }, { 111,4993 }, { 112,4993 },
 { 113,4993 }, { 114,4993 }, { 115,4993 }, { 116,4993 }, { 117,4993 },
 { 118,4993 }, { 119,4993 }, { 120,4993 }, { 121,4993 }, { 122,4993 },
 { 123,4993 }, { 124,4993 }, { 125,4993 }, { 126,4993 }, { 127,4993 },
 { 128,4993 }, { 129,4993 }, { 130,4993 }, { 131,4993 }, { 132,4993 },
 { 133,4993 }, { 134,4993 }, { 135,4993 }, { 136,4993 }, { 137,4993 },
 { 138,4993 }, { 139,4993 }, { 140,4993 }, { 141,4993 }, { 142,4993 },
 { 143,4993 }, { 144,4993 }, { 145,4993 }, { 146,4993 }, { 147,4993 },
 { 148,4993 }, { 149,4993 }, { 150,4993 }, { 151,4993 }, { 152,4993 },

 { 153,4993 }, { 154,4993 }, { 155,4993 }, { 156,4993 }, { 157,4993 },
 { 158,4993 }, { 159,4993 }, { 160,4993 }, { 161,4993 }, { 162,4993 },
 { 163,4993 }, { 164,4993 }, { 165,4993 }, { 166,4993 }, { 167,4993 },
 { 168,4993 }, { 169,4993 }, { 170,4993 }, { 171,4993 }, { 172,4993 },
 { 173,4993 }, { 174,4993 }, { 175,4993 }, { 176,4993 }, { 177,4993 },
 { 178,4993 }, { 179,4993 }, { 180,4993 }, { 181,4993 }, { 182,4993 },
 { 183,4993 }, { 184,4993 }, { 185,4993 }, { 186,4993 }, { 187,4993 },
 { 188,4993 }, { 189,4993 }, { 190,4993 }, { 191,4993 }, { 192,4993 },
 { 193,4993 }, { 194,4993 }, { 195,4993 }, { 196,4993 }, { 197,4993 },
 { 198,4993 }, { 199,4993 }, { 200,4993 }, { 201,4993 }, { 202,4993 },

 { 203,4993 }, { 204,4993 }, { 205,4993 }, { 206,4993 }, { 207,4993 },
 { 208,4993 }, { 209,4993 }, { 210,4993 }, { 211,4993 }, { 212,4993 },
 { 213,4993 }, { 214,4993 }, { 215,4993 }, { 216,4993 }, { 217,4993 },
 { 218,4993 }, { 219,4993 }, { 220,4993 }, { 221,4993 }, { 222,4993 },
 { 223,4993 }, { 224,4993 }, { 225,4993 }, { 226,4993 }, { 227,4993 },
 { 228,4993 }, { 229,4993 }, { 230,4993 }, { 231,4993 }, { 232,4993 },
 { 233,4993 }, { 234,4993 }, { 235,4993 }, { 236,4993 }, { 237,4993 },
 { 238,4993 }, { 239,4993 }, { 240,4993 }, { 241,4993 }, { 242,4993 },
 { 243,4993 }, { 244,4993 }, { 245,4993 }, { 246,4993 }, { 247,4993 },
 { 248,4993 }, { 249,4993 }, { 250,4993 }, { 251,4993 }, { 252,4993 },

 { 253,4993 }, { 254,4993 }, { 255,4993 }, { 256,4993 }, {   0,   0 },
 {   0,19941 }, {   1,4735 }, {   2,4735 }, {   3,4735 }, {   4,4735 },
 {   5,4735 }, {   6,4735 }, {   7,4735 }, {   8,4735 }, {   9,4735 },
 {  10,4735 }, {  11,4735 }, {  12,4735 }, {  13,4735 }, {  14,4735 },
 {  15,4735 }, {  16,4735 }, {  17,4735 }, {  18,4735 }, {  19,4735 },
 {  20,4735 }, {  21,4735 }, {  22,4735 }, {  23,4735 }, {  24,4735 },
 {  25,4735 }, {  26,4735 }, {  27,4735 }, {  28,4735 }, {  29,4735 },
 {  30,4735 }, {  31,4735 }, {  32,4735 }, {  33,4735 }, {  34,1357 },
 {  35,4735 }, {  36,4735 }, {  37,4735 }, {  38,4735 }, {  39,4735 },
 {  40,4735 }, {  41,4735 }, {  42,4735 }, {  43,4735 }, {  44,4735 },

 {  45,4735 }, {  46,4735 }, {  47,4735 }, {  48,4735 }, {  49,4735 },
 {  50,4735 }, {  51,4735 }, {  52,4735 }, {  53,4735 }, {  54,4735 },
 {  55,4735 }, {  56,4735 }, {  57,4735 }, {  58,4735 }, {  59,4735 },
 {  60,4735 }, {  61,4735 }, {  62,4735 }, {  63,4735 }, {  64,4735 },
 {  65,4735 }, {  66,4735 }, {  67,4735 }, {  68,4735 }, {  69,4735 },
 {  70,4735 }, {  71,4735 }, {  72,4735 }, {  73,4735 }, {  74,4735 },
 {  75,4735 }, {  76,4735 }, {  77,4735 }, {  78,4735 }, {  79,4735 },
 {  80,4735 }, {  81,4735 }, {  82,4735 }, {  83,4735 }, {  84,4735 },
 {  85,4735 }, {  86,4735 }, {  87,4735 }, {  88,4735 }, {  89,4735 },
 {  90,4735 }, {  91,4735 }, {  92,4735 }, {  93,4735 }, {  94,4735 },

 {  95,4735 }, {  96,4735 }, {  97,4735 }, {  98,4735 }, {  99,4735 },
 { 100,4735 }, { 101,4735 }, { 102,4735 }, { 103,4735 }, { 104,4735 },
 { 105,4735 }, { 106,4735 }, { 107,4735 }, { 108,4735 }, { 109,4735 },
 { 110,4735 }, { 111,4735 }, { 112,4735 }, { 113,4735 }, { 114,4735 },
 { 115,4735 }, { 116,4735 }, { 117,4735 }, { 118,4735 }, { 119,4735 },
 { 120,4735 }, { 121,4735 }, { 122,4735 }, { 123,4735 }, { 124,4735 },
 { 125,4735 }, { 126,4735 }, { 127,4735 }, { 128,4735 }, { 129,4735 },
 { 130,4735 }, { 131,4735 }, { 132,4735 }, { 133,4735 }, { 134,4735 },
 { 135,4735 }, { 136,4735 }, { 137,4735 }, { 138,4735 }, { 139,4735 },
 { 140,4735 }, { 141,4735 }, { 142,4735 }, { 143,4735 }, { 144,4735 },

 { 145,4735 }, { 146,4735 }, { 147,4735 }, { 148,4735 }, { 149,4735 },
 { 150,4735 }, { 151,4735 }, { 152,4735 }, { 153,4735 }, { 154,4735 },
 { 155,4735 }, { 156,4735 }, { 157,4735 }, { 158,4735 }, { 159,4735 },
 { 160,4735 }, { 161,4735 }, { 162,4735 }, { 163,4735 }, { 164,4735 },
 { 165,4735 }, { 166,4735 }, { 167,4735 }, { 168,4735 }, { 169,4735 },
 { 170,4735 }, { 171,4735 }, { 172,4735 }, { 173,4735 }, { 174,4735 },
 { 175,4735 }, { 176,4735 }, { 177,4735 }, { 178,4735 }, { 179,4735 },
 { 180,4735 }, { 181,4735 }, { 182,4735 }, { 183,4735 }, { 184,4735 },
 { 185,4735 }, { 186,4735 }, { 187,4735 }, { 188,4735 }, { 189,4735 },
 { 190,4735 }, { 191,4735 }, { 192,4735 }, { 193,4735 }, { 194,4735 },

 { 195,4735 }, { 196,4735 }, { 197,4735 }, { 198,4735 }, { 199,4735 },
 { 200,4735 }, { 201,4735 }, { 202,4735 }, { 203,4735 }, { 204,4735 },
 { 205,4735 }, { 206,4735 }, { 207,4735 }, { 208,4735 }, { 209,4735 },
 { 210,4735 }, { 211,4735 }, { 212,4735 }, { 213,4735 }, { 214,4735 },
 { 215,4735 }, { 216,4735 }, { 217,4735 }, { 218,4735 }, { 219,4735 },
 { 220,4735 }, { 221,4735 }, { 222,4735 }, { 223,4735 }, { 224,4735 },
 { 225,4735 }, { 226,4735 }, { 227,4735 }, { 228,4735 }, { 229,4735 },
 { 230,4735 }, { 231,4735 }, { 232,4735 }, { 233,4735 }, { 234,4735 },
 { 235,4735 }, { 236,4735 }, { 237,4735 }, { 238,4735 }, { 239,4735 },
 { 240,4735 }, { 241,4735 }, { 242,4735 }, { 243,4735 }, { 244,4735 },

 { 245,4735 }, { 246,4735 }, { 247,4735 }, { 248,4735 }, { 249,4735 },
 { 250,4735 }, { 251,4735 }, { 252,4735 }, { 253,4735 }, { 254,4735 },
 { 255,4735 }, { 256,4735 }, {   0,   0 }, {   0,19683 }, {   1,4993 },
 {   2,4993 }, {   3,4993 }, {   4,4993 }, {   5,4993 }, {   6,4993 },
 {   7,4993 }, {   8,4993 }, {   9,4993 }, {  10,4993 }, {  11,4993 },
 {  12,4993 }, {  13,4993 }, {  14,4993 }, {  15,4993 }, {  16,4993 },
 {  17,4993 }, {  18,4993 }, {  19,4993 }, {  20,4993 }, {  21,4993 },
 {  22,4993 }, {  23,4993 }, {  24,4993 }, {  25,4993 }, {  26,4993 },
 {  27,4993 }, {  28,4993 }, {  29,4993 }, {  30,4993 }, {  31,4993 },
 {  32,4993 }, {  33,4993 }, {  34,4993 }, {  35,4993 }, {  36,4993 },

 {  37,4993 }, {  38,4993 }, {  39,1090 }, {  40,4993 }, {  41,4993 },
 {  42,4993 }, {  43,4993 }, {  44,4993 }, {  45,4993 }, {  46,4993 },
 {  47,4993 }, {  48,4993 }, {  49,4993 }, {  50,4993 }, {  51,4993 },
 {  52,4993 }, {  53,4993 }, {  54,4993 }, {  55,4993 }, {  56,4993 },
 {  57,4993 }, {  58,4993 }, {  59,4993 }, {  60,4993 }, {  61,4993 },
 {  62,4993 }, {  63,4993 }, {  64,4993 }, {  65,4993 }, {  66,4993 },
 {  67,4993 }, {  68,4993 }, {  69,4993 }, {  70,4993 }, {  71,4993 },
 {  72,4993 }, {  73,4993 }, {  74,4993 }, {  75,4993 }, {  76,4993 },
 {  77,4993 }, {  78,4993 }, {  79,4993 }, {  80,4993 }, {  81,4993 },
 {  82,4993 }, {  83,4993 }, {  84,4993 }, {  85,4993 }, {  86,4993 },

 {  87,4993 }, {  88,4993 }, {  89,4993 }, {  90,4993 }, {  91,4993 },
 {  92,4993 }, {  93,4993 }, {  94,4993 }, {  95,4993 }, {  96,4993 },
 {  97,4993 }, {  98,4993 }, {  99,4993 }, { 100,4993 }, { 101,4993 },
 { 102,4993 }, { 103,4993 }, { 104,4993 }, { 105,4993 }, { 106,4993 },
 { 107,4993 }, { 108,4993 }, { 109,4993 }, { 110,4993 }, { 111,4993 },
 { 112,4993 }, { 113,4993 }, { 114,4993 }, { 115,4993 }, { 116,4993 },
 { 117,4993 }, { 118,4993 }, { 119,4993 }, { 120,4993 }, { 121,4993 },
 { 122,4993 }, { 123,4993 }, { 124,4993 }, { 125,4993 }, { 126,4993 },
 { 127,4993 }, { 128,4993 }, { 129,4993 }, { 130,4993 }, { 131,4993 },
 { 132,4993 }, { 133,4993 }, { 134,4993 }, { 135,4993 }, { 136,4993 },

 { 137,4993 }, { 138,4993 }, { 139,4993 }, { 140,4993 }, { 141,4993 },
 { 142,4993 }, { 143,4993 }, { 144,4993 }, { 145,4993 }, { 146,4993 },
 { 147,4993 }, { 148,4993 }, { 149,4993 }, { 150,4993 }, { 151,4993 },
 { 152,4993 }, { 153,4993 }, { 154,4993 }, { 155,4993 }, { 156,4993 },
 { 157,4993 }, { 158,4993 }, { 159,4993 }, { 160,4993 }, { 161,4993 },
 { 162,4993 }, { 163,4993 }, { 164,4993 }, { 165,4993 }, { 166,4993 },
 { 167,4993 }, { 168,4993 }, { 169,4993 }, { 170,4993 }, { 171,4993 },
 { 172,4993 }, { 173,4993 }, { 174,4993 }, { 175,4993 }, { 176,4993 },
 { 177,4993 }, { 178,4993 }, { 179,4993 }, { 180,4993 }, { 181,4993 },
 { 182,4993 }, { 183,4993 }, { 184,4993 }, { 185,4993 }, { 186,4993 },

 { 187,4993 }, { 188,4993 }, { 189,4993 }, { 190,4993 }, { 191,4993 },
 { 192,4993 }, { 193,4993 }, { 194,4993 }, { 195,4993 }, { 196,4993 },
 { 197,4993 }, { 198,4993 }, { 199,4993 }, { 200,4993 }, { 201,4993 },
 { 202,4993 }, { 203,4993 }, { 204,4993 }, { 205,4993 }, { 206,4993 },
 { 207,4993 }, { 208,4993 }, { 209,4993 }, { 210,4993 }, { 211,4993 },
 { 212,4993 }, { 213,4993 }, { 214,4993 }, { 215,4993 }, { 216,4993 },
 { 217,4993 }, { 218,4993 }, { 219,4993 }, { 220,4993 }, { 221,4993 },
 { 222,4993 }, { 223,4993 }, { 224,4993 }, { 225,4993 }, { 226,4993 },
 { 227,4993 }, { 228,4993 }, { 229,4993 }, { 230,4993 }, { 231,4993 },
 { 232,4993 }, { 233,4993 }, { 234,4993 }, { 235,4993 }, { 236,4993 },

 { 237,4993 }, { 238,4993 }, { 239,4993 }, { 240,4993 }, { 241,4993 },
 { 242,4993 }, { 243,4993 }, { 244,4993 }, { 245,4993 }, { 246,4993 },
 { 247,4993 }, { 248,4993 }, { 249,4993 }, { 250,4993 }, { 251,4993 },
 { 252,4993 }, { 253,4993 }, { 254,4993 }, { 255,4993 }, { 256,4993 },
 {   0,   0 }, {   0,19425 }, {   1,4735 }, {   2,4735 }, {   3,4735 },
 {   4,4735 }, {   5,4735 }, {   6,4735 }, {   7,4735 }, {   8,4735 },
 {   9,4735 }, {  10,4735 }, {  11,4735 }, {  12,4735 }, {  13,4735 },
 {  14,4735 }, {  15,4735 }, {  16,4735 }, {  17,4735 }, {  18,4735 },
 {  19,4735 }, {  20,4735 }, {  21,4735 }, {  22,4735 }, {  23,4735 },
 {  24,4735 }, {  25,4735 }, {  26,4735 }, {  27,4735 }, {  28,4735 },

 {  29,4735 }, {  30,4735 }, {  31,4735 }, {  32,4735 }, {  33,4735 },
 {  34,4735 }, {  35,4735 }, {  36,4735 }, {  37,4735 }, {  38,4735 },
 {  39, 832 }, {  40,4735 }, {  41,4735 }, {  42,4735 }, {  43,4735 },
 {  44,4735 }, {  45,4735 }, {  46,4735 }, {  47,4735 }, {  48,4735 },
 {  49,4735 }, {  50,4735 }, {  51,4735 }, {  52,4735 }, {  53,4735 },
 {  54,4735 }, {  55,4735 }, {  56,4735 }, {  57,4735 }, {  58,4735 },
 {  59,4735 }, {  60,4735 }, {  61,4735 }, {  62,4735 }, {  63,4735 },
 {  64,4735 }, {  65,4735 }, {  66,4735 }, {  67,4735 }, {  68,4735 },
 {  69,4735 }, {  70,4735 }, {  71,4735 }, {  72,4735 }, {  73,4735 },
 {  74,4735 }, {  75,4735 }, {  76,4735 }, {  77,4735 }, {  78,4735 },

 {  79,4735 }, {  80,4735 }, {  81,4735 }, {  82,4735 }, {  83,4735 },
 {  84,4735 }, {  85,4735 }, {  86,4735 }, {  87,4735 }, {  88,4735 },
 {  89,4735 }, {  90,4735 }, {  91,4735 }, {  92,4735 }, {  93,4735 },
 {  94,4735 }, {  95,4735 }, {  96,4735 }, {  97,4735 }, {  98,4735 },
 {  99,4735 }, { 100,4735 }, { 101,4735 }, { 102,4735 }, { 103,4735 },
 { 104,4735 }, { 105,4735 }, { 106,4735 }, { 107,4735 }, { 108,4735 },
 { 109,4735 }, { 110,4735 }, { 111,4735 }, { 112,4735 }, { 113,4735 },
 { 114,4735 }, { 115,4735 }, { 116,4735 }, { 117,4735 }, { 118,4735 },
 { 119,4735 }, { 120,4735 }, { 121,4735 }, { 122,4735 }, { 123,4735 },
 { 124,4735 }, { 125,4735 }, { 126,4735 }, { 127,4735 }, { 128,4735 },

 { 129,4735 }, { 130,4735 }, { 131,4735 }, { 132,4735 }, { 133,4735 },
 { 134,4735 }, { 135,4735 }, { 136,4735 }, { 137,4735 }, { 138,4735 },
 { 139,4735 }, { 140,4735 }, { 141,4735 }, { 142,4735 }, { 143,4735 },
 { 144,4735 }, { 145,4735 }, { 146,4735 }, { 147,4735 }, { 148,4735 },
 { 149,4735 }, { 150,4735 }, { 151,4735 }, { 152,4735 }, { 153,4735 },
 { 154,4735 }, { 155,4735 }, { 156,4735 }, { 157,4735 }, { 158,4735 },
 { 159,4735 }, { 160,4735 }, { 161,4735 }, { 162,4735 }, { 163,4735 },
 { 164,4735 }, { 165,4735 }, { 166,4735 }, { 167,4735 }, { 168,4735 },
 { 169,4735 }, { 170,4735 }, { 171,4735 }, { 172,4735 }, { 173,4735 },
 { 174,4735 }, { 175,4735 }, { 176,4735 }, { 177,4735 }, { 178,4735 },

 { 179,4735 }, { 180,4735 }, { 181,4735 }, { 182,4735 }, { 183,4735 },
 { 184,4735 }, { 185,4735 }, { 186,4735 }, { 187,4735 }, { 188,4735 },
 { 189,4735 }, { 190,4735 }, { 191,4735 }, { 192,4735 }, { 193,4735 },
 { 194,4735 }, { 195,4735 }, { 196,4735 }, { 197,4735 }, { 198,4735 },
 { 199,4735 }, { 200,4735 }, { 201,4735 }, { 202,4735 }, { 203,4735 },
 { 204,4735 }, { 205,4735 }, { 206,4735 }, { 207,4735 }, { 208,4735 },
 { 209,4735 }, { 210,4735 }, { 211,4735 }, { 212,4735 }, { 213,4735 },
 { 214,4735 }, { 215,4735 }, { 216,4735 }, { 217,4735 }, { 218,4735 },
 { 219,4735 }, { 220,4735 }, { 221,4735 }, { 222,4735 }, { 223,4735 },
 { 224,4735 }, { 225,4735 }, { 226,4735 }, { 227,4735 }, { 228,4735 },

 { 229,4735 }, { 230,4735 }, { 231,4735 }, { 232,4735 }, { 233,4735 },
 { 234,4735 }, { 235,4735 }, { 236,4735 }, { 237,4735 }, { 238,4735 },
 { 239,4735 }, { 240,4735 }, { 241,4735 }, { 242,4735 }, { 243,4735 },
 { 244,4735 }, { 245,4735 }, { 246,4735 }, { 247,4735 }, { 248,4735 },
 { 249,4735 }, { 250,4735 }, { 251,4735 }, { 252,4735 }, { 253,4735 },
 { 254,4735 }, { 255,4735 }, { 256,4735 }, {   0,   0 }, {   0,19167 },
 {   1, 593 }, {   2, 593 }, {   3, 593 }, {   4, 593 }, {   5, 593 },
 {   6, 593 }, {   7, 593 }, {   8, 593 }, {   9, 593 }, {  10, 597 },
 {  11, 593 }, {  12, 593 }, {  13, 593 }, {  14, 593 }, {  15, 593 },
 {  16, 593 }, {  17, 593 }, {  18, 593 }, {  19, 593 }, {  20, 593 },

 {  21, 593 }, {  22, 593 }, {  23, 593 }, {  24, 593 }, {  25, 593 },
 {  26, 593 }, {  27, 593 }, {  28, 593 }, {  29, 593 }, {  30, 593 },
 {  31, 593 }, {  32, 593 }, {  33, 593 }, {  34, 593 }, {  35, 593 },
 {  36, 593 }, {  37, 593 }, {  38, 593 }, {  39, 593 }, {  40, 593 },
 {  41, 593 }, {  42, 593 }, {  43, 593 }, {  44, 593 }, {  45, 593 },
 {  46, 593 }, {  47, 593 }, {  48, 593 }, {  49, 593 }, {  50, 593 },
 {  51, 593 }, {  52, 593 }, {  53, 593 }, {  54, 593 }, {  55, 593 },
 {  56, 593 }, {  57, 593 }, {  58, 593 }, {  59, 593 }, {  60, 593 },
 {  61, 593 }, {  62, 593 }, {  63, 593 }, {  64, 593 }, {  65, 593 },
 {  66, 593 }, {  67, 593 }, {  68, 593 }, {  69, 593 }, {  70, 593 },

 {  71, 593 }, {  72, 593 }, {  73, 593 }, {  74, 593 }, {  75, 593 },
 {  76, 593 }, {  77, 593 }, {  78, 593 }, {  79, 593 }, {  80, 593 },
 {  81, 593 }, {  82, 593 }, {  83, 593 }, {  84, 593 }, {  85, 593 },
 {  86, 593 }, {  87, 593 }, {  88, 593 }, {  89, 593 }, {  90, 593 },
 {  91, 593 }, {  92, 637 }, {  93, 593 }, {  94, 593 }, {  95, 593 },
 {  96, 593 }, {  97, 593 }, {  98, 593 }, {  99, 593 }, { 100, 593 },
 { 101, 593 }, { 102, 593 }, { 103, 593 }, { 104, 593 }, { 105, 593 },
 { 106, 593 }, { 107, 593 }, { 108, 593 }, { 109, 593 }, { 110, 593 },
 { 111, 593 }, { 112, 593 }, { 113, 593 }, { 114, 593 }, { 115, 593 },
 { 116, 593 }, { 117, 593 }, { 118, 593 }, { 119, 593 }, { 120, 593 },

 { 121, 593 }, { 122, 593 }, { 123, 593 }, { 124, 593 }, { 125, 593 },
 { 126, 593 }, { 127, 593 }, { 128, 593 }, { 129, 593 }, { 130, 593 },
 { 131, 593 }, { 132, 593 }, { 133, 593 }, { 134, 593 }, { 135, 593 },
 { 136, 593 }, { 137, 593 }, { 138, 593 }, { 139, 593 }, { 140, 593 },
 { 141, 593 }, { 142, 593 }, { 143, 593 }, { 144, 593 }, { 145, 593 },
 { 146, 593 }, { 147, 593 }, { 148, 593 }, { 149, 593 }, { 150, 593 },
 { 151, 593 }, { 152, 593 }, { 153, 593 }, { 154, 593 }, { 155, 593 },
 { 156, 593 }, { 157, 593 }, { 158, 593 }, { 159, 593 }, { 160, 593 },
 { 161, 593 }, { 162, 593 }, { 163, 593 }, { 164, 593 }, { 165, 593 },
 { 166, 593 }, { 167, 593 }, { 168, 593 }, { 169, 593 }, { 170, 593 },

 { 171, 593 }, { 172, 593 }, { 173, 593 }, { 174, 593 }, { 175, 593 },
 { 176, 593 }, { 177, 593 }, { 178, 593 }, { 179, 593 }, { 180, 593 },
 { 181, 593 }, { 182, 593 }, { 183, 593 }, { 184, 593 }, { 185, 593 },
 { 186, 593 }, { 187, 593 }, { 188, 593 }, { 189, 593 }, { 190, 593 },
 { 191, 593 }, { 192, 593 }, { 193, 593 }, { 194, 593 }, { 195, 593 },
 { 196, 593 }, { 197, 593 }, { 198, 593 }, { 199, 593 }, { 200, 593 },
 { 201, 593 }, { 202, 593 }, { 203, 593 }, { 204, 593 }, { 205, 593 },
 { 206, 593 }, { 207, 593 }, { 208, 593 }, { 209, 593 }, { 210, 593 },
 { 211, 593 }, { 212, 593 }, { 213, 593 }, { 214, 593 }, { 215, 593 },
 { 216, 593 }, { 217, 593 }, { 218, 593 }, { 219, 593 }, { 220, 593 },

 { 221, 593 }, { 222, 593 }, { 223, 593 }, { 224, 593 }, { 225, 593 },
 { 226, 593 }, { 227, 593 }, { 228, 593 }, { 229, 593 }, { 230, 593 },
 { 231, 593 }, { 232, 593 }, { 233, 593 }, { 234, 593 }, { 235, 593 },
 { 236, 593 }, { 237, 593 }, { 238, 593 }, { 239, 593 }, { 240, 593 },
 { 241, 593 }, { 242, 593 }, { 243, 593 }, { 244, 593 }, { 245, 593 },
 { 246, 593 }, { 247, 593 }, { 248, 593 }, { 249, 593 }, { 250, 593 },
 { 251, 593 }, { 252, 593 }, { 253, 593 }, { 254, 593 }, { 255, 593 },
 { 256, 593 }, {   0,   0 }, {   0,18909 }, {   1, 335 }, {   2, 335 },
 {   3, 335 }, {   4, 335 }, {   5, 335 }, {   6, 335 }, {   7, 335 },
 {   8, 335 }, {   9, 335 }, {  10, 339 }, {  11, 335 }, {  12, 335 },

 {  13, 335 }, {  14, 335 }, {  15, 335 }, {  16, 335 }, {  17, 335 },
 {  18, 335 }, {  19, 335 }, {  20, 335 }, {  21, 335 }, {  22, 335 },
 {  23, 335 }, {  24, 335 }, {  25, 335 }, {  26, 335 }, {  27, 335 },
 {  28, 335 }, {  29, 335 }, {  30, 335 }, {  31, 335 }, {  32, 335 },
 {  33, 335 }, {  34, 335 }, {  35, 335 }, {  36, 335 }, {  37, 335 },
 {  38, 335 }, {  39, 335 }, {  40, 335 }, {  41, 335 }, {  42, 335 },
 {  43, 335 }, {  44, 335 }, {  45, 335 }, {  46, 335 }, {  47, 335 },
 {  48, 335 }, {  49, 335 }, {  50, 335 }, {  51, 335 }, {  52, 335 },
 {  53, 335 }, {  54, 335 }, {  55, 335 }, {  56, 335 }, {  57, 335 },
 {  58, 335 }, {  59, 335 }, {  60, 335 }, {  61, 335 }, {  62, 335 },

 {  63, 335 }, {  64, 335 }, {  65, 335 }, {  66, 335 }, {  67, 335 },
 {  68, 335 }, {  69, 335 }, {  70, 335 }, {  71, 335 }, {  72, 335 },
 {  73, 335 }, {  74, 335 }, {  75, 335 }, {  76, 335 }, {  77, 335 },
 {  78, 335 }, {  79, 335 }, {  80, 335 }, {  81, 335 }, {  82, 335 },
 {  83, 335 }, {  84, 335 }, {  85, 335 }, {  86, 335 }, {  87, 335 },
 {  88, 335 }, {  89, 335 }, {  90, 335 }, {  91, 335 }, {  92, 379 },
 {  93, 335 }, {  94, 335 }, {  95, 335 }, {  96, 335 }, {  97, 335 },
 {  98, 335 }, {  99, 335 }, { 100, 335 }, { 101, 335 }, { 102, 335 },
 { 103, 335 }, { 104, 335 }, { 105, 335 }, { 106, 335 }, { 107, 335 },
 { 108, 335 }, { 109, 335 }, { 110, 335 }, { 111, 335 }, { 112, 335 },

 { 113, 335 }, { 114, 335 }, { 115, 335 }, { 116, 335 }, { 117, 335 },
 { 118, 335 }, { 119, 335 }, { 120, 335 }, { 121, 335 }, { 122, 335 },
 { 123, 335 }, { 124, 335 }, { 125, 335 }, { 126, 335 }, { 127, 335 },
 { 128, 335 }, { 129, 335 }, { 130, 335 }, { 131, 335 }, { 132, 335 },
 { 133, 335 }, { 134, 335 }, { 135, 335 }, { 136, 335 }, { 137, 335 },
 { 138, 335 }, { 139, 335 }, { 140, 335 }, { 141, 335 }, { 142, 335 },
 { 143, 335 }, { 144, 335 }, { 145, 335 }, { 146, 335 }, { 147, 335 },
 { 148, 335 }, { 149, 335 }, { 150, 335 }, { 151, 335 }, { 152, 335 },
 { 153, 335 }, { 154, 335 }, { 155, 335 }, { 156, 335 }, { 157, 335 },
 { 158, 335 }, { 159, 335 }, { 160, 335 }, { 161, 335 }, { 162, 335 },

 { 163, 335 }, { 164, 335 }, { 165, 335 }, { 166, 335 }, { 167, 335 },
 { 168, 335 }, { 169, 335 }, { 170, 335 }, { 171, 335 }, { 172, 335 },
 { 173, 335 }, { 174, 335 }, { 175, 335 }, { 176, 335 }, { 177, 335 },
 { 178, 335 }, { 179, 335 }, { 180, 335 }, { 181, 335 }, { 182, 335 },
 { 183, 335 }, { 184, 335 }, { 185, 335 }, { 186, 335 }, { 187, 335 },
 { 188, 335 }, { 189, 335 }, { 190, 335 }, { 191, 335 }, { 192, 335 },
 { 193, 335 }, { 194, 335 }, { 195, 335 }, { 196, 335 }, { 197, 335 },
 { 198, 335 }, { 199, 335 }, { 200, 335 }, { 201, 335 }, { 202, 335 },
 { 203, 335 }, { 204, 335 }, { 205, 335 }, { 206, 335 }, { 207, 335 },
 { 208, 335 }, { 209, 335 }, { 210, 335 }, { 211, 335 }, { 212, 335 },

 { 213, 335 }, { 214, 335 }, { 215, 335 }, { 216, 335 }, { 217, 335 },
 { 218, 335 }, { 219, 335 }, { 220, 335 }, { 221, 335 }, { 222, 335 },
 { 223, 335 }, { 224, 335 }, { 225, 335 }, { 226, 335 }, { 227, 335 },
 { 228, 335 }, { 229, 335 }, { 230, 335 }, { 231, 335 }, { 232, 335 },
 { 233, 335 }, { 234, 335 }, { 235, 335 }, { 236, 335 }, { 237, 335 },
 { 238, 335 }, { 239, 335 }, { 240, 335 }, { 241, 335 }, { 242, 335 },
 { 243, 335 }, { 244, 335 }, { 245, 335 }, { 246, 335 }, { 247, 335 },
 { 248, 335 }, { 249, 335 }, { 250, 335 }, { 251, 335 }, { 252, 335 },
 { 253, 335 }, { 254, 335 }, { 255, 335 }, { 256, 335 }, {   0,  75 },
 {   0,18651 }, {   0,   1 }, {   0,18649 }, {   0,  38 }, {   0,18647 },

 {   0,   0 }, {   0,   1 }, {   0,18644 }, {   0,  54 }, {   0,18642 },
 {   0,   0 }, {   9,5585 }, {  10,5585 }, {  11,5585 }, {  12,5585 },
 {  13,5585 }, {   9,5580 }, {  10,5580 }, {  11,5580 }, {  12,5580 },
 {  13,5580 }, {   0,  13 }, {   0,18629 }, {   0,  53 }, {   0,18627 },
 {   0,   0 }, {   0,  53 }, {   0,18624 }, {   0,  16 }, {   0,18622 },
 {   0,   0 }, {   0,   6 }, {   0,18619 }, {   0,   0 }, {  32,5585 },
 {   0,   6 }, {   0,18615 }, {   0,   0 }, {   0,   0 }, {  32,5580 },
 {   0,  40 }, {   0,18610 }, {  33,5833 }, {   0,   0 }, {  35,5833 },
 {   0,   0 }, {  37,5833 }, {  38,5833 }, {   0,  54 }, {   0,18602 },
 {   0,   0 }, {  42,5833 }, {  43,5833 }, {   0,   0 }, {  45,5833 },

 {   0,   0 }, {  47,5833 }, {   0,  16 }, {   0,18593 }, {   0,  19 },
 {   0,18591 }, {   0,  18 }, {   0,18589 }, {   0,   0 }, {   0,  16 },
 {   0,18586 }, {   0,  41 }, {   0,18584 }, {   0,   0 }, {  60,5833 },
 {  61,5844 }, {  62,5833 }, {  63,5833 }, {  64,5833 }, {  42, 363 },
 {  34, 358 }, {   0,  25 }, {   0,18574 }, {  42,8528 }, {  47, 365 },
 {   0,  26 }, {   0,18570 }, {  33,5793 }, {   0,   0 }, {  35,5793 },
 {  58, 349 }, {  37,5793 }, {  38,5793 }, {  61, 351 }, {   0,   0 },
 {   0,   0 }, {  42,5793 }, {  43,5793 }, {   0,   0 }, {  45,5793 },
 {   0,   0 }, {  47,5793 }, {  39, 346 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  34, 332 }, {   0,   0 }, {  94,5833 }, {  39, 339 },

 {  96,5833 }, {   0,   0 }, {  45,9480 }, {   0,   0 }, {  60,5793 },
 {  61,5793 }, {  62,5793 }, {  63,5793 }, {  64,5793 }, {   0,  75 },
 {   0,18536 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,  25 }, {   0,18530 }, {   0,  32 }, {   0,18528 }, {   0,  46 },
 {   0,18526 }, {   0,  68 }, {   0,18524 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 124,5833 }, {   0,   0 },
 { 126,5833 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  94,5793 }, {   0,   0 },
 {  96,5793 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  36,   8 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,5817 }, {  49,5817 },
 {  50,5817 }, {  51,5817 }, {  52,5817 }, {  53,5817 }, {  54,5817 },
 {  55,5817 }, {  56,5817 }, {  57,5817 }, { 124,5793 }, {   0,   0 },
 { 126,5793 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65,6074 }, {  66,6074 }, {  67,6074 }, {  68,6074 }, {  69,6074 },
 {  70,6074 }, {  71,6074 }, {  72,6074 }, {  73,6074 }, {  74,6074 },
 {  75,6074 }, {  76,6074 }, {  77,6074 }, {  78,6074 }, {  79,6074 },
 {  80,6074 }, {  81,6074 }, {  82,6074 }, {  83,6074 }, {  84,6074 },
 {  85,6074 }, {  86,6074 }, {  87,6074 }, {  88,6074 }, {  89,6074 },

 {  90,6074 }, {  85,10625 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  95,6074 }, {   0,   0 }, {  97,6074 }, {  98,6074 }, {  99,6074 },
 { 100,6074 }, { 101,6074 }, { 102,6074 }, { 103,6074 }, { 104,6074 },
 { 105,6074 }, { 106,6074 }, { 107,6074 }, { 108,6074 }, { 109,6074 },
 { 110,6074 }, { 111,6074 }, { 112,6074 }, { 113,6074 }, { 114,6074 },
 { 115,6074 }, { 116,6074 }, { 117,6074 }, { 118,6074 }, { 119,6074 },
 { 120,6074 }, { 121,6074 }, { 122,6074 }, { 117,10648 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,6074 }, { 129,6074 },
 { 130,6074 }, { 131,6074 }, { 132,6074 }, { 133,6074 }, { 134,6074 },
 { 135,6074 }, { 136,6074 }, { 137,6074 }, { 138,6074 }, { 139,6074 },

 { 140,6074 }, { 141,6074 }, { 142,6074 }, { 143,6074 }, { 144,6074 },
 { 145,6074 }, { 146,6074 }, { 147,6074 }, { 148,6074 }, { 149,6074 },
 { 150,6074 }, { 151,6074 }, { 152,6074 }, { 153,6074 }, { 154,6074 },
 { 155,6074 }, { 156,6074 }, { 157,6074 }, { 158,6074 }, { 159,6074 },
 { 160,6074 }, { 161,6074 }, { 162,6074 }, { 163,6074 }, { 164,6074 },
 { 165,6074 }, { 166,6074 }, { 167,6074 }, { 168,6074 }, { 169,6074 },
 { 170,6074 }, { 171,6074 }, { 172,6074 }, { 173,6074 }, { 174,6074 },
 { 175,6074 }, { 176,6074 }, { 177,6074 }, { 178,6074 }, { 179,6074 },
 { 180,6074 }, { 181,6074 }, { 182,6074 }, { 183,6074 }, { 184,6074 },
 { 185,6074 }, { 186,6074 }, { 187,6074 }, { 188,6074 }, { 189,6074 },

 { 190,6074 }, { 191,6074 }, { 192,6074 }, { 193,6074 }, { 194,6074 },
 { 195,6074 }, { 196,6074 }, { 197,6074 }, { 198,6074 }, { 199,6074 },
 { 200,6074 }, { 201,6074 }, { 202,6074 }, { 203,6074 }, { 204,6074 },
 { 205,6074 }, { 206,6074 }, { 207,6074 }, { 208,6074 }, { 209,6074 },
 { 210,6074 }, { 211,6074 }, { 212,6074 }, { 213,6074 }, { 214,6074 },
 { 215,6074 }, { 216,6074 }, { 217,6074 }, { 218,6074 }, { 219,6074 },
 { 220,6074 }, { 221,6074 }, { 222,6074 }, { 223,6074 }, { 224,6074 },
 { 225,6074 }, { 226,6074 }, { 227,6074 }, { 228,6074 }, { 229,6074 },
 { 230,6074 }, { 231,6074 }, { 232,6074 }, { 233,6074 }, { 234,6074 },
 { 235,6074 }, { 236,6074 }, { 237,6074 }, { 238,6074 }, { 239,6074 },

 { 240,6074 }, { 241,6074 }, { 242,6074 }, { 243,6074 }, { 244,6074 },
 { 245,6074 }, { 246,6074 }, { 247,6074 }, { 248,6074 }, { 249,6074 },
 { 250,6074 }, { 251,6074 }, { 252,6074 }, { 253,6074 }, { 254,6074 },
 { 255,6074 }, {   0,  53 }, {   0,18279 }, {   0,  63 }, {   0,18277 },
 {   0,  45 }, {   0,18275 }, {   0,  47 }, {   0,18273 }, {   0,   8 },
 {   0,18271 }, {   0,   0 }, {   0,  53 }, {   0,18268 }, {   0,  14 },
 {   0,18266 }, {   0,  12 }, {   0,18264 }, {   0,   0 }, {   0,  44 },
 {   0,18261 }, {   0,  11 }, {   0,18259 }, {   0,   0 }, {   0,   7 },
 {   0,18256 }, {   0,   4 }, {   0,18254 }, {   0,  42 }, {   0,18252 },
 {   0,   0 }, {   0,  53 }, {   0,18249 }, {   0,  20 }, {   0,18247 },

 {  33,5470 }, {   0,   0 }, {  35,5470 }, {   0,   0 }, {  37,5470 },
 {  38,5470 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  42,5470 },
 {  43,5470 }, {  33,5459 }, {  45,5470 }, {  35,5459 }, {  47,5470 },
 {  37,5459 }, {  38,5459 }, {  48,12088 }, {  49,12088 }, {  34, 104 },
 {  42,5459 }, {  43,5459 }, {   0,   0 }, {  45,6063 }, {  39, 110 },
 {  47,5459 }, {   0,   0 }, {  60,5470 }, {  61,5470 }, {  62,5470 },
 {  63,5470 }, {  64,5470 }, {  42,   0 }, {   0,  18 }, {   0,18212 },
 {   0,  17 }, {   0,18210 }, {  47,   2 }, {  60,5459 }, {  61,5459 },
 {  62,5459 }, {  63,5459 }, {  64,5459 }, {  46,-277 }, {   0,   0 },
 {  48,6302 }, {  49,6302 }, {  50,6302 }, {  51,6302 }, {  52,6302 },

 {  53,6302 }, {  54,6302 }, {  55,6302 }, {  56,6302 }, {  57,6302 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  94,5470 }, {   0,   0 }, {  96,5470 }, {  95, 118 },
 {   0,   0 }, {   0,   0 }, {   0,  53 }, {   0,18178 }, {   0,   0 },
 {   0,  18 }, {   0,18175 }, {  94,5459 }, {   0,   0 }, {  96,5459 },
 {   0,  28 }, {   0,18170 }, {   0,  34 }, {   0,18168 }, {  45,9103 },
 {   0,  56 }, {   0,18165 }, {   0,  72 }, {   0,18163 }, {   0,  65 },
 {   0,18161 }, {   0,  63 }, {   0,18159 }, {   0,  39 }, {   0,18157 },
 {   0,   0 }, { 124,5470 }, {   0,   0 }, { 126,5470 }, {   0,  15 },
 {   0,18151 }, {   0,  71 }, {   0,18149 }, {   0,   0 }, {   0,  57 },

 {   0,18146 }, {  33,5369 }, { 124,5459 }, {  35,5369 }, { 126,5459 },
 {  37,5369 }, {  38,5369 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  42,6488 }, {  43,5369 }, {   0,   0 }, {  45,5369 }, {   0,   0 },
 {  47,5369 }, {  45,13437 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  60,5369 }, {  61,5369 },
 {  62,5369 }, {  63,5369 }, {  64,5369 }, {   0,   0 }, {   0,   0 },
 {  48,11970 }, {  49,11970 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  46,6488 }, {   0,   0 }, {  48,6745 }, {  49,6745 },

 {  50,6745 }, {  51,6745 }, {  52,6745 }, {  53,6745 }, {  54,6745 },
 {  55,6745 }, {  56,6745 }, {  57,6745 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  94,5369 }, {   0,   0 }, {  96,5369 },
 {  65,-378 }, {  66,-131 }, {  67,-378 }, {  68,-378 }, {  69,7002 },
 {  70,-378 }, {  71,-378 }, {  72,-378 }, {  73,-378 }, {  74,-378 },
 {  75,-378 }, {  76,-378 }, {  77,-378 }, {  78,-378 }, {  79,7012 },
 {  80,-378 }, {  81,-378 }, {  82,-378 }, {  83,-378 }, {  84,-378 },
 {  85,-378 }, {  86,-378 }, {  87,-378 }, {  88,7020 }, {  89,-378 },
 {  90,-378 }, {   0,   0 }, { 124,5369 }, {   0,   0 }, { 126,5369 },
 {  95,7043 }, {   0,   0 }, {  97,-378 }, {  98,-131 }, {  99,-378 },

 { 100,-378 }, { 101,7002 }, { 102,-378 }, { 103,-378 }, { 104,-378 },
 { 105,-378 }, { 106,-378 }, { 107,-378 }, { 108,-378 }, { 109,-378 },
 { 110,-378 }, { 111,7012 }, { 112,-378 }, { 113,-378 }, { 114,-378 },
 { 115,-378 }, { 116,-378 }, { 117,-378 }, { 118,-378 }, { 119,-378 },
 { 120,7020 }, { 121,-378 }, { 122,-378 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,-378 }, { 129,-378 },
 { 130,-378 }, { 131,-378 }, { 132,-378 }, { 133,-378 }, { 134,-378 },
 { 135,-378 }, { 136,-378 }, { 137,-378 }, { 138,-378 }, { 139,-378 },
 { 140,-378 }, { 141,-378 }, { 142,-378 }, { 143,-378 }, { 144,-378 },
 { 145,-378 }, { 146,-378 }, { 147,-378 }, { 148,-378 }, { 149,-378 },

 { 150,-378 }, { 151,-378 }, { 152,-378 }, { 153,-378 }, { 154,-378 },
 { 155,-378 }, { 156,-378 }, { 157,-378 }, { 158,-378 }, { 159,-378 },
 { 160,-378 }, { 161,-378 }, { 162,-378 }, { 163,-378 }, { 164,-378 },
 { 165,-378 }, { 166,-378 }, { 167,-378 }, { 168,-378 }, { 169,-378 },
 { 170,-378 }, { 171,-378 }, { 172,-378 }, { 173,-378 }, { 174,-378 },
 { 175,-378 }, { 176,-378 }, { 177,-378 }, { 178,-378 }, { 179,-378 },
 { 180,-378 }, { 181,-378 }, { 182,-378 }, { 183,-378 }, { 184,-378 },
 { 185,-378 }, { 186,-378 }, { 187,-378 }, { 188,-378 }, { 189,-378 },
 { 190,-378 }, { 191,-378 }, { 192,-378 }, { 193,-378 }, { 194,-378 },
 { 195,-378 }, { 196,-378 }, { 197,-378 }, { 198,-378 }, { 199,-378 },

 { 200,-378 }, { 201,-378 }, { 202,-378 }, { 203,-378 }, { 204,-378 },
 { 205,-378 }, { 206,-378 }, { 207,-378 }, { 208,-378 }, { 209,-378 },
 { 210,-378 }, { 211,-378 }, { 212,-378 }, { 213,-378 }, { 214,-378 },
 { 215,-378 }, { 216,-378 }, { 217,-378 }, { 218,-378 }, { 219,-378 },
 { 220,-378 }, { 221,-378 }, { 222,-378 }, { 223,-378 }, { 224,-378 },
 { 225,-378 }, { 226,-378 }, { 227,-378 }, { 228,-378 }, { 229,-378 },
 { 230,-378 }, { 231,-378 }, { 232,-378 }, { 233,-378 }, { 234,-378 },
 { 235,-378 }, { 236,-378 }, { 237,-378 }, { 238,-378 }, { 239,-378 },
 { 240,-378 }, { 241,-378 }, { 242,-378 }, { 243,-378 }, { 244,-378 },
 { 245,-378 }, { 246,-378 }, { 247,-378 }, { 248,-378 }, { 249,-378 },

 { 250,-378 }, { 251,-378 }, { 252,-378 }, { 253,-378 }, { 254,-378 },
 { 255,-378 }, {   0,  57 }, {   0,17889 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,  71 }, {   0,17879 }, {   0,  73 }, {   0,17877 },
 {   0,  70 }, {   0,17875 }, {   0,  69 }, {   0,17873 }, {   0,  29 },
 {   0,17871 }, {   0,  30 }, {   0,17869 }, {   0,  23 }, {   0,17867 },
 {   0,  24 }, {   0,17865 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  46,6231 }, {   0,   0 },
 {  48,6488 }, {  49,6488 }, {  50,6488 }, {  51,6488 }, {  52,6488 },
 {  53,6488 }, {  54,6488 }, {  55,6488 }, {  56,6488 }, {  57,6488 },
 {  48,11690 }, {  49,11690 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  65,-635 }, {  66,-635 }, {  67,-635 },
 {  68,-635 }, {  69,6745 }, {  70,-635 }, {  71,-635 }, {  72,-635 },
 {  73,-635 }, {  74,-635 }, {  75,-635 }, {  76,-635 }, {  77,-635 },
 {  78,-635 }, {  79,-635 }, {  80,-635 }, {  81,-635 }, {  82,-635 },
 {  83,-635 }, {  84,-635 }, {  85,-635 }, {  86,-635 }, {  87,-635 },
 {  88,-635 }, {  89,-635 }, {  90,-635 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {  95,6786 }, {   0,   0 }, {  97,-635 },
 {  98,-635 }, {  99,-635 }, { 100,-635 }, { 101,6745 }, { 102,-635 },
 { 103,-635 }, { 104,-635 }, { 105,-635 }, { 106,-635 }, { 107,-635 },
 { 108,-635 }, { 109,-635 }, { 110,-635 }, { 111,-635 }, { 112,-635 },
 { 113,-635 }, { 114,-635 }, { 115,-635 }, { 116,-635 }, { 117,-635 },
 { 118,-635 }, { 119,-635 }, { 120,-635 }, { 121,-635 }, { 122,-635 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 { 128,-635 }, { 129,-635 }, { 130,-635 }, { 131,-635 }, { 132,-635 },
 { 133,-635 }, { 134,-635 }, { 135,-635 }, { 136,-635 }, { 137,-635 },
 { 138,-635 }, { 139,-635 }, { 140,-635 }, { 141,-635 }, { 142,-635 },

 { 143,-635 }, { 144,-635 }, { 145,-635 }, { 146,-635 }, { 147,-635 },
 { 148,-635 }, { 149,-635 }, { 150,-635 }, { 151,-635 }, { 152,-635 },
 { 153,-635 }, { 154,-635 }, { 155,-635 }, { 156,-635 }, { 157,-635 },
 { 158,-635 }, { 159,-635 }, { 160,-635 }, { 161,-635 }, { 162,-635 },
 { 163,-635 }, { 164,-635 }, { 165,-635 }, { 166,-635 }, { 167,-635 },
 { 168,-635 }, { 169,-635 }, { 170,-635 }, { 171,-635 }, { 172,-635 },
 { 173,-635 }, { 174,-635 }, { 175,-635 }, { 176,-635 }, { 177,-635 },
 { 178,-635 }, { 179,-635 }, { 180,-635 }, { 181,-635 }, { 182,-635 },
 { 183,-635 }, { 184,-635 }, { 185,-635 }, { 186,-635 }, { 187,-635 },
 { 188,-635 }, { 189,-635 }, { 190,-635 }, { 191,-635 }, { 192,-635 },

 { 193,-635 }, { 194,-635 }, { 195,-635 }, { 196,-635 }, { 197,-635 },
 { 198,-635 }, { 199,-635 }, { 200,-635 }, { 201,-635 }, { 202,-635 },
 { 203,-635 }, { 204,-635 }, { 205,-635 }, { 206,-635 }, { 207,-635 },
 { 208,-635 }, { 209,-635 }, { 210,-635 }, { 211,-635 }, { 212,-635 },
 { 213,-635 }, { 214,-635 }, { 215,-635 }, { 216,-635 }, { 217,-635 },
 { 218,-635 }, { 219,-635 }, { 220,-635 }, { 221,-635 }, { 222,-635 },
 { 223,-635 }, { 224,-635 }, { 225,-635 }, { 226,-635 }, { 227,-635 },
 { 228,-635 }, { 229,-635 }, { 230,-635 }, { 231,-635 }, { 232,-635 },
 { 233,-635 }, { 234,-635 }, { 235,-635 }, { 236,-635 }, { 237,-635 },
 { 238,-635 }, { 239,-635 }, { 240,-635 }, { 241,-635 }, { 242,-635 },

 { 243,-635 }, { 244,-635 }, { 245,-635 }, { 246,-635 }, { 247,-635 },
 { 248,-635 }, { 249,-635 }, { 250,-635 }, { 251,-635 }, { 252,-635 },
 { 253,-635 }, { 254,-635 }, { 255,-635 }, {   0,  53 }, {   0,17632 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  53 },
 {   0,17621 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  33,4823 }, {   0,   0 }, {  35,4823 },

 {   0,   0 }, {  37,4823 }, {  38,4823 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  42,4823 }, {  43,4823 }, {  33,4812 }, {  45,4823 },
 {  35,4812 }, {  47,4823 }, {  37,4812 }, {  38,4812 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  42,4812 }, {  43,4812 }, {   0,   0 },
 {  45,4812 }, {   0,   0 }, {  47,4812 }, {   0,   0 }, {  60,4823 },
 {  61,6588 }, {  62,6599 }, {  63,4823 }, {  64,4823 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  60,4812 }, {  61,4812 }, {  62,6655 }, {  63,4812 }, {  64,4812 },
 {   0,   0 }, {   0,  53 }, {   0,17554 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  94,4823 }, {   0,   0 },
 {  96,4823 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  94,4812 },
 {   0,   0 }, {  96,4812 }, {   0,   0 }, {   0,  74 }, {   0,17522 },
 {  33,4745 }, {   0,   0 }, {  35,4745 }, {   0,   0 }, {  37,4745 },
 {  38,4745 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  42,4745 },
 {  43,4745 }, {   0,   0 }, {  45,4745 }, { 124,4823 }, {  47,4745 },
 { 126,4823 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, { 124,4812 },

 {   0,   0 }, { 126,4812 }, {  60,4745 }, {  61,6628 }, {  62,4745 },
 {  63,4745 }, {  64,4745 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  36,6662 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  48,6662 }, {  49,6662 }, {  50,6662 },
 {  51,6662 }, {  52,6662 }, {  53,6662 }, {  54,6662 }, {  55,6662 },
 {  56,6662 }, {  57,6662 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  94,4745 }, {   0,   0 }, {  96,4745 }, {  65,6662 },
 {  66,6662 }, {  67,6662 }, {  68,6662 }, {  69,6662 }, {  70,6662 },
 {  71,6662 }, {  72,6662 }, {  73,6662 }, {  74,6662 }, {  75,6662 },

 {  76,6662 }, {  77,6662 }, {  78,6662 }, {  79,6662 }, {  80,6662 },
 {  81,6662 }, {  82,6662 }, {  83,6662 }, {  84,6662 }, {  85,6662 },
 {  86,6662 }, {  87,6662 }, {  88,6662 }, {  89,6662 }, {  90,6662 },
 {   0,   0 }, { 124,4745 }, {   0,   0 }, { 126,4745 }, {  95,6662 },
 {   0,   0 }, {  97,6662 }, {  98,6662 }, {  99,6662 }, { 100,6662 },
 { 101,6662 }, { 102,6662 }, { 103,6662 }, { 104,6662 }, { 105,6662 },
 { 106,6662 }, { 107,6662 }, { 108,6662 }, { 109,6662 }, { 110,6662 },
 { 111,6662 }, { 112,6662 }, { 113,6662 }, { 114,6662 }, { 115,6662 },
 { 116,6662 }, { 117,6662 }, { 118,6662 }, { 119,6662 }, { 120,6662 },
 { 121,6662 }, { 122,6662 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, { 128,6662 }, { 129,6662 }, { 130,6662 },
 { 131,6662 }, { 132,6662 }, { 133,6662 }, { 134,6662 }, { 135,6662 },
 { 136,6662 }, { 137,6662 }, { 138,6662 }, { 139,6662 }, { 140,6662 },
 { 141,6662 }, { 142,6662 }, { 143,6662 }, { 144,6662 }, { 145,6662 },
 { 146,6662 }, { 147,6662 }, { 148,6662 }, { 149,6662 }, { 150,6662 },
 { 151,6662 }, { 152,6662 }, { 153,6662 }, { 154,6662 }, { 155,6662 },
 { 156,6662 }, { 157,6662 }, { 158,6662 }, { 159,6662 }, { 160,6662 },
 { 161,6662 }, { 162,6662 }, { 163,6662 }, { 164,6662 }, { 165,6662 },
 { 166,6662 }, { 167,6662 }, { 168,6662 }, { 169,6662 }, { 170,6662 },
 { 171,6662 }, { 172,6662 }, { 173,6662 }, { 174,6662 }, { 175,6662 },

 { 176,6662 }, { 177,6662 }, { 178,6662 }, { 179,6662 }, { 180,6662 },
 { 181,6662 }, { 182,6662 }, { 183,6662 }, { 184,6662 }, { 185,6662 },
 { 186,6662 }, { 187,6662 }, { 188,6662 }, { 189,6662 }, { 190,6662 },
 { 191,6662 }, { 192,6662 }, { 193,6662 }, { 194,6662 }, { 195,6662 },
 { 196,6662 }, { 197,6662 }, { 198,6662 }, { 199,6662 }, { 200,6662 },
 { 201,6662 }, { 202,6662 }, { 203,6662 }, { 204,6662 }, { 205,6662 },
 { 206,6662 }, { 207,6662 }, { 208,6662 }, { 209,6662 }, { 210,6662 },
 { 211,6662 }, { 212,6662 }, { 213,6662 }, { 214,6662 }, { 215,6662 },
 { 216,6662 }, { 217,6662 }, { 218,6662 }, { 219,6662 }, { 220,6662 },
 { 221,6662 }, { 222,6662 }, { 223,6662 }, { 224,6662 }, { 225,6662 },

 { 226,6662 }, { 227,6662 }, { 228,6662 }, { 229,6662 }, { 230,6662 },
 { 231,6662 }, { 232,6662 }, { 233,6662 }, { 234,6662 }, { 235,6662 },
 { 236,6662 }, { 237,6662 }, { 238,6662 }, { 239,6662 }, { 240,6662 },
 { 241,6662 }, { 242,6662 }, { 243,6662 }, { 244,6662 }, { 245,6662 },
 { 246,6662 }, { 247,6662 }, { 248,6662 }, { 249,6662 }, { 250,6662 },
 { 251,6662 }, { 252,6662 }, { 253,6662 }, { 254,6662 }, { 255,6662 },
 {   0,  74 }, {   0,17265 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  36,6405 }, {   0,   0 }, {   0,   0 },
 {  39,-1006 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,6405 },
 {  49,6405 }, {  50,6405 }, {  51,6405 }, {  52,6405 }, {  53,6405 },
 {  54,6405 }, {  55,6405 }, {  56,6405 }, {  57,6405 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  65,6405 }, {  66,6405 }, {  67,6405 }, {  68,6405 },

 {  69,6405 }, {  70,6405 }, {  71,6405 }, {  72,6405 }, {  73,6405 },
 {  74,6405 }, {  75,6405 }, {  76,6405 }, {  77,6405 }, {  78,6405 },
 {  79,6405 }, {  80,6405 }, {  81,6405 }, {  82,6405 }, {  83,6405 },
 {  84,6405 }, {  85,6405 }, {  86,6405 }, {  87,6405 }, {  88,6405 },
 {  89,6405 }, {  90,6405 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  95,6405 }, {   0,   0 }, {  97,6405 }, {  98,6405 },
 {  99,6405 }, { 100,6405 }, { 101,6405 }, { 102,6405 }, { 103,6405 },
 { 104,6405 }, { 105,6405 }, { 106,6405 }, { 107,6405 }, { 108,6405 },
 { 109,6405 }, { 110,6405 }, { 111,6405 }, { 112,6405 }, { 113,6405 },
 { 114,6405 }, { 115,6405 }, { 116,6405 }, { 117,6405 }, { 118,6405 },

 { 119,6405 }, { 120,6405 }, { 121,6405 }, { 122,6405 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,6405 },
 { 129,6405 }, { 130,6405 }, { 131,6405 }, { 132,6405 }, { 133,6405 },
 { 134,6405 }, { 135,6405 }, { 136,6405 }, { 137,6405 }, { 138,6405 },
 { 139,6405 }, { 140,6405 }, { 141,6405 }, { 142,6405 }, { 143,6405 },
 { 144,6405 }, { 145,6405 }, { 146,6405 }, { 147,6405 }, { 148,6405 },
 { 149,6405 }, { 150,6405 }, { 151,6405 }, { 152,6405 }, { 153,6405 },
 { 154,6405 }, { 155,6405 }, { 156,6405 }, { 157,6405 }, { 158,6405 },
 { 159,6405 }, { 160,6405 }, { 161,6405 }, { 162,6405 }, { 163,6405 },
 { 164,6405 }, { 165,6405 }, { 166,6405 }, { 167,6405 }, { 168,6405 },

 { 169,6405 }, { 170,6405 }, { 171,6405 }, { 172,6405 }, { 173,6405 },
 { 174,6405 }, { 175,6405 }, { 176,6405 }, { 177,6405 }, { 178,6405 },
 { 179,6405 }, { 180,6405 }, { 181,6405 }, { 182,6405 }, { 183,6405 },
 { 184,6405 }, { 185,6405 }, { 186,6405 }, { 187,6405 }, { 188,6405 },
 { 189,6405 }, { 190,6405 }, { 191,6405 }, { 192,6405 }, { 193,6405 },
 { 194,6405 }, { 195,6405 }, { 196,6405 }, { 197,6405 }, { 198,6405 },
 { 199,6405 }, { 200,6405 }, { 201,6405 }, { 202,6405 }, { 203,6405 },
 { 204,6405 }, { 205,6405 }, { 206,6405 }, { 207,6405 }, { 208,6405 },
 { 209,6405 }, { 210,6405 }, { 211,6405 }, { 212,6405 }, { 213,6405 },
 { 214,6405 }, { 215,6405 }, { 216,6405 }, { 217,6405 }, { 218,6405 },

 { 219,6405 }, { 220,6405 }, { 221,6405 }, { 222,6405 }, { 223,6405 },
 { 224,6405 }, { 225,6405 }, { 226,6405 }, { 227,6405 }, { 228,6405 },
 { 229,6405 }, { 230,6405 }, { 231,6405 }, { 232,6405 }, { 233,6405 },
 { 234,6405 }, { 235,6405 }, { 236,6405 }, { 237,6405 }, { 238,6405 },
 { 239,6405 }, { 240,6405 }, { 241,6405 }, { 242,6405 }, { 243,6405 },
 { 244,6405 }, { 245,6405 }, { 246,6405 }, { 247,6405 }, { 248,6405 },
 { 249,6405 }, { 250,6405 }, { 251,6405 }, { 252,6405 }, { 253,6405 },
 { 254,6405 }, { 255,6405 }, {   0,  74 }, {   0,17008 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  36,6148 },
 {   0,   0 }, {   0,   0 }, {  39,-1258 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  48,6148 }, {  49,6148 }, {  50,6148 }, {  51,6148 },
 {  52,6148 }, {  53,6148 }, {  54,6148 }, {  55,6148 }, {  56,6148 },
 {  57,6148 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,6148 }, {  66,6148 },
 {  67,6148 }, {  68,6148 }, {  69,6148 }, {  70,6148 }, {  71,6148 },
 {  72,6148 }, {  73,6148 }, {  74,6148 }, {  75,6148 }, {  76,6148 },
 {  77,6148 }, {  78,6148 }, {  79,6148 }, {  80,6148 }, {  81,6148 },
 {  82,6148 }, {  83,6148 }, {  84,6148 }, {  85,6148 }, {  86,6148 },
 {  87,6148 }, {  88,6148 }, {  89,6148 }, {  90,6148 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95,6148 }, {   0,   0 },
 {  97,6148 }, {  98,6148 }, {  99,6148 }, { 100,6148 }, { 101,6148 },
 { 102,6148 }, { 103,6148 }, { 104,6148 }, { 105,6148 }, { 106,6148 },
 { 107,6148 }, { 108,6148 }, { 109,6148 }, { 110,6148 }, { 111,6148 },

 { 112,6148 }, { 113,6148 }, { 114,6148 }, { 115,6148 }, { 116,6148 },
 { 117,6148 }, { 118,6148 }, { 119,6148 }, { 120,6148 }, { 121,6148 },
 { 122,6148 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, { 128,6148 }, { 129,6148 }, { 130,6148 }, { 131,6148 },
 { 132,6148 }, { 133,6148 }, { 134,6148 }, { 135,6148 }, { 136,6148 },
 { 137,6148 }, { 138,6148 }, { 139,6148 }, { 140,6148 }, { 141,6148 },
 { 142,6148 }, { 143,6148 }, { 144,6148 }, { 145,6148 }, { 146,6148 },
 { 147,6148 }, { 148,6148 }, { 149,6148 }, { 150,6148 }, { 151,6148 },
 { 152,6148 }, { 153,6148 }, { 154,6148 }, { 155,6148 }, { 156,6148 },
 { 157,6148 }, { 158,6148 }, { 159,6148 }, { 160,6148 }, { 161,6148 },

 { 162,6148 }, { 163,6148 }, { 164,6148 }, { 165,6148 }, { 166,6148 },
 { 167,6148 }, { 168,6148 }, { 169,6148 }, { 170,6148 }, { 171,6148 },
 { 172,6148 }, { 173,6148 }, { 174,6148 }, { 175,6148 }, { 176,6148 },
 { 177,6148 }, { 178,6148 }, { 179,6148 }, { 180,6148 }, { 181,6148 },
 { 182,6148 }, { 183,6148 }, { 184,6148 }, { 185,6148 }, { 186,6148 },
 { 187,6148 }, { 188,6148 }, { 189,6148 }, { 190,6148 }, { 191,6148 },
 { 192,6148 }, { 193,6148 }, { 194,6148 }, { 195,6148 }, { 196,6148 },
 { 197,6148 }, { 198,6148 }, { 199,6148 }, { 200,6148 }, { 201,6148 },
 { 202,6148 }, { 203,6148 }, { 204,6148 }, { 205,6148 }, { 206,6148 },
 { 207,6148 }, { 208,6148 }, { 209,6148 }, { 210,6148 }, { 211,6148 },

 { 212,6148 }, { 213,6148 }, { 214,6148 }, { 215,6148 }, { 216,6148 },
 { 217,6148 }, { 218,6148 }, { 219,6148 }, { 220,6148 }, { 221,6148 },
 { 222,6148 }, { 223,6148 }, { 224,6148 }, { 225,6148 }, { 226,6148 },
 { 227,6148 }, { 228,6148 }, { 229,6148 }, { 230,6148 }, { 231,6148 },
 { 232,6148 }, { 233,6148 }, { 234,6148 }, { 235,6148 }, { 236,6148 },
 { 237,6148 }, { 238,6148 }, { 239,6148 }, { 240,6148 }, { 241,6148 },
 { 242,6148 }, { 243,6148 }, { 244,6148 }, { 245,6148 }, { 246,6148 },
 { 247,6148 }, { 248,6148 }, { 249,6148 }, { 250,6148 }, { 251,6148 },
 { 252,6148 }, { 253,6148 }, { 254,6148 }, { 255,6148 }, {   0,  74 },
 {   0,16751 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  36,5891 }, {   0,   0 }, {   0,   0 }, {  39,-1513 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,5891 }, {  49,5891 },
 {  50,5891 }, {  51,5891 }, {  52,5891 }, {  53,5891 }, {  54,5891 },

 {  55,5891 }, {  56,5891 }, {  57,5891 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65,5891 }, {  66,5891 }, {  67,5891 }, {  68,5891 }, {  69,5891 },
 {  70,5891 }, {  71,5891 }, {  72,5891 }, {  73,5891 }, {  74,5891 },
 {  75,5891 }, {  76,5891 }, {  77,5891 }, {  78,5891 }, {  79,5891 },
 {  80,5891 }, {  81,5891 }, {  82,5891 }, {  83,5891 }, {  84,5891 },
 {  85,5891 }, {  86,5891 }, {  87,5891 }, {  88,5891 }, {  89,5891 },
 {  90,5891 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  95,5891 }, {   0,   0 }, {  97,5891 }, {  98,5891 }, {  99,5891 },
 { 100,5891 }, { 101,5891 }, { 102,5891 }, { 103,5891 }, { 104,5891 },

 { 105,5891 }, { 106,5891 }, { 107,5891 }, { 108,5891 }, { 109,5891 },
 { 110,5891 }, { 111,5891 }, { 112,5891 }, { 113,5891 }, { 114,5891 },
 { 115,5891 }, { 116,5891 }, { 117,5891 }, { 118,5891 }, { 119,5891 },
 { 120,5891 }, { 121,5891 }, { 122,5891 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,5891 }, { 129,5891 },
 { 130,5891 }, { 131,5891 }, { 132,5891 }, { 133,5891 }, { 134,5891 },
 { 135,5891 }, { 136,5891 }, { 137,5891 }, { 138,5891 }, { 139,5891 },
 { 140,5891 }, { 141,5891 }, { 142,5891 }, { 143,5891 }, { 144,5891 },
 { 145,5891 }, { 146,5891 }, { 147,5891 }, { 148,5891 }, { 149,5891 },
 { 150,5891 }, { 151,5891 }, { 152,5891 }, { 153,5891 }, { 154,5891 },

 { 155,5891 }, { 156,5891 }, { 157,5891 }, { 158,5891 }, { 159,5891 },
 { 160,5891 }, { 161,5891 }, { 162,5891 }, { 163,5891 }, { 164,5891 },
 { 165,5891 }, { 166,5891 }, { 167,5891 }, { 168,5891 }, { 169,5891 },
 { 170,5891 }, { 171,5891 }, { 172,5891 }, { 173,5891 }, { 174,5891 },
 { 175,5891 }, { 176,5891 }, { 177,5891 }, { 178,5891 }, { 179,5891 },
 { 180,5891 }, { 181,5891 }, { 182,5891 }, { 183,5891 }, { 184,5891 },
 { 185,5891 }, { 186,5891 }, { 187,5891 }, { 188,5891 }, { 189,5891 },
 { 190,5891 }, { 191,5891 }, { 192,5891 }, { 193,5891 }, { 194,5891 },
 { 195,5891 }, { 196,5891 }, { 197,5891 }, { 198,5891 }, { 199,5891 },
 { 200,5891 }, { 201,5891 }, { 202,5891 }, { 203,5891 }, { 204,5891 },

 { 205,5891 }, { 206,5891 }, { 207,5891 }, { 208,5891 }, { 209,5891 },
 { 210,5891 }, { 211,5891 }, { 212,5891 }, { 213,5891 }, { 214,5891 },
 { 215,5891 }, { 216,5891 }, { 217,5891 }, { 218,5891 }, { 219,5891 },
 { 220,5891 }, { 221,5891 }, { 222,5891 }, { 223,5891 }, { 224,5891 },
 { 225,5891 }, { 226,5891 }, { 227,5891 }, { 228,5891 }, { 229,5891 },
 { 230,5891 }, { 231,5891 }, { 232,5891 }, { 233,5891 }, { 234,5891 },
 { 235,5891 }, { 236,5891 }, { 237,5891 }, { 238,5891 }, { 239,5891 },
 { 240,5891 }, { 241,5891 }, { 242,5891 }, { 243,5891 }, { 244,5891 },
 { 245,5891 }, { 246,5891 }, { 247,5891 }, { 248,5891 }, { 249,5891 },
 { 250,5891 }, { 251,5891 }, { 252,5891 }, { 253,5891 }, { 254,5891 },

 { 255,5891 }, {   0,  74 }, {   0,16494 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  36,5634 }, {   0,   0 },
 {  38,-1767 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {  48,5634 }, {  49,5634 }, {  50,5634 }, {  51,5634 }, {  52,5634 },
 {  53,5634 }, {  54,5634 }, {  55,5634 }, {  56,5634 }, {  57,5634 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  65,5634 }, {  66,5634 }, {  67,5634 },
 {  68,5634 }, {  69,5634 }, {  70,5634 }, {  71,5634 }, {  72,5634 },
 {  73,5634 }, {  74,5634 }, {  75,5634 }, {  76,5634 }, {  77,5634 },
 {  78,5634 }, {  79,5634 }, {  80,5634 }, {  81,5634 }, {  82,5634 },
 {  83,5634 }, {  84,5634 }, {  85,5634 }, {  86,5634 }, {  87,5634 },
 {  88,5634 }, {  89,5634 }, {  90,5634 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  95,5634 }, {   0,   0 }, {  97,5634 },

 {  98,5634 }, {  99,5634 }, { 100,5634 }, { 101,5634 }, { 102,5634 },
 { 103,5634 }, { 104,5634 }, { 105,5634 }, { 106,5634 }, { 107,5634 },
 { 108,5634 }, { 109,5634 }, { 110,5634 }, { 111,5634 }, { 112,5634 },
 { 113,5634 }, { 114,5634 }, { 115,5634 }, { 116,5634 }, { 117,5634 },
 { 118,5634 }, { 119,5634 }, { 120,5634 }, { 121,5634 }, { 122,5634 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 { 128,5634 }, { 129,5634 }, { 130,5634 }, { 131,5634 }, { 132,5634 },
 { 133,5634 }, { 134,5634 }, { 135,5634 }, { 136,5634 }, { 137,5634 },
 { 138,5634 }, { 139,5634 }, { 140,5634 }, { 141,5634 }, { 142,5634 },
 { 143,5634 }, { 144,5634 }, { 145,5634 }, { 146,5634 }, { 147,5634 },

 { 148,5634 }, { 149,5634 }, { 150,5634 }, { 151,5634 }, { 152,5634 },
 { 153,5634 }, { 154,5634 }, { 155,5634 }, { 156,5634 }, { 157,5634 },
 { 158,5634 }, { 159,5634 }, { 160,5634 }, { 161,5634 }, { 162,5634 },
 { 163,5634 }, { 164,5634 }, { 165,5634 }, { 166,5634 }, { 167,5634 },
 { 168,5634 }, { 169,5634 }, { 170,5634 }, { 171,5634 }, { 172,5634 },
 { 173,5634 }, { 174,5634 }, { 175,5634 }, { 176,5634 }, { 177,5634 },
 { 178,5634 }, { 179,5634 }, { 180,5634 }, { 181,5634 }, { 182,5634 },
 { 183,5634 }, { 184,5634 }, { 185,5634 }, { 186,5634 }, { 187,5634 },
 { 188,5634 }, { 189,5634 }, { 190,5634 }, { 191,5634 }, { 192,5634 },
 { 193,5634 }, { 194,5634 }, { 195,5634 }, { 196,5634 }, { 197,5634 },

 { 198,5634 }, { 199,5634 }, { 200,5634 }, { 201,5634 }, { 202,5634 },
 { 203,5634 }, { 204,5634 }, { 205,5634 }, { 206,5634 }, { 207,5634 },
 { 208,5634 }, { 209,5634 }, { 210,5634 }, { 211,5634 }, { 212,5634 },
 { 213,5634 }, { 214,5634 }, { 215,5634 }, { 216,5634 }, { 217,5634 },
 { 218,5634 }, { 219,5634 }, { 220,5634 }, { 221,5634 }, { 222,5634 },
 { 223,5634 }, { 224,5634 }, { 225,5634 }, { 226,5634 }, { 227,5634 },
 { 228,5634 }, { 229,5634 }, { 230,5634 }, { 231,5634 }, { 232,5634 },
 { 233,5634 }, { 234,5634 }, { 235,5634 }, { 236,5634 }, { 237,5634 },
 { 238,5634 }, { 239,5634 }, { 240,5634 }, { 241,5634 }, { 242,5634 },
 { 243,5634 }, { 244,5634 }, { 245,5634 }, { 246,5634 }, { 247,5634 },

 { 248,5634 }, { 249,5634 }, { 250,5634 }, { 251,5634 }, { 252,5634 },
 { 253,5634 }, { 254,5634 }, { 255,5634 }, {   0,  74 }, {   0,16237 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  36,5377 }, {   0,   0 }, {   0,   0 }, {  39,-2022 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  48,5377 }, {  49,5377 }, {  50,5377 },
 {  51,5377 }, {  52,5377 }, {  53,5377 }, {  54,5377 }, {  55,5377 },
 {  56,5377 }, {  57,5377 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,5377 },
 {  66,5377 }, {  67,5377 }, {  68,5377 }, {  69,5377 }, {  70,5377 },
 {  71,5377 }, {  72,5377 }, {  73,5377 }, {  74,5377 }, {  75,5377 },
 {  76,5377 }, {  77,5377 }, {  78,5377 }, {  79,5377 }, {  80,5377 },
 {  81,5377 }, {  82,5377 }, {  83,5377 }, {  84,5377 }, {  85,5377 },
 {  86,5377 }, {  87,5377 }, {  88,5377 }, {  89,5377 }, {  90,5377 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95,5377 },
 {   0,   0 }, {  97,5377 }, {  98,5377 }, {  99,5377 }, { 100,5377 },
 { 101,5377 }, { 102,5377 }, { 103,5377 }, { 104,5377 }, { 105,5377 },
 { 106,5377 }, { 107,5377 }, { 108,5377 }, { 109,5377 }, { 110,5377 },
 { 111,5377 }, { 112,5377 }, { 113,5377 }, { 114,5377 }, { 115,5377 },
 { 116,5377 }, { 117,5377 }, { 118,5377 }, { 119,5377 }, { 120,5377 },
 { 121,5377 }, { 122,5377 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, { 128,5377 }, { 129,5377 }, { 130,5377 },
 { 131,5377 }, { 132,5377 }, { 133,5377 }, { 134,5377 }, { 135,5377 },
 { 136,5377 }, { 137,5377 }, { 138,5377 }, { 139,5377 }, { 140,5377 },

 { 141,5377 }, { 142,5377 }, { 143,5377 }, { 144,5377 }, { 145,5377 },
 { 146,5377 }, { 147,5377 }, { 148,5377 }, { 149,5377 }, { 150,5377 },
 { 151,5377 }, { 152,5377 }, { 153,5377 }, { 154,5377 }, { 155,5377 },
 { 156,5377 }, { 157,5377 }, { 158,5377 }, { 159,5377 }, { 160,5377 },
 { 161,5377 }, { 162,5377 }, { 163,5377 }, { 164,5377 }, { 165,5377 },
 { 166,5377 }, { 167,5377 }, { 168,5377 }, { 169,5377 }, { 170,5377 },
 { 171,5377 }, { 172,5377 }, { 173,5377 }, { 174,5377 }, { 175,5377 },
 { 176,5377 }, { 177,5377 }, { 178,5377 }, { 179,5377 }, { 180,5377 },
 { 181,5377 }, { 182,5377 }, { 183,5377 }, { 184,5377 }, { 185,5377 },
 { 186,5377 }, { 187,5377 }, { 188,5377 }, { 189,5377 }, { 190,5377 },

 { 191,5377 }, { 192,5377 }, { 193,5377 }, { 194,5377 }, { 195,5377 },
 { 196,5377 }, { 197,5377 }, { 198,5377 }, { 199,5377 }, { 200,5377 },
 { 201,5377 }, { 202,5377 }, { 203,5377 }, { 204,5377 }, { 205,5377 },
 { 206,5377 }, { 207,5377 }, { 208,5377 }, { 209,5377 }, { 210,5377 },
 { 211,5377 }, { 212,5377 }, { 213,5377 }, { 214,5377 }, { 215,5377 },
 { 216,5377 }, { 217,5377 }, { 218,5377 }, { 219,5377 }, { 220,5377 },
 { 221,5377 }, { 222,5377 }, { 223,5377 }, { 224,5377 }, { 225,5377 },
 { 226,5377 }, { 227,5377 }, { 228,5377 }, { 229,5377 }, { 230,5377 },
 { 231,5377 }, { 232,5377 }, { 233,5377 }, { 234,5377 }, { 235,5377 },
 { 236,5377 }, { 237,5377 }, { 238,5377 }, { 239,5377 }, { 240,5377 },

 { 241,5377 }, { 242,5377 }, { 243,5377 }, { 244,5377 }, { 245,5377 },
 { 246,5377 }, { 247,5377 }, { 248,5377 }, { 249,5377 }, { 250,5377 },
 { 251,5377 }, { 252,5377 }, { 253,5377 }, { 254,5377 }, { 255,5377 },
 {   0,  10 }, {   0,15980 }, {   1,5377 }, {   2,5377 }, {   3,5377 },
 {   4,5377 }, {   5,5377 }, {   6,5377 }, {   7,5377 }, {   8,5377 },
 {   9,5377 }, {  10,5377 }, {  11,5377 }, {  12,5377 }, {  13,5377 },
 {  14,5377 }, {  15,5377 }, {  16,5377 }, {  17,5377 }, {  18,5377 },
 {  19,5377 }, {  20,5377 }, {  21,5377 }, {  22,5377 }, {  23,5377 },
 {  24,5377 }, {  25,5377 }, {  26,5377 }, {  27,5377 }, {  28,5377 },
 {  29,5377 }, {  30,5377 }, {  31,5377 }, {  32,5377 }, {  33,5377 },

 {  34,5377 }, {  35,5377 }, {  36,5377 }, {  37,5377 }, {  38,5377 },
 {   0,   0 }, {  40,5377 }, {  41,5377 }, {  42,5377 }, {  43,5377 },
 {  44,5377 }, {  45,5377 }, {  46,5377 }, {  47,5377 }, {  48,5377 },
 {  49,5377 }, {  50,5377 }, {  51,5377 }, {  52,5377 }, {  53,5377 },
 {  54,5377 }, {  55,5377 }, {  56,5377 }, {  57,5377 }, {  58,5377 },
 {  59,5377 }, {  60,5377 }, {  61,5377 }, {  62,5377 }, {  63,5377 },
 {  64,5377 }, {  65,5377 }, {  66,5377 }, {  67,5377 }, {  68,5377 },
 {  69,5377 }, {  70,5377 }, {  71,5377 }, {  72,5377 }, {  73,5377 },
 {  74,5377 }, {  75,5377 }, {  76,5377 }, {  77,5377 }, {  78,5377 },
 {  79,5377 }, {  80,5377 }, {  81,5377 }, {  82,5377 }, {  83,5377 },

 {  84,5377 }, {  85,5377 }, {  86,5377 }, {  87,5377 }, {  88,5377 },
 {  89,5377 }, {  90,5377 }, {  91,5377 }, {  92,5377 }, {  93,5377 },
 {  94,5377 }, {  95,5377 }, {  96,5377 }, {  97,5377 }, {  98,5377 },
 {  99,5377 }, { 100,5377 }, { 101,5377 }, { 102,5377 }, { 103,5377 },
 { 104,5377 }, { 105,5377 }, { 106,5377 }, { 107,5377 }, { 108,5377 },
 { 109,5377 }, { 110,5377 }, { 111,5377 }, { 112,5377 }, { 113,5377 },
 { 114,5377 }, { 115,5377 }, { 116,5377 }, { 117,5377 }, { 118,5377 },
 { 119,5377 }, { 120,5377 }, { 121,5377 }, { 122,5377 }, { 123,5377 },
 { 124,5377 }, { 125,5377 }, { 126,5377 }, { 127,5377 }, { 128,5377 },
 { 129,5377 }, { 130,5377 }, { 131,5377 }, { 132,5377 }, { 133,5377 },

 { 134,5377 }, { 135,5377 }, { 136,5377 }, { 137,5377 }, { 138,5377 },
 { 139,5377 }, { 140,5377 }, { 141,5377 }, { 142,5377 }, { 143,5377 },
 { 144,5377 }, { 145,5377 }, { 146,5377 }, { 147,5377 }, { 148,5377 },
 { 149,5377 }, { 150,5377 }, { 151,5377 }, { 152,5377 }, { 153,5377 },
 { 154,5377 }, { 155,5377 }, { 156,5377 }, { 157,5377 }, { 158,5377 },
 { 159,5377 }, { 160,5377 }, { 161,5377 }, { 162,5377 }, { 163,5377 },
 { 164,5377 }, { 165,5377 }, { 166,5377 }, { 167,5377 }, { 168,5377 },
 { 169,5377 }, { 170,5377 }, { 171,5377 }, { 172,5377 }, { 173,5377 },
 { 174,5377 }, { 175,5377 }, { 176,5377 }, { 177,5377 }, { 178,5377 },
 { 179,5377 }, { 180,5377 }, { 181,5377 }, { 182,5377 }, { 183,5377 },

 { 184,5377 }, { 185,5377 }, { 186,5377 }, { 187,5377 }, { 188,5377 },
 { 189,5377 }, { 190,5377 }, { 191,5377 }, { 192,5377 }, { 193,5377 },
 { 194,5377 }, { 195,5377 }, { 196,5377 }, { 197,5377 }, { 198,5377 },
 { 199,5377 }, { 200,5377 }, { 201,5377 }, { 202,5377 }, { 203,5377 },
 { 204,5377 }, { 205,5377 }, { 206,5377 }, { 207,5377 }, { 208,5377 },
 { 209,5377 }, { 210,5377 }, { 211,5377 }, { 212,5377 }, { 213,5377 },
 { 214,5377 }, { 215,5377 }, { 216,5377 }, { 217,5377 }, { 218,5377 },
 { 219,5377 }, { 220,5377 }, { 221,5377 }, { 222,5377 }, { 223,5377 },
 { 224,5377 }, { 225,5377 }, { 226,5377 }, { 227,5377 }, { 228,5377 },
 { 229,5377 }, { 230,5377 }, { 231,5377 }, { 232,5377 }, { 233,5377 },

 { 234,5377 }, { 235,5377 }, { 236,5377 }, { 237,5377 }, { 238,5377 },
 { 239,5377 }, { 240,5377 }, { 241,5377 }, { 242,5377 }, { 243,5377 },
 { 244,5377 }, { 245,5377 }, { 246,5377 }, { 247,5377 }, { 248,5377 },
 { 249,5377 }, { 250,5377 }, { 251,5377 }, { 252,5377 }, { 253,5377 },
 { 254,5377 }, { 255,5377 }, { 256,5377 }, {   0,   5 }, {   0,15722 },
 {   1,5377 }, {   2,5377 }, {   3,5377 }, {   4,5377 }, {   5,5377 },
 {   6,5377 }, {   7,5377 }, {   8,5377 }, {   9,5377 }, {  10,5377 },
 {  11,5377 }, {  12,5377 }, {  13,5377 }, {  14,5377 }, {  15,5377 },
 {  16,5377 }, {  17,5377 }, {  18,5377 }, {  19,5377 }, {  20,5377 },
 {  21,5377 }, {  22,5377 }, {  23,5377 }, {  24,5377 }, {  25,5377 },

 {  26,5377 }, {  27,5377 }, {  28,5377 }, {  29,5377 }, {  30,5377 },
 {  31,5377 }, {  32,5377 }, {  33,5377 }, {  34,5377 }, {  35,5377 },
 {  36,5377 }, {  37,5377 }, {  38,5377 }, {  39,5377 }, {  40,5377 },
 {  41,5377 }, {   0,   0 }, {  43,5377 }, {  44,5377 }, {  45,5377 },
 {  46,5377 }, {   0,   0 }, {  48,5377 }, {  49,5377 }, {  50,5377 },
 {  51,5377 }, {  52,5377 }, {  53,5377 }, {  54,5377 }, {  55,5377 },
 {  56,5377 }, {  57,5377 }, {  58,5377 }, {  59,5377 }, {  60,5377 },
 {  61,5377 }, {  62,5377 }, {  63,5377 }, {  64,5377 }, {  65,5377 },
 {  66,5377 }, {  67,5377 }, {  68,5377 }, {  69,5377 }, {  70,5377 },
 {  71,5377 }, {  72,5377 }, {  73,5377 }, {  74,5377 }, {  75,5377 },

 {  76,5377 }, {  77,5377 }, {  78,5377 }, {  79,5377 }, {  80,5377 },
 {  81,5377 }, {  82,5377 }, {  83,5377 }, {  84,5377 }, {  85,5377 },
 {  86,5377 }, {  87,5377 }, {  88,5377 }, {  89,5377 }, {  90,5377 },
 {  91,5377 }, {  92,5377 }, {  93,5377 }, {  94,5377 }, {  95,5377 },
 {  96,5377 }, {  97,5377 }, {  98,5377 }, {  99,5377 }, { 100,5377 },
 { 101,5377 }, { 102,5377 }, { 103,5377 }, { 104,5377 }, { 105,5377 },
 { 106,5377 }, { 107,5377 }, { 108,5377 }, { 109,5377 }, { 110,5377 },
 { 111,5377 }, { 112,5377 }, { 113,5377 }, { 114,5377 }, { 115,5377 },
 { 116,5377 }, { 117,5377 }, { 118,5377 }, { 119,5377 }, { 120,5377 },
 { 121,5377 }, { 122,5377 }, { 123,5377 }, { 124,5377 }, { 125,5377 },

 { 126,5377 }, { 127,5377 }, { 128,5377 }, { 129,5377 }, { 130,5377 },
 { 131,5377 }, { 132,5377 }, { 133,5377 }, { 134,5377 }, { 135,5377 },
 { 136,5377 }, { 137,5377 }, { 138,5377 }, { 139,5377 }, { 140,5377 },
 { 141,5377 }, { 142,5377 }, { 143,5377 }, { 144,5377 }, { 145,5377 },
 { 146,5377 }, { 147,5377 }, { 148,5377 }, { 149,5377 }, { 150,5377 },
 { 151,5377 }, { 152,5377 }, { 153,5377 }, { 154,5377 }, { 155,5377 },
 { 156,5377 }, { 157,5377 }, { 158,5377 }, { 159,5377 }, { 160,5377 },
 { 161,5377 }, { 162,5377 }, { 163,5377 }, { 164,5377 }, { 165,5377 },
 { 166,5377 }, { 167,5377 }, { 168,5377 }, { 169,5377 }, { 170,5377 },
 { 171,5377 }, { 172,5377 }, { 173,5377 }, { 174,5377 }, { 175,5377 },

 { 176,5377 }, { 177,5377 }, { 178,5377 }, { 179,5377 }, { 180,5377 },
 { 181,5377 }, { 182,5377 }, { 183,5377 }, { 184,5377 }, { 185,5377 },
 { 186,5377 }, { 187,5377 }, { 188,5377 }, { 189,5377 }, { 190,5377 },
 { 191,5377 }, { 192,5377 }, { 193,5377 }, { 194,5377 }, { 195,5377 },
 { 196,5377 }, { 197,5377 }, { 198,5377 }, { 199,5377 }, { 200,5377 },
 { 201,5377 }, { 202,5377 }, { 203,5377 }, { 204,5377 }, { 205,5377 },
 { 206,5377 }, { 207,5377 }, { 208,5377 }, { 209,5377 }, { 210,5377 },
 { 211,5377 }, { 212,5377 }, { 213,5377 }, { 214,5377 }, { 215,5377 },
 { 216,5377 }, { 217,5377 }, { 218,5377 }, { 219,5377 }, { 220,5377 },
 { 221,5377 }, { 222,5377 }, { 223,5377 }, { 224,5377 }, { 225,5377 },

 { 226,5377 }, { 227,5377 }, { 228,5377 }, { 229,5377 }, { 230,5377 },
 { 231,5377 }, { 232,5377 }, { 233,5377 }, { 234,5377 }, { 235,5377 },
 { 236,5377 }, { 237,5377 }, { 238,5377 }, { 239,5377 }, { 240,5377 },
 { 241,5377 }, { 242,5377 }, { 243,5377 }, { 244,5377 }, { 245,5377 },
 { 246,5377 }, { 247,5377 }, { 248,5377 }, { 249,5377 }, { 250,5377 },
 { 251,5377 }, { 252,5377 }, { 253,5377 }, { 254,5377 }, { 255,5377 },
 { 256,5377 }, {   0,   5 }, {   0,15464 }, {   1,5119 }, {   2,5119 },
 {   3,5119 }, {   4,5119 }, {   5,5119 }, {   6,5119 }, {   7,5119 },
 {   8,5119 }, {   9,5119 }, {  10,5119 }, {  11,5119 }, {  12,5119 },
 {  13,5119 }, {  14,5119 }, {  15,5119 }, {  16,5119 }, {  17,5119 },

 {  18,5119 }, {  19,5119 }, {  20,5119 }, {  21,5119 }, {  22,5119 },
 {  23,5119 }, {  24,5119 }, {  25,5119 }, {  26,5119 }, {  27,5119 },
 {  28,5119 }, {  29,5119 }, {  30,5119 }, {  31,5119 }, {  32,5119 },
 {  33,5119 }, {  34,5119 }, {  35,5119 }, {  36,5119 }, {  37,5119 },
 {  38,5119 }, {  39,5119 }, {  40,5119 }, {  41,5119 }, {   0,   0 },
 {  43,5119 }, {  44,5119 }, {  45,5119 }, {  46,5119 }, {   0,   0 },
 {  48,5119 }, {  49,5119 }, {  50,5119 }, {  51,5119 }, {  52,5119 },
 {  53,5119 }, {  54,5119 }, {  55,5119 }, {  56,5119 }, {  57,5119 },
 {  58,5119 }, {  59,5119 }, {  60,5119 }, {  61,5119 }, {  62,5119 },
 {  63,5119 }, {  64,5119 }, {  65,5119 }, {  66,5119 }, {  67,5119 },

 {  68,5119 }, {  69,5119 }, {  70,5119 }, {  71,5119 }, {  72,5119 },
 {  73,5119 }, {  74,5119 }, {  75,5119 }, {  76,5119 }, {  77,5119 },
 {  78,5119 }, {  79,5119 }, {  80,5119 }, {  81,5119 }, {  82,5119 },
 {  83,5119 }, {  84,5119 }, {  85,5119 }, {  86,5119 }, {  87,5119 },
 {  88,5119 }, {  89,5119 }, {  90,5119 }, {  91,5119 }, {  92,5119 },
 {  93,5119 }, {  94,5119 }, {  95,5119 }, {  96,5119 }, {  97,5119 },
 {  98,5119 }, {  99,5119 }, { 100,5119 }, { 101,5119 }, { 102,5119 },
 { 103,5119 }, { 104,5119 }, { 105,5119 }, { 106,5119 }, { 107,5119 },
 { 108,5119 }, { 109,5119 }, { 110,5119 }, { 111,5119 }, { 112,5119 },
 { 113,5119 }, { 114,5119 }, { 115,5119 }, { 116,5119 }, { 117,5119 },

 { 118,5119 }, { 119,5119 }, { 120,5119 }, { 121,5119 }, { 122,5119 },
 { 123,5119 }, { 124,5119 }, { 125,5119 }, { 126,5119 }, { 127,5119 },
 { 128,5119 }, { 129,5119 }, { 130,5119 }, { 131,5119 }, { 132,5119 },
 { 133,5119 }, { 134,5119 }, { 135,5119 }, { 136,5119 }, { 137,5119 },
 { 138,5119 }, { 139,5119 }, { 140,5119 }, { 141,5119 }, { 142,5119 },
 { 143,5119 }, { 144,5119 }, { 145,5119 }, { 146,5119 }, { 147,5119 },
 { 148,5119 }, { 149,5119 }, { 150,5119 }, { 151,5119 }, { 152,5119 },
 { 153,5119 }, { 154,5119 }, { 155,5119 }, { 156,5119 }, { 157,5119 },
 { 158,5119 }, { 159,5119 }, { 160,5119 }, { 161,5119 }, { 162,5119 },
 { 163,5119 }, { 164,5119 }, { 165,5119 }, { 166,5119 }, { 167,5119 },

 { 168,5119 }, { 169,5119 }, { 170,5119 }, { 171,5119 }, { 172,5119 },
 { 173,5119 }, { 174,5119 }, { 175,5119 }, { 176,5119 }, { 177,5119 },
 { 178,5119 }, { 179,5119 }, { 180,5119 }, { 181,5119 }, { 182,5119 },
 { 183,5119 }, { 184,5119 }, { 185,5119 }, { 186,5119 }, { 187,5119 },
 { 188,5119 }, { 189,5119 }, { 190,5119 }, { 191,5119 }, { 192,5119 },
 { 193,5119 }, { 194,5119 }, { 195,5119 }, { 196,5119 }, { 197,5119 },
 { 198,5119 }, { 199,5119 }, { 200,5119 }, { 201,5119 }, { 202,5119 },
 { 203,5119 }, { 204,5119 }, { 205,5119 }, { 206,5119 }, { 207,5119 },
 { 208,5119 }, { 209,5119 }, { 210,5119 }, { 211,5119 }, { 212,5119 },
 { 213,5119 }, { 214,5119 }, { 215,5119 }, { 216,5119 }, { 217,5119 },

 { 218,5119 }, { 219,5119 }, { 220,5119 }, { 221,5119 }, { 222,5119 },
 { 223,5119 }, { 224,5119 }, { 225,5119 }, { 226,5119 }, { 227,5119 },
 { 228,5119 }, { 229,5119 }, { 230,5119 }, { 231,5119 }, { 232,5119 },
 { 233,5119 }, { 234,5119 }, { 235,5119 }, { 236,5119 }, { 237,5119 },
 { 238,5119 }, { 239,5119 }, { 240,5119 }, { 241,5119 }, { 242,5119 },
 { 243,5119 }, { 244,5119 }, { 245,5119 }, { 246,5119 }, { 247,5119 },
 { 248,5119 }, { 249,5119 }, { 250,5119 }, { 251,5119 }, { 252,5119 },
 { 253,5119 }, { 254,5119 }, { 255,5119 }, { 256,5119 }, {   0,  43 },
 {   0,15206 }, {   1,5247 }, {   2,5247 }, {   3,5247 }, {   4,5247 },
 {   5,5247 }, {   6,5247 }, {   7,5247 }, {   8,5247 }, {   9,5247 },

 {  10,5247 }, {  11,5247 }, {  12,5247 }, {  13,5247 }, {  14,5247 },
 {  15,5247 }, {  16,5247 }, {  17,5247 }, {  18,5247 }, {  19,5247 },
 {  20,5247 }, {  21,5247 }, {  22,5247 }, {  23,5247 }, {  24,5247 },
 {  25,5247 }, {  26,5247 }, {  27,5247 }, {  28,5247 }, {  29,5247 },
 {  30,5247 }, {  31,5247 }, {  32,5247 }, {  33,5247 }, {   0,   0 },
 {  35,5247 }, {  36,5247 }, {  37,5247 }, {  38,5247 }, {  39,5247 },
 {  40,5247 }, {  41,5247 }, {  42,5247 }, {  43,5247 }, {  44,5247 },
 {  45,5247 }, {  46,5247 }, {  47,5247 }, {  48,5247 }, {  49,5247 },
 {  50,5247 }, {  51,5247 }, {  52,5247 }, {  53,5247 }, {  54,5247 },
 {  55,5247 }, {  56,5247 }, {  57,5247 }, {  58,5247 }, {  59,5247 },

 {  60,5247 }, {  61,5247 }, {  62,5247 }, {  63,5247 }, {  64,5247 },
 {  65,5247 }, {  66,5247 }, {  67,5247 }, {  68,5247 }, {  69,5247 },
 {  70,5247 }, {  71,5247 }, {  72,5247 }, {  73,5247 }, {  74,5247 },
 {  75,5247 }, {  76,5247 }, {  77,5247 }, {  78,5247 }, {  79,5247 },
 {  80,5247 }, {  81,5247 }, {  82,5247 }, {  83,5247 }, {  84,5247 },
 {  85,5247 }, {  86,5247 }, {  87,5247 }, {  88,5247 }, {  89,5247 },
 {  90,5247 }, {  91,5247 }, {  92,5247 }, {  93,5247 }, {  94,5247 },
 {  95,5247 }, {  96,5247 }, {  97,5247 }, {  98,5247 }, {  99,5247 },
 { 100,5247 }, { 101,5247 }, { 102,5247 }, { 103,5247 }, { 104,5247 },
 { 105,5247 }, { 106,5247 }, { 107,5247 }, { 108,5247 }, { 109,5247 },

 { 110,5247 }, { 111,5247 }, { 112,5247 }, { 113,5247 }, { 114,5247 },
 { 115,5247 }, { 116,5247 }, { 117,5247 }, { 118,5247 }, { 119,5247 },
 { 120,5247 }, { 121,5247 }, { 122,5247 }, { 123,5247 }, { 124,5247 },
 { 125,5247 }, { 126,5247 }, { 127,5247 }, { 128,5247 }, { 129,5247 },
 { 130,5247 }, { 131,5247 }, { 132,5247 }, { 133,5247 }, { 134,5247 },
 { 135,5247 }, { 136,5247 }, { 137,5247 }, { 138,5247 }, { 139,5247 },
 { 140,5247 }, { 141,5247 }, { 142,5247 }, { 143,5247 }, { 144,5247 },
 { 145,5247 }, { 146,5247 }, { 147,5247 }, { 148,5247 }, { 149,5247 },
 { 150,5247 }, { 151,5247 }, { 152,5247 }, { 153,5247 }, { 154,5247 },
 { 155,5247 }, { 156,5247 }, { 157,5247 }, { 158,5247 }, { 159,5247 },

 { 160,5247 }, { 161,5247 }, { 162,5247 }, { 163,5247 }, { 164,5247 },
 { 165,5247 }, { 166,5247 }, { 167,5247 }, { 168,5247 }, { 169,5247 },
 { 170,5247 }, { 171,5247 }, { 172,5247 }, { 173,5247 }, { 174,5247 },
 { 175,5247 }, { 176,5247 }, { 177,5247 }, { 178,5247 }, { 179,5247 },
 { 180,5247 }, { 181,5247 }, { 182,5247 }, { 183,5247 }, { 184,5247 },
 { 185,5247 }, { 186,5247 }, { 187,5247 }, { 188,5247 }, { 189,5247 },
 { 190,5247 }, { 191,5247 }, { 192,5247 }, { 193,5247 }, { 194,5247 },
 { 195,5247 }, { 196,5247 }, { 197,5247 }, { 198,5247 }, { 199,5247 },
 { 200,5247 }, { 201,5247 }, { 202,5247 }, { 203,5247 }, { 204,5247 },
 { 205,5247 }, { 206,5247 }, { 207,5247 }, { 208,5247 }, { 209,5247 },

 { 210,5247 }, { 211,5247 }, { 212,5247 }, { 213,5247 }, { 214,5247 },
 { 215,5247 }, { 216,5247 }, { 217,5247 }, { 218,5247 }, { 219,5247 },
 { 220,5247 }, { 221,5247 }, { 222,5247 }, { 223,5247 }, { 224,5247 },
 { 225,5247 }, { 226,5247 }, { 227,5247 }, { 228,5247 }, { 229,5247 },
 { 230,5247 }, { 231,5247 }, { 232,5247 }, { 233,5247 }, { 234,5247 },
 { 235,5247 }, { 236,5247 }, { 237,5247 }, { 238,5247 }, { 239,5247 },
 { 240,5247 }, { 241,5247 }, { 242,5247 }, { 243,5247 }, { 244,5247 },
 { 245,5247 }, { 246,5247 }, { 247,5247 }, { 248,5247 }, { 249,5247 },
 { 250,5247 }, { 251,5247 }, { 252,5247 }, { 253,5247 }, { 254,5247 },
 { 255,5247 }, { 256,5247 }, {   0,   9 }, {   0,14948 }, {   1,5247 },

 {   2,5247 }, {   3,5247 }, {   4,5247 }, {   5,5247 }, {   6,5247 },
 {   7,5247 }, {   8,5247 }, {   9,5247 }, {  10,5247 }, {  11,5247 },
 {  12,5247 }, {  13,5247 }, {  14,5247 }, {  15,5247 }, {  16,5247 },
 {  17,5247 }, {  18,5247 }, {  19,5247 }, {  20,5247 }, {  21,5247 },
 {  22,5247 }, {  23,5247 }, {  24,5247 }, {  25,5247 }, {  26,5247 },
 {  27,5247 }, {  28,5247 }, {  29,5247 }, {  30,5247 }, {  31,5247 },
 {  32,5247 }, {  33,5247 }, {  34,5247 }, {  35,5247 }, {  36,5247 },
 {  37,5247 }, {  38,5247 }, {   0,   0 }, {  40,5247 }, {  41,5247 },
 {  42,5247 }, {  43,5247 }, {  44,5247 }, {  45,5247 }, {  46,5247 },
 {  47,5247 }, {  48,5247 }, {  49,5247 }, {  50,5247 }, {  51,5247 },

 {  52,5247 }, {  53,5247 }, {  54,5247 }, {  55,5247 }, {  56,5247 },
 {  57,5247 }, {  58,5247 }, {  59,5247 }, {  60,5247 }, {  61,5247 },
 {  62,5247 }, {  63,5247 }, {  64,5247 }, {  65,5247 }, {  66,5247 },
 {  67,5247 }, {  68,5247 }, {  69,5247 }, {  70,5247 }, {  71,5247 },
 {  72,5247 }, {  73,5247 }, {  74,5247 }, {  75,5247 }, {  76,5247 },
 {  77,5247 }, {  78,5247 }, {  79,5247 }, {  80,5247 }, {  81,5247 },
 {  82,5247 }, {  83,5247 }, {  84,5247 }, {  85,5247 }, {  86,5247 },
 {  87,5247 }, {  88,5247 }, {  89,5247 }, {  90,5247 }, {  91,5247 },
 {  92,5247 }, {  93,5247 }, {  94,5247 }, {  95,5247 }, {  96,5247 },
 {  97,5247 }, {  98,5247 }, {  99,5247 }, { 100,5247 }, { 101,5247 },

 { 102,5247 }, { 103,5247 }, { 104,5247 }, { 105,5247 }, { 106,5247 },
 { 107,5247 }, { 108,5247 }, { 109,5247 }, { 110,5247 }, { 111,5247 },
 { 112,5247 }, { 113,5247 }, { 114,5247 }, { 115,5247 }, { 116,5247 },
 { 117,5247 }, { 118,5247 }, { 119,5247 }, { 120,5247 }, { 121,5247 },
 { 122,5247 }, { 123,5247 }, { 124,5247 }, { 125,5247 }, { 126,5247 },
 { 127,5247 }, { 128,5247 }, { 129,5247 }, { 130,5247 }, { 131,5247 },
 { 132,5247 }, { 133,5247 }, { 134,5247 }, { 135,5247 }, { 136,5247 },
 { 137,5247 }, { 138,5247 }, { 139,5247 }, { 140,5247 }, { 141,5247 },
 { 142,5247 }, { 143,5247 }, { 144,5247 }, { 145,5247 }, { 146,5247 },
 { 147,5247 }, { 148,5247 }, { 149,5247 }, { 150,5247 }, { 151,5247 },

 { 152,5247 }, { 153,5247 }, { 154,5247 }, { 155,5247 }, { 156,5247 },
 { 157,5247 }, { 158,5247 }, { 159,5247 }, { 160,5247 }, { 161,5247 },
 { 162,5247 }, { 163,5247 }, { 164,5247 }, { 165,5247 }, { 166,5247 },
 { 167,5247 }, { 168,5247 }, { 169,5247 }, { 170,5247 }, { 171,5247 },
 { 172,5247 }, { 173,5247 }, { 174,5247 }, { 175,5247 }, { 176,5247 },
 { 177,5247 }, { 178,5247 }, { 179,5247 }, { 180,5247 }, { 181,5247 },
 { 182,5247 }, { 183,5247 }, { 184,5247 }, { 185,5247 }, { 186,5247 },
 { 187,5247 }, { 188,5247 }, { 189,5247 }, { 190,5247 }, { 191,5247 },
 { 192,5247 }, { 193,5247 }, { 194,5247 }, { 195,5247 }, { 196,5247 },
 { 197,5247 }, { 198,5247 }, { 199,5247 }, { 200,5247 }, { 201,5247 },

 { 202,5247 }, { 203,5247 }, { 204,5247 }, { 205,5247 }, { 206,5247 },
 { 207,5247 }, { 208,5247 }, { 209,5247 }, { 210,5247 }, { 211,5247 },
 { 212,5247 }, { 213,5247 }, { 214,5247 }, { 215,5247 }, { 216,5247 },
 { 217,5247 }, { 218,5247 }, { 219,5247 }, { 220,5247 }, { 221,5247 },
 { 222,5247 }, { 223,5247 }, { 224,5247 }, { 225,5247 }, { 226,5247 },
 { 227,5247 }, { 228,5247 }, { 229,5247 }, { 230,5247 }, { 231,5247 },
 { 232,5247 }, { 233,5247 }, { 234,5247 }, { 235,5247 }, { 236,5247 },
 { 237,5247 }, { 238,5247 }, { 239,5247 }, { 240,5247 }, { 241,5247 },
 { 242,5247 }, { 243,5247 }, { 244,5247 }, { 245,5247 }, { 246,5247 },
 { 247,5247 }, { 248,5247 }, { 249,5247 }, { 250,5247 }, { 251,5247 },

 { 252,5247 }, { 253,5247 }, { 254,5247 }, { 255,5247 }, { 256,5247 },
 {   0,  21 }, {   0,14690 }, {   1,5247 }, {   2,5247 }, {   3,5247 },
 {   4,5247 }, {   5,5247 }, {   6,5247 }, {   7,5247 }, {   8,5247 },
 {   9,5247 }, {  10,5247 }, {  11,5247 }, {  12,5247 }, {  13,5247 },
 {  14,5247 }, {  15,5247 }, {  16,5247 }, {  17,5247 }, {  18,5247 },
 {  19,5247 }, {  20,5247 }, {  21,5247 }, {  22,5247 }, {  23,5247 },
 {  24,5247 }, {  25,5247 }, {  26,5247 }, {  27,5247 }, {  28,5247 },
 {  29,5247 }, {  30,5247 }, {  31,5247 }, {  32,5247 }, {  33,5247 },
 {  34,5247 }, {  35,5247 }, {  36,5247 }, {  37,5247 }, {  38,5247 },
 {   0,   0 }, {  40,5247 }, {  41,5247 }, {  42,5247 }, {  43,5247 },

 {  44,5247 }, {  45,5247 }, {  46,5247 }, {  47,5247 }, {  48,5247 },
 {  49,5247 }, {  50,5247 }, {  51,5247 }, {  52,5247 }, {  53,5247 },
 {  54,5247 }, {  55,5247 }, {  56,5247 }, {  57,5247 }, {  58,5247 },
 {  59,5247 }, {  60,5247 }, {  61,5247 }, {  62,5247 }, {  63,5247 },
 {  64,5247 }, {  65,5247 }, {  66,5247 }, {  67,5247 }, {  68,5247 },
 {  69,5247 }, {  70,5247 }, {  71,5247 }, {  72,5247 }, {  73,5247 },
 {  74,5247 }, {  75,5247 }, {  76,5247 }, {  77,5247 }, {  78,5247 },
 {  79,5247 }, {  80,5247 }, {  81,5247 }, {  82,5247 }, {  83,5247 },
 {  84,5247 }, {  85,5247 }, {  86,5247 }, {  87,5247 }, {  88,5247 },
 {  89,5247 }, {  90,5247 }, {  91,5247 }, {  92,5247 }, {  93,5247 },

 {  94,5247 }, {  95,5247 }, {  96,5247 }, {  97,5247 }, {  98,5247 },
 {  99,5247 }, { 100,5247 }, { 101,5247 }, { 102,5247 }, { 103,5247 },
 { 104,5247 }, { 105,5247 }, { 106,5247 }, { 107,5247 }, { 108,5247 },
 { 109,5247 }, { 110,5247 }, { 111,5247 }, { 112,5247 }, { 113,5247 },
 { 114,5247 }, { 115,5247 }, { 116,5247 }, { 117,5247 }, { 118,5247 },
 { 119,5247 }, { 120,5247 }, { 121,5247 }, { 122,5247 }, { 123,5247 },
 { 124,5247 }, { 125,5247 }, { 126,5247 }, { 127,5247 }, { 128,5247 },
 { 129,5247 }, { 130,5247 }, { 131,5247 }, { 132,5247 }, { 133,5247 },
 { 134,5247 }, { 135,5247 }, { 136,5247 }, { 137,5247 }, { 138,5247 },
 { 139,5247 }, { 140,5247 }, { 141,5247 }, { 142,5247 }, { 143,5247 },

 { 144,5247 }, { 145,5247 }, { 146,5247 }, { 147,5247 }, { 148,5247 },
 { 149,5247 }, { 150,5247 }, { 151,5247 }, { 152,5247 }, { 153,5247 },
 { 154,5247 }, { 155,5247 }, { 156,5247 }, { 157,5247 }, { 158,5247 },
 { 159,5247 }, { 160,5247 }, { 161,5247 }, { 162,5247 }, { 163,5247 },
 { 164,5247 }, { 165,5247 }, { 166,5247 }, { 167,5247 }, { 168,5247 },
 { 169,5247 }, { 170,5247 }, { 171,5247 }, { 172,5247 }, { 173,5247 },
 { 174,5247 }, { 175,5247 }, { 176,5247 }, { 177,5247 }, { 178,5247 },
 { 179,5247 }, { 180,5247 }, { 181,5247 }, { 182,5247 }, { 183,5247 },
 { 184,5247 }, { 185,5247 }, { 186,5247 }, { 187,5247 }, { 188,5247 },
 { 189,5247 }, { 190,5247 }, { 191,5247 }, { 192,5247 }, { 193,5247 },

 { 194,5247 }, { 195,5247 }, { 196,5247 }, { 197,5247 }, { 198,5247 },
 { 199,5247 }, { 200,5247 }, { 201,5247 }, { 202,5247 }, { 203,5247 },
 { 204,5247 }, { 205,5247 }, { 206,5247 }, { 207,5247 }, { 208,5247 },
 { 209,5247 }, { 210,5247 }, { 211,5247 }, { 212,5247 }, { 213,5247 },
 { 214,5247 }, { 215,5247 }, { 216,5247 }, { 217,5247 }, { 218,5247 },
 { 219,5247 }, { 220,5247 }, { 221,5247 }, { 222,5247 }, { 223,5247 },
 { 224,5247 }, { 225,5247 }, { 226,5247 }, { 227,5247 }, { 228,5247 },
 { 229,5247 }, { 230,5247 }, { 231,5247 }, { 232,5247 }, { 233,5247 },
 { 234,5247 }, { 235,5247 }, { 236,5247 }, { 237,5247 }, { 238,5247 },
 { 239,5247 }, { 240,5247 }, { 241,5247 }, { 242,5247 }, { 243,5247 },

 { 244,5247 }, { 245,5247 }, { 246,5247 }, { 247,5247 }, { 248,5247 },
 { 249,5247 }, { 250,5247 }, { 251,5247 }, { 252,5247 }, { 253,5247 },
 { 254,5247 }, { 255,5247 }, { 256,5247 }, {   0,  18 }, {   0,14432 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  18 }, {   0,14427 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   9,5247 }, {  10,5252 },
 {  11,5247 }, {  12,5247 }, {  13,5252 }, {   9,5271 }, {  10,5271 },
 {  11,5271 }, {  12,5271 }, {  13,5271 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,  18 }, {   0,14403 }, {   0,   0 },
 {   0,   0 }, {  32,5247 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {  32,5271 }, {   9,5247 }, {  10,5247 }, {  11,5247 },
 {  12,5247 }, {  13,5247 }, {   0,   0 }, {  39,-3783 }, {  45,-3780 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  45,-3748 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  32,5247 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  39,-3807 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  45,-3772 }, {   0,  22 },
 {   0,14356 }, {   1,5505 }, {   2,5505 }, {   3,5505 }, {   4,5505 },
 {   5,5505 }, {   6,5505 }, {   7,5505 }, {   8,5505 }, {   9,5505 },

 {  10,5505 }, {  11,5505 }, {  12,5505 }, {  13,5505 }, {  14,5505 },
 {  15,5505 }, {  16,5505 }, {  17,5505 }, {  18,5505 }, {  19,5505 },
 {  20,5505 }, {  21,5505 }, {  22,5505 }, {  23,5505 }, {  24,5505 },
 {  25,5505 }, {  26,5505 }, {  27,5505 }, {  28,5505 }, {  29,5505 },
 {  30,5505 }, {  31,5505 }, {  32,5505 }, {  33,5505 }, {  34,5505 },
 {  35,5505 }, {  36,5505 }, {  37,5505 }, {  38,5505 }, {   0,   0 },
 {  40,5505 }, {  41,5505 }, {  42,5505 }, {  43,5505 }, {  44,5505 },
 {  45,5505 }, {  46,5505 }, {  47,5505 }, {  48,5505 }, {  49,5505 },
 {  50,5505 }, {  51,5505 }, {  52,5505 }, {  53,5505 }, {  54,5505 },
 {  55,5505 }, {  56,5505 }, {  57,5505 }, {  58,5505 }, {  59,5505 },

 {  60,5505 }, {  61,5505 }, {  62,5505 }, {  63,5505 }, {  64,5505 },
 {  65,5505 }, {  66,5505 }, {  67,5505 }, {  68,5505 }, {  69,5505 },
 {  70,5505 }, {  71,5505 }, {  72,5505 }, {  73,5505 }, {  74,5505 },
 {  75,5505 }, {  76,5505 }, {  77,5505 }, {  78,5505 }, {  79,5505 },
 {  80,5505 }, {  81,5505 }, {  82,5505 }, {  83,5505 }, {  84,5505 },
 {  85,5505 }, {  86,5505 }, {  87,5505 }, {  88,5505 }, {  89,5505 },
 {  90,5505 }, {  91,5505 }, {   0,   0 }, {  93,5505 }, {  94,5505 },
 {  95,5505 }, {  96,5505 }, {  97,5505 }, {  98,5505 }, {  99,5505 },
 { 100,5505 }, { 101,5505 }, { 102,5505 }, { 103,5505 }, { 104,5505 },
 { 105,5505 }, { 106,5505 }, { 107,5505 }, { 108,5505 }, { 109,5505 },

 { 110,5505 }, { 111,5505 }, { 112,5505 }, { 113,5505 }, { 114,5505 },
 { 115,5505 }, { 116,5505 }, { 117,5505 }, { 118,5505 }, { 119,5505 },
 { 120,5505 }, { 121,5505 }, { 122,5505 }, { 123,5505 }, { 124,5505 },
 { 125,5505 }, { 126,5505 }, { 127,5505 }, { 128,5505 }, { 129,5505 },
 { 130,5505 }, { 131,5505 }, { 132,5505 }, { 133,5505 }, { 134,5505 },
 { 135,5505 }, { 136,5505 }, { 137,5505 }, { 138,5505 }, { 139,5505 },
 { 140,5505 }, { 141,5505 }, { 142,5505 }, { 143,5505 }, { 144,5505 },
 { 145,5505 }, { 146,5505 }, { 147,5505 }, { 148,5505 }, { 149,5505 },
 { 150,5505 }, { 151,5505 }, { 152,5505 }, { 153,5505 }, { 154,5505 },
 { 155,5505 }, { 156,5505 }, { 157,5505 }, { 158,5505 }, { 159,5505 },

 { 160,5505 }, { 161,5505 }, { 162,5505 }, { 163,5505 }, { 164,5505 },
 { 165,5505 }, { 166,5505 }, { 167,5505 }, { 168,5505 }, { 169,5505 },
 { 170,5505 }, { 171,5505 }, { 172,5505 }, { 173,5505 }, { 174,5505 },
 { 175,5505 }, { 176,5505 }, { 177,5505 }, { 178,5505 }, { 179,5505 },
 { 180,5505 }, { 181,5505 }, { 182,5505 }, { 183,5505 }, { 184,5505 },
 { 185,5505 }, { 186,5505 }, { 187,5505 }, { 188,5505 }, { 189,5505 },
 { 190,5505 }, { 191,5505 }, { 192,5505 }, { 193,5505 }, { 194,5505 },
 { 195,5505 }, { 196,5505 }, { 197,5505 }, { 198,5505 }, { 199,5505 },
 { 200,5505 }, { 201,5505 }, { 202,5505 }, { 203,5505 }, { 204,5505 },
 { 205,5505 }, { 206,5505 }, { 207,5505 }, { 208,5505 }, { 209,5505 },

 { 210,5505 }, { 211,5505 }, { 212,5505 }, { 213,5505 }, { 214,5505 },
 { 215,5505 }, { 216,5505 }, { 217,5505 }, { 218,5505 }, { 219,5505 },
 { 220,5505 }, { 221,5505 }, { 222,5505 }, { 223,5505 }, { 224,5505 },
 { 225,5505 }, { 226,5505 }, { 227,5505 }, { 228,5505 }, { 229,5505 },
 { 230,5505 }, { 231,5505 }, { 232,5505 }, { 233,5505 }, { 234,5505 },
 { 235,5505 }, { 236,5505 }, { 237,5505 }, { 238,5505 }, { 239,5505 },
 { 240,5505 }, { 241,5505 }, { 242,5505 }, { 243,5505 }, { 244,5505 },
 { 245,5505 }, { 246,5505 }, { 247,5505 }, { 248,5505 }, { 249,5505 },
 { 250,5505 }, { 251,5505 }, { 252,5505 }, { 253,5505 }, { 254,5505 },
 { 255,5505 }, { 256,5505 }, {   0,  22 }, {   0,14098 }, {   1,5247 },

 {   2,5247 }, {   3,5247 }, {   4,5247 }, {   5,5247 }, {   6,5247 },
 {   7,5247 }, {   8,5247 }, {   9,5247 }, {  10,5247 }, {  11,5247 },
 {  12,5247 }, {  13,5247 }, {  14,5247 }, {  15,5247 }, {  16,5247 },
 {  17,5247 }, {  18,5247 }, {  19,5247 }, {  20,5247 }, {  21,5247 },
 {  22,5247 }, {  23,5247 }, {  24,5247 }, {  25,5247 }, {  26,5247 },
 {  27,5247 }, {  28,5247 }, {  29,5247 }, {  30,5247 }, {  31,5247 },
 {  32,5247 }, {  33,5247 }, {  34,5247 }, {  35,5247 }, {  36,5247 },
 {  37,5247 }, {  38,5247 }, {   0,   0 }, {  40,5247 }, {  41,5247 },
 {  42,5247 }, {  43,5247 }, {  44,5247 }, {  45,5247 }, {  46,5247 },
 {  47,5247 }, {  48,5247 }, {  49,5247 }, {  50,5247 }, {  51,5247 },

 {  52,5247 }, {  53,5247 }, {  54,5247 }, {  55,5247 }, {  56,5247 },
 {  57,5247 }, {  58,5247 }, {  59,5247 }, {  60,5247 }, {  61,5247 },
 {  62,5247 }, {  63,5247 }, {  64,5247 }, {  65,5247 }, {  66,5247 },
 {  67,5247 }, {  68,5247 }, {  69,5247 }, {  70,5247 }, {  71,5247 },
 {  72,5247 }, {  73,5247 }, {  74,5247 }, {  75,5247 }, {  76,5247 },
 {  77,5247 }, {  78,5247 }, {  79,5247 }, {  80,5247 }, {  81,5247 },
 {  82,5247 }, {  83,5247 }, {  84,5247 }, {  85,5247 }, {  86,5247 },
 {  87,5247 }, {  88,5247 }, {  89,5247 }, {  90,5247 }, {  91,5247 },
 {   0,   0 }, {  93,5247 }, {  94,5247 }, {  95,5247 }, {  96,5247 },
 {  97,5247 }, {  98,5247 }, {  99,5247 }, { 100,5247 }, { 101,5247 },

 { 102,5247 }, { 103,5247 }, { 104,5247 }, { 105,5247 }, { 106,5247 },
 { 107,5247 }, { 108,5247 }, { 109,5247 }, { 110,5247 }, { 111,5247 },
 { 112,5247 }, { 113,5247 }, { 114,5247 }, { 115,5247 }, { 116,5247 },
 { 117,5247 }, { 118,5247 }, { 119,5247 }, { 120,5247 }, { 121,5247 },
 { 122,5247 }, { 123,5247 }, { 124,5247 }, { 125,5247 }, { 126,5247 },
 { 127,5247 }, { 128,5247 }, { 129,5247 }, { 130,5247 }, { 131,5247 },
 { 132,5247 }, { 133,5247 }, { 134,5247 }, { 135,5247 }, { 136,5247 },
 { 137,5247 }, { 138,5247 }, { 139,5247 }, { 140,5247 }, { 141,5247 },
 { 142,5247 }, { 143,5247 }, { 144,5247 }, { 145,5247 }, { 146,5247 },
 { 147,5247 }, { 148,5247 }, { 149,5247 }, { 150,5247 }, { 151,5247 },

 { 152,5247 }, { 153,5247 }, { 154,5247 }, { 155,5247 }, { 156,5247 },
 { 157,5247 }, { 158,5247 }, { 159,5247 }, { 160,5247 }, { 161,5247 },
 { 162,5247 }, { 163,5247 }, { 164,5247 }, { 165,5247 }, { 166,5247 },
 { 167,5247 }, { 168,5247 }, { 169,5247 }, { 170,5247 }, { 171,5247 },
 { 172,5247 }, { 173,5247 }, { 174,5247 }, { 175,5247 }, { 176,5247 },
 { 177,5247 }, { 178,5247 }, { 179,5247 }, { 180,5247 }, { 181,5247 },
 { 182,5247 }, { 183,5247 }, { 184,5247 }, { 185,5247 }, { 186,5247 },
 { 187,5247 }, { 188,5247 }, { 189,5247 }, { 190,5247 }, { 191,5247 },
 { 192,5247 }, { 193,5247 }, { 194,5247 }, { 195,5247 }, { 196,5247 },
 { 197,5247 }, { 198,5247 }, { 199,5247 }, { 200,5247 }, { 201,5247 },

 { 202,5247 }, { 203,5247 }, { 204,5247 }, { 205,5247 }, { 206,5247 },
 { 207,5247 }, { 208,5247 }, { 209,5247 }, { 210,5247 }, { 211,5247 },
 { 212,5247 }, { 213,5247 }, { 214,5247 }, { 215,5247 }, { 216,5247 },
 { 217,5247 }, { 218,5247 }, { 219,5247 }, { 220,5247 }, { 221,5247 },
 { 222,5247 }, { 223,5247 }, { 224,5247 }, { 225,5247 }, { 226,5247 },
 { 227,5247 }, { 228,5247 }, { 229,5247 }, { 230,5247 }, { 231,5247 },
 { 232,5247 }, { 233,5247 }, { 234,5247 }, { 235,5247 }, { 236,5247 },
 { 237,5247 }, { 238,5247 }, { 239,5247 }, { 240,5247 }, { 241,5247 },
 { 242,5247 }, { 243,5247 }, { 244,5247 }, { 245,5247 }, { 246,5247 },
 { 247,5247 }, { 248,5247 }, { 249,5247 }, { 250,5247 }, { 251,5247 },

 { 252,5247 }, { 253,5247 }, { 254,5247 }, { 255,5247 }, { 256,5247 },
 {   0,  31 }, {   0,13840 }, {   1,-4330 }, {   2,-4330 }, {   3,-4330 },
 {   4,-4330 }, {   5,-4330 }, {   6,-4330 }, {   7,-4330 }, {   8,-4330 },
 {   9,-4330 }, {  10,-4330 }, {  11,-4330 }, {  12,-4330 }, {  13,-4330 },
 {  14,-4330 }, {  15,-4330 }, {  16,-4330 }, {  17,-4330 }, {  18,-4330 },
 {  19,-4330 }, {  20,-4330 }, {  21,-4330 }, {  22,-4330 }, {  23,-4330 },
 {  24,-4330 }, {  25,-4330 }, {  26,-4330 }, {  27,-4330 }, {  28,-4330 },
 {  29,-4330 }, {  30,-4330 }, {  31,-4330 }, {  32,-4330 }, {  33,-4330 },
 {  34,-4330 }, {  35,-4330 }, {  36,-4330 }, {  37,-4330 }, {  38,-4330 },
 {  39,-4330 }, {  40,-4330 }, {  41,-4330 }, {  42,-4330 }, {  43,-4330 },

 {  44,-4330 }, {  45,-4330 }, {  46,-4330 }, {  47,-4330 }, {  48,5247 },
 {  49,5247 }, {  50,5247 }, {  51,5247 }, {  52,5247 }, {  53,5247 },
 {  54,5247 }, {  55,5247 }, {  56,-4330 }, {  57,-4330 }, {  58,-4330 },
 {  59,-4330 }, {  60,-4330 }, {  61,-4330 }, {  62,-4330 }, {  63,-4330 },
 {  64,-4330 }, {  65,-4330 }, {  66,-4330 }, {  67,-4330 }, {  68,-4330 },
 {  69,-4330 }, {  70,-4330 }, {  71,-4330 }, {  72,-4330 }, {  73,-4330 },
 {  74,-4330 }, {  75,-4330 }, {  76,-4330 }, {  77,-4330 }, {  78,-4330 },
 {  79,-4330 }, {  80,-4330 }, {  81,-4330 }, {  82,-4330 }, {  83,-4330 },
 {  84,-4330 }, {  85,5255 }, {  86,-4330 }, {  87,-4330 }, {  88,-4330 },
 {  89,-4330 }, {  90,-4330 }, {  91,-4330 }, {  92,-4330 }, {  93,-4330 },

 {  94,-4330 }, {  95,-4330 }, {  96,-4330 }, {  97,-4330 }, {  98,-4330 },
 {  99,-4330 }, { 100,-4330 }, { 101,-4330 }, { 102,-4330 }, { 103,-4330 },
 { 104,-4330 }, { 105,-4330 }, { 106,-4330 }, { 107,-4330 }, { 108,-4330 },
 { 109,-4330 }, { 110,-4330 }, { 111,-4330 }, { 112,-4330 }, { 113,-4330 },
 { 114,-4330 }, { 115,-4330 }, { 116,-4330 }, { 117,5278 }, { 118,-4330 },
 { 119,-4330 }, { 120,5316 }, { 121,-4330 }, { 122,-4330 }, { 123,-4330 },
 { 124,-4330 }, { 125,-4330 }, { 126,-4330 }, { 127,-4330 }, { 128,-4330 },
 { 129,-4330 }, { 130,-4330 }, { 131,-4330 }, { 132,-4330 }, { 133,-4330 },
 { 134,-4330 }, { 135,-4330 }, { 136,-4330 }, { 137,-4330 }, { 138,-4330 },
 { 139,-4330 }, { 140,-4330 }, { 141,-4330 }, { 142,-4330 }, { 143,-4330 },

 { 144,-4330 }, { 145,-4330 }, { 146,-4330 }, { 147,-4330 }, { 148,-4330 },
 { 149,-4330 }, { 150,-4330 }, { 151,-4330 }, { 152,-4330 }, { 153,-4330 },
 { 154,-4330 }, { 155,-4330 }, { 156,-4330 }, { 157,-4330 }, { 158,-4330 },
 { 159,-4330 }, { 160,-4330 }, { 161,-4330 }, { 162,-4330 }, { 163,-4330 },
 { 164,-4330 }, { 165,-4330 }, { 166,-4330 }, { 167,-4330 }, { 168,-4330 },
 { 169,-4330 }, { 170,-4330 }, { 171,-4330 }, { 172,-4330 }, { 173,-4330 },
 { 174,-4330 }, { 175,-4330 }, { 176,-4330 }, { 177,-4330 }, { 178,-4330 },
 { 179,-4330 }, { 180,-4330 }, { 181,-4330 }, { 182,-4330 }, { 183,-4330 },
 { 184,-4330 }, { 185,-4330 }, { 186,-4330 }, { 187,-4330 }, { 188,-4330 },
 { 189,-4330 }, { 190,-4330 }, { 191,-4330 }, { 192,-4330 }, { 193,-4330 },

 { 194,-4330 }, { 195,-4330 }, { 196,-4330 }, { 197,-4330 }, { 198,-4330 },
 { 199,-4330 }, { 200,-4330 }, { 201,-4330 }, { 202,-4330 }, { 203,-4330 },
 { 204,-4330 }, { 205,-4330 }, { 206,-4330 }, { 207,-4330 }, { 208,-4330 },
 { 209,-4330 }, { 210,-4330 }, { 211,-4330 }, { 212,-4330 }, { 213,-4330 },
 { 214,-4330 }, { 215,-4330 }, { 216,-4330 }, { 217,-4330 }, { 218,-4330 },
 { 219,-4330 }, { 220,-4330 }, { 221,-4330 }, { 222,-4330 }, { 223,-4330 },
 { 224,-4330 }, { 225,-4330 }, { 226,-4330 }, { 227,-4330 }, { 228,-4330 },
 { 229,-4330 }, { 230,-4330 }, { 231,-4330 }, { 232,-4330 }, { 233,-4330 },
 { 234,-4330 }, { 235,-4330 }, { 236,-4330 }, { 237,-4330 }, { 238,-4330 },
 { 239,-4330 }, { 240,-4330 }, { 241,-4330 }, { 242,-4330 }, { 243,-4330 },

 { 244,-4330 }, { 245,-4330 }, { 246,-4330 }, { 247,-4330 }, { 248,-4330 },
 { 249,-4330 }, { 250,-4330 }, { 251,-4330 }, { 252,-4330 }, { 253,-4330 },
 { 254,-4330 }, { 255,-4330 }, { 256,-4330 }, {   0,  35 }, {   0,13582 },
 {   1,5162 }, {   2,5162 }, {   3,5162 }, {   4,5162 }, {   5,5162 },
 {   6,5162 }, {   7,5162 }, {   8,5162 }, {   9,5162 }, {  10,5162 },
 {  11,5162 }, {  12,5162 }, {  13,5162 }, {  14,5162 }, {  15,5162 },
 {  16,5162 }, {  17,5162 }, {  18,5162 }, {  19,5162 }, {  20,5162 },
 {  21,5162 }, {  22,5162 }, {  23,5162 }, {  24,5162 }, {  25,5162 },
 {  26,5162 }, {  27,5162 }, {  28,5162 }, {  29,5162 }, {  30,5162 },
 {  31,5162 }, {  32,5162 }, {  33,5162 }, {  34,5162 }, {  35,5162 },

 {   0,   0 }, {  37,5162 }, {  38,5162 }, {  39,5162 }, {  40,5162 },
 {  41,5162 }, {  42,5162 }, {  43,5162 }, {  44,5162 }, {  45,5162 },
 {  46,5162 }, {  47,5162 }, {  48,5162 }, {  49,5162 }, {  50,5162 },
 {  51,5162 }, {  52,5162 }, {  53,5162 }, {  54,5162 }, {  55,5162 },
 {  56,5162 }, {  57,5162 }, {  58,5162 }, {  59,5162 }, {  60,5162 },
 {  61,5162 }, {  62,5162 }, {  63,5162 }, {  64,5162 }, {  65,5162 },
 {  66,5162 }, {  67,5162 }, {  68,5162 }, {  69,5162 }, {  70,5162 },
 {  71,5162 }, {  72,5162 }, {  73,5162 }, {  74,5162 }, {  75,5162 },
 {  76,5162 }, {  77,5162 }, {  78,5162 }, {  79,5162 }, {  80,5162 },
 {  81,5162 }, {  82,5162 }, {  83,5162 }, {  84,5162 }, {  85,5162 },

 {  86,5162 }, {  87,5162 }, {  88,5162 }, {  89,5162 }, {  90,5162 },
 {  91,5162 }, {  92,5162 }, {  93,5162 }, {  94,5162 }, {  95,5162 },
 {  96,5162 }, {  97,5162 }, {  98,5162 }, {  99,5162 }, { 100,5162 },
 { 101,5162 }, { 102,5162 }, { 103,5162 }, { 104,5162 }, { 105,5162 },
 { 106,5162 }, { 107,5162 }, { 108,5162 }, { 109,5162 }, { 110,5162 },
 { 111,5162 }, { 112,5162 }, { 113,5162 }, { 114,5162 }, { 115,5162 },
 { 116,5162 }, { 117,5162 }, { 118,5162 }, { 119,5162 }, { 120,5162 },
 { 121,5162 }, { 122,5162 }, { 123,5162 }, { 124,5162 }, { 125,5162 },
 { 126,5162 }, { 127,5162 }, { 128,5162 }, { 129,5162 }, { 130,5162 },
 { 131,5162 }, { 132,5162 }, { 133,5162 }, { 134,5162 }, { 135,5162 },

 { 136,5162 }, { 137,5162 }, { 138,5162 }, { 139,5162 }, { 140,5162 },
 { 141,5162 }, { 142,5162 }, { 143,5162 }, { 144,5162 }, { 145,5162 },
 { 146,5162 }, { 147,5162 }, { 148,5162 }, { 149,5162 }, { 150,5162 },
 { 151,5162 }, { 152,5162 }, { 153,5162 }, { 154,5162 }, { 155,5162 },
 { 156,5162 }, { 157,5162 }, { 158,5162 }, { 159,5162 }, { 160,5162 },
 { 161,5162 }, { 162,5162 }, { 163,5162 }, { 164,5162 }, { 165,5162 },
 { 166,5162 }, { 167,5162 }, { 168,5162 }, { 169,5162 }, { 170,5162 },
 { 171,5162 }, { 172,5162 }, { 173,5162 }, { 174,5162 }, { 175,5162 },
 { 176,5162 }, { 177,5162 }, { 178,5162 }, { 179,5162 }, { 180,5162 },
 { 181,5162 }, { 182,5162 }, { 183,5162 }, { 184,5162 }, { 185,5162 },

 { 186,5162 }, { 187,5162 }, { 188,5162 }, { 189,5162 }, { 190,5162 },
 { 191,5162 }, { 192,5162 }, { 193,5162 }, { 194,5162 }, { 195,5162 },
 { 196,5162 }, { 197,5162 }, { 198,5162 }, { 199,5162 }, { 200,5162 },
 { 201,5162 }, { 202,5162 }, { 203,5162 }, { 204,5162 }, { 205,5162 },
 { 206,5162 }, { 207,5162 }, { 208,5162 }, { 209,5162 }, { 210,5162 },
 { 211,5162 }, { 212,5162 }, { 213,5162 }, { 214,5162 }, { 215,5162 },
 { 216,5162 }, { 217,5162 }, { 218,5162 }, { 219,5162 }, { 220,5162 },
 { 221,5162 }, { 222,5162 }, { 223,5162 }, { 224,5162 }, { 225,5162 },
 { 226,5162 }, { 227,5162 }, { 228,5162 }, { 229,5162 }, { 230,5162 },
 { 231,5162 }, { 232,5162 }, { 233,5162 }, { 234,5162 }, { 235,5162 },

 { 236,5162 }, { 237,5162 }, { 238,5162 }, { 239,5162 }, { 240,5162 },
 { 241,5162 }, { 242,5162 }, { 243,5162 }, { 244,5162 }, { 245,5162 },
 { 246,5162 }, { 247,5162 }, { 248,5162 }, { 249,5162 }, { 250,5162 },
 { 251,5162 }, { 252,5162 }, { 253,5162 }, { 254,5162 }, { 255,5162 },
 { 256,5162 }, {   0,  35 }, {   0,13324 }, {   1,4904 }, {   2,4904 },
 {   3,4904 }, {   4,4904 }, {   5,4904 }, {   6,4904 }, {   7,4904 },
 {   8,4904 }, {   9,4904 }, {  10,4904 }, {  11,4904 }, {  12,4904 },
 {  13,4904 }, {  14,4904 }, {  15,4904 }, {  16,4904 }, {  17,4904 },
 {  18,4904 }, {  19,4904 }, {  20,4904 }, {  21,4904 }, {  22,4904 },
 {  23,4904 }, {  24,4904 }, {  25,4904 }, {  26,4904 }, {  27,4904 },

 {  28,4904 }, {  29,4904 }, {  30,4904 }, {  31,4904 }, {  32,4904 },
 {  33,4904 }, {  34,4904 }, {  35,4904 }, {   0,   0 }, {  37,4904 },
 {  38,4904 }, {  39,4904 }, {  40,4904 }, {  41,4904 }, {  42,4904 },
 {  43,4904 }, {  44,4904 }, {  45,4904 }, {  46,4904 }, {  47,4904 },
 {  48,4904 }, {  49,4904 }, {  50,4904 }, {  51,4904 }, {  52,4904 },
 {  53,4904 }, {  54,4904 }, {  55,4904 }, {  56,4904 }, {  57,4904 },
 {  58,4904 }, {  59,4904 }, {  60,4904 }, {  61,4904 }, {  62,4904 },
 {  63,4904 }, {  64,4904 }, {  65,4904 }, {  66,4904 }, {  67,4904 },
 {  68,4904 }, {  69,4904 }, {  70,4904 }, {  71,4904 }, {  72,4904 },
 {  73,4904 }, {  74,4904 }, {  75,4904 }, {  76,4904 }, {  77,4904 },

 {  78,4904 }, {  79,4904 }, {  80,4904 }, {  81,4904 }, {  82,4904 },
 {  83,4904 }, {  84,4904 }, {  85,4904 }, {  86,4904 }, {  87,4904 },
 {  88,4904 }, {  89,4904 }, {  90,4904 }, {  91,4904 }, {  92,4904 },
 {  93,4904 }, {  94,4904 }, {  95,4904 }, {  96,4904 }, {  97,4904 },
 {  98,4904 }, {  99,4904 }, { 100,4904 }, { 101,4904 }, { 102,4904 },
 { 103,4904 }, { 104,4904 }, { 105,4904 }, { 106,4904 }, { 107,4904 },
 { 108,4904 }, { 109,4904 }, { 110,4904 }, { 111,4904 }, { 112,4904 },
 { 113,4904 }, { 114,4904 }, { 115,4904 }, { 116,4904 }, { 117,4904 },
 { 118,4904 }, { 119,4904 }, { 120,4904 }, { 121,4904 }, { 122,4904 },
 { 123,4904 }, { 124,4904 }, { 125,4904 }, { 126,4904 }, { 127,4904 },

 { 128,4904 }, { 129,4904 }, { 130,4904 }, { 131,4904 }, { 132,4904 },
 { 133,4904 }, { 134,4904 }, { 135,4904 }, { 136,4904 }, { 137,4904 },
 { 138,4904 }, { 139,4904 }, { 140,4904 }, { 141,4904 }, { 142,4904 },
 { 143,4904 }, { 144,4904 }, { 145,4904 }, { 146,4904 }, { 147,4904 },
 { 148,4904 }, { 149,4904 }, { 150,4904 }, { 151,4904 }, { 152,4904 },
 { 153,4904 }, { 154,4904 }, { 155,4904 }, { 156,4904 }, { 157,4904 },
 { 158,4904 }, { 159,4904 }, { 160,4904 }, { 161,4904 }, { 162,4904 },
 { 163,4904 }, { 164,4904 }, { 165,4904 }, { 166,4904 }, { 167,4904 },
 { 168,4904 }, { 169,4904 }, { 170,4904 }, { 171,4904 }, { 172,4904 },
 { 173,4904 }, { 174,4904 }, { 175,4904 }, { 176,4904 }, { 177,4904 },

 { 178,4904 }, { 179,4904 }, { 180,4904 }, { 181,4904 }, { 182,4904 },
 { 183,4904 }, { 184,4904 }, { 185,4904 }, { 186,4904 }, { 187,4904 },
 { 188,4904 }, { 189,4904 }, { 190,4904 }, { 191,4904 }, { 192,4904 },
 { 193,4904 }, { 194,4904 }, { 195,4904 }, { 196,4904 }, { 197,4904 },
 { 198,4904 }, { 199,4904 }, { 200,4904 }, { 201,4904 }, { 202,4904 },
 { 203,4904 }, { 204,4904 }, { 205,4904 }, { 206,4904 }, { 207,4904 },
 { 208,4904 }, { 209,4904 }, { 210,4904 }, { 211,4904 }, { 212,4904 },
 { 213,4904 }, { 214,4904 }, { 215,4904 }, { 216,4904 }, { 217,4904 },
 { 218,4904 }, { 219,4904 }, { 220,4904 }, { 221,4904 }, { 222,4904 },
 { 223,4904 }, { 224,4904 }, { 225,4904 }, { 226,4904 }, { 227,4904 },

 { 228,4904 }, { 229,4904 }, { 230,4904 }, { 231,4904 }, { 232,4904 },
 { 233,4904 }, { 234,4904 }, { 235,4904 }, { 236,4904 }, { 237,4904 },
 { 238,4904 }, { 239,4904 }, { 240,4904 }, { 241,4904 }, { 242,4904 },
 { 243,4904 }, { 244,4904 }, { 245,4904 }, { 246,4904 }, { 247,4904 },
 { 248,4904 }, { 249,4904 }, { 250,4904 }, { 251,4904 }, { 252,4904 },
 { 253,4904 }, { 254,4904 }, { 255,4904 }, { 256,4904 }, {   0,  37 },
 {   0,13066 }, {   0,   1 }, {   0,13064 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   9,   0 }, {  10,   0 }, {  11,   0 }, {  12,   0 },
 {  13,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  32,   0 },
 {   0,   0 }, {  36,-5102 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65,4904 }, {  66,4904 }, {  67,4904 }, {  68,4904 }, {  69,4904 },

 {  70,4904 }, {  71,4904 }, {  72,4904 }, {  73,4904 }, {  74,4904 },
 {  75,4904 }, {  76,4904 }, {  77,4904 }, {  78,4904 }, {  79,4904 },
 {  80,4904 }, {  81,4904 }, {  82,4904 }, {  83,4904 }, {  84,4904 },
 {  85,4904 }, {  86,4904 }, {  87,4904 }, {  88,4904 }, {  89,4904 },
 {  90,4904 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  95,4904 }, {   0,   0 }, {  97,4904 }, {  98,4904 }, {  99,4904 },
 { 100,4904 }, { 101,4904 }, { 102,4904 }, { 103,4904 }, { 104,4904 },
 { 105,4904 }, { 106,4904 }, { 107,4904 }, { 108,4904 }, { 109,4904 },
 { 110,4904 }, { 111,4904 }, { 112,4904 }, { 113,4904 }, { 114,4904 },
 { 115,4904 }, { 116,4904 }, { 117,4904 }, { 118,4904 }, { 119,4904 },

 { 120,4904 }, { 121,4904 }, { 122,4904 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,4904 }, { 129,4904 },
 { 130,4904 }, { 131,4904 }, { 132,4904 }, { 133,4904 }, { 134,4904 },
 { 135,4904 }, { 136,4904 }, { 137,4904 }, { 138,4904 }, { 139,4904 },
 { 140,4904 }, { 141,4904 }, { 142,4904 }, { 143,4904 }, { 144,4904 },
 { 145,4904 }, { 146,4904 }, { 147,4904 }, { 148,4904 }, { 149,4904 },
 { 150,4904 }, { 151,4904 }, { 152,4904 }, { 153,4904 }, { 154,4904 },
 { 155,4904 }, { 156,4904 }, { 157,4904 }, { 158,4904 }, { 159,4904 },
 { 160,4904 }, { 161,4904 }, { 162,4904 }, { 163,4904 }, { 164,4904 },
 { 165,4904 }, { 166,4904 }, { 167,4904 }, { 168,4904 }, { 169,4904 },

 { 170,4904 }, { 171,4904 }, { 172,4904 }, { 173,4904 }, { 174,4904 },
 { 175,4904 }, { 176,4904 }, { 177,4904 }, { 178,4904 }, { 179,4904 },
 { 180,4904 }, { 181,4904 }, { 182,4904 }, { 183,4904 }, { 184,4904 },
 { 185,4904 }, { 186,4904 }, { 187,4904 }, { 188,4904 }, { 189,4904 },
 { 190,4904 }, { 191,4904 }, { 192,4904 }, { 193,4904 }, { 194,4904 },
 { 195,4904 }, { 196,4904 }, { 197,4904 }, { 198,4904 }, { 199,4904 },
 { 200,4904 }, { 201,4904 }, { 202,4904 }, { 203,4904 }, { 204,4904 },
 { 205,4904 }, { 206,4904 }, { 207,4904 }, { 208,4904 }, { 209,4904 },
 { 210,4904 }, { 211,4904 }, { 212,4904 }, { 213,4904 }, { 214,4904 },
 { 215,4904 }, { 216,4904 }, { 217,4904 }, { 218,4904 }, { 219,4904 },

 { 220,4904 }, { 221,4904 }, { 222,4904 }, { 223,4904 }, { 224,4904 },
 { 225,4904 }, { 226,4904 }, { 227,4904 }, { 228,4904 }, { 229,4904 },
 { 230,4904 }, { 231,4904 }, { 232,4904 }, { 233,4904 }, { 234,4904 },
 { 235,4904 }, { 236,4904 }, { 237,4904 }, { 238,4904 }, { 239,4904 },
 { 240,4904 }, { 241,4904 }, { 242,4904 }, { 243,4904 }, { 244,4904 },
 { 245,4904 }, { 246,4904 }, { 247,4904 }, { 248,4904 }, { 249,4904 },
 { 250,4904 }, { 251,4904 }, { 252,4904 }, { 253,4904 }, { 254,4904 },
 { 255,4904 }, {   0,  54 }, {   0,12809 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,  52 }, {   0,12798 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  33,   0 }, {   0,   0 }, {  35,   0 }, {   0,   0 }, {  37,   0 },
 {  38,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  42,   0 },
 {  43,   0 }, {  33, -11 }, {  45,   0 }, {  35, -11 }, {  47,   0 },
 {  37, -11 }, {  38, -11 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  42, -11 }, {  43, -11 }, {   0,   0 }, {  45, -11 }, {   0,   0 },
 {  47, -11 }, {   0,   0 }, {  60,   0 }, {  61,   0 }, {  62,   0 },

 {  63,   0 }, {  64,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  60, -11 }, {  61, -11 },
 {  62, -11 }, {  63, -11 }, {  64, -11 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,  55 }, {   0,12719 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  94,   0 }, {   0,   0 }, {  96,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  94, -11 }, {   0,   0 }, {  96, -11 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, { 124,   0 }, {   0,   0 }, { 126,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, { 124, -11 }, {   0,   0 }, { 126, -11 },
 {  48,4875 }, {  49,4875 }, {  50,4875 }, {  51,4875 }, {  52,4875 },
 {  53,4875 }, {  54,4875 }, {  55,4875 }, {  56,4875 }, {  57,4875 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  65,-5446 }, {  66,-5446 }, {  67,-5446 },
 {  68,-5446 }, {  69,-5446 }, {  70,-5446 }, {  71,-5446 }, {  72,-5446 },

 {  73,-5446 }, {  74,-5446 }, {  75,-5446 }, {  76,-5446 }, {  77,-5446 },
 {  78,-5446 }, {  79,-5446 }, {  80,-5446 }, {  81,-5446 }, {  82,-5446 },
 {  83,-5446 }, {  84,-5446 }, {  85,-5446 }, {  86,-5446 }, {  87,-5446 },
 {  88,-5446 }, {  89,-5446 }, {  90,-5446 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  95,5132 }, {   0,   0 }, {  97,-5446 },
 {  98,-5446 }, {  99,-5446 }, { 100,-5446 }, { 101,-5446 }, { 102,-5446 },
 { 103,-5446 }, { 104,-5446 }, { 105,-5446 }, { 106,-5446 }, { 107,-5446 },
 { 108,-5446 }, { 109,-5446 }, { 110,-5446 }, { 111,-5446 }, { 112,-5446 },
 { 113,-5446 }, { 114,-5446 }, { 115,-5446 }, { 116,-5446 }, { 117,-5446 },
 { 118,-5446 }, { 119,-5446 }, { 120,-5446 }, { 121,-5446 }, { 122,-5446 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 { 128,-5446 }, { 129,-5446 }, { 130,-5446 }, { 131,-5446 }, { 132,-5446 },
 { 133,-5446 }, { 134,-5446 }, { 135,-5446 }, { 136,-5446 }, { 137,-5446 },
 { 138,-5446 }, { 139,-5446 }, { 140,-5446 }, { 141,-5446 }, { 142,-5446 },
 { 143,-5446 }, { 144,-5446 }, { 145,-5446 }, { 146,-5446 }, { 147,-5446 },
 { 148,-5446 }, { 149,-5446 }, { 150,-5446 }, { 151,-5446 }, { 152,-5446 },
 { 153,-5446 }, { 154,-5446 }, { 155,-5446 }, { 156,-5446 }, { 157,-5446 },
 { 158,-5446 }, { 159,-5446 }, { 160,-5446 }, { 161,-5446 }, { 162,-5446 },
 { 163,-5446 }, { 164,-5446 }, { 165,-5446 }, { 166,-5446 }, { 167,-5446 },
 { 168,-5446 }, { 169,-5446 }, { 170,-5446 }, { 171,-5446 }, { 172,-5446 },

 { 173,-5446 }, { 174,-5446 }, { 175,-5446 }, { 176,-5446 }, { 177,-5446 },
 { 178,-5446 }, { 179,-5446 }, { 180,-5446 }, { 181,-5446 }, { 182,-5446 },
 { 183,-5446 }, { 184,-5446 }, { 185,-5446 }, { 186,-5446 }, { 187,-5446 },
 { 188,-5446 }, { 189,-5446 }, { 190,-5446 }, { 191,-5446 }, { 192,-5446 },
 { 193,-5446 }, { 194,-5446 }, { 195,-5446 }, { 196,-5446 }, { 197,-5446 },
 { 198,-5446 }, { 199,-5446 }, { 200,-5446 }, { 201,-5446 }, { 202,-5446 },
 { 203,-5446 }, { 204,-5446 }, { 205,-5446 }, { 206,-5446 }, { 207,-5446 },
 { 208,-5446 }, { 209,-5446 }, { 210,-5446 }, { 211,-5446 }, { 212,-5446 },
 { 213,-5446 }, { 214,-5446 }, { 215,-5446 }, { 216,-5446 }, { 217,-5446 },
 { 218,-5446 }, { 219,-5446 }, { 220,-5446 }, { 221,-5446 }, { 222,-5446 },

 { 223,-5446 }, { 224,-5446 }, { 225,-5446 }, { 226,-5446 }, { 227,-5446 },
 { 228,-5446 }, { 229,-5446 }, { 230,-5446 }, { 231,-5446 }, { 232,-5446 },
 { 233,-5446 }, { 234,-5446 }, { 235,-5446 }, { 236,-5446 }, { 237,-5446 },
 { 238,-5446 }, { 239,-5446 }, { 240,-5446 }, { 241,-5446 }, { 242,-5446 },
 { 243,-5446 }, { 244,-5446 }, { 245,-5446 }, { 246,-5446 }, { 247,-5446 },
 { 248,-5446 }, { 249,-5446 }, { 250,-5446 }, { 251,-5446 }, { 252,-5446 },
 { 253,-5446 }, { 254,-5446 }, { 255,-5446 }, {   0,  33 }, {   0,12462 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  36,-6066 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  48,4885 }, {  49,4885 }, {  50,4885 },
 {  51,4885 }, {  52,4885 }, {  53,4885 }, {  54,4885 }, {  55,4885 },
 {  56,4885 }, {  57,4885 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,4885 },

 {  66,4885 }, {  67,4885 }, {  68,4885 }, {  69,4885 }, {  70,4885 },
 {  71,4885 }, {  72,4885 }, {  73,4885 }, {  74,4885 }, {  75,4885 },
 {  76,4885 }, {  77,4885 }, {  78,4885 }, {  79,4885 }, {  80,4885 },
 {  81,4885 }, {  82,4885 }, {  83,4885 }, {  84,4885 }, {  85,4885 },
 {  86,4885 }, {  87,4885 }, {  88,4885 }, {  89,4885 }, {  90,4885 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95,4885 },
 {   0,   0 }, {  97,4885 }, {  98,4885 }, {  99,4885 }, { 100,4885 },
 { 101,4885 }, { 102,4885 }, { 103,4885 }, { 104,4885 }, { 105,4885 },
 { 106,4885 }, { 107,4885 }, { 108,4885 }, { 109,4885 }, { 110,4885 },
 { 111,4885 }, { 112,4885 }, { 113,4885 }, { 114,4885 }, { 115,4885 },

 { 116,4885 }, { 117,4885 }, { 118,4885 }, { 119,4885 }, { 120,4885 },
 { 121,4885 }, { 122,4885 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, { 128,4885 }, { 129,4885 }, { 130,4885 },
 { 131,4885 }, { 132,4885 }, { 133,4885 }, { 134,4885 }, { 135,4885 },
 { 136,4885 }, { 137,4885 }, { 138,4885 }, { 139,4885 }, { 140,4885 },
 { 141,4885 }, { 142,4885 }, { 143,4885 }, { 144,4885 }, { 145,4885 },
 { 146,4885 }, { 147,4885 }, { 148,4885 }, { 149,4885 }, { 150,4885 },
 { 151,4885 }, { 152,4885 }, { 153,4885 }, { 154,4885 }, { 155,4885 },
 { 156,4885 }, { 157,4885 }, { 158,4885 }, { 159,4885 }, { 160,4885 },
 { 161,4885 }, { 162,4885 }, { 163,4885 }, { 164,4885 }, { 165,4885 },

 { 166,4885 }, { 167,4885 }, { 168,4885 }, { 169,4885 }, { 170,4885 },
 { 171,4885 }, { 172,4885 }, { 173,4885 }, { 174,4885 }, { 175,4885 },
 { 176,4885 }, { 177,4885 }, { 178,4885 }, { 179,4885 }, { 180,4885 },
 { 181,4885 }, { 182,4885 }, { 183,4885 }, { 184,4885 }, { 185,4885 },
 { 186,4885 }, { 187,4885 }, { 188,4885 }, { 189,4885 }, { 190,4885 },
 { 191,4885 }, { 192,4885 }, { 193,4885 }, { 194,4885 }, { 195,4885 },
 { 196,4885 }, { 197,4885 }, { 198,4885 }, { 199,4885 }, { 200,4885 },
 { 201,4885 }, { 202,4885 }, { 203,4885 }, { 204,4885 }, { 205,4885 },
 { 206,4885 }, { 207,4885 }, { 208,4885 }, { 209,4885 }, { 210,4885 },
 { 211,4885 }, { 212,4885 }, { 213,4885 }, { 214,4885 }, { 215,4885 },

 { 216,4885 }, { 217,4885 }, { 218,4885 }, { 219,4885 }, { 220,4885 },
 { 221,4885 }, { 222,4885 }, { 223,4885 }, { 224,4885 }, { 225,4885 },
 { 226,4885 }, { 227,4885 }, { 228,4885 }, { 229,4885 }, { 230,4885 },
 { 231,4885 }, { 232,4885 }, { 233,4885 }, { 234,4885 }, { 235,4885 },
 { 236,4885 }, { 237,4885 }, { 238,4885 }, { 239,4885 }, { 240,4885 },
 { 241,4885 }, { 242,4885 }, { 243,4885 }, { 244,4885 }, { 245,4885 },
 { 246,4885 }, { 247,4885 }, { 248,4885 }, { 249,4885 }, { 250,4885 },
 { 251,4885 }, { 252,4885 }, { 253,4885 }, { 254,4885 }, { 255,4885 },
 {   0,   1 }, {   0,12205 }, {   1,4885 }, {   2,4885 }, {   3,4885 },
 {   4,4885 }, {   5,4885 }, {   6,4885 }, {   7,4885 }, {   8,4885 },

 {   9,4885 }, {   0,   0 }, {  11,4885 }, {  12,4885 }, {   0,   0 },
 {  14,4885 }, {  15,4885 }, {  16,4885 }, {  17,4885 }, {  18,4885 },
 {  19,4885 }, {  20,4885 }, {  21,4885 }, {  22,4885 }, {  23,4885 },
 {  24,4885 }, {  25,4885 }, {  26,4885 }, {  27,4885 }, {  28,4885 },
 {  29,4885 }, {  30,4885 }, {  31,4885 }, {  32,4885 }, {  33,5143 },
 {  34,4885 }, {  35,5143 }, {  36,4885 }, {  37,5143 }, {  38,5143 },
 {  39,4885 }, {  40,4885 }, {  41,4885 }, {  42,5143 }, {  43,5143 },
 {  44,4885 }, {  45,5143 }, {  46,4885 }, {  47,5143 }, {  48,4885 },
 {  49,4885 }, {  50,4885 }, {  51,4885 }, {  52,4885 }, {  53,4885 },
 {  54,4885 }, {  55,4885 }, {  56,4885 }, {  57,4885 }, {  58,4885 },

 {  59,4885 }, {  60,5143 }, {  61,5143 }, {  62,5143 }, {  63,5143 },
 {  64,5143 }, {  65,4885 }, {  66,4885 }, {  67,4885 }, {  68,4885 },
 {  69,4885 }, {  70,4885 }, {  71,4885 }, {  72,4885 }, {  73,4885 },
 {  74,4885 }, {  75,4885 }, {  76,4885 }, {  77,4885 }, {  78,4885 },
 {  79,4885 }, {  80,4885 }, {  81,4885 }, {  82,4885 }, {  83,4885 },
 {  84,4885 }, {  85,4885 }, {  86,4885 }, {  87,4885 }, {  88,4885 },
 {  89,4885 }, {  90,4885 }, {  91,4885 }, {  92,4885 }, {  93,4885 },
 {  94,5143 }, {  95,4885 }, {  96,5143 }, {  97,4885 }, {  98,4885 },
 {  99,4885 }, { 100,4885 }, { 101,4885 }, { 102,4885 }, { 103,4885 },
 { 104,4885 }, { 105,4885 }, { 106,4885 }, { 107,4885 }, { 108,4885 },

 { 109,4885 }, { 110,4885 }, { 111,4885 }, { 112,4885 }, { 113,4885 },
 { 114,4885 }, { 115,4885 }, { 116,4885 }, { 117,4885 }, { 118,4885 },
 { 119,4885 }, { 120,4885 }, { 121,4885 }, { 122,4885 }, { 123,4885 },
 { 124,5143 }, { 125,4885 }, { 126,5143 }, { 127,4885 }, { 128,4885 },
 { 129,4885 }, { 130,4885 }, { 131,4885 }, { 132,4885 }, { 133,4885 },
 { 134,4885 }, { 135,4885 }, { 136,4885 }, { 137,4885 }, { 138,4885 },
 { 139,4885 }, { 140,4885 }, { 141,4885 }, { 142,4885 }, { 143,4885 },
 { 144,4885 }, { 145,4885 }, { 146,4885 }, { 147,4885 }, { 148,4885 },
 { 149,4885 }, { 150,4885 }, { 151,4885 }, { 152,4885 }, { 153,4885 },
 { 154,4885 }, { 155,4885 }, { 156,4885 }, { 157,4885 }, { 158,4885 },

 { 159,4885 }, { 160,4885 }, { 161,4885 }, { 162,4885 }, { 163,4885 },
 { 164,4885 }, { 165,4885 }, { 166,4885 }, { 167,4885 }, { 168,4885 },
 { 169,4885 }, { 170,4885 }, { 171,4885 }, { 172,4885 }, { 173,4885 },
 { 174,4885 }, { 175,4885 }, { 176,4885 }, { 177,4885 }, { 178,4885 },
 { 179,4885 }, { 180,4885 }, { 181,4885 }, { 182,4885 }, { 183,4885 },
 { 184,4885 }, { 185,4885 }, { 186,4885 }, { 187,4885 }, { 188,4885 },
 { 189,4885 }, { 190,4885 }, { 191,4885 }, { 192,4885 }, { 193,4885 },
 { 194,4885 }, { 195,4885 }, { 196,4885 }, { 197,4885 }, { 198,4885 },
 { 199,4885 }, { 200,4885 }, { 201,4885 }, { 202,4885 }, { 203,4885 },
 { 204,4885 }, { 205,4885 }, { 206,4885 }, { 207,4885 }, { 208,4885 },

 { 209,4885 }, { 210,4885 }, { 211,4885 }, { 212,4885 }, { 213,4885 },
 { 214,4885 }, { 215,4885 }, { 216,4885 }, { 217,4885 }, { 218,4885 },
 { 219,4885 }, { 220,4885 }, { 221,4885 }, { 222,4885 }, { 223,4885 },
 { 224,4885 }, { 225,4885 }, { 226,4885 }, { 227,4885 }, { 228,4885 },
 { 229,4885 }, { 230,4885 }, { 231,4885 }, { 232,4885 }, { 233,4885 },
 { 234,4885 }, { 235,4885 }, { 236,4885 }, { 237,4885 }, { 238,4885 },
 { 239,4885 }, { 240,4885 }, { 241,4885 }, { 242,4885 }, { 243,4885 },
 { 244,4885 }, { 245,4885 }, { 246,4885 }, { 247,4885 }, { 248,4885 },
 { 249,4885 }, { 250,4885 }, { 251,4885 }, { 252,4885 }, { 253,4885 },
 { 254,4885 }, { 255,4885 }, { 256,4885 }, {   0,  64 }, {   0,11947 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  48,5143 }, {  49,5143 }, {  50,5143 },

 {  51,5143 }, {  52,5143 }, {  53,5143 }, {  54,5143 }, {  55,5143 },
 {  56,5143 }, {  57,5143 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,-6216 },
 {  66,-6216 }, {  67,-6216 }, {  68,-6216 }, {  69,5400 }, {  70,-6216 },
 {  71,-6216 }, {  72,-6216 }, {  73,-6216 }, {  74,-6216 }, {  75,-6216 },
 {  76,-6216 }, {  77,-6216 }, {  78,-6216 }, {  79,-6216 }, {  80,-6216 },
 {  81,-6216 }, {  82,-6216 }, {  83,-6216 }, {  84,-6216 }, {  85,-6216 },
 {  86,-6216 }, {  87,-6216 }, {  88,-6216 }, {  89,-6216 }, {  90,-6216 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95,5410 },
 {   0,   0 }, {  97,-6216 }, {  98,-6216 }, {  99,-6216 }, { 100,-6216 },

 { 101,5400 }, { 102,-6216 }, { 103,-6216 }, { 104,-6216 }, { 105,-6216 },
 { 106,-6216 }, { 107,-6216 }, { 108,-6216 }, { 109,-6216 }, { 110,-6216 },
 { 111,-6216 }, { 112,-6216 }, { 113,-6216 }, { 114,-6216 }, { 115,-6216 },
 { 116,-6216 }, { 117,-6216 }, { 118,-6216 }, { 119,-6216 }, { 120,-6216 },
 { 121,-6216 }, { 122,-6216 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, { 128,-6216 }, { 129,-6216 }, { 130,-6216 },
 { 131,-6216 }, { 132,-6216 }, { 133,-6216 }, { 134,-6216 }, { 135,-6216 },
 { 136,-6216 }, { 137,-6216 }, { 138,-6216 }, { 139,-6216 }, { 140,-6216 },
 { 141,-6216 }, { 142,-6216 }, { 143,-6216 }, { 144,-6216 }, { 145,-6216 },
 { 146,-6216 }, { 147,-6216 }, { 148,-6216 }, { 149,-6216 }, { 150,-6216 },

 { 151,-6216 }, { 152,-6216 }, { 153,-6216 }, { 154,-6216 }, { 155,-6216 },
 { 156,-6216 }, { 157,-6216 }, { 158,-6216 }, { 159,-6216 }, { 160,-6216 },
 { 161,-6216 }, { 162,-6216 }, { 163,-6216 }, { 164,-6216 }, { 165,-6216 },
 { 166,-6216 }, { 167,-6216 }, { 168,-6216 }, { 169,-6216 }, { 170,-6216 },
 { 171,-6216 }, { 172,-6216 }, { 173,-6216 }, { 174,-6216 }, { 175,-6216 },
 { 176,-6216 }, { 177,-6216 }, { 178,-6216 }, { 179,-6216 }, { 180,-6216 },
 { 181,-6216 }, { 182,-6216 }, { 183,-6216 }, { 184,-6216 }, { 185,-6216 },
 { 186,-6216 }, { 187,-6216 }, { 188,-6216 }, { 189,-6216 }, { 190,-6216 },
 { 191,-6216 }, { 192,-6216 }, { 193,-6216 }, { 194,-6216 }, { 195,-6216 },
 { 196,-6216 }, { 197,-6216 }, { 198,-6216 }, { 199,-6216 }, { 200,-6216 },

 { 201,-6216 }, { 202,-6216 }, { 203,-6216 }, { 204,-6216 }, { 205,-6216 },
 { 206,-6216 }, { 207,-6216 }, { 208,-6216 }, { 209,-6216 }, { 210,-6216 },
 { 211,-6216 }, { 212,-6216 }, { 213,-6216 }, { 214,-6216 }, { 215,-6216 },
 { 216,-6216 }, { 217,-6216 }, { 218,-6216 }, { 219,-6216 }, { 220,-6216 },
 { 221,-6216 }, { 222,-6216 }, { 223,-6216 }, { 224,-6216 }, { 225,-6216 },
 { 226,-6216 }, { 227,-6216 }, { 228,-6216 }, { 229,-6216 }, { 230,-6216 },
 { 231,-6216 }, { 232,-6216 }, { 233,-6216 }, { 234,-6216 }, { 235,-6216 },
 { 236,-6216 }, { 237,-6216 }, { 238,-6216 }, { 239,-6216 }, { 240,-6216 },
 { 241,-6216 }, { 242,-6216 }, { 243,-6216 }, { 244,-6216 }, { 245,-6216 },
 { 246,-6216 }, { 247,-6216 }, { 248,-6216 }, { 249,-6216 }, { 250,-6216 },

 { 251,-6216 }, { 252,-6216 }, { 253,-6216 }, { 254,-6216 }, { 255,-6216 },
 {   0,   2 }, {   0,11690 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,  64 }, {   0,11658 }, {  33,5178 },
 {   0,   0 }, {  35,5178 }, {   0,   0 }, {  37,5178 }, {  38,5178 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  42,5178 }, {  43,5178 },

 {   0,   0 }, {  45,5178 }, {   0,   0 }, {  47,5178 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  60,5178 }, {  61,5178 }, {  62,5178 }, {  63,5178 },
 {  64,5178 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  46,-6503 },
 {   0,   0 }, {  48,5212 }, {  49,5212 }, {  50,5212 }, {  51,5212 },
 {  52,5212 }, {  53,5212 }, {  54,5212 }, {  55,5212 }, {  56,5212 },
 {  57,5212 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {  94,5178 }, {   0,   0 }, {  96,5178 }, {  65,-6505 }, {  66,-6505 },
 {  67,-6505 }, {  68,-6505 }, {  69,5111 }, {  70,-6505 }, {  71,-6505 },
 {  72,-6505 }, {  73,-6505 }, {  74,-6505 }, {  75,-6505 }, {  76,-6505 },
 {  77,-6505 }, {  78,-6505 }, {  79,-6505 }, {  80,-6505 }, {  81,-6505 },
 {  82,-6505 }, {  83,-6505 }, {  84,-6505 }, {  85,-6505 }, {  86,-6505 },
 {  87,-6505 }, {  88,-6505 }, {  89,-6505 }, {  90,-6505 }, {   0,   0 },
 { 124,5178 }, {   0,   0 }, { 126,5178 }, {  95,-6505 }, {   0,   0 },
 {  97,-6505 }, {  98,-6505 }, {  99,-6505 }, { 100,-6505 }, { 101,5111 },
 { 102,-6505 }, { 103,-6505 }, { 104,-6505 }, { 105,-6505 }, { 106,-6505 },
 { 107,-6505 }, { 108,-6505 }, { 109,-6505 }, { 110,-6505 }, { 111,-6505 },

 { 112,-6505 }, { 113,-6505 }, { 114,-6505 }, { 115,-6505 }, { 116,-6505 },
 { 117,-6505 }, { 118,-6505 }, { 119,-6505 }, { 120,-6505 }, { 121,-6505 },
 { 122,-6505 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, { 128,-6505 }, { 129,-6505 }, { 130,-6505 }, { 131,-6505 },
 { 132,-6505 }, { 133,-6505 }, { 134,-6505 }, { 135,-6505 }, { 136,-6505 },
 { 137,-6505 }, { 138,-6505 }, { 139,-6505 }, { 140,-6505 }, { 141,-6505 },
 { 142,-6505 }, { 143,-6505 }, { 144,-6505 }, { 145,-6505 }, { 146,-6505 },
 { 147,-6505 }, { 148,-6505 }, { 149,-6505 }, { 150,-6505 }, { 151,-6505 },
 { 152,-6505 }, { 153,-6505 }, { 154,-6505 }, { 155,-6505 }, { 156,-6505 },
 { 157,-6505 }, { 158,-6505 }, { 159,-6505 }, { 160,-6505 }, { 161,-6505 },

 { 162,-6505 }, { 163,-6505 }, { 164,-6505 }, { 165,-6505 }, { 166,-6505 },
 { 167,-6505 }, { 168,-6505 }, { 169,-6505 }, { 170,-6505 }, { 171,-6505 },
 { 172,-6505 }, { 173,-6505 }, { 174,-6505 }, { 175,-6505 }, { 176,-6505 },
 { 177,-6505 }, { 178,-6505 }, { 179,-6505 }, { 180,-6505 }, { 181,-6505 },
 { 182,-6505 }, { 183,-6505 }, { 184,-6505 }, { 185,-6505 }, { 186,-6505 },
 { 187,-6505 }, { 188,-6505 }, { 189,-6505 }, { 190,-6505 }, { 191,-6505 },
 { 192,-6505 }, { 193,-6505 }, { 194,-6505 }, { 195,-6505 }, { 196,-6505 },
 { 197,-6505 }, { 198,-6505 }, { 199,-6505 }, { 200,-6505 }, { 201,-6505 },
 { 202,-6505 }, { 203,-6505 }, { 204,-6505 }, { 205,-6505 }, { 206,-6505 },
 { 207,-6505 }, { 208,-6505 }, { 209,-6505 }, { 210,-6505 }, { 211,-6505 },

 { 212,-6505 }, { 213,-6505 }, { 214,-6505 }, { 215,-6505 }, { 216,-6505 },
 { 217,-6505 }, { 218,-6505 }, { 219,-6505 }, { 220,-6505 }, { 221,-6505 },
 { 222,-6505 }, { 223,-6505 }, { 224,-6505 }, { 225,-6505 }, { 226,-6505 },
 { 227,-6505 }, { 228,-6505 }, { 229,-6505 }, { 230,-6505 }, { 231,-6505 },
 { 232,-6505 }, { 233,-6505 }, { 234,-6505 }, { 235,-6505 }, { 236,-6505 },
 { 237,-6505 }, { 238,-6505 }, { 239,-6505 }, { 240,-6505 }, { 241,-6505 },
 { 242,-6505 }, { 243,-6505 }, { 244,-6505 }, { 245,-6505 }, { 246,-6505 },
 { 247,-6505 }, { 248,-6505 }, { 249,-6505 }, { 250,-6505 }, { 251,-6505 },
 { 252,-6505 }, { 253,-6505 }, { 254,-6505 }, { 255,-6505 }, {   0,  57 },
 {   0,11401 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  46,-257 }, {   0,   0 }, {  48,   0 }, {  49,   0 },
 {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 }, {  54,   0 },

 {  55,   0 }, {  56,   0 }, {  57,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65,-7123 }, {  66,-7123 }, {  67,-7123 }, {  68,-7123 }, {  69, 257 },
 {  70,-7123 }, {  71,-7123 }, {  72,-7123 }, {  73,-7123 }, {  74,-7123 },
 {  75,-7123 }, {  76,-7123 }, {  77,-7123 }, {  78,-7123 }, {  79,-7123 },
 {  80,-7123 }, {  81,-7123 }, {  82,-7123 }, {  83,-7123 }, {  84,-7123 },
 {  85,-7123 }, {  86,-7123 }, {  87,-7123 }, {  88,-7123 }, {  89,-7123 },
 {  90,-7123 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  95, 298 }, {   0,   0 }, {  97,-7123 }, {  98,-7123 }, {  99,-7123 },
 { 100,-7123 }, { 101, 257 }, { 102,-7123 }, { 103,-7123 }, { 104,-7123 },

 { 105,-7123 }, { 106,-7123 }, { 107,-7123 }, { 108,-7123 }, { 109,-7123 },
 { 110,-7123 }, { 111,-7123 }, { 112,-7123 }, { 113,-7123 }, { 114,-7123 },
 { 115,-7123 }, { 116,-7123 }, { 117,-7123 }, { 118,-7123 }, { 119,-7123 },
 { 120,-7123 }, { 121,-7123 }, { 122,-7123 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,-7123 }, { 129,-7123 },
 { 130,-7123 }, { 131,-7123 }, { 132,-7123 }, { 133,-7123 }, { 134,-7123 },
 { 135,-7123 }, { 136,-7123 }, { 137,-7123 }, { 138,-7123 }, { 139,-7123 },
 { 140,-7123 }, { 141,-7123 }, { 142,-7123 }, { 143,-7123 }, { 144,-7123 },
 { 145,-7123 }, { 146,-7123 }, { 147,-7123 }, { 148,-7123 }, { 149,-7123 },
 { 150,-7123 }, { 151,-7123 }, { 152,-7123 }, { 153,-7123 }, { 154,-7123 },

 { 155,-7123 }, { 156,-7123 }, { 157,-7123 }, { 158,-7123 }, { 159,-7123 },
 { 160,-7123 }, { 161,-7123 }, { 162,-7123 }, { 163,-7123 }, { 164,-7123 },
 { 165,-7123 }, { 166,-7123 }, { 167,-7123 }, { 168,-7123 }, { 169,-7123 },
 { 170,-7123 }, { 171,-7123 }, { 172,-7123 }, { 173,-7123 }, { 174,-7123 },
 { 175,-7123 }, { 176,-7123 }, { 177,-7123 }, { 178,-7123 }, { 179,-7123 },
 { 180,-7123 }, { 181,-7123 }, { 182,-7123 }, { 183,-7123 }, { 184,-7123 },
 { 185,-7123 }, { 186,-7123 }, { 187,-7123 }, { 188,-7123 }, { 189,-7123 },
 { 190,-7123 }, { 191,-7123 }, { 192,-7123 }, { 193,-7123 }, { 194,-7123 },
 { 195,-7123 }, { 196,-7123 }, { 197,-7123 }, { 198,-7123 }, { 199,-7123 },
 { 200,-7123 }, { 201,-7123 }, { 202,-7123 }, { 203,-7123 }, { 204,-7123 },

 { 205,-7123 }, { 206,-7123 }, { 207,-7123 }, { 208,-7123 }, { 209,-7123 },
 { 210,-7123 }, { 211,-7123 }, { 212,-7123 }, { 213,-7123 }, { 214,-7123 },
 { 215,-7123 }, { 216,-7123 }, { 217,-7123 }, { 218,-7123 }, { 219,-7123 },
 { 220,-7123 }, { 221,-7123 }, { 222,-7123 }, { 223,-7123 }, { 224,-7123 },
 { 225,-7123 }, { 226,-7123 }, { 227,-7123 }, { 228,-7123 }, { 229,-7123 },
 { 230,-7123 }, { 231,-7123 }, { 232,-7123 }, { 233,-7123 }, { 234,-7123 },
 { 235,-7123 }, { 236,-7123 }, { 237,-7123 }, { 238,-7123 }, { 239,-7123 },
 { 240,-7123 }, { 241,-7123 }, { 242,-7123 }, { 243,-7123 }, { 244,-7123 },
 { 245,-7123 }, { 246,-7123 }, { 247,-7123 }, { 248,-7123 }, { 249,-7123 },
 { 250,-7123 }, { 251,-7123 }, { 252,-7123 }, { 253,-7123 }, { 254,-7123 },

 { 255,-7123 }, {   0,  68 }, {   0,11144 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,  62 }, {   0,11134 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  61 },
 {   0,11126 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,  68 }, {   0,11103 }, {   0,   0 },
 {  43,4957 }, {   0,   0 }, {  45,4957 }, {   0,   0 }, {   0,   0 },

 {  48,5212 }, {  49,5212 }, {  50,5212 }, {  51,5212 }, {  52,5212 },
 {  53,5212 }, {  54,5212 }, {  55,5212 }, {  56,5212 }, {  57,5212 },
 {  48,5459 }, {  49,5459 }, {  50,5459 }, {  51,5459 }, {  52,5459 },
 {  53,5459 }, {  54,5459 }, {  55,5459 }, {  48,5708 }, {  49,5708 },
 {  50,5708 }, {  51,5708 }, {  52,5708 }, {  53,5708 }, {  54,5708 },
 {  55,5708 }, {  56,5708 }, {  57,5708 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65,5708 }, {  66,5708 }, {  67,5708 }, {  68,5708 }, {  69,5708 },
 {  70,5708 }, {  48,5980 }, {  49,5980 }, {  50,5980 }, {  51,5980 },
 {  52,5980 }, {  53,5980 }, {  54,5980 }, {  55,5980 }, {  56,5980 },

 {  57,5980 }, {   0,  49 }, {   0,11044 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  95,5467 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,  51 }, {   0,11033 }, {   0,   0 },
 {  95,5965 }, {   0,   0 }, {  97,5708 }, {  98,5708 }, {  99,5708 },
 { 100,5708 }, { 101,5708 }, { 102,5708 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  33,-1765 }, {   0,   0 }, {  35,-1765 }, {   0,   0 }, {  37,-1765 },
 {  38,-1765 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  42,-1765 },
 {  43,-1765 }, {  33,-1776 }, {  45,-1765 }, {  35,-1776 }, {  47,-1765 },

 {  37,-1776 }, {  38,-1776 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  42,-1776 }, {  43,-1776 }, {   0,   0 }, {  45,-1776 }, {   0,   0 },
 {  47,-1776 }, {   0,   0 }, {  60,-1765 }, {  61,-1765 }, {  62,-1765 },
 {  63,-1765 }, {  64,-1765 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  60,-1776 }, {  61,-1776 },
 {  62,-1776 }, {  63,-1776 }, {  64,-1776 }, {   0,   0 }, {   0,  48 },
 {   0,10966 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  94,-1765 }, {   0,   0 }, {  96,-1765 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  94,-1776 }, {   0,   0 }, {  96,-1776 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  33,-1843 }, {   0,   0 },
 {  35,-1843 }, {   0,   0 }, {  37,-1843 }, {  38,-1843 }, {   0,  50 },
 {   0,10926 }, {   0,   0 }, {  42,-1843 }, {  43,-1843 }, {   0,   0 },
 {  45,-1843 }, { 124,-1765 }, {  47,-1843 }, { 126,-1765 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, { 124,-1776 }, {   0,   0 }, { 126,-1776 },
 {  60,-1843 }, {  61,-1843 }, {  62,-1843 }, {  63,-1843 }, {  64,-1843 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  33,-1883 }, {   0,   0 },
 {  35,-1883 }, {   0,   0 }, {  37,-1883 }, {  38,-1883 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  42,-1883 }, {  43,-1883 }, {   0,   0 },
 {  45,-1883 }, {   0,   0 }, {  47,-1883 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  94,-1843 },
 {   0,   0 }, {  96,-1843 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  60,-1883 }, {  61,-1883 }, {  62,-1883 }, {  63,-1883 }, {  64,-1883 },
 {   0,  74 }, {   0,10860 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, { 124,-1843 },
 {   0,   0 }, { 126,-1843 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  94,-1883 },
 {   0,   0 }, {  96,-1883 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  36,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,   0 },
 {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 },
 {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 }, { 124,-1883 },
 {   0,   0 }, { 126,-1883 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {  65,   0 }, {  66,   0 }, {  67,   0 }, {  68,   0 },
 {  69,   0 }, {  70,   0 }, {  71,   0 }, {  72,   0 }, {  73,   0 },
 {  74,   0 }, {  75,   0 }, {  76,   0 }, {  77,   0 }, {  78,   0 },
 {  79,   0 }, {  80,   0 }, {  81,   0 }, {  82,   0 }, {  83,   0 },
 {  84,   0 }, {  85,   0 }, {  86,   0 }, {  87,   0 }, {  88,   0 },
 {  89,   0 }, {  90,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  95,   0 }, {   0,   0 }, {  97,   0 }, {  98,   0 },
 {  99,   0 }, { 100,   0 }, { 101,   0 }, { 102,   0 }, { 103,   0 },
 { 104,   0 }, { 105,   0 }, { 106,   0 }, { 107,   0 }, { 108,   0 },
 { 109,   0 }, { 110,   0 }, { 111,   0 }, { 112,   0 }, { 113,   0 },

 { 114,   0 }, { 115,   0 }, { 116,   0 }, { 117,   0 }, { 118,   0 },
 { 119,   0 }, { 120,   0 }, { 121,   0 }, { 122,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,   0 },
 { 129,   0 }, { 130,   0 }, { 131,   0 }, { 132,   0 }, { 133,   0 },
 { 134,   0 }, { 135,   0 }, { 136,   0 }, { 137,   0 }, { 138,   0 },
 { 139,   0 }, { 140,   0 }, { 141,   0 }, { 142,   0 }, { 143,   0 },
 { 144,   0 }, { 145,   0 }, { 146,   0 }, { 147,   0 }, { 148,   0 },
 { 149,   0 }, { 150,   0 }, { 151,   0 }, { 152,   0 }, { 153,   0 },
 { 154,   0 }, { 155,   0 }, { 156,   0 }, { 157,   0 }, { 158,   0 },
 { 159,   0 }, { 160,   0 }, { 161,   0 }, { 162,   0 }, { 163,   0 },

 { 164,   0 }, { 165,   0 }, { 166,   0 }, { 167,   0 }, { 168,   0 },
 { 169,   0 }, { 170,   0 }, { 171,   0 }, { 172,   0 }, { 173,   0 },
 { 174,   0 }, { 175,   0 }, { 176,   0 }, { 177,   0 }, { 178,   0 },
 { 179,   0 }, { 180,   0 }, { 181,   0 }, { 182,   0 }, { 183,   0 },
 { 184,   0 }, { 185,   0 }, { 186,   0 }, { 187,   0 }, { 188,   0 },
 { 189,   0 }, { 190,   0 }, { 191,   0 }, { 192,   0 }, { 193,   0 },
 { 194,   0 }, { 195,   0 }, { 196,   0 }, { 197,   0 }, { 198,   0 },
 { 199,   0 }, { 200,   0 }, { 201,   0 }, { 202,   0 }, { 203,   0 },
 { 204,   0 }, { 205,   0 }, { 206,   0 }, { 207,   0 }, { 208,   0 },
 { 209,   0 }, { 210,   0 }, { 211,   0 }, { 212,   0 }, { 213,   0 },

 { 214,   0 }, { 215,   0 }, { 216,   0 }, { 217,   0 }, { 218,   0 },
 { 219,   0 }, { 220,   0 }, { 221,   0 }, { 222,   0 }, { 223,   0 },
 { 224,   0 }, { 225,   0 }, { 226,   0 }, { 227,   0 }, { 228,   0 },
 { 229,   0 }, { 230,   0 }, { 231,   0 }, { 232,   0 }, { 233,   0 },
 { 234,   0 }, { 235,   0 }, { 236,   0 }, { 237,   0 }, { 238,   0 },
 { 239,   0 }, { 240,   0 }, { 241,   0 }, { 242,   0 }, { 243,   0 },
 { 244,   0 }, { 245,   0 }, { 246,   0 }, { 247,   0 }, { 248,   0 },
 { 249,   0 }, { 250,   0 }, { 251,   0 }, { 252,   0 }, { 253,   0 },
 { 254,   0 }, { 255,   0 }, {   0,  10 }, {   0,10603 }, {   1,   0 },
 {   2,   0 }, {   3,   0 }, {   4,   0 }, {   5,   0 }, {   6,   0 },

 {   7,   0 }, {   8,   0 }, {   9,   0 }, {  10,   0 }, {  11,   0 },
 {  12,   0 }, {  13,   0 }, {  14,   0 }, {  15,   0 }, {  16,   0 },
 {  17,   0 }, {  18,   0 }, {  19,   0 }, {  20,   0 }, {  21,   0 },
 {  22,   0 }, {  23,   0 }, {  24,   0 }, {  25,   0 }, {  26,   0 },
 {  27,   0 }, {  28,   0 }, {  29,   0 }, {  30,   0 }, {  31,   0 },
 {  32,   0 }, {  33,   0 }, {  34,   0 }, {  35,   0 }, {  36,   0 },
 {  37,   0 }, {  38,   0 }, {   0,   0 }, {  40,   0 }, {  41,   0 },
 {  42,   0 }, {  43,   0 }, {  44,   0 }, {  45,   0 }, {  46,   0 },
 {  47,   0 }, {  48,   0 }, {  49,   0 }, {  50,   0 }, {  51,   0 },
 {  52,   0 }, {  53,   0 }, {  54,   0 }, {  55,   0 }, {  56,   0 },

 {  57,   0 }, {  58,   0 }, {  59,   0 }, {  60,   0 }, {  61,   0 },
 {  62,   0 }, {  63,   0 }, {  64,   0 }, {  65,   0 }, {  66,   0 },
 {  67,   0 }, {  68,   0 }, {  69,   0 }, {  70,   0 }, {  71,   0 },
 {  72,   0 }, {  73,   0 }, {  74,   0 }, {  75,   0 }, {  76,   0 },
 {  77,   0 }, {  78,   0 }, {  79,   0 }, {  80,   0 }, {  81,   0 },
 {  82,   0 }, {  83,   0 }, {  84,   0 }, {  85,   0 }, {  86,   0 },
 {  87,   0 }, {  88,   0 }, {  89,   0 }, {  90,   0 }, {  91,   0 },
 {  92,   0 }, {  93,   0 }, {  94,   0 }, {  95,   0 }, {  96,   0 },
 {  97,   0 }, {  98,   0 }, {  99,   0 }, { 100,   0 }, { 101,   0 },
 { 102,   0 }, { 103,   0 }, { 104,   0 }, { 105,   0 }, { 106,   0 },

 { 107,   0 }, { 108,   0 }, { 109,   0 }, { 110,   0 }, { 111,   0 },
 { 112,   0 }, { 113,   0 }, { 114,   0 }, { 115,   0 }, { 116,   0 },
 { 117,   0 }, { 118,   0 }, { 119,   0 }, { 120,   0 }, { 121,   0 },
 { 122,   0 }, { 123,   0 }, { 124,   0 }, { 125,   0 }, { 126,   0 },
 { 127,   0 }, { 128,   0 }, { 129,   0 }, { 130,   0 }, { 131,   0 },
 { 132,   0 }, { 133,   0 }, { 134,   0 }, { 135,   0 }, { 136,   0 },
 { 137,   0 }, { 138,   0 }, { 139,   0 }, { 140,   0 }, { 141,   0 },
 { 142,   0 }, { 143,   0 }, { 144,   0 }, { 145,   0 }, { 146,   0 },
 { 147,   0 }, { 148,   0 }, { 149,   0 }, { 150,   0 }, { 151,   0 },
 { 152,   0 }, { 153,   0 }, { 154,   0 }, { 155,   0 }, { 156,   0 },

 { 157,   0 }, { 158,   0 }, { 159,   0 }, { 160,   0 }, { 161,   0 },
 { 162,   0 }, { 163,   0 }, { 164,   0 }, { 165,   0 }, { 166,   0 },
 { 167,   0 }, { 168,   0 }, { 169,   0 }, { 170,   0 }, { 171,   0 },
 { 172,   0 }, { 173,   0 }, { 174,   0 }, { 175,   0 }, { 176,   0 },
 { 177,   0 }, { 178,   0 }, { 179,   0 }, { 180,   0 }, { 181,   0 },
 { 182,   0 }, { 183,   0 }, { 184,   0 }, { 185,   0 }, { 186,   0 },
 { 187,   0 }, { 188,   0 }, { 189,   0 }, { 190,   0 }, { 191,   0 },
 { 192,   0 }, { 193,   0 }, { 194,   0 }, { 195,   0 }, { 196,   0 },
 { 197,   0 }, { 198,   0 }, { 199,   0 }, { 200,   0 }, { 201,   0 },
 { 202,   0 }, { 203,   0 }, { 204,   0 }, { 205,   0 }, { 206,   0 },

 { 207,   0 }, { 208,   0 }, { 209,   0 }, { 210,   0 }, { 211,   0 },
 { 212,   0 }, { 213,   0 }, { 214,   0 }, { 215,   0 }, { 216,   0 },
 { 217,   0 }, { 218,   0 }, { 219,   0 }, { 220,   0 }, { 221,   0 },
 { 222,   0 }, { 223,   0 }, { 224,   0 }, { 225,   0 }, { 226,   0 },
 { 227,   0 }, { 228,   0 }, { 229,   0 }, { 230,   0 }, { 231,   0 },
 { 232,   0 }, { 233,   0 }, { 234,   0 }, { 235,   0 }, { 236,   0 },
 { 237,   0 }, { 238,   0 }, { 239,   0 }, { 240,   0 }, { 241,   0 },
 { 242,   0 }, { 243,   0 }, { 244,   0 }, { 245,   0 }, { 246,   0 },
 { 247,   0 }, { 248,   0 }, { 249,   0 }, { 250,   0 }, { 251,   0 },
 { 252,   0 }, { 253,   0 }, { 254,   0 }, { 255,   0 }, { 256,   0 },

 {   0,   5 }, {   0,10345 }, {   1,   0 }, {   2,   0 }, {   3,   0 },
 {   4,   0 }, {   5,   0 }, {   6,   0 }, {   7,   0 }, {   8,   0 },
 {   9,   0 }, {  10,   0 }, {  11,   0 }, {  12,   0 }, {  13,   0 },
 {  14,   0 }, {  15,   0 }, {  16,   0 }, {  17,   0 }, {  18,   0 },
 {  19,   0 }, {  20,   0 }, {  21,   0 }, {  22,   0 }, {  23,   0 },
 {  24,   0 }, {  25,   0 }, {  26,   0 }, {  27,   0 }, {  28,   0 },
 {  29,   0 }, {  30,   0 }, {  31,   0 }, {  32,   0 }, {  33,   0 },
 {  34,   0 }, {  35,   0 }, {  36,   0 }, {  37,   0 }, {  38,   0 },
 {  39,   0 }, {  40,   0 }, {  41,   0 }, {   0,   0 }, {  43,   0 },
 {  44,   0 }, {  45,   0 }, {  46,   0 }, {   0,   0 }, {  48,   0 },

 {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 },
 {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 }, {  58,   0 },
 {  59,   0 }, {  60,   0 }, {  61,   0 }, {  62,   0 }, {  63,   0 },
 {  64,   0 }, {  65,   0 }, {  66,   0 }, {  67,   0 }, {  68,   0 },
 {  69,   0 }, {  70,   0 }, {  71,   0 }, {  72,   0 }, {  73,   0 },
 {  74,   0 }, {  75,   0 }, {  76,   0 }, {  77,   0 }, {  78,   0 },
 {  79,   0 }, {  80,   0 }, {  81,   0 }, {  82,   0 }, {  83,   0 },
 {  84,   0 }, {  85,   0 }, {  86,   0 }, {  87,   0 }, {  88,   0 },
 {  89,   0 }, {  90,   0 }, {  91,   0 }, {  92,   0 }, {  93,   0 },
 {  94,   0 }, {  95,   0 }, {  96,   0 }, {  97,   0 }, {  98,   0 },

 {  99,   0 }, { 100,   0 }, { 101,   0 }, { 102,   0 }, { 103,   0 },
 { 104,   0 }, { 105,   0 }, { 106,   0 }, { 107,   0 }, { 108,   0 },
 { 109,   0 }, { 110,   0 }, { 111,   0 }, { 112,   0 }, { 113,   0 },
 { 114,   0 }, { 115,   0 }, { 116,   0 }, { 117,   0 }, { 118,   0 },
 { 119,   0 }, { 120,   0 }, { 121,   0 }, { 122,   0 }, { 123,   0 },
 { 124,   0 }, { 125,   0 }, { 126,   0 }, { 127,   0 }, { 128,   0 },
 { 129,   0 }, { 130,   0 }, { 131,   0 }, { 132,   0 }, { 133,   0 },
 { 134,   0 }, { 135,   0 }, { 136,   0 }, { 137,   0 }, { 138,   0 },
 { 139,   0 }, { 140,   0 }, { 141,   0 }, { 142,   0 }, { 143,   0 },
 { 144,   0 }, { 145,   0 }, { 146,   0 }, { 147,   0 }, { 148,   0 },

 { 149,   0 }, { 150,   0 }, { 151,   0 }, { 152,   0 }, { 153,   0 },
 { 154,   0 }, { 155,   0 }, { 156,   0 }, { 157,   0 }, { 158,   0 },
 { 159,   0 }, { 160,   0 }, { 161,   0 }, { 162,   0 }, { 163,   0 },
 { 164,   0 }, { 165,   0 }, { 166,   0 }, { 167,   0 }, { 168,   0 },
 { 169,   0 }, { 170,   0 }, { 171,   0 }, { 172,   0 }, { 173,   0 },
 { 174,   0 }, { 175,   0 }, { 176,   0 }, { 177,   0 }, { 178,   0 },
 { 179,   0 }, { 180,   0 }, { 181,   0 }, { 182,   0 }, { 183,   0 },
 { 184,   0 }, { 185,   0 }, { 186,   0 }, { 187,   0 }, { 188,   0 },
 { 189,   0 }, { 190,   0 }, { 191,   0 }, { 192,   0 }, { 193,   0 },
 { 194,   0 }, { 195,   0 }, { 196,   0 }, { 197,   0 }, { 198,   0 },

 { 199,   0 }, { 200,   0 }, { 201,   0 }, { 202,   0 }, { 203,   0 },
 { 204,   0 }, { 205,   0 }, { 206,   0 }, { 207,   0 }, { 208,   0 },
 { 209,   0 }, { 210,   0 }, { 211,   0 }, { 212,   0 }, { 213,   0 },
 { 214,   0 }, { 215,   0 }, { 216,   0 }, { 217,   0 }, { 218,   0 },
 { 219,   0 }, { 220,   0 }, { 221,   0 }, { 222,   0 }, { 223,   0 },
 { 224,   0 }, { 225,   0 }, { 226,   0 }, { 227,   0 }, { 228,   0 },
 { 229,   0 }, { 230,   0 }, { 231,   0 }, { 232,   0 }, { 233,   0 },
 { 234,   0 }, { 235,   0 }, { 236,   0 }, { 237,   0 }, { 238,   0 },
 { 239,   0 }, { 240,   0 }, { 241,   0 }, { 242,   0 }, { 243,   0 },
 { 244,   0 }, { 245,   0 }, { 246,   0 }, { 247,   0 }, { 248,   0 },

 { 249,   0 }, { 250,   0 }, { 251,   0 }, { 252,   0 }, { 253,   0 },
 { 254,   0 }, { 255,   0 }, { 256,   0 }, {   0,   3 }, {   0,10087 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  33,5221 }, {   0,   0 }, {  35,5221 },
 {   0,   0 }, {  37,5221 }, {  38,5221 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {  42,5221 }, {  43,5221 }, {   0,   0 }, {  45,5221 },
 {   0,   0 }, {  47,5221 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  60,5221 },
 {  61,5221 }, {  62,5221 }, {  63,5221 }, {  64,5221 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  94,5221 }, {   0,   0 },
 {  96,5221 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 124,5221 }, {   0,   0 },
 { 126,5221 }, {   0,  43 }, {   0,9959 }, {   1,   0 }, {   2,   0 },
 {   3,   0 }, {   4,   0 }, {   5,   0 }, {   6,   0 }, {   7,   0 },
 {   8,   0 }, {   9,   0 }, {  10,   0 }, {  11,   0 }, {  12,   0 },

 {  13,   0 }, {  14,   0 }, {  15,   0 }, {  16,   0 }, {  17,   0 },
 {  18,   0 }, {  19,   0 }, {  20,   0 }, {  21,   0 }, {  22,   0 },
 {  23,   0 }, {  24,   0 }, {  25,   0 }, {  26,   0 }, {  27,   0 },
 {  28,   0 }, {  29,   0 }, {  30,   0 }, {  31,   0 }, {  32,   0 },
 {  33,   0 }, {   0,   0 }, {  35,   0 }, {  36,   0 }, {  37,   0 },
 {  38,   0 }, {  39,   0 }, {  40,   0 }, {  41,   0 }, {  42,   0 },
 {  43,   0 }, {  44,   0 }, {  45,   0 }, {  46,   0 }, {  47,   0 },
 {  48,   0 }, {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 },
 {  53,   0 }, {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 },
 {  58,   0 }, {  59,   0 }, {  60,   0 }, {  61,   0 }, {  62,   0 },

 {  63,   0 }, {  64,   0 }, {  65,   0 }, {  66,   0 }, {  67,   0 },
 {  68,   0 }, {  69,   0 }, {  70,   0 }, {  71,   0 }, {  72,   0 },
 {  73,   0 }, {  74,   0 }, {  75,   0 }, {  76,   0 }, {  77,   0 },
 {  78,   0 }, {  79,   0 }, {  80,   0 }, {  81,   0 }, {  82,   0 },
 {  83,   0 }, {  84,   0 }, {  85,   0 }, {  86,   0 }, {  87,   0 },
 {  88,   0 }, {  89,   0 }, {  90,   0 }, {  91,   0 }, {  92,   0 },
 {  93,   0 }, {  94,   0 }, {  95,   0 }, {  96,   0 }, {  97,   0 },
 {  98,   0 }, {  99,   0 }, { 100,   0 }, { 101,   0 }, { 102,   0 },
 { 103,   0 }, { 104,   0 }, { 105,   0 }, { 106,   0 }, { 107,   0 },
 { 108,   0 }, { 109,   0 }, { 110,   0 }, { 111,   0 }, { 112,   0 },

 { 113,   0 }, { 114,   0 }, { 115,   0 }, { 116,   0 }, { 117,   0 },
 { 118,   0 }, { 119,   0 }, { 120,   0 }, { 121,   0 }, { 122,   0 },
 { 123,   0 }, { 124,   0 }, { 125,   0 }, { 126,   0 }, { 127,   0 },
 { 128,   0 }, { 129,   0 }, { 130,   0 }, { 131,   0 }, { 132,   0 },
 { 133,   0 }, { 134,   0 }, { 135,   0 }, { 136,   0 }, { 137,   0 },
 { 138,   0 }, { 139,   0 }, { 140,   0 }, { 141,   0 }, { 142,   0 },
 { 143,   0 }, { 144,   0 }, { 145,   0 }, { 146,   0 }, { 147,   0 },
 { 148,   0 }, { 149,   0 }, { 150,   0 }, { 151,   0 }, { 152,   0 },
 { 153,   0 }, { 154,   0 }, { 155,   0 }, { 156,   0 }, { 157,   0 },
 { 158,   0 }, { 159,   0 }, { 160,   0 }, { 161,   0 }, { 162,   0 },

 { 163,   0 }, { 164,   0 }, { 165,   0 }, { 166,   0 }, { 167,   0 },
 { 168,   0 }, { 169,   0 }, { 170,   0 }, { 171,   0 }, { 172,   0 },
 { 173,   0 }, { 174,   0 }, { 175,   0 }, { 176,   0 }, { 177,   0 },
 { 178,   0 }, { 179,   0 }, { 180,   0 }, { 181,   0 }, { 182,   0 },
 { 183,   0 }, { 184,   0 }, { 185,   0 }, { 186,   0 }, { 187,   0 },
 { 188,   0 }, { 189,   0 }, { 190,   0 }, { 191,   0 }, { 192,   0 },
 { 193,   0 }, { 194,   0 }, { 195,   0 }, { 196,   0 }, { 197,   0 },
 { 198,   0 }, { 199,   0 }, { 200,   0 }, { 201,   0 }, { 202,   0 },
 { 203,   0 }, { 204,   0 }, { 205,   0 }, { 206,   0 }, { 207,   0 },
 { 208,   0 }, { 209,   0 }, { 210,   0 }, { 211,   0 }, { 212,   0 },

 { 213,   0 }, { 214,   0 }, { 215,   0 }, { 216,   0 }, { 217,   0 },
 { 218,   0 }, { 219,   0 }, { 220,   0 }, { 221,   0 }, { 222,   0 },
 { 223,   0 }, { 224,   0 }, { 225,   0 }, { 226,   0 }, { 227,   0 },
 { 228,   0 }, { 229,   0 }, { 230,   0 }, { 231,   0 }, { 232,   0 },
 { 233,   0 }, { 234,   0 }, { 235,   0 }, { 236,   0 }, { 237,   0 },
 { 238,   0 }, { 239,   0 }, { 240,   0 }, { 241,   0 }, { 242,   0 },
 { 243,   0 }, { 244,   0 }, { 245,   0 }, { 246,   0 }, { 247,   0 },
 { 248,   0 }, { 249,   0 }, { 250,   0 }, { 251,   0 }, { 252,   0 },
 { 253,   0 }, { 254,   0 }, { 255,   0 }, { 256,   0 }, {   0,   9 },
 {   0,9701 }, {   1,   0 }, {   2,   0 }, {   3,   0 }, {   4,   0 },

 {   5,   0 }, {   6,   0 }, {   7,   0 }, {   8,   0 }, {   9,   0 },
 {  10,   0 }, {  11,   0 }, {  12,   0 }, {  13,   0 }, {  14,   0 },
 {  15,   0 }, {  16,   0 }, {  17,   0 }, {  18,   0 }, {  19,   0 },
 {  20,   0 }, {  21,   0 }, {  22,   0 }, {  23,   0 }, {  24,   0 },
 {  25,   0 }, {  26,   0 }, {  27,   0 }, {  28,   0 }, {  29,   0 },
 {  30,   0 }, {  31,   0 }, {  32,   0 }, {  33,   0 }, {  34,   0 },
 {  35,   0 }, {  36,   0 }, {  37,   0 }, {  38,   0 }, {   0,   0 },
 {  40,   0 }, {  41,   0 }, {  42,   0 }, {  43,   0 }, {  44,   0 },
 {  45,   0 }, {  46,   0 }, {  47,   0 }, {  48,   0 }, {  49,   0 },
 {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 }, {  54,   0 },

 {  55,   0 }, {  56,   0 }, {  57,   0 }, {  58,   0 }, {  59,   0 },
 {  60,   0 }, {  61,   0 }, {  62,   0 }, {  63,   0 }, {  64,   0 },
 {  65,   0 }, {  66,   0 }, {  67,   0 }, {  68,   0 }, {  69,   0 },
 {  70,   0 }, {  71,   0 }, {  72,   0 }, {  73,   0 }, {  74,   0 },
 {  75,   0 }, {  76,   0 }, {  77,   0 }, {  78,   0 }, {  79,   0 },
 {  80,   0 }, {  81,   0 }, {  82,   0 }, {  83,   0 }, {  84,   0 },
 {  85,   0 }, {  86,   0 }, {  87,   0 }, {  88,   0 }, {  89,   0 },
 {  90,   0 }, {  91,   0 }, {  92,   0 }, {  93,   0 }, {  94,   0 },
 {  95,   0 }, {  96,   0 }, {  97,   0 }, {  98,   0 }, {  99,   0 },
 { 100,   0 }, { 101,   0 }, { 102,   0 }, { 103,   0 }, { 104,   0 },

 { 105,   0 }, { 106,   0 }, { 107,   0 }, { 108,   0 }, { 109,   0 },
 { 110,   0 }, { 111,   0 }, { 112,   0 }, { 113,   0 }, { 114,   0 },
 { 115,   0 }, { 116,   0 }, { 117,   0 }, { 118,   0 }, { 119,   0 },
 { 120,   0 }, { 121,   0 }, { 122,   0 }, { 123,   0 }, { 124,   0 },
 { 125,   0 }, { 126,   0 }, { 127,   0 }, { 128,   0 }, { 129,   0 },
 { 130,   0 }, { 131,   0 }, { 132,   0 }, { 133,   0 }, { 134,   0 },
 { 135,   0 }, { 136,   0 }, { 137,   0 }, { 138,   0 }, { 139,   0 },
 { 140,   0 }, { 141,   0 }, { 142,   0 }, { 143,   0 }, { 144,   0 },
 { 145,   0 }, { 146,   0 }, { 147,   0 }, { 148,   0 }, { 149,   0 },
 { 150,   0 }, { 151,   0 }, { 152,   0 }, { 153,   0 }, { 154,   0 },

 { 155,   0 }, { 156,   0 }, { 157,   0 }, { 158,   0 }, { 159,   0 },
 { 160,   0 }, { 161,   0 }, { 162,   0 }, { 163,   0 }, { 164,   0 },
 { 165,   0 }, { 166,   0 }, { 167,   0 }, { 168,   0 }, { 169,   0 },
 { 170,   0 }, { 171,   0 }, { 172,   0 }, { 173,   0 }, { 174,   0 },
 { 175,   0 }, { 176,   0 }, { 177,   0 }, { 178,   0 }, { 179,   0 },
 { 180,   0 }, { 181,   0 }, { 182,   0 }, { 183,   0 }, { 184,   0 },
 { 185,   0 }, { 186,   0 }, { 187,   0 }, { 188,   0 }, { 189,   0 },
 { 190,   0 }, { 191,   0 }, { 192,   0 }, { 193,   0 }, { 194,   0 },
 { 195,   0 }, { 196,   0 }, { 197,   0 }, { 198,   0 }, { 199,   0 },
 { 200,   0 }, { 201,   0 }, { 202,   0 }, { 203,   0 }, { 204,   0 },

 { 205,   0 }, { 206,   0 }, { 207,   0 }, { 208,   0 }, { 209,   0 },
 { 210,   0 }, { 211,   0 }, { 212,   0 }, { 213,   0 }, { 214,   0 },
 { 215,   0 }, { 216,   0 }, { 217,   0 }, { 218,   0 }, { 219,   0 },
 { 220,   0 }, { 221,   0 }, { 222,   0 }, { 223,   0 }, { 224,   0 },
 { 225,   0 }, { 226,   0 }, { 227,   0 }, { 228,   0 }, { 229,   0 },
 { 230,   0 }, { 231,   0 }, { 232,   0 }, { 233,   0 }, { 234,   0 },
 { 235,   0 }, { 236,   0 }, { 237,   0 }, { 238,   0 }, { 239,   0 },
 { 240,   0 }, { 241,   0 }, { 242,   0 }, { 243,   0 }, { 244,   0 },
 { 245,   0 }, { 246,   0 }, { 247,   0 }, { 248,   0 }, { 249,   0 },
 { 250,   0 }, { 251,   0 }, { 252,   0 }, { 253,   0 }, { 254,   0 },

 { 255,   0 }, { 256,   0 }, {   0,  21 }, {   0,9443 }, {   1,   0 },
 {   2,   0 }, {   3,   0 }, {   4,   0 }, {   5,   0 }, {   6,   0 },
 {   7,   0 }, {   8,   0 }, {   9,   0 }, {  10,   0 }, {  11,   0 },
 {  12,   0 }, {  13,   0 }, {  14,   0 }, {  15,   0 }, {  16,   0 },
 {  17,   0 }, {  18,   0 }, {  19,   0 }, {  20,   0 }, {  21,   0 },
 {  22,   0 }, {  23,   0 }, {  24,   0 }, {  25,   0 }, {  26,   0 },
 {  27,   0 }, {  28,   0 }, {  29,   0 }, {  30,   0 }, {  31,   0 },
 {  32,   0 }, {  33,   0 }, {  34,   0 }, {  35,   0 }, {  36,   0 },
 {  37,   0 }, {  38,   0 }, {   0,   0 }, {  40,   0 }, {  41,   0 },
 {  42,   0 }, {  43,   0 }, {  44,   0 }, {  45,   0 }, {  46,   0 },

 {  47,   0 }, {  48,   0 }, {  49,   0 }, {  50,   0 }, {  51,   0 },
 {  52,   0 }, {  53,   0 }, {  54,   0 }, {  55,   0 }, {  56,   0 },
 {  57,   0 }, {  58,   0 }, {  59,   0 }, {  60,   0 }, {  61,   0 },
 {  62,   0 }, {  63,   0 }, {  64,   0 }, {  65,   0 }, {  66,   0 },
 {  67,   0 }, {  68,   0 }, {  69,   0 }, {  70,   0 }, {  71,   0 },
 {  72,   0 }, {  73,   0 }, {  74,   0 }, {  75,   0 }, {  76,   0 },
 {  77,   0 }, {  78,   0 }, {  79,   0 }, {  80,   0 }, {  81,   0 },
 {  82,   0 }, {  83,   0 }, {  84,   0 }, {  85,   0 }, {  86,   0 },
 {  87,   0 }, {  88,   0 }, {  89,   0 }, {  90,   0 }, {  91,   0 },
 {  92,   0 }, {  93,   0 }, {  94,   0 }, {  95,   0 }, {  96,   0 },

 {  97,   0 }, {  98,   0 }, {  99,   0 }, { 100,   0 }, { 101,   0 },
 { 102,   0 }, { 103,   0 }, { 104,   0 }, { 105,   0 }, { 106,   0 },
 { 107,   0 }, { 108,   0 }, { 109,   0 }, { 110,   0 }, { 111,   0 },
 { 112,   0 }, { 113,   0 }, { 114,   0 }, { 115,   0 }, { 116,   0 },
 { 117,   0 }, { 118,   0 }, { 119,   0 }, { 120,   0 }, { 121,   0 },
 { 122,   0 }, { 123,   0 }, { 124,   0 }, { 125,   0 }, { 126,   0 },
 { 127,   0 }, { 128,   0 }, { 129,   0 }, { 130,   0 }, { 131,   0 },
 { 132,   0 }, { 133,   0 }, { 134,   0 }, { 135,   0 }, { 136,   0 },
 { 137,   0 }, { 138,   0 }, { 139,   0 }, { 140,   0 }, { 141,   0 },
 { 142,   0 }, { 143,   0 }, { 144,   0 }, { 145,   0 }, { 146,   0 },

 { 147,   0 }, { 148,   0 }, { 149,   0 }, { 150,   0 }, { 151,   0 },
 { 152,   0 }, { 153,   0 }, { 154,   0 }, { 155,   0 }, { 156,   0 },
 { 157,   0 }, { 158,   0 }, { 159,   0 }, { 160,   0 }, { 161,   0 },
 { 162,   0 }, { 163,   0 }, { 164,   0 }, { 165,   0 }, { 166,   0 },
 { 167,   0 }, { 168,   0 }, { 169,   0 }, { 170,   0 }, { 171,   0 },
 { 172,   0 }, { 173,   0 }, { 174,   0 }, { 175,   0 }, { 176,   0 },
 { 177,   0 }, { 178,   0 }, { 179,   0 }, { 180,   0 }, { 181,   0 },
 { 182,   0 }, { 183,   0 }, { 184,   0 }, { 185,   0 }, { 186,   0 },
 { 187,   0 }, { 188,   0 }, { 189,   0 }, { 190,   0 }, { 191,   0 },
 { 192,   0 }, { 193,   0 }, { 194,   0 }, { 195,   0 }, { 196,   0 },

 { 197,   0 }, { 198,   0 }, { 199,   0 }, { 200,   0 }, { 201,   0 },
 { 202,   0 }, { 203,   0 }, { 204,   0 }, { 205,   0 }, { 206,   0 },
 { 207,   0 }, { 208,   0 }, { 209,   0 }, { 210,   0 }, { 211,   0 },
 { 212,   0 }, { 213,   0 }, { 214,   0 }, { 215,   0 }, { 216,   0 },
 { 217,   0 }, { 218,   0 }, { 219,   0 }, { 220,   0 }, { 221,   0 },
 { 222,   0 }, { 223,   0 }, { 224,   0 }, { 225,   0 }, { 226,   0 },
 { 227,   0 }, { 228,   0 }, { 229,   0 }, { 230,   0 }, { 231,   0 },
 { 232,   0 }, { 233,   0 }, { 234,   0 }, { 235,   0 }, { 236,   0 },
 { 237,   0 }, { 238,   0 }, { 239,   0 }, { 240,   0 }, { 241,   0 },
 { 242,   0 }, { 243,   0 }, { 244,   0 }, { 245,   0 }, { 246,   0 },

 { 247,   0 }, { 248,   0 }, { 249,   0 }, { 250,   0 }, { 251,   0 },
 { 252,   0 }, { 253,   0 }, { 254,   0 }, { 255,   0 }, { 256,   0 },
 {   0,  18 }, {   0,9185 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,  18 }, {   0,9180 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   9,   0 }, {  10,   5 }, {  11,   0 }, {  12,   0 }, {  13,   5 },
 {   9,  24 }, {  10,  24 }, {  11,  24 }, {  12,  24 }, {  13,  24 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  18 },
 {   0,9156 }, {   0,   0 }, {   0,   0 }, {  32,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  32,  24 }, {   9,   0 },

 {  10,   0 }, {  11,   0 }, {  12,   0 }, {  13,   0 }, {   0,   0 },
 {  39,-9030 }, {  45,-9027 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  45,-8995 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  32,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  39,-9054 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  45,-9019 }, {   0,  18 }, {   0,9109 }, {   1,4629 }, {   2,4629 },
 {   3,4629 }, {   4,4629 }, {   5,4629 }, {   6,4629 }, {   7,4629 },
 {   8,4629 }, {   9,4887 }, {  10, -71 }, {  11,4887 }, {  12,4887 },

 {  13, -71 }, {  14,4629 }, {  15,4629 }, {  16,4629 }, {  17,4629 },
 {  18,4629 }, {  19,4629 }, {  20,4629 }, {  21,4629 }, {  22,4629 },
 {  23,4629 }, {  24,4629 }, {  25,4629 }, {  26,4629 }, {  27,4629 },
 {  28,4629 }, {  29,4629 }, {  30,4629 }, {  31,4629 }, {  32,4887 },
 {  33,4629 }, {  34,4629 }, {  35,4629 }, {  36,4629 }, {  37,4629 },
 {  38,4629 }, {  39,4629 }, {  40,4629 }, {  41,4629 }, {  42,4629 },
 {  43,4629 }, {  44,4629 }, {  45,5145 }, {  46,4629 }, {  47,4629 },
 {  48,4629 }, {  49,4629 }, {  50,4629 }, {  51,4629 }, {  52,4629 },
 {  53,4629 }, {  54,4629 }, {  55,4629 }, {  56,4629 }, {  57,4629 },
 {  58,4629 }, {  59,4629 }, {  60,4629 }, {  61,4629 }, {  62,4629 },

 {  63,4629 }, {  64,4629 }, {  65,4629 }, {  66,4629 }, {  67,4629 },
 {  68,4629 }, {  69,4629 }, {  70,4629 }, {  71,4629 }, {  72,4629 },
 {  73,4629 }, {  74,4629 }, {  75,4629 }, {  76,4629 }, {  77,4629 },
 {  78,4629 }, {  79,4629 }, {  80,4629 }, {  81,4629 }, {  82,4629 },
 {  83,4629 }, {  84,4629 }, {  85,4629 }, {  86,4629 }, {  87,4629 },
 {  88,4629 }, {  89,4629 }, {  90,4629 }, {  91,4629 }, {  92,4629 },
 {  93,4629 }, {  94,4629 }, {  95,4629 }, {  96,4629 }, {  97,4629 },
 {  98,4629 }, {  99,4629 }, { 100,4629 }, { 101,4629 }, { 102,4629 },
 { 103,4629 }, { 104,4629 }, { 105,4629 }, { 106,4629 }, { 107,4629 },
 { 108,4629 }, { 109,4629 }, { 110,4629 }, { 111,4629 }, { 112,4629 },

 { 113,4629 }, { 114,4629 }, { 115,4629 }, { 116,4629 }, { 117,4629 },
 { 118,4629 }, { 119,4629 }, { 120,4629 }, { 121,4629 }, { 122,4629 },
 { 123,4629 }, { 124,4629 }, { 125,4629 }, { 126,4629 }, { 127,4629 },
 { 128,4629 }, { 129,4629 }, { 130,4629 }, { 131,4629 }, { 132,4629 },
 { 133,4629 }, { 134,4629 }, { 135,4629 }, { 136,4629 }, { 137,4629 },
 { 138,4629 }, { 139,4629 }, { 140,4629 }, { 141,4629 }, { 142,4629 },
 { 143,4629 }, { 144,4629 }, { 145,4629 }, { 146,4629 }, { 147,4629 },
 { 148,4629 }, { 149,4629 }, { 150,4629 }, { 151,4629 }, { 152,4629 },
 { 153,4629 }, { 154,4629 }, { 155,4629 }, { 156,4629 }, { 157,4629 },
 { 158,4629 }, { 159,4629 }, { 160,4629 }, { 161,4629 }, { 162,4629 },

 { 163,4629 }, { 164,4629 }, { 165,4629 }, { 166,4629 }, { 167,4629 },
 { 168,4629 }, { 169,4629 }, { 170,4629 }, { 171,4629 }, { 172,4629 },
 { 173,4629 }, { 174,4629 }, { 175,4629 }, { 176,4629 }, { 177,4629 },
 { 178,4629 }, { 179,4629 }, { 180,4629 }, { 181,4629 }, { 182,4629 },
 { 183,4629 }, { 184,4629 }, { 185,4629 }, { 186,4629 }, { 187,4629 },
 { 188,4629 }, { 189,4629 }, { 190,4629 }, { 191,4629 }, { 192,4629 },
 { 193,4629 }, { 194,4629 }, { 195,4629 }, { 196,4629 }, { 197,4629 },
 { 198,4629 }, { 199,4629 }, { 200,4629 }, { 201,4629 }, { 202,4629 },
 { 203,4629 }, { 204,4629 }, { 205,4629 }, { 206,4629 }, { 207,4629 },
 { 208,4629 }, { 209,4629 }, { 210,4629 }, { 211,4629 }, { 212,4629 },

 { 213,4629 }, { 214,4629 }, { 215,4629 }, { 216,4629 }, { 217,4629 },
 { 218,4629 }, { 219,4629 }, { 220,4629 }, { 221,4629 }, { 222,4629 },
 { 223,4629 }, { 224,4629 }, { 225,4629 }, { 226,4629 }, { 227,4629 },
 { 228,4629 }, { 229,4629 }, { 230,4629 }, { 231,4629 }, { 232,4629 },
 { 233,4629 }, { 234,4629 }, { 235,4629 }, { 236,4629 }, { 237,4629 },
 { 238,4629 }, { 239,4629 }, { 240,4629 }, { 241,4629 }, { 242,4629 },
 { 243,4629 }, { 244,4629 }, { 245,4629 }, { 246,4629 }, { 247,4629 },
 { 248,4629 }, { 249,4629 }, { 250,4629 }, { 251,4629 }, { 252,4629 },
 { 253,4629 }, { 254,4629 }, { 255,4629 }, { 256,4629 }, {   0,  22 },
 {   0,8851 }, {   1,   0 }, {   2,   0 }, {   3,   0 }, {   4,   0 },

 {   5,   0 }, {   6,   0 }, {   7,   0 }, {   8,   0 }, {   9,   0 },
 {  10,   0 }, {  11,   0 }, {  12,   0 }, {  13,   0 }, {  14,   0 },
 {  15,   0 }, {  16,   0 }, {  17,   0 }, {  18,   0 }, {  19,   0 },
 {  20,   0 }, {  21,   0 }, {  22,   0 }, {  23,   0 }, {  24,   0 },
 {  25,   0 }, {  26,   0 }, {  27,   0 }, {  28,   0 }, {  29,   0 },
 {  30,   0 }, {  31,   0 }, {  32,   0 }, {  33,   0 }, {  34,   0 },
 {  35,   0 }, {  36,   0 }, {  37,   0 }, {  38,   0 }, {   0,   0 },
 {  40,   0 }, {  41,   0 }, {  42,   0 }, {  43,   0 }, {  44,   0 },
 {  45,   0 }, {  46,   0 }, {  47,   0 }, {  48,   0 }, {  49,   0 },
 {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 }, {  54,   0 },

 {  55,   0 }, {  56,   0 }, {  57,   0 }, {  58,   0 }, {  59,   0 },
 {  60,   0 }, {  61,   0 }, {  62,   0 }, {  63,   0 }, {  64,   0 },
 {  65,   0 }, {  66,   0 }, {  67,   0 }, {  68,   0 }, {  69,   0 },
 {  70,   0 }, {  71,   0 }, {  72,   0 }, {  73,   0 }, {  74,   0 },
 {  75,   0 }, {  76,   0 }, {  77,   0 }, {  78,   0 }, {  79,   0 },
 {  80,   0 }, {  81,   0 }, {  82,   0 }, {  83,   0 }, {  84,   0 },
 {  85,   0 }, {  86,   0 }, {  87,   0 }, {  88,   0 }, {  89,   0 },
 {  90,   0 }, {  91,   0 }, {   0,   0 }, {  93,   0 }, {  94,   0 },
 {  95,   0 }, {  96,   0 }, {  97,   0 }, {  98,   0 }, {  99,   0 },
 { 100,   0 }, { 101,   0 }, { 102,   0 }, { 103,   0 }, { 104,   0 },

 { 105,   0 }, { 106,   0 }, { 107,   0 }, { 108,   0 }, { 109,   0 },
 { 110,   0 }, { 111,   0 }, { 112,   0 }, { 113,   0 }, { 114,   0 },
 { 115,   0 }, { 116,   0 }, { 117,   0 }, { 118,   0 }, { 119,   0 },
 { 120,   0 }, { 121,   0 }, { 122,   0 }, { 123,   0 }, { 124,   0 },
 { 125,   0 }, { 126,   0 }, { 127,   0 }, { 128,   0 }, { 129,   0 },
 { 130,   0 }, { 131,   0 }, { 132,   0 }, { 133,   0 }, { 134,   0 },
 { 135,   0 }, { 136,   0 }, { 137,   0 }, { 138,   0 }, { 139,   0 },
 { 140,   0 }, { 141,   0 }, { 142,   0 }, { 143,   0 }, { 144,   0 },
 { 145,   0 }, { 146,   0 }, { 147,   0 }, { 148,   0 }, { 149,   0 },
 { 150,   0 }, { 151,   0 }, { 152,   0 }, { 153,   0 }, { 154,   0 },

 { 155,   0 }, { 156,   0 }, { 157,   0 }, { 158,   0 }, { 159,   0 },
 { 160,   0 }, { 161,   0 }, { 162,   0 }, { 163,   0 }, { 164,   0 },
 { 165,   0 }, { 166,   0 }, { 167,   0 }, { 168,   0 }, { 169,   0 },
 { 170,   0 }, { 171,   0 }, { 172,   0 }, { 173,   0 }, { 174,   0 },
 { 175,   0 }, { 176,   0 }, { 177,   0 }, { 178,   0 }, { 179,   0 },
 { 180,   0 }, { 181,   0 }, { 182,   0 }, { 183,   0 }, { 184,   0 },
 { 185,   0 }, { 186,   0 }, { 187,   0 }, { 188,   0 }, { 189,   0 },
 { 190,   0 }, { 191,   0 }, { 192,   0 }, { 193,   0 }, { 194,   0 },
 { 195,   0 }, { 196,   0 }, { 197,   0 }, { 198,   0 }, { 199,   0 },
 { 200,   0 }, { 201,   0 }, { 202,   0 }, { 203,   0 }, { 204,   0 },

 { 205,   0 }, { 206,   0 }, { 207,   0 }, { 208,   0 }, { 209,   0 },
 { 210,   0 }, { 211,   0 }, { 212,   0 }, { 213,   0 }, { 214,   0 },
 { 215,   0 }, { 216,   0 }, { 217,   0 }, { 218,   0 }, { 219,   0 },
 { 220,   0 }, { 221,   0 }, { 222,   0 }, { 223,   0 }, { 224,   0 },
 { 225,   0 }, { 226,   0 }, { 227,   0 }, { 228,   0 }, { 229,   0 },
 { 230,   0 }, { 231,   0 }, { 232,   0 }, { 233,   0 }, { 234,   0 },
 { 235,   0 }, { 236,   0 }, { 237,   0 }, { 238,   0 }, { 239,   0 },
 { 240,   0 }, { 241,   0 }, { 242,   0 }, { 243,   0 }, { 244,   0 },
 { 245,   0 }, { 246,   0 }, { 247,   0 }, { 248,   0 }, { 249,   0 },
 { 250,   0 }, { 251,   0 }, { 252,   0 }, { 253,   0 }, { 254,   0 },

 { 255,   0 }, { 256,   0 }, {   0,  29 }, {   0,8593 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,  27 }, {   0,8585 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  27 }, {   0,8562 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {  48,4887 }, {  49,4887 }, {  50,4887 }, {  51,4887 },
 {  52,4887 }, {  53,4887 }, {  54,4887 }, {  55,4887 }, {  48,4887 },
 {  49,4887 }, {  50,4887 }, {  51,4887 }, {  52,4887 }, {  53,4887 },
 {  54,4887 }, {  55,4887 }, {  56,4887 }, {  57,4887 }, {   0,   0 },
 {   0,   0 }, {   0,  28 }, {   0,8524 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  65,4887 }, {  66,4887 }, {  67,4887 }, {  68,4887 },
 {  69,4887 }, {  70,4887 }, {  48,4887 }, {  49,4887 }, {  50,4887 },
 {  51,4887 }, {  52,4887 }, {  53,4887 }, {  54,4887 }, {  55,4887 },
 {  56,4887 }, {  57,4887 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,4887 },

 {  66,4887 }, {  67,4887 }, {  68,4887 }, {  69,4887 }, {  70,4887 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  97,4887 }, {  98,4887 },
 {  99,4887 }, { 100,4887 }, { 101,4887 }, { 102,4887 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  48,4887 }, {  49,4887 }, {  50,4887 }, {  51,4887 }, {  52,4887 },
 {  53,4887 }, {  54,4887 }, {  55,4887 }, {  56,4887 }, {  57,4887 },
 {   0,   0 }, {  97,4887 }, {  98,4887 }, {  99,4887 }, { 100,4887 },
 { 101,4887 }, { 102,4887 }, {  65,4887 }, {  66,4887 }, {  67,4887 },
 {  68,4887 }, {  69,4887 }, {  70,4887 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  97,4887 },
 {  98,4887 }, {  99,4887 }, { 100,4887 }, { 101,4887 }, { 102,4887 },
 {   0,  35 }, {   0,8420 }, {   1,   0 }, {   2,   0 }, {   3,   0 },
 {   4,   0 }, {   5,   0 }, {   6,   0 }, {   7,   0 }, {   8,   0 },
 {   9,   0 }, {  10,   0 }, {  11,   0 }, {  12,   0 }, {  13,   0 },
 {  14,   0 }, {  15,   0 }, {  16,   0 }, {  17,   0 }, {  18,   0 },
 {  19,   0 }, {  20,   0 }, {  21,   0 }, {  22,   0 }, {  23,   0 },

 {  24,   0 }, {  25,   0 }, {  26,   0 }, {  27,   0 }, {  28,   0 },
 {  29,   0 }, {  30,   0 }, {  31,   0 }, {  32,   0 }, {  33,   0 },
 {  34,   0 }, {  35,   0 }, {   0,   0 }, {  37,   0 }, {  38,   0 },
 {  39,   0 }, {  40,   0 }, {  41,   0 }, {  42,   0 }, {  43,   0 },
 {  44,   0 }, {  45,   0 }, {  46,   0 }, {  47,   0 }, {  48,   0 },
 {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 },
 {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 }, {  58,   0 },
 {  59,   0 }, {  60,   0 }, {  61,   0 }, {  62,   0 }, {  63,   0 },
 {  64,   0 }, {  65,   0 }, {  66,   0 }, {  67,   0 }, {  68,   0 },
 {  69,   0 }, {  70,   0 }, {  71,   0 }, {  72,   0 }, {  73,   0 },

 {  74,   0 }, {  75,   0 }, {  76,   0 }, {  77,   0 }, {  78,   0 },
 {  79,   0 }, {  80,   0 }, {  81,   0 }, {  82,   0 }, {  83,   0 },
 {  84,   0 }, {  85,   0 }, {  86,   0 }, {  87,   0 }, {  88,   0 },
 {  89,   0 }, {  90,   0 }, {  91,   0 }, {  92,   0 }, {  93,   0 },
 {  94,   0 }, {  95,   0 }, {  96,   0 }, {  97,   0 }, {  98,   0 },
 {  99,   0 }, { 100,   0 }, { 101,   0 }, { 102,   0 }, { 103,   0 },
 { 104,   0 }, { 105,   0 }, { 106,   0 }, { 107,   0 }, { 108,   0 },
 { 109,   0 }, { 110,   0 }, { 111,   0 }, { 112,   0 }, { 113,   0 },
 { 114,   0 }, { 115,   0 }, { 116,   0 }, { 117,   0 }, { 118,   0 },
 { 119,   0 }, { 120,   0 }, { 121,   0 }, { 122,   0 }, { 123,   0 },

 { 124,   0 }, { 125,   0 }, { 126,   0 }, { 127,   0 }, { 128,   0 },
 { 129,   0 }, { 130,   0 }, { 131,   0 }, { 132,   0 }, { 133,   0 },
 { 134,   0 }, { 135,   0 }, { 136,   0 }, { 137,   0 }, { 138,   0 },
 { 139,   0 }, { 140,   0 }, { 141,   0 }, { 142,   0 }, { 143,   0 },
 { 144,   0 }, { 145,   0 }, { 146,   0 }, { 147,   0 }, { 148,   0 },
 { 149,   0 }, { 150,   0 }, { 151,   0 }, { 152,   0 }, { 153,   0 },
 { 154,   0 }, { 155,   0 }, { 156,   0 }, { 157,   0 }, { 158,   0 },
 { 159,   0 }, { 160,   0 }, { 161,   0 }, { 162,   0 }, { 163,   0 },
 { 164,   0 }, { 165,   0 }, { 166,   0 }, { 167,   0 }, { 168,   0 },
 { 169,   0 }, { 170,   0 }, { 171,   0 }, { 172,   0 }, { 173,   0 },

 { 174,   0 }, { 175,   0 }, { 176,   0 }, { 177,   0 }, { 178,   0 },
 { 179,   0 }, { 180,   0 }, { 181,   0 }, { 182,   0 }, { 183,   0 },
 { 184,   0 }, { 185,   0 }, { 186,   0 }, { 187,   0 }, { 188,   0 },
 { 189,   0 }, { 190,   0 }, { 191,   0 }, { 192,   0 }, { 193,   0 },
 { 194,   0 }, { 195,   0 }, { 196,   0 }, { 197,   0 }, { 198,   0 },
 { 199,   0 }, { 200,   0 }, { 201,   0 }, { 202,   0 }, { 203,   0 },
 { 204,   0 }, { 205,   0 }, { 206,   0 }, { 207,   0 }, { 208,   0 },
 { 209,   0 }, { 210,   0 }, { 211,   0 }, { 212,   0 }, { 213,   0 },
 { 214,   0 }, { 215,   0 }, { 216,   0 }, { 217,   0 }, { 218,   0 },
 { 219,   0 }, { 220,   0 }, { 221,   0 }, { 222,   0 }, { 223,   0 },

 { 224,   0 }, { 225,   0 }, { 226,   0 }, { 227,   0 }, { 228,   0 },
 { 229,   0 }, { 230,   0 }, { 231,   0 }, { 232,   0 }, { 233,   0 },
 { 234,   0 }, { 235,   0 }, { 236,   0 }, { 237,   0 }, { 238,   0 },
 { 239,   0 }, { 240,   0 }, { 241,   0 }, { 242,   0 }, { 243,   0 },
 { 244,   0 }, { 245,   0 }, { 246,   0 }, { 247,   0 }, { 248,   0 },
 { 249,   0 }, { 250,   0 }, { 251,   0 }, { 252,   0 }, { 253,   0 },
 { 254,   0 }, { 255,   0 }, { 256,   0 }, {   0,  36 }, {   0,8162 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  36,-10006 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  48,4597 }, {  49,4597 }, {  50,4597 },
 {  51,4597 }, {  52,4597 }, {  53,4597 }, {  54,4597 }, {  55,4597 },
 {  56,4597 }, {  57,4597 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,4597 },

 {  66,4597 }, {  67,4597 }, {  68,4597 }, {  69,4597 }, {  70,4597 },
 {  71,4597 }, {  72,4597 }, {  73,4597 }, {  74,4597 }, {  75,4597 },
 {  76,4597 }, {  77,4597 }, {  78,4597 }, {  79,4597 }, {  80,4597 },
 {  81,4597 }, {  82,4597 }, {  83,4597 }, {  84,4597 }, {  85,4597 },
 {  86,4597 }, {  87,4597 }, {  88,4597 }, {  89,4597 }, {  90,4597 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95,4597 },
 {   0,   0 }, {  97,4597 }, {  98,4597 }, {  99,4597 }, { 100,4597 },
 { 101,4597 }, { 102,4597 }, { 103,4597 }, { 104,4597 }, { 105,4597 },
 { 106,4597 }, { 107,4597 }, { 108,4597 }, { 109,4597 }, { 110,4597 },
 { 111,4597 }, { 112,4597 }, { 113,4597 }, { 114,4597 }, { 115,4597 },

 { 116,4597 }, { 117,4597 }, { 118,4597 }, { 119,4597 }, { 120,4597 },
 { 121,4597 }, { 122,4597 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, { 128,4597 }, { 129,4597 }, { 130,4597 },
 { 131,4597 }, { 132,4597 }, { 133,4597 }, { 134,4597 }, { 135,4597 },
 { 136,4597 }, { 137,4597 }, { 138,4597 }, { 139,4597 }, { 140,4597 },
 { 141,4597 }, { 142,4597 }, { 143,4597 }, { 144,4597 }, { 145,4597 },
 { 146,4597 }, { 147,4597 }, { 148,4597 }, { 149,4597 }, { 150,4597 },
 { 151,4597 }, { 152,4597 }, { 153,4597 }, { 154,4597 }, { 155,4597 },
 { 156,4597 }, { 157,4597 }, { 158,4597 }, { 159,4597 }, { 160,4597 },
 { 161,4597 }, { 162,4597 }, { 163,4597 }, { 164,4597 }, { 165,4597 },

 { 166,4597 }, { 167,4597 }, { 168,4597 }, { 169,4597 }, { 170,4597 },
 { 171,4597 }, { 172,4597 }, { 173,4597 }, { 174,4597 }, { 175,4597 },
 { 176,4597 }, { 177,4597 }, { 178,4597 }, { 179,4597 }, { 180,4597 },
 { 181,4597 }, { 182,4597 }, { 183,4597 }, { 184,4597 }, { 185,4597 },
 { 186,4597 }, { 187,4597 }, { 188,4597 }, { 189,4597 }, { 190,4597 },
 { 191,4597 }, { 192,4597 }, { 193,4597 }, { 194,4597 }, { 195,4597 },
 { 196,4597 }, { 197,4597 }, { 198,4597 }, { 199,4597 }, { 200,4597 },
 { 201,4597 }, { 202,4597 }, { 203,4597 }, { 204,4597 }, { 205,4597 },
 { 206,4597 }, { 207,4597 }, { 208,4597 }, { 209,4597 }, { 210,4597 },
 { 211,4597 }, { 212,4597 }, { 213,4597 }, { 214,4597 }, { 215,4597 },

 { 216,4597 }, { 217,4597 }, { 218,4597 }, { 219,4597 }, { 220,4597 },
 { 221,4597 }, { 222,4597 }, { 223,4597 }, { 224,4597 }, { 225,4597 },
 { 226,4597 }, { 227,4597 }, { 228,4597 }, { 229,4597 }, { 230,4597 },
 { 231,4597 }, { 232,4597 }, { 233,4597 }, { 234,4597 }, { 235,4597 },
 { 236,4597 }, { 237,4597 }, { 238,4597 }, { 239,4597 }, { 240,4597 },
 { 241,4597 }, { 242,4597 }, { 243,4597 }, { 244,4597 }, { 245,4597 },
 { 246,4597 }, { 247,4597 }, { 248,4597 }, { 249,4597 }, { 250,4597 },
 { 251,4597 }, { 252,4597 }, { 253,4597 }, { 254,4597 }, { 255,4597 },
 {   0,  27 }, {   0,7905 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  27 }, {   0,7882 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,4597 },
 {  49,4597 }, {  50,4597 }, {  51,4597 }, {  52,4597 }, {  53,4597 },
 {  54,4597 }, {  55,4597 }, {  56,4597 }, {  57,4597 }, {   0,   0 },

 {   0,   0 }, {   0,  55 }, {   0,7844 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  65,4597 }, {  66,4597 }, {  67,4597 }, {  68,4597 },
 {  69,4597 }, {  70,4597 }, {  48,4597 }, {  49,4597 }, {  50,4597 },
 {  51,4597 }, {  52,4597 }, {  53,4597 }, {  54,4597 }, {  55,4597 },
 {  56,4597 }, {  57,4597 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,4597 },
 {  66,4597 }, {  67,4597 }, {  68,4597 }, {  69,4597 }, {  70,4597 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  97,4597 }, {  98,4597 },
 {  99,4597 }, { 100,4597 }, { 101,4597 }, { 102,4597 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {  48,   0 }, {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 },
 {  53,   0 }, {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 },
 {   0,   0 }, {  97,4597 }, {  98,4597 }, {  99,4597 }, { 100,4597 },
 { 101,4597 }, { 102,4597 }, {  65,-10321 }, {  66,-10321 }, {  67,-10321 },
 {  68,-10321 }, {  69,-10321 }, {  70,-10321 }, {  71,-10321 }, {  72,-10321 },
 {  73,-10321 }, {  74,-10321 }, {  75,-10321 }, {  76,-10321 }, {  77,-10321 },
 {  78,-10321 }, {  79,-10321 }, {  80,-10321 }, {  81,-10321 }, {  82,-10321 },
 {  83,-10321 }, {  84,-10321 }, {  85,-10321 }, {  86,-10321 }, {  87,-10321 },
 {  88,-10321 }, {  89,-10321 }, {  90,-10321 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  95, 257 }, {   0,   0 }, {  97,-10321 },

 {  98,-10321 }, {  99,-10321 }, { 100,-10321 }, { 101,-10321 }, { 102,-10321 },
 { 103,-10321 }, { 104,-10321 }, { 105,-10321 }, { 106,-10321 }, { 107,-10321 },
 { 108,-10321 }, { 109,-10321 }, { 110,-10321 }, { 111,-10321 }, { 112,-10321 },
 { 113,-10321 }, { 114,-10321 }, { 115,-10321 }, { 116,-10321 }, { 117,-10321 },
 { 118,-10321 }, { 119,-10321 }, { 120,-10321 }, { 121,-10321 }, { 122,-10321 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 { 128,-10321 }, { 129,-10321 }, { 130,-10321 }, { 131,-10321 }, { 132,-10321 },
 { 133,-10321 }, { 134,-10321 }, { 135,-10321 }, { 136,-10321 }, { 137,-10321 },
 { 138,-10321 }, { 139,-10321 }, { 140,-10321 }, { 141,-10321 }, { 142,-10321 },
 { 143,-10321 }, { 144,-10321 }, { 145,-10321 }, { 146,-10321 }, { 147,-10321 },

 { 148,-10321 }, { 149,-10321 }, { 150,-10321 }, { 151,-10321 }, { 152,-10321 },
 { 153,-10321 }, { 154,-10321 }, { 155,-10321 }, { 156,-10321 }, { 157,-10321 },
 { 158,-10321 }, { 159,-10321 }, { 160,-10321 }, { 161,-10321 }, { 162,-10321 },
 { 163,-10321 }, { 164,-10321 }, { 165,-10321 }, { 166,-10321 }, { 167,-10321 },
 { 168,-10321 }, { 169,-10321 }, { 170,-10321 }, { 171,-10321 }, { 172,-10321 },
 { 173,-10321 }, { 174,-10321 }, { 175,-10321 }, { 176,-10321 }, { 177,-10321 },
 { 178,-10321 }, { 179,-10321 }, { 180,-10321 }, { 181,-10321 }, { 182,-10321 },
 { 183,-10321 }, { 184,-10321 }, { 185,-10321 }, { 186,-10321 }, { 187,-10321 },
 { 188,-10321 }, { 189,-10321 }, { 190,-10321 }, { 191,-10321 }, { 192,-10321 },
 { 193,-10321 }, { 194,-10321 }, { 195,-10321 }, { 196,-10321 }, { 197,-10321 },

 { 198,-10321 }, { 199,-10321 }, { 200,-10321 }, { 201,-10321 }, { 202,-10321 },
 { 203,-10321 }, { 204,-10321 }, { 205,-10321 }, { 206,-10321 }, { 207,-10321 },
 { 208,-10321 }, { 209,-10321 }, { 210,-10321 }, { 211,-10321 }, { 212,-10321 },
 { 213,-10321 }, { 214,-10321 }, { 215,-10321 }, { 216,-10321 }, { 217,-10321 },
 { 218,-10321 }, { 219,-10321 }, { 220,-10321 }, { 221,-10321 }, { 222,-10321 },
 { 223,-10321 }, { 224,-10321 }, { 225,-10321 }, { 226,-10321 }, { 227,-10321 },
 { 228,-10321 }, { 229,-10321 }, { 230,-10321 }, { 231,-10321 }, { 232,-10321 },
 { 233,-10321 }, { 234,-10321 }, { 235,-10321 }, { 236,-10321 }, { 237,-10321 },
 { 238,-10321 }, { 239,-10321 }, { 240,-10321 }, { 241,-10321 }, { 242,-10321 },
 { 243,-10321 }, { 244,-10321 }, { 245,-10321 }, { 246,-10321 }, { 247,-10321 },

 { 248,-10321 }, { 249,-10321 }, { 250,-10321 }, { 251,-10321 }, { 252,-10321 },
 { 253,-10321 }, { 254,-10321 }, { 255,-10321 }, {   0,  56 }, {   0,7587 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  33 }, {   0,7577 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  36,-10951 }, {   0,   0 }, {  48,-257 }, {  49,-257 }, {  50,-257 },
 {  51,-257 }, {  52,-257 }, {  53,-257 }, {  54,-257 }, {  55,-257 },
 {  56,-257 }, {  57,-257 }, {  48,   0 }, {  49,   0 }, {  50,   0 },
 {  51,   0 }, {  52,   0 }, {  53,   0 }, {  54,   0 }, {  55,   0 },
 {  56,   0 }, {  57,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,   0 },
 {  66,   0 }, {  67,   0 }, {  68,   0 }, {  69,   0 }, {  70,   0 },
 {  71,   0 }, {  72,   0 }, {  73,   0 }, {  74,   0 }, {  75,   0 },
 {  76,   0 }, {  77,   0 }, {  78,   0 }, {  79,   0 }, {  80,   0 },

 {  81,   0 }, {  82,   0 }, {  83,   0 }, {  84,   0 }, {  85,   0 },
 {  86,   0 }, {  87,   0 }, {  88,   0 }, {  89,   0 }, {  90,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95,   0 },
 {   0,   0 }, {  97,   0 }, {  98,   0 }, {  99,   0 }, { 100,   0 },
 { 101,   0 }, { 102,   0 }, { 103,   0 }, { 104,   0 }, { 105,   0 },
 { 106,   0 }, { 107,   0 }, { 108,   0 }, { 109,   0 }, { 110,   0 },
 { 111,   0 }, { 112,   0 }, { 113,   0 }, { 114,   0 }, { 115,   0 },
 { 116,   0 }, { 117,   0 }, { 118,   0 }, { 119,   0 }, { 120,   0 },
 { 121,   0 }, { 122,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, { 128,   0 }, { 129,   0 }, { 130,   0 },

 { 131,   0 }, { 132,   0 }, { 133,   0 }, { 134,   0 }, { 135,   0 },
 { 136,   0 }, { 137,   0 }, { 138,   0 }, { 139,   0 }, { 140,   0 },
 { 141,   0 }, { 142,   0 }, { 143,   0 }, { 144,   0 }, { 145,   0 },
 { 146,   0 }, { 147,   0 }, { 148,   0 }, { 149,   0 }, { 150,   0 },
 { 151,   0 }, { 152,   0 }, { 153,   0 }, { 154,   0 }, { 155,   0 },
 { 156,   0 }, { 157,   0 }, { 158,   0 }, { 159,   0 }, { 160,   0 },
 { 161,   0 }, { 162,   0 }, { 163,   0 }, { 164,   0 }, { 165,   0 },
 { 166,   0 }, { 167,   0 }, { 168,   0 }, { 169,   0 }, { 170,   0 },
 { 171,   0 }, { 172,   0 }, { 173,   0 }, { 174,   0 }, { 175,   0 },
 { 176,   0 }, { 177,   0 }, { 178,   0 }, { 179,   0 }, { 180,   0 },

 { 181,   0 }, { 182,   0 }, { 183,   0 }, { 184,   0 }, { 185,   0 },
 { 186,   0 }, { 187,   0 }, { 188,   0 }, { 189,   0 }, { 190,   0 },
 { 191,   0 }, { 192,   0 }, { 193,   0 }, { 194,   0 }, { 195,   0 },
 { 196,   0 }, { 197,   0 }, { 198,   0 }, { 199,   0 }, { 200,   0 },
 { 201,   0 }, { 202,   0 }, { 203,   0 }, { 204,   0 }, { 205,   0 },
 { 206,   0 }, { 207,   0 }, { 208,   0 }, { 209,   0 }, { 210,   0 },
 { 211,   0 }, { 212,   0 }, { 213,   0 }, { 214,   0 }, { 215,   0 },
 { 216,   0 }, { 217,   0 }, { 218,   0 }, { 219,   0 }, { 220,   0 },
 { 221,   0 }, { 222,   0 }, { 223,   0 }, { 224,   0 }, { 225,   0 },
 { 226,   0 }, { 227,   0 }, { 228,   0 }, { 229,   0 }, { 230,   0 },

 { 231,   0 }, { 232,   0 }, { 233,   0 }, { 234,   0 }, { 235,   0 },
 { 236,   0 }, { 237,   0 }, { 238,   0 }, { 239,   0 }, { 240,   0 },
 { 241,   0 }, { 242,   0 }, { 243,   0 }, { 244,   0 }, { 245,   0 },
 { 246,   0 }, { 247,   0 }, { 248,   0 }, { 249,   0 }, { 250,   0 },
 { 251,   0 }, { 252,   0 }, { 253,   0 }, { 254,   0 }, { 255,   0 },
 {   0,   1 }, {   0,7320 }, {   1,   0 }, {   2,   0 }, {   3,   0 },
 {   4,   0 }, {   5,   0 }, {   6,   0 }, {   7,   0 }, {   8,   0 },
 {   9,   0 }, {   0,   0 }, {  11,   0 }, {  12,   0 }, {   0,   0 },
 {  14,   0 }, {  15,   0 }, {  16,   0 }, {  17,   0 }, {  18,   0 },
 {  19,   0 }, {  20,   0 }, {  21,   0 }, {  22,   0 }, {  23,   0 },

 {  24,   0 }, {  25,   0 }, {  26,   0 }, {  27,   0 }, {  28,   0 },
 {  29,   0 }, {  30,   0 }, {  31,   0 }, {  32,   0 }, {  33,   0 },
 {  34,   0 }, {  35,   0 }, {  36,   0 }, {  37,   0 }, {  38,   0 },
 {  39,   0 }, {  40,   0 }, {  41,   0 }, {  42,   0 }, {  43,   0 },
 {  44,   0 }, {  45,   0 }, {  46,   0 }, {  47,   0 }, {  48,   0 },
 {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 },
 {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 }, {  58,   0 },
 {  59,   0 }, {  60,   0 }, {  61,   0 }, {  62,   0 }, {  63,   0 },
 {  64,   0 }, {  65,   0 }, {  66,   0 }, {  67,   0 }, {  68,   0 },
 {  69,   0 }, {  70,   0 }, {  71,   0 }, {  72,   0 }, {  73,   0 },

 {  74,   0 }, {  75,   0 }, {  76,   0 }, {  77,   0 }, {  78,   0 },
 {  79,   0 }, {  80,   0 }, {  81,   0 }, {  82,   0 }, {  83,   0 },
 {  84,   0 }, {  85,   0 }, {  86,   0 }, {  87,   0 }, {  88,   0 },
 {  89,   0 }, {  90,   0 }, {  91,   0 }, {  92,   0 }, {  93,   0 },
 {  94,   0 }, {  95,   0 }, {  96,   0 }, {  97,   0 }, {  98,   0 },
 {  99,   0 }, { 100,   0 }, { 101,   0 }, { 102,   0 }, { 103,   0 },
 { 104,   0 }, { 105,   0 }, { 106,   0 }, { 107,   0 }, { 108,   0 },
 { 109,   0 }, { 110,   0 }, { 111,   0 }, { 112,   0 }, { 113,   0 },
 { 114,   0 }, { 115,   0 }, { 116,   0 }, { 117,   0 }, { 118,   0 },
 { 119,   0 }, { 120,   0 }, { 121,   0 }, { 122,   0 }, { 123,   0 },

 { 124,   0 }, { 125,   0 }, { 126,   0 }, { 127,   0 }, { 128,   0 },
 { 129,   0 }, { 130,   0 }, { 131,   0 }, { 132,   0 }, { 133,   0 },
 { 134,   0 }, { 135,   0 }, { 136,   0 }, { 137,   0 }, { 138,   0 },
 { 139,   0 }, { 140,   0 }, { 141,   0 }, { 142,   0 }, { 143,   0 },
 { 144,   0 }, { 145,   0 }, { 146,   0 }, { 147,   0 }, { 148,   0 },
 { 149,   0 }, { 150,   0 }, { 151,   0 }, { 152,   0 }, { 153,   0 },
 { 154,   0 }, { 155,   0 }, { 156,   0 }, { 157,   0 }, { 158,   0 },
 { 159,   0 }, { 160,   0 }, { 161,   0 }, { 162,   0 }, { 163,   0 },
 { 164,   0 }, { 165,   0 }, { 166,   0 }, { 167,   0 }, { 168,   0 },
 { 169,   0 }, { 170,   0 }, { 171,   0 }, { 172,   0 }, { 173,   0 },

 { 174,   0 }, { 175,   0 }, { 176,   0 }, { 177,   0 }, { 178,   0 },
 { 179,   0 }, { 180,   0 }, { 181,   0 }, { 182,   0 }, { 183,   0 },
 { 184,   0 }, { 185,   0 }, { 186,   0 }, { 187,   0 }, { 188,   0 },
 { 189,   0 }, { 190,   0 }, { 191,   0 }, { 192,   0 }, { 193,   0 },
 { 194,   0 }, { 195,   0 }, { 196,   0 }, { 197,   0 }, { 198,   0 },
 { 199,   0 }, { 200,   0 }, { 201,   0 }, { 202,   0 }, { 203,   0 },
 { 204,   0 }, { 205,   0 }, { 206,   0 }, { 207,   0 }, { 208,   0 },
 { 209,   0 }, { 210,   0 }, { 211,   0 }, { 212,   0 }, { 213,   0 },
 { 214,   0 }, { 215,   0 }, { 216,   0 }, { 217,   0 }, { 218,   0 },
 { 219,   0 }, { 220,   0 }, { 221,   0 }, { 222,   0 }, { 223,   0 },

 { 224,   0 }, { 225,   0 }, { 226,   0 }, { 227,   0 }, { 228,   0 },
 { 229,   0 }, { 230,   0 }, { 231,   0 }, { 232,   0 }, { 233,   0 },
 { 234,   0 }, { 235,   0 }, { 236,   0 }, { 237,   0 }, { 238,   0 },
 { 239,   0 }, { 240,   0 }, { 241,   0 }, { 242,   0 }, { 243,   0 },
 { 244,   0 }, { 245,   0 }, { 246,   0 }, { 247,   0 }, { 248,   0 },
 { 249,   0 }, { 250,   0 }, { 251,   0 }, { 252,   0 }, { 253,   0 },
 { 254,   0 }, { 255,   0 }, { 256,   0 }, {   0,   1 }, {   0,7062 },
 {   1,-258 }, {   2,-258 }, {   3,-258 }, {   4,-258 }, {   5,-258 },
 {   6,-258 }, {   7,-258 }, {   8,-258 }, {   9,-258 }, {   0,   0 },
 {  11,-258 }, {  12,-258 }, {   0,   0 }, {  14,-258 }, {  15,-258 },

 {  16,-258 }, {  17,-258 }, {  18,-258 }, {  19,-258 }, {  20,-258 },
 {  21,-258 }, {  22,-258 }, {  23,-258 }, {  24,-258 }, {  25,-258 },
 {  26,-258 }, {  27,-258 }, {  28,-258 }, {  29,-258 }, {  30,-258 },
 {  31,-258 }, {  32,-258 }, {  33,   0 }, {  34,-258 }, {  35,   0 },
 {  36,-258 }, {  37,   0 }, {  38,   0 }, {  39,-258 }, {  40,-258 },
 {  41,-258 }, {  42,   0 }, {  43,   0 }, {  44,-258 }, {  45,   0 },
 {  46,-258 }, {  47,   0 }, {  48,-258 }, {  49,-258 }, {  50,-258 },
 {  51,-258 }, {  52,-258 }, {  53,-258 }, {  54,-258 }, {  55,-258 },
 {  56,-258 }, {  57,-258 }, {  58,-258 }, {  59,-258 }, {  60,   0 },
 {  61,   0 }, {  62,   0 }, {  63,   0 }, {  64,   0 }, {  65,-258 },

 {  66,-258 }, {  67,-258 }, {  68,-258 }, {  69,-258 }, {  70,-258 },
 {  71,-258 }, {  72,-258 }, {  73,-258 }, {  74,-258 }, {  75,-258 },
 {  76,-258 }, {  77,-258 }, {  78,-258 }, {  79,-258 }, {  80,-258 },
 {  81,-258 }, {  82,-258 }, {  83,-258 }, {  84,-258 }, {  85,-258 },
 {  86,-258 }, {  87,-258 }, {  88,-258 }, {  89,-258 }, {  90,-258 },
 {  91,-258 }, {  92,-258 }, {  93,-258 }, {  94,   0 }, {  95,-258 },
 {  96,   0 }, {  97,-258 }, {  98,-258 }, {  99,-258 }, { 100,-258 },
 { 101,-258 }, { 102,-258 }, { 103,-258 }, { 104,-258 }, { 105,-258 },
 { 106,-258 }, { 107,-258 }, { 108,-258 }, { 109,-258 }, { 110,-258 },
 { 111,-258 }, { 112,-258 }, { 113,-258 }, { 114,-258 }, { 115,-258 },

 { 116,-258 }, { 117,-258 }, { 118,-258 }, { 119,-258 }, { 120,-258 },
 { 121,-258 }, { 122,-258 }, { 123,-258 }, { 124,   0 }, { 125,-258 },
 { 126,   0 }, { 127,-258 }, { 128,-258 }, { 129,-258 }, { 130,-258 },
 { 131,-258 }, { 132,-258 }, { 133,-258 }, { 134,-258 }, { 135,-258 },
 { 136,-258 }, { 137,-258 }, { 138,-258 }, { 139,-258 }, { 140,-258 },
 { 141,-258 }, { 142,-258 }, { 143,-258 }, { 144,-258 }, { 145,-258 },
 { 146,-258 }, { 147,-258 }, { 148,-258 }, { 149,-258 }, { 150,-258 },
 { 151,-258 }, { 152,-258 }, { 153,-258 }, { 154,-258 }, { 155,-258 },
 { 156,-258 }, { 157,-258 }, { 158,-258 }, { 159,-258 }, { 160,-258 },
 { 161,-258 }, { 162,-258 }, { 163,-258 }, { 164,-258 }, { 165,-258 },

 { 166,-258 }, { 167,-258 }, { 168,-258 }, { 169,-258 }, { 170,-258 },
 { 171,-258 }, { 172,-258 }, { 173,-258 }, { 174,-258 }, { 175,-258 },
 { 176,-258 }, { 177,-258 }, { 178,-258 }, { 179,-258 }, { 180,-258 },
 { 181,-258 }, { 182,-258 }, { 183,-258 }, { 184,-258 }, { 185,-258 },
 { 186,-258 }, { 187,-258 }, { 188,-258 }, { 189,-258 }, { 190,-258 },
 { 191,-258 }, { 192,-258 }, { 193,-258 }, { 194,-258 }, { 195,-258 },
 { 196,-258 }, { 197,-258 }, { 198,-258 }, { 199,-258 }, { 200,-258 },
 { 201,-258 }, { 202,-258 }, { 203,-258 }, { 204,-258 }, { 205,-258 },
 { 206,-258 }, { 207,-258 }, { 208,-258 }, { 209,-258 }, { 210,-258 },
 { 211,-258 }, { 212,-258 }, { 213,-258 }, { 214,-258 }, { 215,-258 },

 { 216,-258 }, { 217,-258 }, { 218,-258 }, { 219,-258 }, { 220,-258 },
 { 221,-258 }, { 222,-258 }, { 223,-258 }, { 224,-258 }, { 225,-258 },
 { 226,-258 }, { 227,-258 }, { 228,-258 }, { 229,-258 }, { 230,-258 },
 { 231,-258 }, { 232,-258 }, { 233,-258 }, { 234,-258 }, { 235,-258 },
 { 236,-258 }, { 237,-258 }, { 238,-258 }, { 239,-258 }, { 240,-258 },
 { 241,-258 }, { 242,-258 }, { 243,-258 }, { 244,-258 }, { 245,-258 },
 { 246,-258 }, { 247,-258 }, { 248,-258 }, { 249,-258 }, { 250,-258 },
 { 251,-258 }, { 252,-258 }, { 253,-258 }, { 254,-258 }, { 255,-258 },
 { 256,-258 }, {   0,  64 }, {   0,6804 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  48,   0 }, {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 },
 {  53,   0 }, {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  65,-11359 }, {  66,-11359 }, {  67,-11359 },
 {  68,-11359 }, {  69, 257 }, {  70,-11359 }, {  71,-11359 }, {  72,-11359 },
 {  73,-11359 }, {  74,-11359 }, {  75,-11359 }, {  76,-11359 }, {  77,-11359 },
 {  78,-11359 }, {  79,-11359 }, {  80,-11359 }, {  81,-11359 }, {  82,-11359 },
 {  83,-11359 }, {  84,-11359 }, {  85,-11359 }, {  86,-11359 }, {  87,-11359 },
 {  88,-11359 }, {  89,-11359 }, {  90,-11359 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  95, 267 }, {   0,   0 }, {  97,-11359 },
 {  98,-11359 }, {  99,-11359 }, { 100,-11359 }, { 101, 257 }, { 102,-11359 },
 { 103,-11359 }, { 104,-11359 }, { 105,-11359 }, { 106,-11359 }, { 107,-11359 },

 { 108,-11359 }, { 109,-11359 }, { 110,-11359 }, { 111,-11359 }, { 112,-11359 },
 { 113,-11359 }, { 114,-11359 }, { 115,-11359 }, { 116,-11359 }, { 117,-11359 },
 { 118,-11359 }, { 119,-11359 }, { 120,-11359 }, { 121,-11359 }, { 122,-11359 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 { 128,-11359 }, { 129,-11359 }, { 130,-11359 }, { 131,-11359 }, { 132,-11359 },
 { 133,-11359 }, { 134,-11359 }, { 135,-11359 }, { 136,-11359 }, { 137,-11359 },
 { 138,-11359 }, { 139,-11359 }, { 140,-11359 }, { 141,-11359 }, { 142,-11359 },
 { 143,-11359 }, { 144,-11359 }, { 145,-11359 }, { 146,-11359 }, { 147,-11359 },
 { 148,-11359 }, { 149,-11359 }, { 150,-11359 }, { 151,-11359 }, { 152,-11359 },
 { 153,-11359 }, { 154,-11359 }, { 155,-11359 }, { 156,-11359 }, { 157,-11359 },

 { 158,-11359 }, { 159,-11359 }, { 160,-11359 }, { 161,-11359 }, { 162,-11359 },
 { 163,-11359 }, { 164,-11359 }, { 165,-11359 }, { 166,-11359 }, { 167,-11359 },
 { 168,-11359 }, { 169,-11359 }, { 170,-11359 }, { 171,-11359 }, { 172,-11359 },
 { 173,-11359 }, { 174,-11359 }, { 175,-11359 }, { 176,-11359 }, { 177,-11359 },
 { 178,-11359 }, { 179,-11359 }, { 180,-11359 }, { 181,-11359 }, { 182,-11359 },
 { 183,-11359 }, { 184,-11359 }, { 185,-11359 }, { 186,-11359 }, { 187,-11359 },
 { 188,-11359 }, { 189,-11359 }, { 190,-11359 }, { 191,-11359 }, { 192,-11359 },
 { 193,-11359 }, { 194,-11359 }, { 195,-11359 }, { 196,-11359 }, { 197,-11359 },
 { 198,-11359 }, { 199,-11359 }, { 200,-11359 }, { 201,-11359 }, { 202,-11359 },
 { 203,-11359 }, { 204,-11359 }, { 205,-11359 }, { 206,-11359 }, { 207,-11359 },

 { 208,-11359 }, { 209,-11359 }, { 210,-11359 }, { 211,-11359 }, { 212,-11359 },
 { 213,-11359 }, { 214,-11359 }, { 215,-11359 }, { 216,-11359 }, { 217,-11359 },
 { 218,-11359 }, { 219,-11359 }, { 220,-11359 }, { 221,-11359 }, { 222,-11359 },
 { 223,-11359 }, { 224,-11359 }, { 225,-11359 }, { 226,-11359 }, { 227,-11359 },
 { 228,-11359 }, { 229,-11359 }, { 230,-11359 }, { 231,-11359 }, { 232,-11359 },
 { 233,-11359 }, { 234,-11359 }, { 235,-11359 }, { 236,-11359 }, { 237,-11359 },
 { 238,-11359 }, { 239,-11359 }, { 240,-11359 }, { 241,-11359 }, { 242,-11359 },
 { 243,-11359 }, { 244,-11359 }, { 245,-11359 }, { 246,-11359 }, { 247,-11359 },
 { 248,-11359 }, { 249,-11359 }, { 250,-11359 }, { 251,-11359 }, { 252,-11359 },
 { 253,-11359 }, { 254,-11359 }, { 255,-11359 }, {   0,  72 }, {   0,6547 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  72 }, {   0,6537 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   2 }, {   0,6512 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  43, 360 }, {   0,   0 }, {  45, 360 },
 {   0,   0 }, {   0,   0 }, {  48, 615 }, {  49, 615 }, {  50, 615 },

 {  51, 615 }, {  52, 615 }, {  53, 615 }, {  54, 615 }, {  55, 615 },
 {  56, 615 }, {  57, 615 }, {  48,-267 }, {  49,-267 }, {  50,-267 },
 {  51,-267 }, {  52,-267 }, {  53,-267 }, {  54,-267 }, {  55,-267 },
 {  56,-267 }, {  57,-267 }, {  33,   0 }, {   0,   0 }, {  35,   0 },
 {   0,   0 }, {  37,   0 }, {  38,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  42,   0 }, {  43,   0 }, {   0,   0 }, {  45,   0 },
 {   0,   0 }, {  47,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  60,   0 },
 {  61,   0 }, {  62,   0 }, {  63,   0 }, {  64,   0 }, {   0,  64 },

 {   0,6446 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  94,   0 }, {   0,   0 },
 {  96,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,3199 }, {  49,3199 },

 {  50,3199 }, {  51,3199 }, {  52,3199 }, {  53,3199 }, {  54,3199 },
 {  55,3199 }, {  56,3199 }, {  57,3199 }, { 124,   0 }, {   0,   0 },
 { 126,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65,-11717 }, {  66,-11717 }, {  67,-11717 }, {  68,-11717 }, {  69,-101 },
 {  70,-11717 }, {  71,-11717 }, {  72,-11717 }, {  73,-11717 }, {  74,-11717 },
 {  75,-11717 }, {  76,-11717 }, {  77,-11717 }, {  78,-11717 }, {  79,-11717 },
 {  80,-11717 }, {  81,-11717 }, {  82,-11717 }, {  83,-11717 }, {  84,-11717 },
 {  85,-11717 }, {  86,-11717 }, {  87,-11717 }, {  88,-11717 }, {  89,-11717 },
 {  90,-11717 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  95,3456 }, {   0,   0 }, {  97,-11717 }, {  98,-11717 }, {  99,-11717 },

 { 100,-11717 }, { 101,-101 }, { 102,-11717 }, { 103,-11717 }, { 104,-11717 },
 { 105,-11717 }, { 106,-11717 }, { 107,-11717 }, { 108,-11717 }, { 109,-11717 },
 { 110,-11717 }, { 111,-11717 }, { 112,-11717 }, { 113,-11717 }, { 114,-11717 },
 { 115,-11717 }, { 116,-11717 }, { 117,-11717 }, { 118,-11717 }, { 119,-11717 },
 { 120,-11717 }, { 121,-11717 }, { 122,-11717 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,-11717 }, { 129,-11717 },
 { 130,-11717 }, { 131,-11717 }, { 132,-11717 }, { 133,-11717 }, { 134,-11717 },
 { 135,-11717 }, { 136,-11717 }, { 137,-11717 }, { 138,-11717 }, { 139,-11717 },
 { 140,-11717 }, { 141,-11717 }, { 142,-11717 }, { 143,-11717 }, { 144,-11717 },
 { 145,-11717 }, { 146,-11717 }, { 147,-11717 }, { 148,-11717 }, { 149,-11717 },

 { 150,-11717 }, { 151,-11717 }, { 152,-11717 }, { 153,-11717 }, { 154,-11717 },
 { 155,-11717 }, { 156,-11717 }, { 157,-11717 }, { 158,-11717 }, { 159,-11717 },
 { 160,-11717 }, { 161,-11717 }, { 162,-11717 }, { 163,-11717 }, { 164,-11717 },
 { 165,-11717 }, { 166,-11717 }, { 167,-11717 }, { 168,-11717 }, { 169,-11717 },
 { 170,-11717 }, { 171,-11717 }, { 172,-11717 }, { 173,-11717 }, { 174,-11717 },
 { 175,-11717 }, { 176,-11717 }, { 177,-11717 }, { 178,-11717 }, { 179,-11717 },
 { 180,-11717 }, { 181,-11717 }, { 182,-11717 }, { 183,-11717 }, { 184,-11717 },
 { 185,-11717 }, { 186,-11717 }, { 187,-11717 }, { 188,-11717 }, { 189,-11717 },
 { 190,-11717 }, { 191,-11717 }, { 192,-11717 }, { 193,-11717 }, { 194,-11717 },
 { 195,-11717 }, { 196,-11717 }, { 197,-11717 }, { 198,-11717 }, { 199,-11717 },

 { 200,-11717 }, { 201,-11717 }, { 202,-11717 }, { 203,-11717 }, { 204,-11717 },
 { 205,-11717 }, { 206,-11717 }, { 207,-11717 }, { 208,-11717 }, { 209,-11717 },
 { 210,-11717 }, { 211,-11717 }, { 212,-11717 }, { 213,-11717 }, { 214,-11717 },
 { 215,-11717 }, { 216,-11717 }, { 217,-11717 }, { 218,-11717 }, { 219,-11717 },
 { 220,-11717 }, { 221,-11717 }, { 222,-11717 }, { 223,-11717 }, { 224,-11717 },
 { 225,-11717 }, { 226,-11717 }, { 227,-11717 }, { 228,-11717 }, { 229,-11717 },
 { 230,-11717 }, { 231,-11717 }, { 232,-11717 }, { 233,-11717 }, { 234,-11717 },
 { 235,-11717 }, { 236,-11717 }, { 237,-11717 }, { 238,-11717 }, { 239,-11717 },
 { 240,-11717 }, { 241,-11717 }, { 242,-11717 }, { 243,-11717 }, { 244,-11717 },
 { 245,-11717 }, { 246,-11717 }, { 247,-11717 }, { 248,-11717 }, { 249,-11717 },

 { 250,-11717 }, { 251,-11717 }, { 252,-11717 }, { 253,-11717 }, { 254,-11717 },
 { 255,-11717 }, {   0,  60 }, {   0,6189 }, {   0,  67 }, {   0,6187 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  48,   0 }, {  49,   0 }, {  48, 255 }, {  49, 255 }, {  50, 255 },
 {  51, 255 }, {  52, 255 }, {  53, 255 }, {  54, 255 }, {  55, 255 },
 {  56, 255 }, {  57, 255 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  65,-11960 }, {  66,-11960 }, {  67,-11960 },
 {  68,-11960 }, {  69,-11960 }, {  70,-11960 }, {  71,-11960 }, {  72,-11960 },
 {  73,-11960 }, {  74,-11960 }, {  75,-11960 }, {  76,-11960 }, {  77,-11960 },
 {  78,-11960 }, {  79,-11960 }, {  80,-11960 }, {  81,-11960 }, {  82,-11960 },
 {  83,-11960 }, {  84,-11960 }, {  85,-11960 }, {  86,-11960 }, {  87,-11960 },
 {  88,-11960 }, {  89,-11960 }, {  90,-11960 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {  95,-11690 }, {   0,   0 }, {  97,-11960 },
 {  98,-11960 }, {  99,-11960 }, { 100,-11960 }, { 101,-11960 }, { 102,-11960 },
 { 103,-11960 }, { 104,-11960 }, { 105,-11960 }, { 106,-11960 }, { 107,-11960 },
 { 108,-11960 }, { 109,-11960 }, { 110,-11960 }, { 111,-11960 }, { 112,-11960 },
 { 113,-11960 }, { 114,-11960 }, { 115,-11960 }, { 116,-11960 }, { 117,-11960 },
 { 118,-11960 }, { 119,-11960 }, { 120,-11960 }, { 121,-11960 }, { 122,-11960 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 { 128,-11960 }, { 129,-11960 }, { 130,-11960 }, { 131,-11960 }, { 132,-11960 },
 { 133,-11960 }, { 134,-11960 }, { 135,-11960 }, { 136,-11960 }, { 137,-11960 },
 { 138,-11960 }, { 139,-11960 }, { 140,-11960 }, { 141,-11960 }, { 142,-11960 },

 { 143,-11960 }, { 144,-11960 }, { 145,-11960 }, { 146,-11960 }, { 147,-11960 },
 { 148,-11960 }, { 149,-11960 }, { 150,-11960 }, { 151,-11960 }, { 152,-11960 },
 { 153,-11960 }, { 154,-11960 }, { 155,-11960 }, { 156,-11960 }, { 157,-11960 },
 { 158,-11960 }, { 159,-11960 }, { 160,-11960 }, { 161,-11960 }, { 162,-11960 },
 { 163,-11960 }, { 164,-11960 }, { 165,-11960 }, { 166,-11960 }, { 167,-11960 },
 { 168,-11960 }, { 169,-11960 }, { 170,-11960 }, { 171,-11960 }, { 172,-11960 },
 { 173,-11960 }, { 174,-11960 }, { 175,-11960 }, { 176,-11960 }, { 177,-11960 },
 { 178,-11960 }, { 179,-11960 }, { 180,-11960 }, { 181,-11960 }, { 182,-11960 },
 { 183,-11960 }, { 184,-11960 }, { 185,-11960 }, { 186,-11960 }, { 187,-11960 },
 { 188,-11960 }, { 189,-11960 }, { 190,-11960 }, { 191,-11960 }, { 192,-11960 },

 { 193,-11960 }, { 194,-11960 }, { 195,-11960 }, { 196,-11960 }, { 197,-11960 },
 { 198,-11960 }, { 199,-11960 }, { 200,-11960 }, { 201,-11960 }, { 202,-11960 },
 { 203,-11960 }, { 204,-11960 }, { 205,-11960 }, { 206,-11960 }, { 207,-11960 },
 { 208,-11960 }, { 209,-11960 }, { 210,-11960 }, { 211,-11960 }, { 212,-11960 },
 { 213,-11960 }, { 214,-11960 }, { 215,-11960 }, { 216,-11960 }, { 217,-11960 },
 { 218,-11960 }, { 219,-11960 }, { 220,-11960 }, { 221,-11960 }, { 222,-11960 },
 { 223,-11960 }, { 224,-11960 }, { 225,-11960 }, { 226,-11960 }, { 227,-11960 },
 { 228,-11960 }, { 229,-11960 }, { 230,-11960 }, { 231,-11960 }, { 232,-11960 },
 { 233,-11960 }, { 234,-11960 }, { 235,-11960 }, { 236,-11960 }, { 237,-11960 },
 { 238,-11960 }, { 239,-11960 }, { 240,-11960 }, { 241,-11960 }, { 242,-11960 },

 { 243,-11960 }, { 244,-11960 }, { 245,-11960 }, { 246,-11960 }, { 247,-11960 },
 { 248,-11960 }, { 249,-11960 }, { 250,-11960 }, { 251,-11960 }, { 252,-11960 },
 { 253,-11960 }, { 254,-11960 }, { 255,-11960 }, {   0,  66 }, {   0,5932 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  48,2952 }, {  49,2952 }, {  50,2952 },
 {  51,2952 }, {  52,2952 }, {  53,2952 }, {  54,2952 }, {  55,2952 },
 {  56,2952 }, {  57,2952 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,-11945 },
 {  66,-11945 }, {  67,-11945 }, {  68,-11945 }, {  69,-11945 }, {  70,-11945 },
 {  71,-11945 }, {  72,-11945 }, {  73,-11945 }, {  74,-11945 }, {  75,-11945 },
 {  76,-11945 }, {  77,-11945 }, {  78,-11945 }, {  79,-11945 }, {  80,-11945 },
 {  81,-11945 }, {  82,-11945 }, {  83,-11945 }, {  84,-11945 }, {  85,-11945 },

 {  86,-11945 }, {  87,-11945 }, {  88,-11945 }, {  89,-11945 }, {  90,-11945 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95,3209 },
 {   0,   0 }, {  97,-11945 }, {  98,-11945 }, {  99,-11945 }, { 100,-11945 },
 { 101,-11945 }, { 102,-11945 }, { 103,-11945 }, { 104,-11945 }, { 105,-11945 },
 { 106,-11945 }, { 107,-11945 }, { 108,-11945 }, { 109,-11945 }, { 110,-11945 },
 { 111,-11945 }, { 112,-11945 }, { 113,-11945 }, { 114,-11945 }, { 115,-11945 },
 { 116,-11945 }, { 117,-11945 }, { 118,-11945 }, { 119,-11945 }, { 120,-11945 },
 { 121,-11945 }, { 122,-11945 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, { 128,-11945 }, { 129,-11945 }, { 130,-11945 },
 { 131,-11945 }, { 132,-11945 }, { 133,-11945 }, { 134,-11945 }, { 135,-11945 },

 { 136,-11945 }, { 137,-11945 }, { 138,-11945 }, { 139,-11945 }, { 140,-11945 },
 { 141,-11945 }, { 142,-11945 }, { 143,-11945 }, { 144,-11945 }, { 145,-11945 },
 { 146,-11945 }, { 147,-11945 }, { 148,-11945 }, { 149,-11945 }, { 150,-11945 },
 { 151,-11945 }, { 152,-11945 }, { 153,-11945 }, { 154,-11945 }, { 155,-11945 },
 { 156,-11945 }, { 157,-11945 }, { 158,-11945 }, { 159,-11945 }, { 160,-11945 },
 { 161,-11945 }, { 162,-11945 }, { 163,-11945 }, { 164,-11945 }, { 165,-11945 },
 { 166,-11945 }, { 167,-11945 }, { 168,-11945 }, { 169,-11945 }, { 170,-11945 },
 { 171,-11945 }, { 172,-11945 }, { 173,-11945 }, { 174,-11945 }, { 175,-11945 },
 { 176,-11945 }, { 177,-11945 }, { 178,-11945 }, { 179,-11945 }, { 180,-11945 },
 { 181,-11945 }, { 182,-11945 }, { 183,-11945 }, { 184,-11945 }, { 185,-11945 },

 { 186,-11945 }, { 187,-11945 }, { 188,-11945 }, { 189,-11945 }, { 190,-11945 },
 { 191,-11945 }, { 192,-11945 }, { 193,-11945 }, { 194,-11945 }, { 195,-11945 },
 { 196,-11945 }, { 197,-11945 }, { 198,-11945 }, { 199,-11945 }, { 200,-11945 },
 { 201,-11945 }, { 202,-11945 }, { 203,-11945 }, { 204,-11945 }, { 205,-11945 },
 { 206,-11945 }, { 207,-11945 }, { 208,-11945 }, { 209,-11945 }, { 210,-11945 },
 { 211,-11945 }, { 212,-11945 }, { 213,-11945 }, { 214,-11945 }, { 215,-11945 },
 { 216,-11945 }, { 217,-11945 }, { 218,-11945 }, { 219,-11945 }, { 220,-11945 },
 { 221,-11945 }, { 222,-11945 }, { 223,-11945 }, { 224,-11945 }, { 225,-11945 },
 { 226,-11945 }, { 227,-11945 }, { 228,-11945 }, { 229,-11945 }, { 230,-11945 },
 { 231,-11945 }, { 232,-11945 }, { 233,-11945 }, { 234,-11945 }, { 235,-11945 },

 { 236,-11945 }, { 237,-11945 }, { 238,-11945 }, { 239,-11945 }, { 240,-11945 },
 { 241,-11945 }, { 242,-11945 }, { 243,-11945 }, { 244,-11945 }, { 245,-11945 },
 { 246,-11945 }, { 247,-11945 }, { 248,-11945 }, { 249,-11945 }, { 250,-11945 },
 { 251,-11945 }, { 252,-11945 }, { 253,-11945 }, { 254,-11945 }, { 255,-11945 },
 {   0,  59 }, {   0,5675 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  62 }, {   0,5667 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,   0 },
 {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 },
 {  54,   0 }, {  55,   0 }, {  48,  -8 }, {  49,  -8 }, {  50,  -8 },
 {  51,  -8 }, {  52,  -8 }, {  53,  -8 }, {  54,  -8 }, {  55,  -8 },
 {   0,   0 }, {  65,-12200 }, {  66,-12200 }, {  67,-12200 }, {  68,-12200 },
 {  69,-12200 }, {  70,-12200 }, {  71,-12200 }, {  72,-12200 }, {  73,-12200 },
 {  74,-12200 }, {  75,-12200 }, {  76,-12200 }, {  77,-12200 }, {  78,-12200 },

 {  79,-12200 }, {  80,-12200 }, {  81,-12200 }, {  82,-12200 }, {  83,-12200 },
 {  84,-12200 }, {  85,-12200 }, {  86,-12200 }, {  87,-12200 }, {  88,-12200 },
 {  89,-12200 }, {  90,-12200 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  95,2962 }, {   0,   0 }, {  97,-12200 }, {  98,-12200 },
 {  99,-12200 }, { 100,-12200 }, { 101,-12200 }, { 102,-12200 }, { 103,-12200 },
 { 104,-12200 }, { 105,-12200 }, { 106,-12200 }, { 107,-12200 }, { 108,-12200 },
 { 109,-12200 }, { 110,-12200 }, { 111,-12200 }, { 112,-12200 }, { 113,-12200 },
 { 114,-12200 }, { 115,-12200 }, { 116,-12200 }, { 117,-12200 }, { 118,-12200 },
 { 119,-12200 }, { 120,-12200 }, { 121,-12200 }, { 122,-12200 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,-12200 },

 { 129,-12200 }, { 130,-12200 }, { 131,-12200 }, { 132,-12200 }, { 133,-12200 },
 { 134,-12200 }, { 135,-12200 }, { 136,-12200 }, { 137,-12200 }, { 138,-12200 },
 { 139,-12200 }, { 140,-12200 }, { 141,-12200 }, { 142,-12200 }, { 143,-12200 },
 { 144,-12200 }, { 145,-12200 }, { 146,-12200 }, { 147,-12200 }, { 148,-12200 },
 { 149,-12200 }, { 150,-12200 }, { 151,-12200 }, { 152,-12200 }, { 153,-12200 },
 { 154,-12200 }, { 155,-12200 }, { 156,-12200 }, { 157,-12200 }, { 158,-12200 },
 { 159,-12200 }, { 160,-12200 }, { 161,-12200 }, { 162,-12200 }, { 163,-12200 },
 { 164,-12200 }, { 165,-12200 }, { 166,-12200 }, { 167,-12200 }, { 168,-12200 },
 { 169,-12200 }, { 170,-12200 }, { 171,-12200 }, { 172,-12200 }, { 173,-12200 },
 { 174,-12200 }, { 175,-12200 }, { 176,-12200 }, { 177,-12200 }, { 178,-12200 },

 { 179,-12200 }, { 180,-12200 }, { 181,-12200 }, { 182,-12200 }, { 183,-12200 },
 { 184,-12200 }, { 185,-12200 }, { 186,-12200 }, { 187,-12200 }, { 188,-12200 },
 { 189,-12200 }, { 190,-12200 }, { 191,-12200 }, { 192,-12200 }, { 193,-12200 },
 { 194,-12200 }, { 195,-12200 }, { 196,-12200 }, { 197,-12200 }, { 198,-12200 },
 { 199,-12200 }, { 200,-12200 }, { 201,-12200 }, { 202,-12200 }, { 203,-12200 },
 { 204,-12200 }, { 205,-12200 }, { 206,-12200 }, { 207,-12200 }, { 208,-12200 },
 { 209,-12200 }, { 210,-12200 }, { 211,-12200 }, { 212,-12200 }, { 213,-12200 },
 { 214,-12200 }, { 215,-12200 }, { 216,-12200 }, { 217,-12200 }, { 218,-12200 },
 { 219,-12200 }, { 220,-12200 }, { 221,-12200 }, { 222,-12200 }, { 223,-12200 },
 { 224,-12200 }, { 225,-12200 }, { 226,-12200 }, { 227,-12200 }, { 228,-12200 },

 { 229,-12200 }, { 230,-12200 }, { 231,-12200 }, { 232,-12200 }, { 233,-12200 },
 { 234,-12200 }, { 235,-12200 }, { 236,-12200 }, { 237,-12200 }, { 238,-12200 },
 { 239,-12200 }, { 240,-12200 }, { 241,-12200 }, { 242,-12200 }, { 243,-12200 },
 { 244,-12200 }, { 245,-12200 }, { 246,-12200 }, { 247,-12200 }, { 248,-12200 },
 { 249,-12200 }, { 250,-12200 }, { 251,-12200 }, { 252,-12200 }, { 253,-12200 },
 { 254,-12200 }, { 255,-12200 }, {   0,  58 }, {   0,5418 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  48,   0 }, {  49,   0 }, {  50,   0 }, {  51,   0 },
 {  52,   0 }, {  53,   0 }, {  54,   0 }, {  55,   0 }, {  56,   0 },
 {  57,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,2713 }, {  66,2713 },
 {  67,2713 }, {  68,2713 }, {  69,2713 }, {  70,2713 }, {  71,-12455 },

 {  72,-12455 }, {  73,-12455 }, {  74,-12455 }, {  75,-12455 }, {  76,-12455 },
 {  77,-12455 }, {  78,-12455 }, {  79,-12455 }, {  80,-12455 }, {  81,-12455 },
 {  82,-12455 }, {  83,-12455 }, {  84,-12455 }, {  85,-12455 }, {  86,-12455 },
 {  87,-12455 }, {  88,-12455 }, {  89,-12455 }, {  90,-12455 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95,2970 }, {   0,   0 },
 {  97,2713 }, {  98,2713 }, {  99,2713 }, { 100,2713 }, { 101,2713 },
 { 102,2713 }, { 103,-12455 }, { 104,-12455 }, { 105,-12455 }, { 106,-12455 },
 { 107,-12455 }, { 108,-12455 }, { 109,-12455 }, { 110,-12455 }, { 111,-12455 },
 { 112,-12455 }, { 113,-12455 }, { 114,-12455 }, { 115,-12455 }, { 116,-12455 },
 { 117,-12455 }, { 118,-12455 }, { 119,-12455 }, { 120,-12455 }, { 121,-12455 },

 { 122,-12455 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, { 128,-12455 }, { 129,-12455 }, { 130,-12455 }, { 131,-12455 },
 { 132,-12455 }, { 133,-12455 }, { 134,-12455 }, { 135,-12455 }, { 136,-12455 },
 { 137,-12455 }, { 138,-12455 }, { 139,-12455 }, { 140,-12455 }, { 141,-12455 },
 { 142,-12455 }, { 143,-12455 }, { 144,-12455 }, { 145,-12455 }, { 146,-12455 },
 { 147,-12455 }, { 148,-12455 }, { 149,-12455 }, { 150,-12455 }, { 151,-12455 },
 { 152,-12455 }, { 153,-12455 }, { 154,-12455 }, { 155,-12455 }, { 156,-12455 },
 { 157,-12455 }, { 158,-12455 }, { 159,-12455 }, { 160,-12455 }, { 161,-12455 },
 { 162,-12455 }, { 163,-12455 }, { 164,-12455 }, { 165,-12455 }, { 166,-12455 },
 { 167,-12455 }, { 168,-12455 }, { 169,-12455 }, { 170,-12455 }, { 171,-12455 },

 { 172,-12455 }, { 173,-12455 }, { 174,-12455 }, { 175,-12455 }, { 176,-12455 },
 { 177,-12455 }, { 178,-12455 }, { 179,-12455 }, { 180,-12455 }, { 181,-12455 },
 { 182,-12455 }, { 183,-12455 }, { 184,-12455 }, { 185,-12455 }, { 186,-12455 },
 { 187,-12455 }, { 188,-12455 }, { 189,-12455 }, { 190,-12455 }, { 191,-12455 },
 { 192,-12455 }, { 193,-12455 }, { 194,-12455 }, { 195,-12455 }, { 196,-12455 },
 { 197,-12455 }, { 198,-12455 }, { 199,-12455 }, { 200,-12455 }, { 201,-12455 },
 { 202,-12455 }, { 203,-12455 }, { 204,-12455 }, { 205,-12455 }, { 206,-12455 },
 { 207,-12455 }, { 208,-12455 }, { 209,-12455 }, { 210,-12455 }, { 211,-12455 },
 { 212,-12455 }, { 213,-12455 }, { 214,-12455 }, { 215,-12455 }, { 216,-12455 },
 { 217,-12455 }, { 218,-12455 }, { 219,-12455 }, { 220,-12455 }, { 221,-12455 },

 { 222,-12455 }, { 223,-12455 }, { 224,-12455 }, { 225,-12455 }, { 226,-12455 },
 { 227,-12455 }, { 228,-12455 }, { 229,-12455 }, { 230,-12455 }, { 231,-12455 },
 { 232,-12455 }, { 233,-12455 }, { 234,-12455 }, { 235,-12455 }, { 236,-12455 },
 { 237,-12455 }, { 238,-12455 }, { 239,-12455 }, { 240,-12455 }, { 241,-12455 },
 { 242,-12455 }, { 243,-12455 }, { 244,-12455 }, { 245,-12455 }, { 246,-12455 },
 { 247,-12455 }, { 248,-12455 }, { 249,-12455 }, { 250,-12455 }, { 251,-12455 },
 { 252,-12455 }, { 253,-12455 }, { 254,-12455 }, { 255,-12455 }, {   0,  61 },
 {   0,5161 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,  57 }, {   0,5123 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,-257 }, {  49,-257 },
 {  50,-257 }, {  51,-257 }, {  52,-257 }, {  53,-257 }, {  54,-257 },
 {  55,-257 }, {  56,-257 }, {  57,-257 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {  65,-257 }, {  66,-257 }, {  67,-257 }, {  68,-257 }, {  69,-257 },
 {  70,-257 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  46,2713 },
 {   0,   0 }, {  48,   0 }, {  49,   0 }, {  50,   0 }, {  51,   0 },
 {  52,   0 }, {  53,   0 }, {  54,   0 }, {  55,   0 }, {  56,   0 },
 {  57,   0 }, {   0,   0 }, {  97,-257 }, {  98,-257 }, {  99,-257 },
 { 100,-257 }, { 101,-257 }, { 102,-257 }, {  65,-13401 }, {  66,-13401 },
 {  67,-13401 }, {  68,-13401 }, {  69,-6021 }, {  70,-13401 }, {  71,-13401 },
 {  72,-13401 }, {  73,-13401 }, {  74,-13401 }, {  75,-13401 }, {  76,-13401 },

 {  77,-13401 }, {  78,-13401 }, {  79,-13401 }, {  80,-13401 }, {  81,-13401 },
 {  82,-13401 }, {  83,-13401 }, {  84,-13401 }, {  85,-13401 }, {  86,-13401 },
 {  87,-13401 }, {  88,-13401 }, {  89,-13401 }, {  90,-13401 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95,-5980 }, {   0,   0 },
 {  97,-13401 }, {  98,-13401 }, {  99,-13401 }, { 100,-13401 }, { 101,-6021 },
 { 102,-13401 }, { 103,-13401 }, { 104,-13401 }, { 105,-13401 }, { 106,-13401 },
 { 107,-13401 }, { 108,-13401 }, { 109,-13401 }, { 110,-13401 }, { 111,-13401 },
 { 112,-13401 }, { 113,-13401 }, { 114,-13401 }, { 115,-13401 }, { 116,-13401 },
 { 117,-13401 }, { 118,-13401 }, { 119,-13401 }, { 120,-13401 }, { 121,-13401 },
 { 122,-13401 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, { 128,-13401 }, { 129,-13401 }, { 130,-13401 }, { 131,-13401 },
 { 132,-13401 }, { 133,-13401 }, { 134,-13401 }, { 135,-13401 }, { 136,-13401 },
 { 137,-13401 }, { 138,-13401 }, { 139,-13401 }, { 140,-13401 }, { 141,-13401 },
 { 142,-13401 }, { 143,-13401 }, { 144,-13401 }, { 145,-13401 }, { 146,-13401 },
 { 147,-13401 }, { 148,-13401 }, { 149,-13401 }, { 150,-13401 }, { 151,-13401 },
 { 152,-13401 }, { 153,-13401 }, { 154,-13401 }, { 155,-13401 }, { 156,-13401 },
 { 157,-13401 }, { 158,-13401 }, { 159,-13401 }, { 160,-13401 }, { 161,-13401 },
 { 162,-13401 }, { 163,-13401 }, { 164,-13401 }, { 165,-13401 }, { 166,-13401 },
 { 167,-13401 }, { 168,-13401 }, { 169,-13401 }, { 170,-13401 }, { 171,-13401 },
 { 172,-13401 }, { 173,-13401 }, { 174,-13401 }, { 175,-13401 }, { 176,-13401 },

 { 177,-13401 }, { 178,-13401 }, { 179,-13401 }, { 180,-13401 }, { 181,-13401 },
 { 182,-13401 }, { 183,-13401 }, { 184,-13401 }, { 185,-13401 }, { 186,-13401 },
 { 187,-13401 }, { 188,-13401 }, { 189,-13401 }, { 190,-13401 }, { 191,-13401 },
 { 192,-13401 }, { 193,-13401 }, { 194,-13401 }, { 195,-13401 }, { 196,-13401 },
 { 197,-13401 }, { 198,-13401 }, { 199,-13401 }, { 200,-13401 }, { 201,-13401 },
 { 202,-13401 }, { 203,-13401 }, { 204,-13401 }, { 205,-13401 }, { 206,-13401 },
 { 207,-13401 }, { 208,-13401 }, { 209,-13401 }, { 210,-13401 }, { 211,-13401 },
 { 212,-13401 }, { 213,-13401 }, { 214,-13401 }, { 215,-13401 }, { 216,-13401 },
 { 217,-13401 }, { 218,-13401 }, { 219,-13401 }, { 220,-13401 }, { 221,-13401 },
 { 222,-13401 }, { 223,-13401 }, { 224,-13401 }, { 225,-13401 }, { 226,-13401 },

 { 227,-13401 }, { 228,-13401 }, { 229,-13401 }, { 230,-13401 }, { 231,-13401 },
 { 232,-13401 }, { 233,-13401 }, { 234,-13401 }, { 235,-13401 }, { 236,-13401 },
 { 237,-13401 }, { 238,-13401 }, { 239,-13401 }, { 240,-13401 }, { 241,-13401 },
 { 242,-13401 }, { 243,-13401 }, { 244,-13401 }, { 245,-13401 }, { 246,-13401 },
 { 247,-13401 }, { 248,-13401 }, { 249,-13401 }, { 250,-13401 }, { 251,-13401 },
 { 252,-13401 }, { 253,-13401 }, { 254,-13401 }, { 255,-13401 }, {   0,   3 },
 {   0,4866 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  33,   0 }, {   0,   0 },
 {  35,   0 }, {   0,   0 }, {  37,   0 }, {  38,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  42,   0 }, {  43,   0 }, {   0,   0 },
 {  45,   0 }, {   0,   0 }, {  47,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  60,   0 }, {  61,   0 }, {  62,   0 }, {  63,   0 }, {  64,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  94,   0 },
 {   0,   0 }, {  96,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, { 124,   0 },
 {   0,   0 }, { 126,   0 }, {   0,  18 }, {   0,4738 }, {   1,2585 },
 {   2,2585 }, {   3,2585 }, {   4,2585 }, {   5,2585 }, {   6,2585 },
 {   7,2585 }, {   8,2585 }, {   9,2843 }, {  10,3101 }, {  11,2843 },
 {  12,2843 }, {  13,3101 }, {  14,2585 }, {  15,2585 }, {  16,2585 },
 {  17,2585 }, {  18,2585 }, {  19,2585 }, {  20,2585 }, {  21,2585 },
 {  22,2585 }, {  23,2585 }, {  24,2585 }, {  25,2585 }, {  26,2585 },
 {  27,2585 }, {  28,2585 }, {  29,2585 }, {  30,2585 }, {  31,2585 },
 {  32,2843 }, {  33,2585 }, {  34,2585 }, {  35,2585 }, {  36,2585 },
 {  37,2585 }, {  38,2585 }, {  39,2585 }, {  40,2585 }, {  41,2585 },

 {  42,2585 }, {  43,2585 }, {  44,2585 }, {  45,3148 }, {  46,2585 },
 {  47,2585 }, {  48,2585 }, {  49,2585 }, {  50,2585 }, {  51,2585 },
 {  52,2585 }, {  53,2585 }, {  54,2585 }, {  55,2585 }, {  56,2585 },
 {  57,2585 }, {  58,2585 }, {  59,2585 }, {  60,2585 }, {  61,2585 },
 {  62,2585 }, {  63,2585 }, {  64,2585 }, {  65,2585 }, {  66,2585 },
 {  67,2585 }, {  68,2585 }, {  69,2585 }, {  70,2585 }, {  71,2585 },
 {  72,2585 }, {  73,2585 }, {  74,2585 }, {  75,2585 }, {  76,2585 },
 {  77,2585 }, {  78,2585 }, {  79,2585 }, {  80,2585 }, {  81,2585 },
 {  82,2585 }, {  83,2585 }, {  84,2585 }, {  85,2585 }, {  86,2585 },
 {  87,2585 }, {  88,2585 }, {  89,2585 }, {  90,2585 }, {  91,2585 },

 {  92,2585 }, {  93,2585 }, {  94,2585 }, {  95,2585 }, {  96,2585 },
 {  97,2585 }, {  98,2585 }, {  99,2585 }, { 100,2585 }, { 101,2585 },
 { 102,2585 }, { 103,2585 }, { 104,2585 }, { 105,2585 }, { 106,2585 },
 { 107,2585 }, { 108,2585 }, { 109,2585 }, { 110,2585 }, { 111,2585 },
 { 112,2585 }, { 113,2585 }, { 114,2585 }, { 115,2585 }, { 116,2585 },
 { 117,2585 }, { 118,2585 }, { 119,2585 }, { 120,2585 }, { 121,2585 },
 { 122,2585 }, { 123,2585 }, { 124,2585 }, { 125,2585 }, { 126,2585 },
 { 127,2585 }, { 128,2585 }, { 129,2585 }, { 130,2585 }, { 131,2585 },
 { 132,2585 }, { 133,2585 }, { 134,2585 }, { 135,2585 }, { 136,2585 },
 { 137,2585 }, { 138,2585 }, { 139,2585 }, { 140,2585 }, { 141,2585 },

 { 142,2585 }, { 143,2585 }, { 144,2585 }, { 145,2585 }, { 146,2585 },
 { 147,2585 }, { 148,2585 }, { 149,2585 }, { 150,2585 }, { 151,2585 },
 { 152,2585 }, { 153,2585 }, { 154,2585 }, { 155,2585 }, { 156,2585 },
 { 157,2585 }, { 158,2585 }, { 159,2585 }, { 160,2585 }, { 161,2585 },
 { 162,2585 }, { 163,2585 }, { 164,2585 }, { 165,2585 }, { 166,2585 },
 { 167,2585 }, { 168,2585 }, { 169,2585 }, { 170,2585 }, { 171,2585 },
 { 172,2585 }, { 173,2585 }, { 174,2585 }, { 175,2585 }, { 176,2585 },
 { 177,2585 }, { 178,2585 }, { 179,2585 }, { 180,2585 }, { 181,2585 },
 { 182,2585 }, { 183,2585 }, { 184,2585 }, { 185,2585 }, { 186,2585 },
 { 187,2585 }, { 188,2585 }, { 189,2585 }, { 190,2585 }, { 191,2585 },

 { 192,2585 }, { 193,2585 }, { 194,2585 }, { 195,2585 }, { 196,2585 },
 { 197,2585 }, { 198,2585 }, { 199,2585 }, { 200,2585 }, { 201,2585 },
 { 202,2585 }, { 203,2585 }, { 204,2585 }, { 205,2585 }, { 206,2585 },
 { 207,2585 }, { 208,2585 }, { 209,2585 }, { 210,2585 }, { 211,2585 },
 { 212,2585 }, { 213,2585 }, { 214,2585 }, { 215,2585 }, { 216,2585 },
 { 217,2585 }, { 218,2585 }, { 219,2585 }, { 220,2585 }, { 221,2585 },
 { 222,2585 }, { 223,2585 }, { 224,2585 }, { 225,2585 }, { 226,2585 },
 { 227,2585 }, { 228,2585 }, { 229,2585 }, { 230,2585 }, { 231,2585 },
 { 232,2585 }, { 233,2585 }, { 234,2585 }, { 235,2585 }, { 236,2585 },
 { 237,2585 }, { 238,2585 }, { 239,2585 }, { 240,2585 }, { 241,2585 },

 { 242,2585 }, { 243,2585 }, { 244,2585 }, { 245,2585 }, { 246,2585 },
 { 247,2585 }, { 248,2585 }, { 249,2585 }, { 250,2585 }, { 251,2585 },
 { 252,2585 }, { 253,2585 }, { 254,2585 }, { 255,2585 }, { 256,2585 },
 {   0,  18 }, {   0,4480 }, {   1,   0 }, {   2,   0 }, {   3,   0 },
 {   4,   0 }, {   5,   0 }, {   6,   0 }, {   7,   0 }, {   8,   0 },
 {   9, 258 }, {  10,-4700 }, {  11, 258 }, {  12, 258 }, {  13,-4700 },
 {  14,   0 }, {  15,   0 }, {  16,   0 }, {  17,   0 }, {  18,   0 },
 {  19,   0 }, {  20,   0 }, {  21,   0 }, {  22,   0 }, {  23,   0 },
 {  24,   0 }, {  25,   0 }, {  26,   0 }, {  27,   0 }, {  28,   0 },
 {  29,   0 }, {  30,   0 }, {  31,   0 }, {  32, 258 }, {  33,   0 },

 {  34,   0 }, {  35,   0 }, {  36,   0 }, {  37,   0 }, {  38,   0 },
 {  39,   0 }, {  40,   0 }, {  41,   0 }, {  42,   0 }, {  43,   0 },
 {  44,   0 }, {  45, 516 }, {  46,   0 }, {  47,   0 }, {  48,   0 },
 {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 },
 {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 }, {  58,   0 },
 {  59,   0 }, {  60,   0 }, {  61,   0 }, {  62,   0 }, {  63,   0 },
 {  64,   0 }, {  65,   0 }, {  66,   0 }, {  67,   0 }, {  68,   0 },
 {  69,   0 }, {  70,   0 }, {  71,   0 }, {  72,   0 }, {  73,   0 },
 {  74,   0 }, {  75,   0 }, {  76,   0 }, {  77,   0 }, {  78,   0 },
 {  79,   0 }, {  80,   0 }, {  81,   0 }, {  82,   0 }, {  83,   0 },

 {  84,   0 }, {  85,   0 }, {  86,   0 }, {  87,   0 }, {  88,   0 },
 {  89,   0 }, {  90,   0 }, {  91,   0 }, {  92,   0 }, {  93,   0 },
 {  94,   0 }, {  95,   0 }, {  96,   0 }, {  97,   0 }, {  98,   0 },
 {  99,   0 }, { 100,   0 }, { 101,   0 }, { 102,   0 }, { 103,   0 },
 { 104,   0 }, { 105,   0 }, { 106,   0 }, { 107,   0 }, { 108,   0 },
 { 109,   0 }, { 110,   0 }, { 111,   0 }, { 112,   0 }, { 113,   0 },
 { 114,   0 }, { 115,   0 }, { 116,   0 }, { 117,   0 }, { 118,   0 },
 { 119,   0 }, { 120,   0 }, { 121,   0 }, { 122,   0 }, { 123,   0 },
 { 124,   0 }, { 125,   0 }, { 126,   0 }, { 127,   0 }, { 128,   0 },
 { 129,   0 }, { 130,   0 }, { 131,   0 }, { 132,   0 }, { 133,   0 },

 { 134,   0 }, { 135,   0 }, { 136,   0 }, { 137,   0 }, { 138,   0 },
 { 139,   0 }, { 140,   0 }, { 141,   0 }, { 142,   0 }, { 143,   0 },
 { 144,   0 }, { 145,   0 }, { 146,   0 }, { 147,   0 }, { 148,   0 },
 { 149,   0 }, { 150,   0 }, { 151,   0 }, { 152,   0 }, { 153,   0 },
 { 154,   0 }, { 155,   0 }, { 156,   0 }, { 157,   0 }, { 158,   0 },
 { 159,   0 }, { 160,   0 }, { 161,   0 }, { 162,   0 }, { 163,   0 },
 { 164,   0 }, { 165,   0 }, { 166,   0 }, { 167,   0 }, { 168,   0 },
 { 169,   0 }, { 170,   0 }, { 171,   0 }, { 172,   0 }, { 173,   0 },
 { 174,   0 }, { 175,   0 }, { 176,   0 }, { 177,   0 }, { 178,   0 },
 { 179,   0 }, { 180,   0 }, { 181,   0 }, { 182,   0 }, { 183,   0 },

 { 184,   0 }, { 185,   0 }, { 186,   0 }, { 187,   0 }, { 188,   0 },
 { 189,   0 }, { 190,   0 }, { 191,   0 }, { 192,   0 }, { 193,   0 },
 { 194,   0 }, { 195,   0 }, { 196,   0 }, { 197,   0 }, { 198,   0 },
 { 199,   0 }, { 200,   0 }, { 201,   0 }, { 202,   0 }, { 203,   0 },
 { 204,   0 }, { 205,   0 }, { 206,   0 }, { 207,   0 }, { 208,   0 },
 { 209,   0 }, { 210,   0 }, { 211,   0 }, { 212,   0 }, { 213,   0 },
 { 214,   0 }, { 215,   0 }, { 216,   0 }, { 217,   0 }, { 218,   0 },
 { 219,   0 }, { 220,   0 }, { 221,   0 }, { 222,   0 }, { 223,   0 },
 { 224,   0 }, { 225,   0 }, { 226,   0 }, { 227,   0 }, { 228,   0 },
 { 229,   0 }, { 230,   0 }, { 231,   0 }, { 232,   0 }, { 233,   0 },

 { 234,   0 }, { 235,   0 }, { 236,   0 }, { 237,   0 }, { 238,   0 },
 { 239,   0 }, { 240,   0 }, { 241,   0 }, { 242,   0 }, { 243,   0 },
 { 244,   0 }, { 245,   0 }, { 246,   0 }, { 247,   0 }, { 248,   0 },
 { 249,   0 }, { 250,   0 }, { 251,   0 }, { 252,   0 }, { 253,   0 },
 { 254,   0 }, { 255,   0 }, { 256,   0 }, {   0,  18 }, {   0,4222 },
 {   1,-258 }, {   2,-258 }, {   3,-258 }, {   4,-258 }, {   5,-258 },
 {   6,-258 }, {   7,-258 }, {   8,-258 }, {   9,   0 }, {  10,-4958 },
 {  11,   0 }, {  12,   0 }, {  13,-4958 }, {  14,-258 }, {  15,-258 },
 {  16,-258 }, {  17,-258 }, {  18,-258 }, {  19,-258 }, {  20,-258 },
 {  21,-258 }, {  22,-258 }, {  23,-258 }, {  24,-258 }, {  25,-258 },

 {  26,-258 }, {  27,-258 }, {  28,-258 }, {  29,-258 }, {  30,-258 },
 {  31,-258 }, {  32,   0 }, {  33,-258 }, {  34,-258 }, {  35,-258 },
 {  36,-258 }, {  37,-258 }, {  38,-258 }, {  39,-258 }, {  40,-258 },
 {  41,-258 }, {  42,-258 }, {  43,-258 }, {  44,-258 }, {  45, 258 },
 {  46,-258 }, {  47,-258 }, {  48,-258 }, {  49,-258 }, {  50,-258 },
 {  51,-258 }, {  52,-258 }, {  53,-258 }, {  54,-258 }, {  55,-258 },
 {  56,-258 }, {  57,-258 }, {  58,-258 }, {  59,-258 }, {  60,-258 },
 {  61,-258 }, {  62,-258 }, {  63,-258 }, {  64,-258 }, {  65,-258 },
 {  66,-258 }, {  67,-258 }, {  68,-258 }, {  69,-258 }, {  70,-258 },
 {  71,-258 }, {  72,-258 }, {  73,-258 }, {  74,-258 }, {  75,-258 },

 {  76,-258 }, {  77,-258 }, {  78,-258 }, {  79,-258 }, {  80,-258 },
 {  81,-258 }, {  82,-258 }, {  83,-258 }, {  84,-258 }, {  85,-258 },
 {  86,-258 }, {  87,-258 }, {  88,-258 }, {  89,-258 }, {  90,-258 },
 {  91,-258 }, {  92,-258 }, {  93,-258 }, {  94,-258 }, {  95,-258 },
 {  96,-258 }, {  97,-258 }, {  98,-258 }, {  99,-258 }, { 100,-258 },
 { 101,-258 }, { 102,-258 }, { 103,-258 }, { 104,-258 }, { 105,-258 },
 { 106,-258 }, { 107,-258 }, { 108,-258 }, { 109,-258 }, { 110,-258 },
 { 111,-258 }, { 112,-258 }, { 113,-258 }, { 114,-258 }, { 115,-258 },
 { 116,-258 }, { 117,-258 }, { 118,-258 }, { 119,-258 }, { 120,-258 },
 { 121,-258 }, { 122,-258 }, { 123,-258 }, { 124,-258 }, { 125,-258 },

 { 126,-258 }, { 127,-258 }, { 128,-258 }, { 129,-258 }, { 130,-258 },
 { 131,-258 }, { 132,-258 }, { 133,-258 }, { 134,-258 }, { 135,-258 },
 { 136,-258 }, { 137,-258 }, { 138,-258 }, { 139,-258 }, { 140,-258 },
 { 141,-258 }, { 142,-258 }, { 143,-258 }, { 144,-258 }, { 145,-258 },
 { 146,-258 }, { 147,-258 }, { 148,-258 }, { 149,-258 }, { 150,-258 },
 { 151,-258 }, { 152,-258 }, { 153,-258 }, { 154,-258 }, { 155,-258 },
 { 156,-258 }, { 157,-258 }, { 158,-258 }, { 159,-258 }, { 160,-258 },
 { 161,-258 }, { 162,-258 }, { 163,-258 }, { 164,-258 }, { 165,-258 },
 { 166,-258 }, { 167,-258 }, { 168,-258 }, { 169,-258 }, { 170,-258 },
 { 171,-258 }, { 172,-258 }, { 173,-258 }, { 174,-258 }, { 175,-258 },

 { 176,-258 }, { 177,-258 }, { 178,-258 }, { 179,-258 }, { 180,-258 },
 { 181,-258 }, { 182,-258 }, { 183,-258 }, { 184,-258 }, { 185,-258 },
 { 186,-258 }, { 187,-258 }, { 188,-258 }, { 189,-258 }, { 190,-258 },
 { 191,-258 }, { 192,-258 }, { 193,-258 }, { 194,-258 }, { 195,-258 },
 { 196,-258 }, { 197,-258 }, { 198,-258 }, { 199,-258 }, { 200,-258 },
 { 201,-258 }, { 202,-258 }, { 203,-258 }, { 204,-258 }, { 205,-258 },
 { 206,-258 }, { 207,-258 }, { 208,-258 }, { 209,-258 }, { 210,-258 },
 { 211,-258 }, { 212,-258 }, { 213,-258 }, { 214,-258 }, { 215,-258 },
 { 216,-258 }, { 217,-258 }, { 218,-258 }, { 219,-258 }, { 220,-258 },
 { 221,-258 }, { 222,-258 }, { 223,-258 }, { 224,-258 }, { 225,-258 },

 { 226,-258 }, { 227,-258 }, { 228,-258 }, { 229,-258 }, { 230,-258 },
 { 231,-258 }, { 232,-258 }, { 233,-258 }, { 234,-258 }, { 235,-258 },
 { 236,-258 }, { 237,-258 }, { 238,-258 }, { 239,-258 }, { 240,-258 },
 { 241,-258 }, { 242,-258 }, { 243,-258 }, { 244,-258 }, { 245,-258 },
 { 246,-258 }, { 247,-258 }, { 248,-258 }, { 249,-258 }, { 250,-258 },
 { 251,-258 }, { 252,-258 }, { 253,-258 }, { 254,-258 }, { 255,-258 },
 { 256,-258 }, {   0,  18 }, {   0,3964 }, {   1,-516 }, {   2,-516 },
 {   3,-516 }, {   4,-516 }, {   5,-516 }, {   6,-516 }, {   7,-516 },
 {   8,-516 }, {   9,-258 }, {  10,-5216 }, {  11,-258 }, {  12,-258 },
 {  13,-5216 }, {  14,-516 }, {  15,-516 }, {  16,-516 }, {  17,-516 },

 {  18,-516 }, {  19,-516 }, {  20,-516 }, {  21,-516 }, {  22,-516 },
 {  23,-516 }, {  24,-516 }, {  25,-516 }, {  26,-516 }, {  27,-516 },
 {  28,-516 }, {  29,-516 }, {  30,-516 }, {  31,-516 }, {  32,-258 },
 {  33,-516 }, {  34,-516 }, {  35,-516 }, {  36,-516 }, {  37,-516 },
 {  38,-516 }, {  39,-516 }, {  40,-516 }, {  41,-516 }, {  42,-516 },
 {  43,-516 }, {  44,-516 }, {  45,2632 }, {  46,-516 }, {  47,-516 },
 {  48,-516 }, {  49,-516 }, {  50,-516 }, {  51,-516 }, {  52,-516 },
 {  53,-516 }, {  54,-516 }, {  55,-516 }, {  56,-516 }, {  57,-516 },
 {  58,-516 }, {  59,-516 }, {  60,-516 }, {  61,-516 }, {  62,-516 },
 {  63,-516 }, {  64,-516 }, {  65,-516 }, {  66,-516 }, {  67,-516 },

 {  68,-516 }, {  69,-516 }, {  70,-516 }, {  71,-516 }, {  72,-516 },
 {  73,-516 }, {  74,-516 }, {  75,-516 }, {  76,-516 }, {  77,-516 },
 {  78,-516 }, {  79,-516 }, {  80,-516 }, {  81,-516 }, {  82,-516 },
 {  83,-516 }, {  84,-516 }, {  85,-516 }, {  86,-516 }, {  87,-516 },
 {  88,-516 }, {  89,-516 }, {  90,-516 }, {  91,-516 }, {  92,-516 },
 {  93,-516 }, {  94,-516 }, {  95,-516 }, {  96,-516 }, {  97,-516 },
 {  98,-516 }, {  99,-516 }, { 100,-516 }, { 101,-516 }, { 102,-516 },
 { 103,-516 }, { 104,-516 }, { 105,-516 }, { 106,-516 }, { 107,-516 },
 { 108,-516 }, { 109,-516 }, { 110,-516 }, { 111,-516 }, { 112,-516 },
 { 113,-516 }, { 114,-516 }, { 115,-516 }, { 116,-516 }, { 117,-516 },

 { 118,-516 }, { 119,-516 }, { 120,-516 }, { 121,-516 }, { 122,-516 },
 { 123,-516 }, { 124,-516 }, { 125,-516 }, { 126,-516 }, { 127,-516 },
 { 128,-516 }, { 129,-516 }, { 130,-516 }, { 131,-516 }, { 132,-516 },
 { 133,-516 }, { 134,-516 }, { 135,-516 }, { 136,-516 }, { 137,-516 },
 { 138,-516 }, { 139,-516 }, { 140,-516 }, { 141,-516 }, { 142,-516 },
 { 143,-516 }, { 144,-516 }, { 145,-516 }, { 146,-516 }, { 147,-516 },
 { 148,-516 }, { 149,-516 }, { 150,-516 }, { 151,-516 }, { 152,-516 },
 { 153,-516 }, { 154,-516 }, { 155,-516 }, { 156,-516 }, { 157,-516 },
 { 158,-516 }, { 159,-516 }, { 160,-516 }, { 161,-516 }, { 162,-516 },
 { 163,-516 }, { 164,-516 }, { 165,-516 }, { 166,-516 }, { 167,-516 },

 { 168,-516 }, { 169,-516 }, { 170,-516 }, { 171,-516 }, { 172,-516 },
 { 173,-516 }, { 174,-516 }, { 175,-516 }, { 176,-516 }, { 177,-516 },
 { 178,-516 }, { 179,-516 }, { 180,-516 }, { 181,-516 }, { 182,-516 },
 { 183,-516 }, { 184,-516 }, { 185,-516 }, { 186,-516 }, { 187,-516 },
 { 188,-516 }, { 189,-516 }, { 190,-516 }, { 191,-516 }, { 192,-516 },
 { 193,-516 }, { 194,-516 }, { 195,-516 }, { 196,-516 }, { 197,-516 },
 { 198,-516 }, { 199,-516 }, { 200,-516 }, { 201,-516 }, { 202,-516 },
 { 203,-516 }, { 204,-516 }, { 205,-516 }, { 206,-516 }, { 207,-516 },
 { 208,-516 }, { 209,-516 }, { 210,-516 }, { 211,-516 }, { 212,-516 },
 { 213,-516 }, { 214,-516 }, { 215,-516 }, { 216,-516 }, { 217,-516 },

 { 218,-516 }, { 219,-516 }, { 220,-516 }, { 221,-516 }, { 222,-516 },
 { 223,-516 }, { 224,-516 }, { 225,-516 }, { 226,-516 }, { 227,-516 },
 { 228,-516 }, { 229,-516 }, { 230,-516 }, { 231,-516 }, { 232,-516 },
 { 233,-516 }, { 234,-516 }, { 235,-516 }, { 236,-516 }, { 237,-516 },
 { 238,-516 }, { 239,-516 }, { 240,-516 }, { 241,-516 }, { 242,-516 },
 { 243,-516 }, { 244,-516 }, { 245,-516 }, { 246,-516 }, { 247,-516 },
 { 248,-516 }, { 249,-516 }, { 250,-516 }, { 251,-516 }, { 252,-516 },
 { 253,-516 }, { 254,-516 }, { 255,-516 }, { 256,-516 }, {   0,  29 },
 {   0,3706 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,  27 }, {   0,3698 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,  27 }, {   0,3675 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,-14165 }, {  49,-14165 },
 {  50,-14165 }, {  51,-14165 }, {  52,-14165 }, {  53,-14165 }, {  54,-14165 },
 {  55,-14165 }, {  48,2624 }, {  49,2624 }, {  50,2624 }, {  51,2624 },

 {  52,2624 }, {  53,2624 }, {  54,2624 }, {  55,2624 }, {  56,2624 },
 {  57,2624 }, {   0,   0 }, {   0,   0 }, {   0,  30 }, {   0,3637 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,2624 }, {  66,2624 },
 {  67,2624 }, {  68,2624 }, {  69,2624 }, {  70,2624 }, {  48,2624 },
 {  49,2624 }, {  50,2624 }, {  51,2624 }, {  52,2624 }, {  53,2624 },
 {  54,2624 }, {  55,2624 }, {  56,2624 }, {  57,2624 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  65,2624 }, {  66,2624 }, {  67,2624 }, {  68,2624 },
 {  69,2624 }, {  70,2624 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  97,2624 }, {  98,2624 }, {  99,2624 }, { 100,2624 }, { 101,2624 },

 { 102,2624 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  48,-14232 }, {  49,-14232 }, {  50,-14232 },
 {  51,-14232 }, {  52,-14232 }, {  53,-14232 }, {  54,-14232 }, {  55,-14232 },
 {  56,-14232 }, {  57,-14232 }, {   0,   0 }, {  97,2624 }, {  98,2624 },
 {  99,2624 }, { 100,2624 }, { 101,2624 }, { 102,2624 }, {  65,-14232 },
 {  66,-14232 }, {  67,-14232 }, {  68,-14232 }, {  69,-14232 }, {  70,-14232 },
 {   0,  36 }, {   0,3565 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  97,-14232 }, {  98,-14232 }, {  99,-14232 }, { 100,-14232 },
 { 101,-14232 }, { 102,-14232 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  36,-14603 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,   0 },
 {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 },
 {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  65,   0 }, {  66,   0 }, {  67,   0 }, {  68,   0 },

 {  69,   0 }, {  70,   0 }, {  71,   0 }, {  72,   0 }, {  73,   0 },
 {  74,   0 }, {  75,   0 }, {  76,   0 }, {  77,   0 }, {  78,   0 },
 {  79,   0 }, {  80,   0 }, {  81,   0 }, {  82,   0 }, {  83,   0 },
 {  84,   0 }, {  85,   0 }, {  86,   0 }, {  87,   0 }, {  88,   0 },
 {  89,   0 }, {  90,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  95,   0 }, {   0,   0 }, {  97,   0 }, {  98,   0 },
 {  99,   0 }, { 100,   0 }, { 101,   0 }, { 102,   0 }, { 103,   0 },
 { 104,   0 }, { 105,   0 }, { 106,   0 }, { 107,   0 }, { 108,   0 },
 { 109,   0 }, { 110,   0 }, { 111,   0 }, { 112,   0 }, { 113,   0 },
 { 114,   0 }, { 115,   0 }, { 116,   0 }, { 117,   0 }, { 118,   0 },

 { 119,   0 }, { 120,   0 }, { 121,   0 }, { 122,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,   0 },
 { 129,   0 }, { 130,   0 }, { 131,   0 }, { 132,   0 }, { 133,   0 },
 { 134,   0 }, { 135,   0 }, { 136,   0 }, { 137,   0 }, { 138,   0 },
 { 139,   0 }, { 140,   0 }, { 141,   0 }, { 142,   0 }, { 143,   0 },
 { 144,   0 }, { 145,   0 }, { 146,   0 }, { 147,   0 }, { 148,   0 },
 { 149,   0 }, { 150,   0 }, { 151,   0 }, { 152,   0 }, { 153,   0 },
 { 154,   0 }, { 155,   0 }, { 156,   0 }, { 157,   0 }, { 158,   0 },
 { 159,   0 }, { 160,   0 }, { 161,   0 }, { 162,   0 }, { 163,   0 },
 { 164,   0 }, { 165,   0 }, { 166,   0 }, { 167,   0 }, { 168,   0 },

 { 169,   0 }, { 170,   0 }, { 171,   0 }, { 172,   0 }, { 173,   0 },
 { 174,   0 }, { 175,   0 }, { 176,   0 }, { 177,   0 }, { 178,   0 },
 { 179,   0 }, { 180,   0 }, { 181,   0 }, { 182,   0 }, { 183,   0 },
 { 184,   0 }, { 185,   0 }, { 186,   0 }, { 187,   0 }, { 188,   0 },
 { 189,   0 }, { 190,   0 }, { 191,   0 }, { 192,   0 }, { 193,   0 },
 { 194,   0 }, { 195,   0 }, { 196,   0 }, { 197,   0 }, { 198,   0 },
 { 199,   0 }, { 200,   0 }, { 201,   0 }, { 202,   0 }, { 203,   0 },
 { 204,   0 }, { 205,   0 }, { 206,   0 }, { 207,   0 }, { 208,   0 },
 { 209,   0 }, { 210,   0 }, { 211,   0 }, { 212,   0 }, { 213,   0 },
 { 214,   0 }, { 215,   0 }, { 216,   0 }, { 217,   0 }, { 218,   0 },

 { 219,   0 }, { 220,   0 }, { 221,   0 }, { 222,   0 }, { 223,   0 },
 { 224,   0 }, { 225,   0 }, { 226,   0 }, { 227,   0 }, { 228,   0 },
 { 229,   0 }, { 230,   0 }, { 231,   0 }, { 232,   0 }, { 233,   0 },
 { 234,   0 }, { 235,   0 }, { 236,   0 }, { 237,   0 }, { 238,   0 },
 { 239,   0 }, { 240,   0 }, { 241,   0 }, { 242,   0 }, { 243,   0 },
 { 244,   0 }, { 245,   0 }, { 246,   0 }, { 247,   0 }, { 248,   0 },
 { 249,   0 }, { 250,   0 }, { 251,   0 }, { 252,   0 }, { 253,   0 },
 { 254,   0 }, { 255,   0 }, {   0,  27 }, {   0,3308 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,  27 }, {   0,3285 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  48,2295 }, {  49,2295 }, {  50,2295 }, {  51,2295 },
 {  52,2295 }, {  53,2295 }, {  54,2295 }, {  55,2295 }, {  56,2295 },
 {  57,2295 }, {   0,   0 }, {   0,   0 }, {   0,  64 }, {   0,3247 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,2295 }, {  66,2295 },
 {  67,2295 }, {  68,2295 }, {  69,2295 }, {  70,2295 }, {  48,2295 },
 {  49,2295 }, {  50,2295 }, {  51,2295 }, {  52,2295 }, {  53,2295 },
 {  54,2295 }, {  55,2295 }, {  56,2295 }, {  57,2295 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  65,2295 }, {  66,2295 }, {  67,2295 }, {  68,2295 },
 {  69,2295 }, {  70,2295 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  97,2295 }, {  98,2295 }, {  99,2295 }, { 100,2295 }, { 101,2295 },
 { 102,2295 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  48,   0 }, {  49,   0 }, {  50,   0 },

 {  51,   0 }, {  52,   0 }, {  53,   0 }, {  54,   0 }, {  55,   0 },
 {  56,   0 }, {  57,   0 }, {   0,   0 }, {  97,2295 }, {  98,2295 },
 {  99,2295 }, { 100,2295 }, { 101,2295 }, { 102,2295 }, {  65,-14916 },
 {  66,-14916 }, {  67,-14916 }, {  68,-14916 }, {  69,-3300 }, {  70,-14916 },
 {  71,-14916 }, {  72,-14916 }, {  73,-14916 }, {  74,-14916 }, {  75,-14916 },
 {  76,-14916 }, {  77,-14916 }, {  78,-14916 }, {  79,-14916 }, {  80,-14916 },
 {  81,-14916 }, {  82,-14916 }, {  83,-14916 }, {  84,-14916 }, {  85,-14916 },
 {  86,-14916 }, {  87,-14916 }, {  88,-14916 }, {  89,-14916 }, {  90,-14916 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  95, 257 },
 {   0,   0 }, {  97,-14916 }, {  98,-14916 }, {  99,-14916 }, { 100,-14916 },

 { 101,-3300 }, { 102,-14916 }, { 103,-14916 }, { 104,-14916 }, { 105,-14916 },
 { 106,-14916 }, { 107,-14916 }, { 108,-14916 }, { 109,-14916 }, { 110,-14916 },
 { 111,-14916 }, { 112,-14916 }, { 113,-14916 }, { 114,-14916 }, { 115,-14916 },
 { 116,-14916 }, { 117,-14916 }, { 118,-14916 }, { 119,-14916 }, { 120,-14916 },
 { 121,-14916 }, { 122,-14916 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, { 128,-14916 }, { 129,-14916 }, { 130,-14916 },
 { 131,-14916 }, { 132,-14916 }, { 133,-14916 }, { 134,-14916 }, { 135,-14916 },
 { 136,-14916 }, { 137,-14916 }, { 138,-14916 }, { 139,-14916 }, { 140,-14916 },
 { 141,-14916 }, { 142,-14916 }, { 143,-14916 }, { 144,-14916 }, { 145,-14916 },
 { 146,-14916 }, { 147,-14916 }, { 148,-14916 }, { 149,-14916 }, { 150,-14916 },

 { 151,-14916 }, { 152,-14916 }, { 153,-14916 }, { 154,-14916 }, { 155,-14916 },
 { 156,-14916 }, { 157,-14916 }, { 158,-14916 }, { 159,-14916 }, { 160,-14916 },
 { 161,-14916 }, { 162,-14916 }, { 163,-14916 }, { 164,-14916 }, { 165,-14916 },
 { 166,-14916 }, { 167,-14916 }, { 168,-14916 }, { 169,-14916 }, { 170,-14916 },
 { 171,-14916 }, { 172,-14916 }, { 173,-14916 }, { 174,-14916 }, { 175,-14916 },
 { 176,-14916 }, { 177,-14916 }, { 178,-14916 }, { 179,-14916 }, { 180,-14916 },
 { 181,-14916 }, { 182,-14916 }, { 183,-14916 }, { 184,-14916 }, { 185,-14916 },
 { 186,-14916 }, { 187,-14916 }, { 188,-14916 }, { 189,-14916 }, { 190,-14916 },
 { 191,-14916 }, { 192,-14916 }, { 193,-14916 }, { 194,-14916 }, { 195,-14916 },
 { 196,-14916 }, { 197,-14916 }, { 198,-14916 }, { 199,-14916 }, { 200,-14916 },

 { 201,-14916 }, { 202,-14916 }, { 203,-14916 }, { 204,-14916 }, { 205,-14916 },
 { 206,-14916 }, { 207,-14916 }, { 208,-14916 }, { 209,-14916 }, { 210,-14916 },
 { 211,-14916 }, { 212,-14916 }, { 213,-14916 }, { 214,-14916 }, { 215,-14916 },
 { 216,-14916 }, { 217,-14916 }, { 218,-14916 }, { 219,-14916 }, { 220,-14916 },
 { 221,-14916 }, { 222,-14916 }, { 223,-14916 }, { 224,-14916 }, { 225,-14916 },
 { 226,-14916 }, { 227,-14916 }, { 228,-14916 }, { 229,-14916 }, { 230,-14916 },
 { 231,-14916 }, { 232,-14916 }, { 233,-14916 }, { 234,-14916 }, { 235,-14916 },
 { 236,-14916 }, { 237,-14916 }, { 238,-14916 }, { 239,-14916 }, { 240,-14916 },
 { 241,-14916 }, { 242,-14916 }, { 243,-14916 }, { 244,-14916 }, { 245,-14916 },
 { 246,-14916 }, { 247,-14916 }, { 248,-14916 }, { 249,-14916 }, { 250,-14916 },

 { 251,-14916 }, { 252,-14916 }, { 253,-14916 }, { 254,-14916 }, { 255,-14916 },
 {   0,  72 }, {   0,2990 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,  66 }, {   0,2980 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,-257 },
 {  49,-257 }, {  50,-257 }, {  51,-257 }, {  52,-257 }, {  53,-257 },
 {  54,-257 }, {  55,-257 }, {  56,-257 }, {  57,-257 }, {  48,   0 },
 {  49,   0 }, {  50,   0 }, {  51,   0 }, {  52,   0 }, {  53,   0 },
 {  54,   0 }, {  55,   0 }, {  56,   0 }, {  57,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  65,-14897 }, {  66,-14897 }, {  67,-14897 }, {  68,-14897 },
 {  69,-14897 }, {  70,-14897 }, {  71,-14897 }, {  72,-14897 }, {  73,-14897 },
 {  74,-14897 }, {  75,-14897 }, {  76,-14897 }, {  77,-14897 }, {  78,-14897 },
 {  79,-14897 }, {  80,-14897 }, {  81,-14897 }, {  82,-14897 }, {  83,-14897 },

 {  84,-14897 }, {  85,-14897 }, {  86,-14897 }, {  87,-14897 }, {  88,-14897 },
 {  89,-14897 }, {  90,-14897 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  95, 257 }, {   0,   0 }, {  97,-14897 }, {  98,-14897 },
 {  99,-14897 }, { 100,-14897 }, { 101,-14897 }, { 102,-14897 }, { 103,-14897 },
 { 104,-14897 }, { 105,-14897 }, { 106,-14897 }, { 107,-14897 }, { 108,-14897 },
 { 109,-14897 }, { 110,-14897 }, { 111,-14897 }, { 112,-14897 }, { 113,-14897 },
 { 114,-14897 }, { 115,-14897 }, { 116,-14897 }, { 117,-14897 }, { 118,-14897 },
 { 119,-14897 }, { 120,-14897 }, { 121,-14897 }, { 122,-14897 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,-14897 },
 { 129,-14897 }, { 130,-14897 }, { 131,-14897 }, { 132,-14897 }, { 133,-14897 },

 { 134,-14897 }, { 135,-14897 }, { 136,-14897 }, { 137,-14897 }, { 138,-14897 },
 { 139,-14897 }, { 140,-14897 }, { 141,-14897 }, { 142,-14897 }, { 143,-14897 },
 { 144,-14897 }, { 145,-14897 }, { 146,-14897 }, { 147,-14897 }, { 148,-14897 },
 { 149,-14897 }, { 150,-14897 }, { 151,-14897 }, { 152,-14897 }, { 153,-14897 },
 { 154,-14897 }, { 155,-14897 }, { 156,-14897 }, { 157,-14897 }, { 158,-14897 },
 { 159,-14897 }, { 160,-14897 }, { 161,-14897 }, { 162,-14897 }, { 163,-14897 },
 { 164,-14897 }, { 165,-14897 }, { 166,-14897 }, { 167,-14897 }, { 168,-14897 },
 { 169,-14897 }, { 170,-14897 }, { 171,-14897 }, { 172,-14897 }, { 173,-14897 },
 { 174,-14897 }, { 175,-14897 }, { 176,-14897 }, { 177,-14897 }, { 178,-14897 },
 { 179,-14897 }, { 180,-14897 }, { 181,-14897 }, { 182,-14897 }, { 183,-14897 },

 { 184,-14897 }, { 185,-14897 }, { 186,-14897 }, { 187,-14897 }, { 188,-14897 },
 { 189,-14897 }, { 190,-14897 }, { 191,-14897 }, { 192,-14897 }, { 193,-14897 },
 { 194,-14897 }, { 195,-14897 }, { 196,-14897 }, { 197,-14897 }, { 198,-14897 },
 { 199,-14897 }, { 200,-14897 }, { 201,-14897 }, { 202,-14897 }, { 203,-14897 },
 { 204,-14897 }, { 205,-14897 }, { 206,-14897 }, { 207,-14897 }, { 208,-14897 },
 { 209,-14897 }, { 210,-14897 }, { 211,-14897 }, { 212,-14897 }, { 213,-14897 },
 { 214,-14897 }, { 215,-14897 }, { 216,-14897 }, { 217,-14897 }, { 218,-14897 },
 { 219,-14897 }, { 220,-14897 }, { 221,-14897 }, { 222,-14897 }, { 223,-14897 },
 { 224,-14897 }, { 225,-14897 }, { 226,-14897 }, { 227,-14897 }, { 228,-14897 },
 { 229,-14897 }, { 230,-14897 }, { 231,-14897 }, { 232,-14897 }, { 233,-14897 },

 { 234,-14897 }, { 235,-14897 }, { 236,-14897 }, { 237,-14897 }, { 238,-14897 },
 { 239,-14897 }, { 240,-14897 }, { 241,-14897 }, { 242,-14897 }, { 243,-14897 },
 { 244,-14897 }, { 245,-14897 }, { 246,-14897 }, { 247,-14897 }, { 248,-14897 },
 { 249,-14897 }, { 250,-14897 }, { 251,-14897 }, { 252,-14897 }, { 253,-14897 },
 { 254,-14897 }, { 255,-14897 }, {   0,  73 }, {   0,2723 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,  70 }, {   0,2713 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,  58 }, {   0,2705 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  48,-257 }, {  49,-257 }, {  50,-257 }, {  51,-257 },
 {  52,-257 }, {  53,-257 }, {  54,-257 }, {  55,-257 }, {  56,-257 },
 {  57,-257 }, {  48,-2962 }, {  49,-2962 }, {  50,-2962 }, {  51,-2962 },
 {  52,-2962 }, {  53,-2962 }, {  54,-2962 }, {  55,-2962 }, {  48,-2713 },
 {  49,-2713 }, {  50,-2713 }, {  51,-2713 }, {  52,-2713 }, {  53,-2713 },
 {  54,-2713 }, {  55,-2713 }, {  56,-2713 }, {  57,-2713 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  65,   0 }, {  66,   0 }, {  67,   0 }, {  68,   0 },
 {  69,   0 }, {  70,   0 }, {  71,-15168 }, {  72,-15168 }, {  73,-15168 },
 {  74,-15168 }, {  75,-15168 }, {  76,-15168 }, {  77,-15168 }, {  78,-15168 },
 {  79,-15168 }, {  80,-15168 }, {  81,-15168 }, {  82,-15168 }, {  83,-15168 },
 {  84,-15168 }, {  85,-15168 }, {  86,-15168 }, {  87,-15168 }, {  88,-15168 },
 {  89,-15168 }, {  90,-15168 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  95, 257 }, {   0,   0 }, {  97,   0 }, {  98,   0 },
 {  99,   0 }, { 100,   0 }, { 101,   0 }, { 102,   0 }, { 103,-15168 },
 { 104,-15168 }, { 105,-15168 }, { 106,-15168 }, { 107,-15168 }, { 108,-15168 },

 { 109,-15168 }, { 110,-15168 }, { 111,-15168 }, { 112,-15168 }, { 113,-15168 },
 { 114,-15168 }, { 115,-15168 }, { 116,-15168 }, { 117,-15168 }, { 118,-15168 },
 { 119,-15168 }, { 120,-15168 }, { 121,-15168 }, { 122,-15168 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,-15168 },
 { 129,-15168 }, { 130,-15168 }, { 131,-15168 }, { 132,-15168 }, { 133,-15168 },
 { 134,-15168 }, { 135,-15168 }, { 136,-15168 }, { 137,-15168 }, { 138,-15168 },
 { 139,-15168 }, { 140,-15168 }, { 141,-15168 }, { 142,-15168 }, { 143,-15168 },
 { 144,-15168 }, { 145,-15168 }, { 146,-15168 }, { 147,-15168 }, { 148,-15168 },
 { 149,-15168 }, { 150,-15168 }, { 151,-15168 }, { 152,-15168 }, { 153,-15168 },
 { 154,-15168 }, { 155,-15168 }, { 156,-15168 }, { 157,-15168 }, { 158,-15168 },

 { 159,-15168 }, { 160,-15168 }, { 161,-15168 }, { 162,-15168 }, { 163,-15168 },
 { 164,-15168 }, { 165,-15168 }, { 166,-15168 }, { 167,-15168 }, { 168,-15168 },
 { 169,-15168 }, { 170,-15168 }, { 171,-15168 }, { 172,-15168 }, { 173,-15168 },
 { 174,-15168 }, { 175,-15168 }, { 176,-15168 }, { 177,-15168 }, { 178,-15168 },
 { 179,-15168 }, { 180,-15168 }, { 181,-15168 }, { 182,-15168 }, { 183,-15168 },
 { 184,-15168 }, { 185,-15168 }, { 186,-15168 }, { 187,-15168 }, { 188,-15168 },
 { 189,-15168 }, { 190,-15168 }, { 191,-15168 }, { 192,-15168 }, { 193,-15168 },
 { 194,-15168 }, { 195,-15168 }, { 196,-15168 }, { 197,-15168 }, { 198,-15168 },
 { 199,-15168 }, { 200,-15168 }, { 201,-15168 }, { 202,-15168 }, { 203,-15168 },
 { 204,-15168 }, { 205,-15168 }, { 206,-15168 }, { 207,-15168 }, { 208,-15168 },

 { 209,-15168 }, { 210,-15168 }, { 211,-15168 }, { 212,-15168 }, { 213,-15168 },
 { 214,-15168 }, { 215,-15168 }, { 216,-15168 }, { 217,-15168 }, { 218,-15168 },
 { 219,-15168 }, { 220,-15168 }, { 221,-15168 }, { 222,-15168 }, { 223,-15168 },
 { 224,-15168 }, { 225,-15168 }, { 226,-15168 }, { 227,-15168 }, { 228,-15168 },
 { 229,-15168 }, { 230,-15168 }, { 231,-15168 }, { 232,-15168 }, { 233,-15168 },
 { 234,-15168 }, { 235,-15168 }, { 236,-15168 }, { 237,-15168 }, { 238,-15168 },
 { 239,-15168 }, { 240,-15168 }, { 241,-15168 }, { 242,-15168 }, { 243,-15168 },
 { 244,-15168 }, { 245,-15168 }, { 246,-15168 }, { 247,-15168 }, { 248,-15168 },
 { 249,-15168 }, { 250,-15168 }, { 251,-15168 }, { 252,-15168 }, { 253,-15168 },
 { 254,-15168 }, { 255,-15168 }, {   0,  69 }, {   0,2448 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,  64 }, {   0,2410 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  48,-2970 }, {  49,-2970 }, {  50,-2970 }, {  51,-2970 },

 {  52,-2970 }, {  53,-2970 }, {  54,-2970 }, {  55,-2970 }, {  56,-2970 },
 {  57,-2970 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,-2970 }, {  66,-2970 },
 {  67,-2970 }, {  68,-2970 }, {  69,-2970 }, {  70,-2970 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,-4036 },
 {  49,-4036 }, {  50,-4036 }, {  51,-4036 }, {  52,-4036 }, {  53,-4036 },
 {  54,-4036 }, {  55,-4036 }, {  56,-4036 }, {  57,-4036 }, {   0,   0 },
 {  97,-2970 }, {  98,-2970 }, {  99,-2970 }, { 100,-2970 }, { 101,-2970 },

 { 102,-2970 }, {  65,-15753 }, {  66,-15753 }, {  67,-15753 }, {  68,-15753 },
 {  69,-4137 }, {  70,-15753 }, {  71,-15753 }, {  72,-15753 }, {  73,-15753 },
 {  74,-15753 }, {  75,-15753 }, {  76,-15753 }, {  77,-15753 }, {  78,-15753 },
 {  79,-15753 }, {  80,-15753 }, {  81,-15753 }, {  82,-15753 }, {  83,-15753 },
 {  84,-15753 }, {  85,-15753 }, {  86,-15753 }, {  87,-15753 }, {  88,-15753 },
 {  89,-15753 }, {  90,-15753 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  95,-15753 }, {   0,   0 }, {  97,-15753 }, {  98,-15753 },
 {  99,-15753 }, { 100,-15753 }, { 101,-4137 }, { 102,-15753 }, { 103,-15753 },
 { 104,-15753 }, { 105,-15753 }, { 106,-15753 }, { 107,-15753 }, { 108,-15753 },
 { 109,-15753 }, { 110,-15753 }, { 111,-15753 }, { 112,-15753 }, { 113,-15753 },

 { 114,-15753 }, { 115,-15753 }, { 116,-15753 }, { 117,-15753 }, { 118,-15753 },
 { 119,-15753 }, { 120,-15753 }, { 121,-15753 }, { 122,-15753 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, { 128,-15753 },
 { 129,-15753 }, { 130,-15753 }, { 131,-15753 }, { 132,-15753 }, { 133,-15753 },
 { 134,-15753 }, { 135,-15753 }, { 136,-15753 }, { 137,-15753 }, { 138,-15753 },
 { 139,-15753 }, { 140,-15753 }, { 141,-15753 }, { 142,-15753 }, { 143,-15753 },
 { 144,-15753 }, { 145,-15753 }, { 146,-15753 }, { 147,-15753 }, { 148,-15753 },
 { 149,-15753 }, { 150,-15753 }, { 151,-15753 }, { 152,-15753 }, { 153,-15753 },
 { 154,-15753 }, { 155,-15753 }, { 156,-15753 }, { 157,-15753 }, { 158,-15753 },
 { 159,-15753 }, { 160,-15753 }, { 161,-15753 }, { 162,-15753 }, { 163,-15753 },

 { 164,-15753 }, { 165,-15753 }, { 166,-15753 }, { 167,-15753 }, { 168,-15753 },
 { 169,-15753 }, { 170,-15753 }, { 171,-15753 }, { 172,-15753 }, { 173,-15753 },
 { 174,-15753 }, { 175,-15753 }, { 176,-15753 }, { 177,-15753 }, { 178,-15753 },
 { 179,-15753 }, { 180,-15753 }, { 181,-15753 }, { 182,-15753 }, { 183,-15753 },
 { 184,-15753 }, { 185,-15753 }, { 186,-15753 }, { 187,-15753 }, { 188,-15753 },
 { 189,-15753 }, { 190,-15753 }, { 191,-15753 }, { 192,-15753 }, { 193,-15753 },
 { 194,-15753 }, { 195,-15753 }, { 196,-15753 }, { 197,-15753 }, { 198,-15753 },
 { 199,-15753 }, { 200,-15753 }, { 201,-15753 }, { 202,-15753 }, { 203,-15753 },
 { 204,-15753 }, { 205,-15753 }, { 206,-15753 }, { 207,-15753 }, { 208,-15753 },
 { 209,-15753 }, { 210,-15753 }, { 211,-15753 }, { 212,-15753 }, { 213,-15753 },

 { 214,-15753 }, { 215,-15753 }, { 216,-15753 }, { 217,-15753 }, { 218,-15753 },
 { 219,-15753 }, { 220,-15753 }, { 221,-15753 }, { 222,-15753 }, { 223,-15753 },
 { 224,-15753 }, { 225,-15753 }, { 226,-15753 }, { 227,-15753 }, { 228,-15753 },
 { 229,-15753 }, { 230,-15753 }, { 231,-15753 }, { 232,-15753 }, { 233,-15753 },
 { 234,-15753 }, { 235,-15753 }, { 236,-15753 }, { 237,-15753 }, { 238,-15753 },
 { 239,-15753 }, { 240,-15753 }, { 241,-15753 }, { 242,-15753 }, { 243,-15753 },
 { 244,-15753 }, { 245,-15753 }, { 246,-15753 }, { 247,-15753 }, { 248,-15753 },
 { 249,-15753 }, { 250,-15753 }, { 251,-15753 }, { 252,-15753 }, { 253,-15753 },
 { 254,-15753 }, { 255,-15753 }, {   0,  18 }, {   0,2153 }, {   1,   0 },
 {   2,   0 }, {   3,   0 }, {   4,   0 }, {   5,   0 }, {   6,   0 },

 {   7,   0 }, {   8,   0 }, {   9, 258 }, {  10, 516 }, {  11, 258 },
 {  12, 258 }, {  13, 516 }, {  14,   0 }, {  15,   0 }, {  16,   0 },
 {  17,   0 }, {  18,   0 }, {  19,   0 }, {  20,   0 }, {  21,   0 },
 {  22,   0 }, {  23,   0 }, {  24,   0 }, {  25,   0 }, {  26,   0 },
 {  27,   0 }, {  28,   0 }, {  29,   0 }, {  30,   0 }, {  31,   0 },
 {  32, 258 }, {  33,   0 }, {  34,   0 }, {  35,   0 }, {  36,   0 },
 {  37,   0 }, {  38,   0 }, {  39,   0 }, {  40,   0 }, {  41,   0 },
 {  42,   0 }, {  43,   0 }, {  44,   0 }, {  45, 563 }, {  46,   0 },
 {  47,   0 }, {  48,   0 }, {  49,   0 }, {  50,   0 }, {  51,   0 },
 {  52,   0 }, {  53,   0 }, {  54,   0 }, {  55,   0 }, {  56,   0 },

 {  57,   0 }, {  58,   0 }, {  59,   0 }, {  60,   0 }, {  61,   0 },
 {  62,   0 }, {  63,   0 }, {  64,   0 }, {  65,   0 }, {  66,   0 },
 {  67,   0 }, {  68,   0 }, {  69,   0 }, {  70,   0 }, {  71,   0 },
 {  72,   0 }, {  73,   0 }, {  74,   0 }, {  75,   0 }, {  76,   0 },
 {  77,   0 }, {  78,   0 }, {  79,   0 }, {  80,   0 }, {  81,   0 },
 {  82,   0 }, {  83,   0 }, {  84,   0 }, {  85,   0 }, {  86,   0 },
 {  87,   0 }, {  88,   0 }, {  89,   0 }, {  90,   0 }, {  91,   0 },
 {  92,   0 }, {  93,   0 }, {  94,   0 }, {  95,   0 }, {  96,   0 },
 {  97,   0 }, {  98,   0 }, {  99,   0 }, { 100,   0 }, { 101,   0 },
 { 102,   0 }, { 103,   0 }, { 104,   0 }, { 105,   0 }, { 106,   0 },

 { 107,   0 }, { 108,   0 }, { 109,   0 }, { 110,   0 }, { 111,   0 },
 { 112,   0 }, { 113,   0 }, { 114,   0 }, { 115,   0 }, { 116,   0 },
 { 117,   0 }, { 118,   0 }, { 119,   0 }, { 120,   0 }, { 121,   0 },
 { 122,   0 }, { 123,   0 }, { 124,   0 }, { 125,   0 }, { 126,   0 },
 { 127,   0 }, { 128,   0 }, { 129,   0 }, { 130,   0 }, { 131,   0 },
 { 132,   0 }, { 133,   0 }, { 134,   0 }, { 135,   0 }, { 136,   0 },
 { 137,   0 }, { 138,   0 }, { 139,   0 }, { 140,   0 }, { 141,   0 },
 { 142,   0 }, { 143,   0 }, { 144,   0 }, { 145,   0 }, { 146,   0 },
 { 147,   0 }, { 148,   0 }, { 149,   0 }, { 150,   0 }, { 151,   0 },
 { 152,   0 }, { 153,   0 }, { 154,   0 }, { 155,   0 }, { 156,   0 },

 { 157,   0 }, { 158,   0 }, { 159,   0 }, { 160,   0 }, { 161,   0 },
 { 162,   0 }, { 163,   0 }, { 164,   0 }, { 165,   0 }, { 166,   0 },
 { 167,   0 }, { 168,   0 }, { 169,   0 }, { 170,   0 }, { 171,   0 },
 { 172,   0 }, { 173,   0 }, { 174,   0 }, { 175,   0 }, { 176,   0 },
 { 177,   0 }, { 178,   0 }, { 179,   0 }, { 180,   0 }, { 181,   0 },
 { 182,   0 }, { 183,   0 }, { 184,   0 }, { 185,   0 }, { 186,   0 },
 { 187,   0 }, { 188,   0 }, { 189,   0 }, { 190,   0 }, { 191,   0 },
 { 192,   0 }, { 193,   0 }, { 194,   0 }, { 195,   0 }, { 196,   0 },
 { 197,   0 }, { 198,   0 }, { 199,   0 }, { 200,   0 }, { 201,   0 },
 { 202,   0 }, { 203,   0 }, { 204,   0 }, { 205,   0 }, { 206,   0 },

 { 207,   0 }, { 208,   0 }, { 209,   0 }, { 210,   0 }, { 211,   0 },
 { 212,   0 }, { 213,   0 }, { 214,   0 }, { 215,   0 }, { 216,   0 },
 { 217,   0 }, { 218,   0 }, { 219,   0 }, { 220,   0 }, { 221,   0 },
 { 222,   0 }, { 223,   0 }, { 224,   0 }, { 225,   0 }, { 226,   0 },
 { 227,   0 }, { 228,   0 }, { 229,   0 }, { 230,   0 }, { 231,   0 },
 { 232,   0 }, { 233,   0 }, { 234,   0 }, { 235,   0 }, { 236,   0 },
 { 237,   0 }, { 238,   0 }, { 239,   0 }, { 240,   0 }, { 241,   0 },
 { 242,   0 }, { 243,   0 }, { 244,   0 }, { 245,   0 }, { 246,   0 },
 { 247,   0 }, { 248,   0 }, { 249,   0 }, { 250,   0 }, { 251,   0 },
 { 252,   0 }, { 253,   0 }, { 254,   0 }, { 255,   0 }, { 256,   0 },

 {   0,  18 }, {   0,1895 }, {   1,-258 }, {   2,-258 }, {   3,-258 },
 {   4,-258 }, {   5,-258 }, {   6,-258 }, {   7,-258 }, {   8,-258 },
 {   9,   0 }, {  10, 258 }, {  11,   0 }, {  12,   0 }, {  13, 258 },
 {  14,-258 }, {  15,-258 }, {  16,-258 }, {  17,-258 }, {  18,-258 },
 {  19,-258 }, {  20,-258 }, {  21,-258 }, {  22,-258 }, {  23,-258 },
 {  24,-258 }, {  25,-258 }, {  26,-258 }, {  27,-258 }, {  28,-258 },
 {  29,-258 }, {  30,-258 }, {  31,-258 }, {  32,   0 }, {  33,-258 },
 {  34,-258 }, {  35,-258 }, {  36,-258 }, {  37,-258 }, {  38,-258 },
 {  39,-258 }, {  40,-258 }, {  41,-258 }, {  42,-258 }, {  43,-258 },
 {  44,-258 }, {  45, 305 }, {  46,-258 }, {  47,-258 }, {  48,-258 },

 {  49,-258 }, {  50,-258 }, {  51,-258 }, {  52,-258 }, {  53,-258 },
 {  54,-258 }, {  55,-258 }, {  56,-258 }, {  57,-258 }, {  58,-258 },
 {  59,-258 }, {  60,-258 }, {  61,-258 }, {  62,-258 }, {  63,-258 },
 {  64,-258 }, {  65,-258 }, {  66,-258 }, {  67,-258 }, {  68,-258 },
 {  69,-258 }, {  70,-258 }, {  71,-258 }, {  72,-258 }, {  73,-258 },
 {  74,-258 }, {  75,-258 }, {  76,-258 }, {  77,-258 }, {  78,-258 },
 {  79,-258 }, {  80,-258 }, {  81,-258 }, {  82,-258 }, {  83,-258 },
 {  84,-258 }, {  85,-258 }, {  86,-258 }, {  87,-258 }, {  88,-258 },
 {  89,-258 }, {  90,-258 }, {  91,-258 }, {  92,-258 }, {  93,-258 },
 {  94,-258 }, {  95,-258 }, {  96,-258 }, {  97,-258 }, {  98,-258 },

 {  99,-258 }, { 100,-258 }, { 101,-258 }, { 102,-258 }, { 103,-258 },
 { 104,-258 }, { 105,-258 }, { 106,-258 }, { 107,-258 }, { 108,-258 },
 { 109,-258 }, { 110,-258 }, { 111,-258 }, { 112,-258 }, { 113,-258 },
 { 114,-258 }, { 115,-258 }, { 116,-258 }, { 117,-258 }, { 118,-258 },
 { 119,-258 }, { 120,-258 }, { 121,-258 }, { 122,-258 }, { 123,-258 },
 { 124,-258 }, { 125,-258 }, { 126,-258 }, { 127,-258 }, { 128,-258 },
 { 129,-258 }, { 130,-258 }, { 131,-258 }, { 132,-258 }, { 133,-258 },
 { 134,-258 }, { 135,-258 }, { 136,-258 }, { 137,-258 }, { 138,-258 },
 { 139,-258 }, { 140,-258 }, { 141,-258 }, { 142,-258 }, { 143,-258 },
 { 144,-258 }, { 145,-258 }, { 146,-258 }, { 147,-258 }, { 148,-258 },

 { 149,-258 }, { 150,-258 }, { 151,-258 }, { 152,-258 }, { 153,-258 },
 { 154,-258 }, { 155,-258 }, { 156,-258 }, { 157,-258 }, { 158,-258 },
 { 159,-258 }, { 160,-258 }, { 161,-258 }, { 162,-258 }, { 163,-258 },
 { 164,-258 }, { 165,-258 }, { 166,-258 }, { 167,-258 }, { 168,-258 },
 { 169,-258 }, { 170,-258 }, { 171,-258 }, { 172,-258 }, { 173,-258 },
 { 174,-258 }, { 175,-258 }, { 176,-258 }, { 177,-258 }, { 178,-258 },
 { 179,-258 }, { 180,-258 }, { 181,-258 }, { 182,-258 }, { 183,-258 },
 { 184,-258 }, { 185,-258 }, { 186,-258 }, { 187,-258 }, { 188,-258 },
 { 189,-258 }, { 190,-258 }, { 191,-258 }, { 192,-258 }, { 193,-258 },
 { 194,-258 }, { 195,-258 }, { 196,-258 }, { 197,-258 }, { 198,-258 },

 { 199,-258 }, { 200,-258 }, { 201,-258 }, { 202,-258 }, { 203,-258 },
 { 204,-258 }, { 205,-258 }, { 206,-258 }, { 207,-258 }, { 208,-258 },
 { 209,-258 }, { 210,-258 }, { 211,-258 }, { 212,-258 }, { 213,-258 },
 { 214,-258 }, { 215,-258 }, { 216,-258 }, { 217,-258 }, { 218,-258 },
 { 219,-258 }, { 220,-258 }, { 221,-258 }, { 222,-258 }, { 223,-258 },
 { 224,-258 }, { 225,-258 }, { 226,-258 }, { 227,-258 }, { 228,-258 },
 { 229,-258 }, { 230,-258 }, { 231,-258 }, { 232,-258 }, { 233,-258 },
 { 234,-258 }, { 235,-258 }, { 236,-258 }, { 237,-258 }, { 238,-258 },
 { 239,-258 }, { 240,-258 }, { 241,-258 }, { 242,-258 }, { 243,-258 },
 { 244,-258 }, { 245,-258 }, { 246,-258 }, { 247,-258 }, { 248,-258 },

 { 249,-258 }, { 250,-258 }, { 251,-258 }, { 252,-258 }, { 253,-258 },
 { 254,-258 }, { 255,-258 }, { 256,-258 }, {   0,  18 }, {   0,1637 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   9,-7519 }, {  10,-7519 },
 {  11,-7519 }, {  12,-7519 }, {  13,-7519 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  32,-7519 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  39,-16573 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  45,-16538 },
 {   0,  18 }, {   0,1590 }, {   1,-563 }, {   2,-563 }, {   3,-563 },
 {   4,-563 }, {   5,-563 }, {   6,-563 }, {   7,-563 }, {   8,-563 },
 {   9,-305 }, {  10, -47 }, {  11,-305 }, {  12,-305 }, {  13, -47 },
 {  14,-563 }, {  15,-563 }, {  16,-563 }, {  17,-563 }, {  18,-563 },
 {  19,-563 }, {  20,-563 }, {  21,-563 }, {  22,-563 }, {  23,-563 },
 {  24,-563 }, {  25,-563 }, {  26,-563 }, {  27,-563 }, {  28,-563 },
 {  29,-563 }, {  30,-563 }, {  31,-563 }, {  32,-305 }, {  33,-563 },
 {  34,-563 }, {  35,-563 }, {  36,-563 }, {  37,-563 }, {  38,-563 },
 {  39,-563 }, {  40,-563 }, {  41,-563 }, {  42,-563 }, {  43,-563 },

 {  44,-563 }, {  45, 704 }, {  46,-563 }, {  47,-563 }, {  48,-563 },
 {  49,-563 }, {  50,-563 }, {  51,-563 }, {  52,-563 }, {  53,-563 },
 {  54,-563 }, {  55,-563 }, {  56,-563 }, {  57,-563 }, {  58,-563 },
 {  59,-563 }, {  60,-563 }, {  61,-563 }, {  62,-563 }, {  63,-563 },
 {  64,-563 }, {  65,-563 }, {  66,-563 }, {  67,-563 }, {  68,-563 },
 {  69,-563 }, {  70,-563 }, {  71,-563 }, {  72,-563 }, {  73,-563 },
 {  74,-563 }, {  75,-563 }, {  76,-563 }, {  77,-563 }, {  78,-563 },
 {  79,-563 }, {  80,-563 }, {  81,-563 }, {  82,-563 }, {  83,-563 },
 {  84,-563 }, {  85,-563 }, {  86,-563 }, {  87,-563 }, {  88,-563 },
 {  89,-563 }, {  90,-563 }, {  91,-563 }, {  92,-563 }, {  93,-563 },

 {  94,-563 }, {  95,-563 }, {  96,-563 }, {  97,-563 }, {  98,-563 },
 {  99,-563 }, { 100,-563 }, { 101,-563 }, { 102,-563 }, { 103,-563 },
 { 104,-563 }, { 105,-563 }, { 106,-563 }, { 107,-563 }, { 108,-563 },
 { 109,-563 }, { 110,-563 }, { 111,-563 }, { 112,-563 }, { 113,-563 },
 { 114,-563 }, { 115,-563 }, { 116,-563 }, { 117,-563 }, { 118,-563 },
 { 119,-563 }, { 120,-563 }, { 121,-563 }, { 122,-563 }, { 123,-563 },
 { 124,-563 }, { 125,-563 }, { 126,-563 }, { 127,-563 }, { 128,-563 },
 { 129,-563 }, { 130,-563 }, { 131,-563 }, { 132,-563 }, { 133,-563 },
 { 134,-563 }, { 135,-563 }, { 136,-563 }, { 137,-563 }, { 138,-563 },
 { 139,-563 }, { 140,-563 }, { 141,-563 }, { 142,-563 }, { 143,-563 },

 { 144,-563 }, { 145,-563 }, { 146,-563 }, { 147,-563 }, { 148,-563 },
 { 149,-563 }, { 150,-563 }, { 151,-563 }, { 152,-563 }, { 153,-563 },
 { 154,-563 }, { 155,-563 }, { 156,-563 }, { 157,-563 }, { 158,-563 },
 { 159,-563 }, { 160,-563 }, { 161,-563 }, { 162,-563 }, { 163,-563 },
 { 164,-563 }, { 165,-563 }, { 166,-563 }, { 167,-563 }, { 168,-563 },
 { 169,-563 }, { 170,-563 }, { 171,-563 }, { 172,-563 }, { 173,-563 },
 { 174,-563 }, { 175,-563 }, { 176,-563 }, { 177,-563 }, { 178,-563 },
 { 179,-563 }, { 180,-563 }, { 181,-563 }, { 182,-563 }, { 183,-563 },
 { 184,-563 }, { 185,-563 }, { 186,-563 }, { 187,-563 }, { 188,-563 },
 { 189,-563 }, { 190,-563 }, { 191,-563 }, { 192,-563 }, { 193,-563 },

 { 194,-563 }, { 195,-563 }, { 196,-563 }, { 197,-563 }, { 198,-563 },
 { 199,-563 }, { 200,-563 }, { 201,-563 }, { 202,-563 }, { 203,-563 },
 { 204,-563 }, { 205,-563 }, { 206,-563 }, { 207,-563 }, { 208,-563 },
 { 209,-563 }, { 210,-563 }, { 211,-563 }, { 212,-563 }, { 213,-563 },
 { 214,-563 }, { 215,-563 }, { 216,-563 }, { 217,-563 }, { 218,-563 },
 { 219,-563 }, { 220,-563 }, { 221,-563 }, { 222,-563 }, { 223,-563 },
 { 224,-563 }, { 225,-563 }, { 226,-563 }, { 227,-563 }, { 228,-563 },
 { 229,-563 }, { 230,-563 }, { 231,-563 }, { 232,-563 }, { 233,-563 },
 { 234,-563 }, { 235,-563 }, { 236,-563 }, { 237,-563 }, { 238,-563 },
 { 239,-563 }, { 240,-563 }, { 241,-563 }, { 242,-563 }, { 243,-563 },

 { 244,-563 }, { 245,-563 }, { 246,-563 }, { 247,-563 }, { 248,-563 },
 { 249,-563 }, { 250,-563 }, { 251,-563 }, { 252,-563 }, { 253,-563 },
 { 254,-563 }, { 255,-563 }, { 256,-563 }, {   0,  18 }, {   0,1332 },
 {   1,-3148 }, {   2,-3148 }, {   3,-3148 }, {   4,-3148 }, {   5,-3148 },
 {   6,-3148 }, {   7,-3148 }, {   8,-3148 }, {   9,-2890 }, {  10,-7848 },
 {  11,-2890 }, {  12,-2890 }, {  13,-7848 }, {  14,-3148 }, {  15,-3148 },
 {  16,-3148 }, {  17,-3148 }, {  18,-3148 }, {  19,-3148 }, {  20,-3148 },
 {  21,-3148 }, {  22,-3148 }, {  23,-3148 }, {  24,-3148 }, {  25,-3148 },
 {  26,-3148 }, {  27,-3148 }, {  28,-3148 }, {  29,-3148 }, {  30,-3148 },
 {  31,-3148 }, {  32,-2890 }, {  33,-3148 }, {  34,-3148 }, {  35,-3148 },

 {  36,-3148 }, {  37,-3148 }, {  38,-3148 }, {  39,-3148 }, {  40,-3148 },
 {  41,-3148 }, {  42,-3148 }, {  43,-3148 }, {  44,-3148 }, {  45,   0 },
 {  46,-3148 }, {  47,-3148 }, {  48,-3148 }, {  49,-3148 }, {  50,-3148 },
 {  51,-3148 }, {  52,-3148 }, {  53,-3148 }, {  54,-3148 }, {  55,-3148 },
 {  56,-3148 }, {  57,-3148 }, {  58,-3148 }, {  59,-3148 }, {  60,-3148 },
 {  61,-3148 }, {  62,-3148 }, {  63,-3148 }, {  64,-3148 }, {  65,-3148 },
 {  66,-3148 }, {  67,-3148 }, {  68,-3148 }, {  69,-3148 }, {  70,-3148 },
 {  71,-3148 }, {  72,-3148 }, {  73,-3148 }, {  74,-3148 }, {  75,-3148 },
 {  76,-3148 }, {  77,-3148 }, {  78,-3148 }, {  79,-3148 }, {  80,-3148 },
 {  81,-3148 }, {  82,-3148 }, {  83,-3148 }, {  84,-3148 }, {  85,-3148 },

 {  86,-3148 }, {  87,-3148 }, {  88,-3148 }, {  89,-3148 }, {  90,-3148 },
 {  91,-3148 }, {  92,-3148 }, {  93,-3148 }, {  94,-3148 }, {  95,-3148 },
 {  96,-3148 }, {  97,-3148 }, {  98,-3148 }, {  99,-3148 }, { 100,-3148 },
 { 101,-3148 }, { 102,-3148 }, { 103,-3148 }, { 104,-3148 }, { 105,-3148 },
 { 106,-3148 }, { 107,-3148 }, { 108,-3148 }, { 109,-3148 }, { 110,-3148 },
 { 111,-3148 }, { 112,-3148 }, { 113,-3148 }, { 114,-3148 }, { 115,-3148 },
 { 116,-3148 }, { 117,-3148 }, { 118,-3148 }, { 119,-3148 }, { 120,-3148 },
 { 121,-3148 }, { 122,-3148 }, { 123,-3148 }, { 124,-3148 }, { 125,-3148 },
 { 126,-3148 }, { 127,-3148 }, { 128,-3148 }, { 129,-3148 }, { 130,-3148 },
 { 131,-3148 }, { 132,-3148 }, { 133,-3148 }, { 134,-3148 }, { 135,-3148 },

 { 136,-3148 }, { 137,-3148 }, { 138,-3148 }, { 139,-3148 }, { 140,-3148 },
 { 141,-3148 }, { 142,-3148 }, { 143,-3148 }, { 144,-3148 }, { 145,-3148 },
 { 146,-3148 }, { 147,-3148 }, { 148,-3148 }, { 149,-3148 }, { 150,-3148 },
 { 151,-3148 }, { 152,-3148 }, { 153,-3148 }, { 154,-3148 }, { 155,-3148 },
 { 156,-3148 }, { 157,-3148 }, { 158,-3148 }, { 159,-3148 }, { 160,-3148 },
 { 161,-3148 }, { 162,-3148 }, { 163,-3148 }, { 164,-3148 }, { 165,-3148 },
 { 166,-3148 }, { 167,-3148 }, { 168,-3148 }, { 169,-3148 }, { 170,-3148 },
 { 171,-3148 }, { 172,-3148 }, { 173,-3148 }, { 174,-3148 }, { 175,-3148 },
 { 176,-3148 }, { 177,-3148 }, { 178,-3148 }, { 179,-3148 }, { 180,-3148 },
 { 181,-3148 }, { 182,-3148 }, { 183,-3148 }, { 184,-3148 }, { 185,-3148 },

 { 186,-3148 }, { 187,-3148 }, { 188,-3148 }, { 189,-3148 }, { 190,-3148 },
 { 191,-3148 }, { 192,-3148 }, { 193,-3148 }, { 194,-3148 }, { 195,-3148 },
 { 196,-3148 }, { 197,-3148 }, { 198,-3148 }, { 199,-3148 }, { 200,-3148 },
 { 201,-3148 }, { 202,-3148 }, { 203,-3148 }, { 204,-3148 }, { 205,-3148 },
 { 206,-3148 }, { 207,-3148 }, { 208,-3148 }, { 209,-3148 }, { 210,-3148 },
 { 211,-3148 }, { 212,-3148 }, { 213,-3148 }, { 214,-3148 }, { 215,-3148 },
 { 216,-3148 }, { 217,-3148 }, { 218,-3148 }, { 219,-3148 }, { 220,-3148 },
 { 221,-3148 }, { 222,-3148 }, { 223,-3148 }, { 224,-3148 }, { 225,-3148 },
 { 226,-3148 }, { 227,-3148 }, { 228,-3148 }, { 229,-3148 }, { 230,-3148 },
 { 231,-3148 }, { 232,-3148 }, { 233,-3148 }, { 234,-3148 }, { 235,-3148 },

 { 236,-3148 }, { 237,-3148 }, { 238,-3148 }, { 239,-3148 }, { 240,-3148 },
 { 241,-3148 }, { 242,-3148 }, { 243,-3148 }, { 244,-3148 }, { 245,-3148 },
 { 246,-3148 }, { 247,-3148 }, { 248,-3148 }, { 249,-3148 }, { 250,-3148 },
 { 251,-3148 }, { 252,-3148 }, { 253,-3148 }, { 254,-3148 }, { 255,-3148 },
 { 256,-3148 }, {   0,  27 }, {   0,1074 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,  27 },
 {   0,1051 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  48, 446 }, {  49, 446 }, {  50, 446 }, {  51, 446 }, {  52, 446 },
 {  53, 446 }, {  54, 446 }, {  55, 446 }, {  56, 446 }, {  57, 446 },
 {   0,   0 }, {   0,   0 }, {   0,  27 }, {   0,1013 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  65, 446 }, {  66, 446 }, {  67, 446 },
 {  68, 446 }, {  69, 446 }, {  70, 446 }, {  48, 446 }, {  49, 446 },
 {  50, 446 }, {  51, 446 }, {  52, 446 }, {  53, 446 }, {  54, 446 },

 {  55, 446 }, {  56, 446 }, {  57, 446 }, {   0,   0 }, {   0,   0 },
 {   0,  27 }, {   0, 990 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65, 446 }, {  66, 446 }, {  67, 446 }, {  68, 446 }, {  69, 446 },
 {  70, 446 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  97, 446 },
 {  98, 446 }, {  99, 446 }, { 100, 446 }, { 101, 446 }, { 102, 446 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  48, 446 }, {  49, 446 }, {  50, 446 }, {  51, 446 },
 {  52, 446 }, {  53, 446 }, {  54, 446 }, {  55, 446 }, {  56, 446 },
 {  57, 446 }, {   0,   0 }, {  97, 446 }, {  98, 446 }, {  99, 446 },
 { 100, 446 }, { 101, 446 }, { 102, 446 }, {  65, 446 }, {  66, 446 },

 {  67, 446 }, {  68, 446 }, {  69, 446 }, {  70, 446 }, {  48, 446 },
 {  49, 446 }, {  50, 446 }, {  51, 446 }, {  52, 446 }, {  53, 446 },
 {  54, 446 }, {  55, 446 }, {  56, 446 }, {  57, 446 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  65, 446 }, {  66, 446 }, {  67, 446 }, {  68, 446 },
 {  69, 446 }, {  70, 446 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  97, 446 }, {  98, 446 }, {  99, 446 }, { 100, 446 }, { 101, 446 },
 { 102, 446 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  97, 446 }, {  98, 446 },
 {  99, 446 }, { 100, 446 }, { 101, 446 }, { 102, 446 }, {   0,  18 },
 {   0, 886 }, {   1,-1267 }, {   2,-1267 }, {   3,-1267 }, {   4,-1267 },
 {   5,-1267 }, {   6,-1267 }, {   7,-1267 }, {   8,-1267 }, {   9,-1009 },
 {  10,-751 }, {  11,-1009 }, {  12,-1009 }, {  13,-751 }, {  14,-1267 },
 {  15,-1267 }, {  16,-1267 }, {  17,-1267 }, {  18,-1267 }, {  19,-1267 },
 {  20,-1267 }, {  21,-1267 }, {  22,-1267 }, {  23,-1267 }, {  24,-1267 },
 {  25,-1267 }, {  26,-1267 }, {  27,-1267 }, {  28,-1267 }, {  29,-1267 },
 {  30,-1267 }, {  31,-1267 }, {  32,-1009 }, {  33,-1267 }, {  34,-1267 },
 {  35,-1267 }, {  36,-1267 }, {  37,-1267 }, {  38,-1267 }, {  39,-1267 },

 {  40,-1267 }, {  41,-1267 }, {  42,-1267 }, {  43,-1267 }, {  44,-1267 },
 {  45,   0 }, {  46,-1267 }, {  47,-1267 }, {  48,-1267 }, {  49,-1267 },
 {  50,-1267 }, {  51,-1267 }, {  52,-1267 }, {  53,-1267 }, {  54,-1267 },
 {  55,-1267 }, {  56,-1267 }, {  57,-1267 }, {  58,-1267 }, {  59,-1267 },
 {  60,-1267 }, {  61,-1267 }, {  62,-1267 }, {  63,-1267 }, {  64,-1267 },
 {  65,-1267 }, {  66,-1267 }, {  67,-1267 }, {  68,-1267 }, {  69,-1267 },
 {  70,-1267 }, {  71,-1267 }, {  72,-1267 }, {  73,-1267 }, {  74,-1267 },
 {  75,-1267 }, {  76,-1267 }, {  77,-1267 }, {  78,-1267 }, {  79,-1267 },
 {  80,-1267 }, {  81,-1267 }, {  82,-1267 }, {  83,-1267 }, {  84,-1267 },
 {  85,-1267 }, {  86,-1267 }, {  87,-1267 }, {  88,-1267 }, {  89,-1267 },

 {  90,-1267 }, {  91,-1267 }, {  92,-1267 }, {  93,-1267 }, {  94,-1267 },
 {  95,-1267 }, {  96,-1267 }, {  97,-1267 }, {  98,-1267 }, {  99,-1267 },
 { 100,-1267 }, { 101,-1267 }, { 102,-1267 }, { 103,-1267 }, { 104,-1267 },
 { 105,-1267 }, { 106,-1267 }, { 107,-1267 }, { 108,-1267 }, { 109,-1267 },
 { 110,-1267 }, { 111,-1267 }, { 112,-1267 }, { 113,-1267 }, { 114,-1267 },
 { 115,-1267 }, { 116,-1267 }, { 117,-1267 }, { 118,-1267 }, { 119,-1267 },
 { 120,-1267 }, { 121,-1267 }, { 122,-1267 }, { 123,-1267 }, { 124,-1267 },
 { 125,-1267 }, { 126,-1267 }, { 127,-1267 }, { 128,-1267 }, { 129,-1267 },
 { 130,-1267 }, { 131,-1267 }, { 132,-1267 }, { 133,-1267 }, { 134,-1267 },
 { 135,-1267 }, { 136,-1267 }, { 137,-1267 }, { 138,-1267 }, { 139,-1267 },

 { 140,-1267 }, { 141,-1267 }, { 142,-1267 }, { 143,-1267 }, { 144,-1267 },
 { 145,-1267 }, { 146,-1267 }, { 147,-1267 }, { 148,-1267 }, { 149,-1267 },
 { 150,-1267 }, { 151,-1267 }, { 152,-1267 }, { 153,-1267 }, { 154,-1267 },
 { 155,-1267 }, { 156,-1267 }, { 157,-1267 }, { 158,-1267 }, { 159,-1267 },
 { 160,-1267 }, { 161,-1267 }, { 162,-1267 }, { 163,-1267 }, { 164,-1267 },
 { 165,-1267 }, { 166,-1267 }, { 167,-1267 }, { 168,-1267 }, { 169,-1267 },
 { 170,-1267 }, { 171,-1267 }, { 172,-1267 }, { 173,-1267 }, { 174,-1267 },
 { 175,-1267 }, { 176,-1267 }, { 177,-1267 }, { 178,-1267 }, { 179,-1267 },
 { 180,-1267 }, { 181,-1267 }, { 182,-1267 }, { 183,-1267 }, { 184,-1267 },
 { 185,-1267 }, { 186,-1267 }, { 187,-1267 }, { 188,-1267 }, { 189,-1267 },

 { 190,-1267 }, { 191,-1267 }, { 192,-1267 }, { 193,-1267 }, { 194,-1267 },
 { 195,-1267 }, { 196,-1267 }, { 197,-1267 }, { 198,-1267 }, { 199,-1267 },
 { 200,-1267 }, { 201,-1267 }, { 202,-1267 }, { 203,-1267 }, { 204,-1267 },
 { 205,-1267 }, { 206,-1267 }, { 207,-1267 }, { 208,-1267 }, { 209,-1267 },
 { 210,-1267 }, { 211,-1267 }, { 212,-1267 }, { 213,-1267 }, { 214,-1267 },
 { 215,-1267 }, { 216,-1267 }, { 217,-1267 }, { 218,-1267 }, { 219,-1267 },
 { 220,-1267 }, { 221,-1267 }, { 222,-1267 }, { 223,-1267 }, { 224,-1267 },
 { 225,-1267 }, { 226,-1267 }, { 227,-1267 }, { 228,-1267 }, { 229,-1267 },
 { 230,-1267 }, { 231,-1267 }, { 232,-1267 }, { 233,-1267 }, { 234,-1267 },
 { 235,-1267 }, { 236,-1267 }, { 237,-1267 }, { 238,-1267 }, { 239,-1267 },

 { 240,-1267 }, { 241,-1267 }, { 242,-1267 }, { 243,-1267 }, { 244,-1267 },
 { 245,-1267 }, { 246,-1267 }, { 247,-1267 }, { 248,-1267 }, { 249,-1267 },
 { 250,-1267 }, { 251,-1267 }, { 252,-1267 }, { 253,-1267 }, { 254,-1267 },
 { 255,-1267 }, { 256,-1267 }, {   0,  27 }, {   0, 628 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,  27 }, {   0, 605 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  48, 143 }, {  49, 143 }, {  50, 143 }, {  51, 143 },
 {  52, 143 }, {  53, 143 }, {  54, 143 }, {  55, 143 }, {  56, 143 },
 {  57, 143 }, {   0,   0 }, {   0,   0 }, {   0,  27 }, {   0, 567 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65, 143 }, {  66, 143 },
 {  67, 143 }, {  68, 143 }, {  69, 143 }, {  70, 143 }, {  48,-17262 },
 {  49,-17262 }, {  50,-17262 }, {  51,-17262 }, {  52,-17262 }, {  53,-17262 },
 {  54,-17262 }, {  55,-17262 }, {  56,-17262 }, {  57,-17262 }, {   0,   0 },

 {   0,   0 }, {   0,  27 }, {   0, 544 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  65,-17262 }, {  66,-17262 }, {  67,-17262 }, {  68,-17262 },
 {  69,-17262 }, {  70,-17262 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  97, 143 }, {  98, 143 }, {  99, 143 }, { 100, 143 }, { 101, 143 },
 { 102, 143 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  48, 105 }, {  49, 105 }, {  50, 105 },
 {  51, 105 }, {  52, 105 }, {  53, 105 }, {  54, 105 }, {  55, 105 },
 {  56, 105 }, {  57, 105 }, {   0,   0 }, {  97,-17262 }, {  98,-17262 },
 {  99,-17262 }, { 100,-17262 }, { 101,-17262 }, { 102,-17262 }, {  65, 105 },
 {  66, 105 }, {  67, 105 }, {  68, 105 }, {  69, 105 }, {  70, 105 },

 {  48,-17321 }, {  49,-17321 }, {  50,-17321 }, {  51,-17321 }, {  52,-17321 },
 {  53,-17321 }, {  54,-17321 }, {  55,-17321 }, {  56,-17321 }, {  57,-17321 },
 {   0,  27 }, {   0, 485 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  65,-17321 }, {  66,-17321 }, {  67,-17321 },
 {  68,-17321 }, {  69,-17321 }, {  70,-17321 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  97, 105 }, {  98, 105 }, {  99, 105 }, { 100, 105 },
 { 101, 105 }, { 102, 105 }, {   0,   0 }, {   0,  27 }, {   0, 462 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  97,-17321 },

 {  98,-17321 }, {  99,-17321 }, { 100,-17321 }, { 101,-17321 }, { 102,-17321 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,  61 },
 {  49,  61 }, {  50,  61 }, {  51,  61 }, {  52,  61 }, {  53,  61 },
 {  54,  61 }, {  55,  61 }, {  56,  61 }, {  57,  61 }, {   0,   0 },
 {   0,   0 }, {   0,  27 }, {   0, 424 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {  65,  61 }, {  66,  61 }, {  67,  61 }, {  68,  61 },
 {  69,  61 }, {  70,  61 }, {  48,  61 }, {  49,  61 }, {  50,  61 },
 {  51,  61 }, {  52,  61 }, {  53,  61 }, {  54,  61 }, {  55,  61 },
 {  56,  61 }, {  57,  61 }, {   0,   0 }, {   0,   0 }, {   0,  27 },
 {   0, 401 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,  61 },

 {  66,  61 }, {  67,  61 }, {  68,  61 }, {  69,  61 }, {  70,  61 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  97,  61 }, {  98,  61 },
 {  99,  61 }, { 100,  61 }, { 101,  61 }, { 102,  61 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  48,  82 }, {  49,  82 }, {  50,  82 }, {  51,  82 }, {  52,  82 },
 {  53,  82 }, {  54,  82 }, {  55,  82 }, {  56,  82 }, {  57,  82 },
 {   0,   0 }, {  97,  61 }, {  98,  61 }, {  99,  61 }, { 100,  61 },
 { 101,  61 }, { 102,  61 }, {  65,  82 }, {  66,  82 }, {  67,  82 },
 {  68,  82 }, {  69,  82 }, {  70,  82 }, {  48,  82 }, {  49,  82 },
 {  50,  82 }, {  51,  82 }, {  52,  82 }, {  53,  82 }, {  54,  82 },

 {  55,  82 }, {  56,  82 }, {  57,  82 }, {   0,  27 }, {   0, 342 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  65,  82 }, {  66,  82 }, {  67,  82 }, {  68,  82 }, {  69,  82 },
 {  70,  82 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  97,  82 },
 {  98,  82 }, {  99,  82 }, { 100,  82 }, { 101,  82 }, { 102,  82 },
 {   0,   0 }, {   0,  27 }, {   0, 319 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  97,  82 }, {  98,  82 }, {  99,  82 },
 { 100,  82 }, { 101,  82 }, { 102,  82 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {  48,  61 }, {  49,  61 }, {  50,  61 },
 {  51,  61 }, {  52,  61 }, {  53,  61 }, {  54,  61 }, {  55,  61 },
 {  56,  61 }, {  57,  61 }, {   0,   0 }, {   0,   0 }, {   0,  27 },
 {   0, 281 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,  61 },
 {  66,  61 }, {  67,  61 }, {  68,  61 }, {  69,  61 }, {  70,  61 },
 {  48,  61 }, {  49,  61 }, {  50,  61 }, {  51,  61 }, {  52,  61 },
 {  53,  61 }, {  54,  61 }, {  55,  61 }, {  56,  61 }, {  57,  61 },
 {   0,   0 }, {   0,   0 }, {   0,  27 }, {   0, 258 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  65,  61 }, {  66,  61 }, {  67,  61 },
 {  68,  61 }, {  69,  61 }, {  70,  61 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {  97,  61 }, {  98,  61 }, {  99,  61 }, { 100,  61 },
 { 101,  61 }, { 102,  61 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  48,-17586 }, {  49,-17586 },
 {  50,-17586 }, {  51,-17586 }, {  52,-17586 }, {  53,-17586 }, {  54,-17586 },
 {  55,-17586 }, {  56,-17586 }, {  57,-17586 }, {   0,   0 }, {  97,  61 },
 {  98,  61 }, {  99,  61 }, { 100,  61 }, { 101,  61 }, { 102,  61 },
 {  65,-17586 }, {  66,-17586 }, {  67,-17586 }, {  68,-17586 }, {  69,-17586 },
 {  70,-17586 }, {  48,-17607 }, {  49,-17607 }, {  50,-17607 }, {  51,-17607 },
 {  52,-17607 }, {  53,-17607 }, {  54,-17607 }, {  55,-17607 }, {  56,-17607 },
 {  57,-17607 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {  65,-17607 }, {  66,-17607 },
 {  67,-17607 }, {  68,-17607 }, {  69,-17607 }, {  70,-17607 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {  97,-17586 }, {  98,-17586 }, {  99,-17586 },
 { 100,-17586 }, { 101,-17586 }, { 102,-17586 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {  97,-17607 }, {  98,-17607 }, {  99,-17607 }, { 100,-17607 }, { 101,-17607 },
 { 102,-17607 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },

 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 }, {   0,   0 },
 { 257,  77 }, {   1,   0 },    };

static yyconst struct yy_trans_info *yy_start_state_list[25] =
    {
    &yy_transition[1],
    &yy_transition[3],
    &yy_transition[261],
    &yy_transition[519],
    &yy_transition[777],
    &yy_transition[1035],
    &yy_transition[1293],
    &yy_transition[1551],
    &yy_transition[1809],
    &yy_transition[2067],
    &yy_transition[2325],
    &yy_transition[2583],
    &yy_transition[2841],
    &yy_transition[3099],
    &yy_transition[3357],
    &yy_transition[3615],
    &yy_transition[3873],
    &yy_transition[4131],
    &yy_transition[4389],
    &yy_transition[4647],
    &yy_transition[4905],
    &yy_transition[5163],
    &yy_transition[5421],
    &yy_transition[5679],
    &yy_transition[5937],

    } ;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
#line 1 "scan.l"

#line 49 "scan.l"

/* LCOV_EXCL_START */

/* Avoid exit() on fatal scanner errors (a bit ugly -- see yy_fatal_error) */
#undef fprintf
#define fprintf(file, fmt, msg)  fprintf_to_ereport(fmt, msg)

static void
fprintf_to_ereport(const char *fmt, const char *msg)
{
	ereport(ERROR, (errmsg_internal("%s", msg)));
}

/*
 * GUC variables.  This is a DIRECT violation of the warning given at the
 * head of gram.y, ie flex/bison code must not depend on any GUC variables;
 * as such, changing their values can induce very unintuitive behavior.
 * But we shall have to live with it until we can remove these variables.
 */
int			backslash_quote = BACKSLASH_QUOTE_SAFE_ENCODING;
bool		escape_string_warning = true;
bool		standard_conforming_strings = true;

/*
 * Constant data exported from this file.  This array maps from the
 * zero-based keyword numbers returned by ScanKeywordLookup to the
 * Bison token numbers needed by gram.y.  This is exported because
 * callers need to pass it to scanner_init, if they are using the
 * standard keyword list ScanKeywords.
 */
#define PG_KEYWORD(kwname, value, category, collabel) value,

const uint16 ScanKeywordTokens[] = {
#include "parser/kwlist.h"
};

#undef PG_KEYWORD

/*
 * Set the type of YYSTYPE.
 */
#define YYSTYPE core_YYSTYPE

/*
 * Set the type of yyextra.  All state variables used by the scanner should
 * be in yyextra, *not* statically allocated.
 */
#define YY_EXTRA_TYPE core_yy_extra_type *

/*
 * Each call to core_yylex must set yylloc to the location of the found token
 * (expressed as a byte offset from the start of the input text).
 * When we parse a token that requires multiple lexer rules to process,
 * this should be done in the first such rule, else yylloc will point
 * into the middle of the token.
 */
#define SET_YYLLOC()  (*(yylloc) = yytext - yyextra->scanbuf)

/*
 * Advance yylloc by the given number of bytes.
 */
#define ADVANCE_YYLLOC(delta)  ( *(yylloc) += (delta) )

/*
 * Sometimes, we do want yylloc to point into the middle of a token; this is
 * useful for instance to throw an error about an escape sequence within a
 * string literal.  But if we find no error there, we want to revert yylloc
 * to the token start, so that that's the location reported to the parser.
 * Use PUSH_YYLLOC/POP_YYLLOC to save/restore yylloc around such code.
 * (Currently the implied "stack" is just one location, but someday we might
 * need to nest these.)
 */
#define PUSH_YYLLOC()	(yyextra->save_yylloc = *(yylloc))
#define POP_YYLLOC()	(*(yylloc) = yyextra->save_yylloc)

#define startlit()	( yyextra->literallen = 0 )
static void addlit(char *ytext, int yleng, core_yyscan_t yyscanner);
static void addlitchar(unsigned char ychar, core_yyscan_t yyscanner);
static char *litbufdup(core_yyscan_t yyscanner);
static unsigned char unescape_single_char(unsigned char c, core_yyscan_t yyscanner);
static int	process_integer_literal(const char *token, YYSTYPE *lval, int base);
static void addunicode(pg_wchar c, yyscan_t yyscanner);

#define yyerror(msg)  scanner_yyerror(msg, yyscanner)

#define lexer_errposition()  scanner_errposition(*(yylloc), yyscanner)

static void check_string_escape_warning(unsigned char ychar, core_yyscan_t yyscanner);
static void check_escape_warning(core_yyscan_t yyscanner);

/*
 * Work around a bug in flex 2.5.35: it emits a couple of functions that
 * it forgets to emit declarations for.  Since we use -Wmissing-prototypes,
 * this would cause warnings.  Providing our own declarations should be
 * harmless even when the bug gets fixed.
 */
extern int	core_yyget_column(yyscan_t yyscanner);
extern void core_yyset_column(int column_no, yyscan_t yyscanner);

#define YY_NO_INPUT 1
/*
 * OK, here is a short description of lex/flex rules behavior.
 * The longest pattern which matches an input string is always chosen.
 * For equal-length patterns, the first occurring in the rules list is chosen.
 * INITIAL is the starting state, to which all non-conditional rules apply.
 * Exclusive states change parsing rules while the state is active.  When in
 * an exclusive state, only those rules defined for that state apply.
 *
 * We use exclusive states for quoted strings, extended comments,
 * and to eliminate parsing troubles for numeric strings.
 * Exclusive states:
 *  <xb> bit string literal
 *  <xc> extended C-style comments
 *  <xd> delimited identifiers (double-quoted identifiers)
 *  <xh> hexadecimal byte string
 *  <xq> standard quoted strings
 *  <xqs> quote stop (detect continued strings)
 *  <xe> extended quoted strings (support backslash escape sequences)
 *  <xdolq> $foo$ quoted strings
 *  <xui> quoted identifier with Unicode escapes
 *  <xus> quoted string with Unicode escapes
 *  <xeu> Unicode surrogate pair in extended quoted string
 *
 * Remember to add an <<EOF>> case whenever you add a new exclusive state!
 * The default one is probably not the right thing.
 */











/*
 * In order to make the world safe for Windows and Mac clients as well as
 * Unix ones, we accept either \n or \r as a newline.  A DOS-style \r\n
 * sequence will be seen as two successive newlines, but that doesn't cause
 * any problems.  Comments that start with -- and extend to the next
 * newline are treated as equivalent to a single whitespace character.
 *
 * NOTE a fine point: if there is no newline following --, we will absorb
 * everything to the end of the input as a comment.  This is correct.  Older
 * versions of Postgres failed to recognize -- as a comment if the input
 * did not end with a newline.
 *
 * non_newline_space tracks all the other space characters except newlines.
 *
 * XXX if you change the set of whitespace characters, fix scanner_isspace()
 * to agree.
 */
/*
 * SQL requires at least one newline in the whitespace separating
 * string literals that are to be concatenated.  Silly, but who are we
 * to argue?  Note that {whitespace_with_newline} should not have * after
 * it, whereas {whitespace} should generally have a * after it...
 */
/* If we see {quote} then {quotecontinue}, the quoted string continues */
/*
 * {quotecontinuefail} is needed to avoid lexer backup when we fail to match
 * {quotecontinue}.  It might seem that this could just be {whitespace}*,
 * but if there's a dash after {whitespace_with_newline}, it must be consumed
 * to see if there's another dash --- which would start a {comment} and thus
 * allow continuation of the {quotecontinue} token.
 */
/* Bit string
 * It is tempting to scan the string for only those characters
 * which are allowed. However, this leads to silently swallowed
 * characters if illegal characters are included in the string.
 * For example, if xbinside is [01] then B'ABCD' is interpreted
 * as a zero-length string, and the ABCD' is lost!
 * Better to pass the string forward and let the input routines
 * validate the contents.
 */
/* Hexadecimal byte string */
/* National character */
/* Quoted string that allows backslash escapes */
/* Extended quote
 * xqdouble implements embedded quote, ''''
 */
/* $foo$ style quotes ("dollar quoting")
 * The quoted string starts with $foo$ where "foo" is an optional string
 * in the form of an identifier, except that it may not contain "$",
 * and extends to the first occurrence of an identical string.
 * There is *no* processing of the quoted text.
 *
 * {dolqfailed} is an error rule to avoid scanner backup when {dolqdelim}
 * fails to match its trailing "$".
 */
/* Double quote
 * Allows embedded spaces and other special characters into identifiers.
 */
/* Quoted identifier with Unicode escapes */
/* Quoted string with Unicode escapes */
/* error rule to avoid backup */
/* C-style comments
 *
 * The "extended comment" syntax closely resembles allowable operator syntax.
 * The tricky part here is to get lex to recognize a string starting with
 * slash-star as a comment, when interpreting it as an operator would produce
 * a longer match --- remember lex will prefer a longer match!  Also, if we
 * have something like plus-slash-star, lex will think this is a 3-character
 * operator whereas we want to see it as a + operator and a comment start.
 * The solution is two-fold:
 * 1. append {op_chars}* to xcstart so that it matches as much text as
 *    {operator} would. Then the tie-breaker (first matching rule of same
 *    length) ensures xcstart wins.  We put back the extra stuff with yyless()
 *    in case it contains a star-slash that should terminate the comment.
 * 2. In the operator rule, check for slash-star within the operator, and
 *    if found throw it back with yyless().  This handles the plus-slash-star
 *    problem.
 * Dash-dash comments have similar interactions with the operator rule.
 */
/* Assorted special-case operators and operator-like tokens */
/*
 * These operator-like tokens (unlike the above ones) also match the {operator}
 * rule, which means that they might be overridden by a longer match if they
 * are followed by a comment start or a + or - character. Accordingly, if you
 * add to this list, you must also add corresponding code to the {operator}
 * block to return the correct token in such cases. (This is not needed in
 * psqlscan.l since the token value is ignored there.)
 */
/*
 * "self" is the set of chars that should be returned as single-character
 * tokens.  "op_chars" is the set of chars that can make up "Op" tokens,
 * which can be one or more characters long (but if a single-char token
 * appears in the "self" set, it is not to be returned as an Op).  Note
 * that the sets overlap, but each has some chars that are not in the other.
 *
 * If you change either set, adjust the character lists appearing in the
 * rule for "operator"!
 */
/*
 * Numbers
 *
 * Unary minus is not part of a number here.  Instead we pass it separately to
 * the parser, and there it gets coerced via doNegate().
 *
 * {numericfail} is used because we would like "1..10" to lex as 1, dot_dot, 10.
 *
 * {realfail} is added to prevent the need for scanner
 * backup when the {real} rule fails to match completely.
 */
/*
 * Dollar quoted strings are totally opaque, and no escaping is done on them.
 * Other quoted strings must allow some special characters such as single-quote
 *  and newline.
 * Embedded single-quotes are implemented both in the SQL standard
 *  style of two adjacent single quotes "''" and in the Postgres/Java style
 *  of escaped-quote "\'".
 * Other embedded escaped characters are matched explicitly and the leading
 *  backslash is dropped from the string.
 * Note that xcstart must appear before operator, as explained above!
 *  Also whitespace (comment) must appear before operator.
 */
#line 6169 "scan.c"

#define INITIAL 0
#define xb 1
#define xc 2
#define xd 3
#define xh 4
#define xq 5
#define xqs 6
#define xe 7
#define xdolq 8
#define xui 9
#define xus 10
#define xeu 11

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

/* Holds the entire state of the reentrant scanner. */
struct yyguts_t
    {

    /* User-defined. Not touched by flex. */
    YY_EXTRA_TYPE yyextra_r;

    /* The rest are the same as the globals declared in the non-reentrant scanner. */
    FILE *yyin_r, *yyout_r;
    size_t yy_buffer_stack_top; /**< index of top of stack. */
    size_t yy_buffer_stack_max; /**< capacity of stack. */
    YY_BUFFER_STATE * yy_buffer_stack; /**< Stack as an array. */
    char yy_hold_char;
    int yy_n_chars;
    int yyleng_r;
    char *yy_c_buf_p;
    int yy_init;
    int yy_start;
    int yy_did_buffer_switch_on_eof;
    int yy_start_stack_ptr;
    int yy_start_stack_depth;
    int *yy_start_stack;
    yy_state_type yy_last_accepting_state;
    char* yy_last_accepting_cpos;

    int yylineno_r;
    int yy_flex_debug_r;

    char *yytext_r;
    int yy_more_flag;
    int yy_more_len;

    YYSTYPE * yylval_r;

    YYLTYPE * yylloc_r;

    }; /* end struct yyguts_t */

static int yy_init_globals (yyscan_t yyscanner );

    /* This must go here because YYSTYPE and YYLTYPE are included
     * from bison output in section 1.*/
    #    define yylval yyg->yylval_r
    
    #    define yylloc yyg->yylloc_r
    
int core_yylex_init (yyscan_t* scanner);

int core_yylex_init_extra (YY_EXTRA_TYPE user_defined,yyscan_t* scanner);

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int core_yylex_destroy (yyscan_t yyscanner );

int core_yyget_debug (yyscan_t yyscanner );

void core_yyset_debug (int debug_flag ,yyscan_t yyscanner );

YY_EXTRA_TYPE core_yyget_extra (yyscan_t yyscanner );

void core_yyset_extra (YY_EXTRA_TYPE user_defined ,yyscan_t yyscanner );

FILE *core_yyget_in (yyscan_t yyscanner );

void core_yyset_in  (FILE * _in_str ,yyscan_t yyscanner );

FILE *core_yyget_out (yyscan_t yyscanner );

void core_yyset_out  (FILE * _out_str ,yyscan_t yyscanner );

			int core_yyget_leng (yyscan_t yyscanner );

char *core_yyget_text (yyscan_t yyscanner );

int core_yyget_lineno (yyscan_t yyscanner );

void core_yyset_lineno (int _line_number ,yyscan_t yyscanner );

int core_yyget_column  (yyscan_t yyscanner );

void core_yyset_column (int _column_no ,yyscan_t yyscanner );

YYSTYPE * core_yyget_lval (yyscan_t yyscanner );

void core_yyset_lval (YYSTYPE * yylval_param ,yyscan_t yyscanner );

       YYLTYPE *core_yyget_lloc (yyscan_t yyscanner );
    
        void core_yyset_lloc (YYLTYPE * yylloc_param ,yyscan_t yyscanner );
    
/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int core_yywrap (yyscan_t yyscanner );
#else
extern int core_yywrap (yyscan_t yyscanner );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int ,yyscan_t yyscanner);
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * ,yyscan_t yyscanner);
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (yyscan_t yyscanner );
#else
static int input (yyscan_t yyscanner );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg , yyscanner)
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int core_yylex \
               (YYSTYPE * yylval_param,YYLTYPE * yylloc_param ,yyscan_t yyscanner);

#define YY_DECL int core_yylex \
               (YYSTYPE * yylval_param, YYLTYPE * yylloc_param , yyscan_t yyscanner)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    yylval = yylval_param;

    yylloc = yylloc_param;

	if ( !yyg->yy_init )
		{
		yyg->yy_init = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! yyg->yy_start )
			yyg->yy_start = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			core_yyensure_buffer_stack (yyscanner);
			YY_CURRENT_BUFFER_LVALUE =
				core_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
		}

		core_yy_load_buffer_state(yyscanner );
		}

	{
#line 440 "scan.l"


#line 6466 "scan.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = yyg->yy_c_buf_p;

		/* Support of yytext. */
		*yy_cp = yyg->yy_hold_char;

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = yy_start_state_list[yyg->yy_start];
yy_match:
		{
		yyconst struct yy_trans_info *yy_trans_info;

		YY_CHAR yy_c;

		for ( yy_c = YY_SC_TO_UI(*yy_cp);
		      (yy_trans_info = &yy_current_state[(unsigned int) yy_c])->
		yy_verify == yy_c;
		      yy_c = YY_SC_TO_UI(*++yy_cp) )
			yy_current_state += yy_trans_info->yy_nxt;
		}

yy_find_action:
		yy_act = yy_current_state[-1].yy_nxt;

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 442 "scan.l"
{
					/* ignore */
				}
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 446 "scan.l"
{
					/* Set location in case of syntax error in comment */
					SET_YYLLOC();
					yyextra->xcdepth = 0;
					BEGIN(xc);
					/* Put back any characters past slash-star; see above */
					yyless(2);
				}
	YY_BREAK

case 3:
YY_RULE_SETUP
#line 456 "scan.l"
{
					(yyextra->xcdepth)++;
					/* Put back any characters past slash-star; see above */
					yyless(2);
				}
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 462 "scan.l"
{
					if (yyextra->xcdepth <= 0)
						BEGIN(INITIAL);
					else
						(yyextra->xcdepth)--;
				}
	YY_BREAK
case 5:
/* rule 5 can match eol */
YY_RULE_SETUP
#line 469 "scan.l"
{
					/* ignore */
				}
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 473 "scan.l"
{
					/* ignore */
				}
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 477 "scan.l"
{
					/* ignore */
				}
	YY_BREAK
case YY_STATE_EOF(xc):
#line 481 "scan.l"
{
					yyerror("unterminated /* comment");
				}
	YY_BREAK
/* <xc> */
case 8:
YY_RULE_SETUP
#line 486 "scan.l"
{
					/* Binary bit type.
					 * At some point we should simply pass the string
					 * forward to the parser and label it there.
					 * In the meantime, place a leading "b" on the string
					 * to mark it for the input routine as a binary string.
					 */
					SET_YYLLOC();
					BEGIN(xb);
					startlit();
					addlitchar('b', yyscanner);
				}
	YY_BREAK
case 9:
/* rule 9 can match eol */
#line 499 "scan.l"
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 499 "scan.l"
{
					addlit(yytext, yyleng, yyscanner);
				}
	YY_BREAK
case YY_STATE_EOF(xb):
#line 502 "scan.l"
{ yyerror("unterminated bit string literal"); }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 504 "scan.l"
{
					/* Hexadecimal bit type.
					 * At some point we should simply pass the string
					 * forward to the parser and label it there.
					 * In the meantime, place a leading "x" on the string
					 * to mark it for the input routine as a hex string.
					 */
					SET_YYLLOC();
					BEGIN(xh);
					startlit();
					addlitchar('x', yyscanner);
				}
	YY_BREAK
case YY_STATE_EOF(xh):
#line 516 "scan.l"
{ yyerror("unterminated hexadecimal string literal"); }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 518 "scan.l"
{
					/* National character.
					 * We will pass this along as a normal character string,
					 * but preceded with an internally-generated "NCHAR".
					 */
					int		kwnum;

					SET_YYLLOC();
					yyless(1);	/* eat only 'n' this time */

					kwnum = ScanKeywordLookup("nchar",
											  yyextra->keywordlist);
					if (kwnum >= 0)
					{
						yylval->keyword = GetScanKeyword(kwnum,
														 yyextra->keywordlist);
						return yyextra->keyword_tokens[kwnum];
					}
					else
					{
						/* If NCHAR isn't a keyword, just return "n" */
						yylval->str = pstrdup("n");
						return IDENT;
					}
				}
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 544 "scan.l"
{
					yyextra->warn_on_first_escape = true;
					yyextra->saw_non_ascii = false;
					SET_YYLLOC();
					if (yyextra->standard_conforming_strings)
						BEGIN(xq);
					else
						BEGIN(xe);
					startlit();
				}
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 554 "scan.l"
{
					yyextra->warn_on_first_escape = false;
					yyextra->saw_non_ascii = false;
					SET_YYLLOC();
					BEGIN(xe);
					startlit();
				}
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 561 "scan.l"
{
					SET_YYLLOC();
					if (!yyextra->standard_conforming_strings)
						ereport(ERROR,
								(errcode(ERRCODE_FEATURE_NOT_SUPPORTED),
								 errmsg("unsafe use of string constant with Unicode escapes"),
								 errdetail("String constants with Unicode escapes cannot be used when standard_conforming_strings is off."),
								 lexer_errposition()));
					BEGIN(xus);
					startlit();
				}
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 573 "scan.l"
{
					/*
					 * When we are scanning a quoted string and see an end
					 * quote, we must look ahead for a possible continuation.
					 * If we don't see one, we know the end quote was in fact
					 * the end of the string.  To reduce the lexer table size,
					 * we use a single "xqs" state to do the lookahead for all
					 * types of strings.
					 */
					yyextra->state_before_str_stop = YYSTATE;
					BEGIN(xqs);
				}
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 585 "scan.l"
{
					/*
					 * Found a quote continuation, so return to the in-quote
					 * state and continue scanning the literal.  Nothing is
					 * added to the literal's contents.
					 */
					BEGIN(yyextra->state_before_str_stop);
				}
	YY_BREAK
case 18:
/* rule 18 can match eol */
#line 594 "scan.l"
case 19:
/* rule 19 can match eol */
#line 595 "scan.l"
YY_RULE_SETUP
case YY_STATE_EOF(xqs):
#line 595 "scan.l"
{
					/*
					 * Failed to see a quote continuation.  Throw back
					 * everything after the end quote, and handle the string
					 * according to the state we were in previously.
					 */
					yyless(0);
					BEGIN(INITIAL);

					switch (yyextra->state_before_str_stop)
					{
						case xb:
							yylval->str = litbufdup(yyscanner);
							return BCONST;
						case xh:
							yylval->str = litbufdup(yyscanner);
							return XCONST;
						case xq:
						case xe:
							/*
							 * Check that the data remains valid, if it might
							 * have been made invalid by unescaping any chars.
							 */
							if (yyextra->saw_non_ascii)
								pg_verifymbstr(yyextra->literalbuf,
											   yyextra->literallen,
											   false);
							yylval->str = litbufdup(yyscanner);
							return SCONST;
						case xus:
							yylval->str = litbufdup(yyscanner);
							return USCONST;
						default:
							yyerror("unhandled previous state in xqs");
					}
				}
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 632 "scan.l"
{
					addlitchar('\'', yyscanner);
				}
	YY_BREAK
case 21:
/* rule 21 can match eol */
YY_RULE_SETUP
#line 635 "scan.l"
{
					addlit(yytext, yyleng, yyscanner);
				}
	YY_BREAK
case 22:
/* rule 22 can match eol */
YY_RULE_SETUP
#line 638 "scan.l"
{
					addlit(yytext, yyleng, yyscanner);
				}
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 641 "scan.l"
{
					pg_wchar	c = strtoul(yytext + 2, NULL, 16);

					/*
					 * For consistency with other productions, issue any
					 * escape warning with cursor pointing to start of string.
					 * We might want to change that, someday.
					 */
					check_escape_warning(yyscanner);

					/* Remember start of overall string token ... */
					PUSH_YYLLOC();
					/* ... and set the error cursor to point at this esc seq */
					SET_YYLLOC();

					if (is_utf16_surrogate_first(c))
					{
						yyextra->utf16_first_part = c;
						BEGIN(xeu);
					}
					else if (is_utf16_surrogate_second(c))
						yyerror("invalid Unicode surrogate pair");
					else
						addunicode(c, yyscanner);

					/* Restore yylloc to be start of string token */
					POP_YYLLOC();
				}
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 669 "scan.l"
{
					pg_wchar	c = strtoul(yytext + 2, NULL, 16);

					/* Remember start of overall string token ... */
					PUSH_YYLLOC();
					/* ... and set the error cursor to point at this esc seq */
					SET_YYLLOC();

					if (!is_utf16_surrogate_second(c))
						yyerror("invalid Unicode surrogate pair");

					c = surrogate_pair_to_codepoint(yyextra->utf16_first_part, c);

					addunicode(c, yyscanner);

					/* Restore yylloc to be start of string token */
					POP_YYLLOC();

					BEGIN(xe);
				}
	YY_BREAK
case 25:
#line 690 "scan.l"
case 26:
/* rule 26 can match eol */
#line 691 "scan.l"
YY_RULE_SETUP
case YY_STATE_EOF(xeu):
#line 691 "scan.l"
{
					/* Set the error cursor to point at missing esc seq */
					SET_YYLLOC();
					yyerror("invalid Unicode surrogate pair");
				}
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 696 "scan.l"
{
					/* Set the error cursor to point at malformed esc seq */
					SET_YYLLOC();
					ereport(ERROR,
							(errcode(ERRCODE_INVALID_ESCAPE_SEQUENCE),
							 errmsg("invalid Unicode escape"),
							 errhint("Unicode escapes must be \\uXXXX or \\UXXXXXXXX."),
							 lexer_errposition()));
				}
	YY_BREAK
case 28:
/* rule 28 can match eol */
YY_RULE_SETUP
#line 705 "scan.l"
{
					if (yytext[1] == '\'')
					{
						if (yyextra->backslash_quote == BACKSLASH_QUOTE_OFF ||
							(yyextra->backslash_quote == BACKSLASH_QUOTE_SAFE_ENCODING &&
							 PG_ENCODING_IS_CLIENT_ONLY(pg_get_client_encoding())))
							ereport(ERROR,
									(errcode(ERRCODE_NONSTANDARD_USE_OF_ESCAPE_CHARACTER),
									 errmsg("unsafe use of \\' in a string literal"),
									 errhint("Use '' to write quotes in strings. \\' is insecure in client-only encodings."),
									 lexer_errposition()));
					}
					check_string_escape_warning(yytext[1], yyscanner);
					addlitchar(unescape_single_char(yytext[1], yyscanner),
							   yyscanner);
				}
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 721 "scan.l"
{
					unsigned char c = strtoul(yytext + 1, NULL, 8);

					check_escape_warning(yyscanner);
					addlitchar(c, yyscanner);
					if (c == '\0' || IS_HIGHBIT_SET(c))
						yyextra->saw_non_ascii = true;
				}
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 729 "scan.l"
{
					unsigned char c = strtoul(yytext + 2, NULL, 16);

					check_escape_warning(yyscanner);
					addlitchar(c, yyscanner);
					if (c == '\0' || IS_HIGHBIT_SET(c))
						yyextra->saw_non_ascii = true;
				}
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 737 "scan.l"
{
					/* This is only needed for \ just before EOF */
					addlitchar(yytext[0], yyscanner);
				}
	YY_BREAK
case YY_STATE_EOF(xq):
case YY_STATE_EOF(xe):
case YY_STATE_EOF(xus):
#line 741 "scan.l"
{ yyerror("unterminated quoted string"); }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 743 "scan.l"
{
					SET_YYLLOC();
					yyextra->dolqstart = pstrdup(yytext);
					BEGIN(xdolq);
					startlit();
				}
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 749 "scan.l"
{
					SET_YYLLOC();
					/* throw back all but the initial "$" */
					yyless(1);
					/* and treat it as {other} */
					return yytext[0];
				}
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 756 "scan.l"
{
					if (strcmp(yytext, yyextra->dolqstart) == 0)
					{
						pfree(yyextra->dolqstart);
						yyextra->dolqstart = NULL;
						BEGIN(INITIAL);
						yylval->str = litbufdup(yyscanner);
						return SCONST;
					}
					else
					{
						/*
						 * When we fail to match $...$ to dolqstart, transfer
						 * the $... part to the output, but put back the final
						 * $ for rescanning.  Consider $delim$...$junk$delim$
						 */
						addlit(yytext, yyleng - 1, yyscanner);
						yyless(yyleng - 1);
					}
				}
	YY_BREAK
case 35:
/* rule 35 can match eol */
YY_RULE_SETUP
#line 776 "scan.l"
{
					addlit(yytext, yyleng, yyscanner);
				}
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 779 "scan.l"
{
					addlit(yytext, yyleng, yyscanner);
				}
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 782 "scan.l"
{
					/* This is only needed for $ inside the quoted text */
					addlitchar(yytext[0], yyscanner);
				}
	YY_BREAK
case YY_STATE_EOF(xdolq):
#line 786 "scan.l"
{ yyerror("unterminated dollar-quoted string"); }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 788 "scan.l"
{
					SET_YYLLOC();
					BEGIN(xd);
					startlit();
				}
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 793 "scan.l"
{
					SET_YYLLOC();
					BEGIN(xui);
					startlit();
				}
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 798 "scan.l"
{
					char	   *ident;

					BEGIN(INITIAL);
					if (yyextra->literallen == 0)
						yyerror("zero-length delimited identifier");
					ident = litbufdup(yyscanner);
					if (yyextra->literallen >= NAMEDATALEN)
						truncate_identifier(ident, yyextra->literallen, true);
					yylval->str = ident;
					return IDENT;
				}
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 810 "scan.l"
{
					BEGIN(INITIAL);
					if (yyextra->literallen == 0)
						yyerror("zero-length delimited identifier");
					/* can't truncate till after we de-escape the ident */
					yylval->str = litbufdup(yyscanner);
					return UIDENT;
				}
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 818 "scan.l"
{
					addlitchar('"', yyscanner);
				}
	YY_BREAK
case 43:
/* rule 43 can match eol */
YY_RULE_SETUP
#line 821 "scan.l"
{
					addlit(yytext, yyleng, yyscanner);
				}
	YY_BREAK
case YY_STATE_EOF(xd):
case YY_STATE_EOF(xui):
#line 824 "scan.l"
{ yyerror("unterminated quoted identifier"); }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 826 "scan.l"
{
					char	   *ident;

					SET_YYLLOC();
					/* throw back all but the initial u/U */
					yyless(1);
					/* and treat it as {identifier} */
					ident = downcase_truncate_identifier(yytext, yyleng, true);
					yylval->str = ident;
					return IDENT;
				}
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 838 "scan.l"
{
					SET_YYLLOC();
					return TYPECAST;
				}
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 843 "scan.l"
{
					SET_YYLLOC();
					return DOT_DOT;
				}
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 848 "scan.l"
{
					SET_YYLLOC();
					return COLON_EQUALS;
				}
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 853 "scan.l"
{
					SET_YYLLOC();
					return EQUALS_GREATER;
				}
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 858 "scan.l"
{
					SET_YYLLOC();
					return LESS_EQUALS;
				}
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 863 "scan.l"
{
					SET_YYLLOC();
					return GREATER_EQUALS;
				}
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 868 "scan.l"
{
					/* We accept both "<>" and "!=" as meaning NOT_EQUALS */
					SET_YYLLOC();
					return NOT_EQUALS;
				}
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 874 "scan.l"
{
					/* We accept both "<>" and "!=" as meaning NOT_EQUALS */
					SET_YYLLOC();
					return NOT_EQUALS;
				}
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 880 "scan.l"
{
					SET_YYLLOC();
					return yytext[0];
				}
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 885 "scan.l"
{
					/*
					 * Check for embedded slash-star or dash-dash; those
					 * are comment starts, so operator must stop there.
					 * Note that slash-star or dash-dash at the first
					 * character will match a prior rule, not this one.
					 */
					int			nchars = yyleng;
					char	   *slashstar = strstr(yytext, "/*");
					char	   *dashdash = strstr(yytext, "--");

					if (slashstar && dashdash)
					{
						/* if both appear, take the first one */
						if (slashstar > dashdash)
							slashstar = dashdash;
					}
					else if (!slashstar)
						slashstar = dashdash;
					if (slashstar)
						nchars = slashstar - yytext;

					/*
					 * For SQL compatibility, '+' and '-' cannot be the
					 * last char of a multi-char operator unless the operator
					 * contains chars that are not in SQL operators.
					 * The idea is to lex '=-' as two operators, but not
					 * to forbid operator names like '?-' that could not be
					 * sequences of SQL operators.
					 */
					if (nchars > 1 &&
						(yytext[nchars - 1] == '+' ||
						 yytext[nchars - 1] == '-'))
					{
						int			ic;

						for (ic = nchars - 2; ic >= 0; ic--)
						{
							char c = yytext[ic];
							if (c == '~' || c == '!' || c == '@' ||
								c == '#' || c == '^' || c == '&' ||
								c == '|' || c == '`' || c == '?' ||
								c == '%')
								break;
						}
						if (ic < 0)
						{
							/*
							 * didn't find a qualifying character, so remove
							 * all trailing [+-]
							 */
							do {
								nchars--;
							} while (nchars > 1 &&
								 (yytext[nchars - 1] == '+' ||
								  yytext[nchars - 1] == '-'));
						}
					}

					SET_YYLLOC();

					if (nchars < yyleng)
					{
						/* Strip the unwanted chars from the token */
						yyless(nchars);
						/*
						 * If what we have left is only one char, and it's
						 * one of the characters matching "self", then
						 * return it as a character token the same way
						 * that the "self" rule would have.
						 */
						if (nchars == 1 &&
							strchr(",()[].;:+-*/%^<>=", yytext[0]))
							return yytext[0];
						/*
						 * Likewise, if what we have left is two chars, and
						 * those match the tokens ">=", "<=", "=>", "<>" or
						 * "!=", then we must return the appropriate token
						 * rather than the generic Op.
						 */
						if (nchars == 2)
						{
							if (yytext[0] == '=' && yytext[1] == '>')
								return EQUALS_GREATER;
							if (yytext[0] == '>' && yytext[1] == '=')
								return GREATER_EQUALS;
							if (yytext[0] == '<' && yytext[1] == '=')
								return LESS_EQUALS;
							if (yytext[0] == '<' && yytext[1] == '>')
								return NOT_EQUALS;
							if (yytext[0] == '!' && yytext[1] == '=')
								return NOT_EQUALS;
						}
					}

					/*
					 * Complain if operator is too long.  Unlike the case
					 * for identifiers, we make this an error not a notice-
					 * and-truncate, because the odds are we are looking at
					 * a syntactic mistake anyway.
					 */
					if (nchars >= NAMEDATALEN)
						yyerror("operator too long");

					yylval->str = pstrdup(yytext);
					return Op;
				}
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 993 "scan.l"
{
					SET_YYLLOC();
					yylval->ival = atol(yytext + 1);
					return PARAM;
				}
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 998 "scan.l"
{
					SET_YYLLOC();
					yyerror("trailing junk after parameter");
				}
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 1003 "scan.l"
{
					SET_YYLLOC();
					return process_integer_literal(yytext, yylval, 10);
				}
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 1007 "scan.l"
{
					SET_YYLLOC();
					return process_integer_literal(yytext, yylval, 16);
				}
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 1011 "scan.l"
{
					SET_YYLLOC();
					return process_integer_literal(yytext, yylval, 8);
				}
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 1015 "scan.l"
{
					SET_YYLLOC();
					return process_integer_literal(yytext, yylval, 2);
				}
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 1019 "scan.l"
{
					SET_YYLLOC();
					yyerror("invalid hexadecimal integer");
				}
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 1023 "scan.l"
{
					SET_YYLLOC();
					yyerror("invalid octal integer");
				}
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 1027 "scan.l"
{
					SET_YYLLOC();
					yyerror("invalid binary integer");
				}
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 1031 "scan.l"
{
					SET_YYLLOC();
					yylval->str = pstrdup(yytext);
					return FCONST;
				}
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 1036 "scan.l"
{
					/* throw back the .., and treat as integer */
					yyless(yyleng - 2);
					SET_YYLLOC();
					return process_integer_literal(yytext, yylval, 10);
				}
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 1042 "scan.l"
{
					SET_YYLLOC();
					yylval->str = pstrdup(yytext);
					return FCONST;
				}
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 1047 "scan.l"
{
					SET_YYLLOC();
					yyerror("trailing junk after numeric literal");
				}
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 1051 "scan.l"
{
					SET_YYLLOC();
					yyerror("trailing junk after numeric literal");
				}
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 1055 "scan.l"
{
					SET_YYLLOC();
					yyerror("trailing junk after numeric literal");
				}
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 1059 "scan.l"
{
					SET_YYLLOC();
					yyerror("trailing junk after numeric literal");
				}
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 1063 "scan.l"
{
					SET_YYLLOC();
					yyerror("trailing junk after numeric literal");
				}
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 1067 "scan.l"
{
					SET_YYLLOC();
					yyerror("trailing junk after numeric literal");
				}
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 1071 "scan.l"
{
					SET_YYLLOC();
					yyerror("trailing junk after numeric literal");
				}
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 1077 "scan.l"
{
					int			kwnum;
					char	   *ident;

					SET_YYLLOC();

					/* Is it a keyword? */
					kwnum = ScanKeywordLookup(yytext,
											  yyextra->keywordlist);
					if (kwnum >= 0)
					{
						yylval->keyword = GetScanKeyword(kwnum,
														 yyextra->keywordlist);
						return yyextra->keyword_tokens[kwnum];
					}

					/*
					 * No.  Convert the identifier to lower case, and truncate
					 * if necessary.
					 */
					ident = downcase_truncate_identifier(yytext, yyleng, true);
					yylval->str = ident;
					return IDENT;
				}
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 1102 "scan.l"
{
					SET_YYLLOC();
					return yytext[0];
				}
	YY_BREAK
case YY_STATE_EOF(INITIAL):
#line 1107 "scan.l"
{
					SET_YYLLOC();
					yyterminate();
				}
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 1112 "scan.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 7475 "scan.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - yyg->yytext_ptr) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = yyg->yy_hold_char;
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * core_yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( yyg->yy_c_buf_p <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			yyg->yy_c_buf_p = yyg->yytext_ptr + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state( yyscanner );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state , yyscanner);

			yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++yyg->yy_c_buf_p;
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = yyg->yy_c_buf_p;
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer( yyscanner ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				yyg->yy_did_buffer_switch_on_eof = 0;

				if ( core_yywrap(yyscanner ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					yyg->yy_c_buf_p = yyg->yytext_ptr + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				yyg->yy_c_buf_p =
					yyg->yytext_ptr + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				yyg->yy_c_buf_p =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars];

				yy_current_state = yy_get_previous_state( yyscanner );

				yy_cp = yyg->yy_c_buf_p;
				yy_bp = yyg->yytext_ptr + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of core_yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = yyg->yytext_ptr;
	yy_size_t number_to_move, i;
	int ret_val;

	if ( yyg->yy_c_buf_p > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( yyg->yy_c_buf_p - yyg->yytext_ptr - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (yy_size_t) (yyg->yy_c_buf_p - yyg->yytext_ptr) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) (yyg->yy_c_buf_p - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				int new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					core_yyrealloc((void *) b->yy_ch_buf,(yy_size_t) (b->yy_buf_size + 2) ,yyscanner );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = NULL;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			yyg->yy_c_buf_p = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			yyg->yy_n_chars, num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	if ( yyg->yy_n_chars == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			core_yyrestart(yyin  ,yyscanner);
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((int) (yyg->yy_n_chars + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = yyg->yy_n_chars + number_to_move + (yyg->yy_n_chars >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) core_yyrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,(yy_size_t) new_size ,yyscanner );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	yyg->yy_n_chars += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars + 1] = YY_END_OF_BUFFER_CHAR;

	yyg->yytext_ptr = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (yyscan_t yyscanner)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	yy_current_state = yy_start_state_list[yyg->yy_start];

	for ( yy_cp = yyg->yytext_ptr + YY_MORE_ADJ; yy_cp < yyg->yy_c_buf_p; ++yy_cp )
		{
		yy_current_state += yy_current_state[(*yy_cp ? YY_SC_TO_UI(*yy_cp) : 256)].yy_nxt;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state , yyscan_t yyscanner)
{
	int yy_is_jam;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner; /* This var may be unused depending upon options. */

	int yy_c = 256;
	yyconst struct yy_trans_info *yy_trans_info;

	yy_trans_info = &yy_current_state[(unsigned int) yy_c];
	yy_current_state += yy_trans_info->yy_nxt;
	yy_is_jam = (yy_trans_info->yy_verify != yy_c);

	(void)yyg;
	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (yyscan_t yyscanner)
#else
    static int input  (yyscan_t yyscanner)
#endif

{
	int c;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	*yyg->yy_c_buf_p = yyg->yy_hold_char;

	if ( *yyg->yy_c_buf_p == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( yyg->yy_c_buf_p < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[yyg->yy_n_chars] )
			/* This was really a NUL. */
			*yyg->yy_c_buf_p = '\0';

		else
			{ /* need more input */
			int offset = yyg->yy_c_buf_p - yyg->yytext_ptr;
			++yyg->yy_c_buf_p;

			switch ( yy_get_next_buffer( yyscanner ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					core_yyrestart(yyin ,yyscanner);

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( core_yywrap(yyscanner ) )
						return 0;

					if ( ! yyg->yy_did_buffer_switch_on_eof )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput(yyscanner);
#else
					return input(yyscanner);
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					yyg->yy_c_buf_p = yyg->yytext_ptr + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) yyg->yy_c_buf_p;	/* cast for 8-bit char's */
	*yyg->yy_c_buf_p = '\0';	/* preserve yytext */
	yyg->yy_hold_char = *++yyg->yy_c_buf_p;

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * @param yyscanner The scanner object.
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void core_yyrestart  (FILE * input_file , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! YY_CURRENT_BUFFER ){
        core_yyensure_buffer_stack (yyscanner);
		YY_CURRENT_BUFFER_LVALUE =
            core_yy_create_buffer(yyin,YY_BUF_SIZE ,yyscanner);
	}

	core_yy_init_buffer(YY_CURRENT_BUFFER,input_file ,yyscanner);
	core_yy_load_buffer_state(yyscanner );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * @param yyscanner The scanner object.
 */
    void core_yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	/* TODO. We should be able to replace this entire function body
	 * with
	 *		core_yypop_buffer_state();
	 *		core_yypush_buffer_state(new_buffer);
     */
	core_yyensure_buffer_stack (yyscanner);
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	core_yy_load_buffer_state(yyscanner );

	/* We don't actually know whether we did this switch during
	 * EOF (core_yywrap()) processing, but the only time this flag
	 * is looked at is after core_yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	yyg->yy_did_buffer_switch_on_eof = 1;
}

static void core_yy_load_buffer_state  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	yyg->yy_n_chars = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	yyg->yytext_ptr = yyg->yy_c_buf_p = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	yyg->yy_hold_char = *yyg->yy_c_buf_p;
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * @param yyscanner The scanner object.
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE core_yy_create_buffer  (FILE * file, int  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) core_yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in core_yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) core_yyalloc((yy_size_t) (b->yy_buf_size + 2) ,yyscanner );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in core_yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	core_yy_init_buffer(b,file ,yyscanner);

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with core_yy_create_buffer()
 * @param yyscanner The scanner object.
 */
    void core_yy_delete_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		core_yyfree((void *) b->yy_ch_buf ,yyscanner );

	core_yyfree((void *) b ,yyscanner );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a core_yyrestart() or at EOF.
 */
    static void core_yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file , yyscan_t yyscanner)

{
	int oerrno = errno;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	core_yy_flush_buffer(b ,yyscanner);

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then core_yy_init_buffer was _probably_
     * called from core_yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * @param yyscanner The scanner object.
 */
    void core_yy_flush_buffer (YY_BUFFER_STATE  b , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		core_yy_load_buffer_state(yyscanner );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  @param yyscanner The scanner object.
 */
void core_yypush_buffer_state (YY_BUFFER_STATE new_buffer , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (new_buffer == NULL)
		return;

	core_yyensure_buffer_stack(yyscanner);

	/* This block is copied from core_yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*yyg->yy_c_buf_p = yyg->yy_hold_char;
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = yyg->yy_c_buf_p;
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = yyg->yy_n_chars;
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		yyg->yy_buffer_stack_top++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from core_yy_switch_to_buffer. */
	core_yy_load_buffer_state(yyscanner );
	yyg->yy_did_buffer_switch_on_eof = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  @param yyscanner The scanner object.
 */
void core_yypop_buffer_state (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	if (!YY_CURRENT_BUFFER)
		return;

	core_yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner);
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if (yyg->yy_buffer_stack_top > 0)
		--yyg->yy_buffer_stack_top;

	if (YY_CURRENT_BUFFER) {
		core_yy_load_buffer_state(yyscanner );
		yyg->yy_did_buffer_switch_on_eof = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void core_yyensure_buffer_stack (yyscan_t yyscanner)
{
	int num_to_alloc;
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

	if (!yyg->yy_buffer_stack) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		yyg->yy_buffer_stack = (struct yy_buffer_state**)core_yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in core_yyensure_buffer_stack()" );
								  
		memset(yyg->yy_buffer_stack, 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		yyg->yy_buffer_stack_max = num_to_alloc;
		yyg->yy_buffer_stack_top = 0;
		return;
	}

	if (yyg->yy_buffer_stack_top >= (yyg->yy_buffer_stack_max) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = yyg->yy_buffer_stack_max + grow_size;
		yyg->yy_buffer_stack = (struct yy_buffer_state**)core_yyrealloc
								(yyg->yy_buffer_stack,
								num_to_alloc * sizeof(struct yy_buffer_state*)
								, yyscanner);
		if ( ! yyg->yy_buffer_stack )
			YY_FATAL_ERROR( "out of dynamic memory in core_yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset(yyg->yy_buffer_stack + yyg->yy_buffer_stack_max, 0, grow_size * sizeof(struct yy_buffer_state*));
		yyg->yy_buffer_stack_max = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE core_yy_scan_buffer  (char * base, yy_size_t  size , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) core_yyalloc(sizeof( struct yy_buffer_state ) ,yyscanner );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in core_yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	core_yy_switch_to_buffer(b ,yyscanner );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to core_yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       core_yy_scan_bytes() instead.
 */
YY_BUFFER_STATE core_yy_scan_string (yyconst char * yystr , yyscan_t yyscanner)
{
    
	return core_yy_scan_bytes(yystr,(int) strlen(yystr) ,yyscanner);
}

/** Setup the input buffer state to scan the given bytes. The next call to core_yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * @param yyscanner The scanner object.
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE core_yy_scan_bytes  (yyconst char * yybytes, int  _yybytes_len , yyscan_t yyscanner)
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) core_yyalloc(n ,yyscanner );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in core_yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = core_yy_scan_buffer(buf,n ,yyscanner);
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in core_yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (yyconst char* msg , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;
	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        yy_size_t yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = yyg->yy_hold_char; \
		yyg->yy_c_buf_p = yytext + yyless_macro_arg; \
		yyg->yy_hold_char = *yyg->yy_c_buf_p; \
		*yyg->yy_c_buf_p = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the user-defined data for this scanner.
 * @param yyscanner The scanner object.
 */
YY_EXTRA_TYPE core_yyget_extra  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyextra;
}

/** Get the current line number.
 * @param yyscanner The scanner object.
 */
int core_yyget_lineno  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yylineno;
}

/** Get the current column number.
 * @param yyscanner The scanner object.
 */
int core_yyget_column  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    
        if (! YY_CURRENT_BUFFER)
            return 0;
    
    return yycolumn;
}

/** Get the input stream.
 * @param yyscanner The scanner object.
 */
FILE *core_yyget_in  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyin;
}

/** Get the output stream.
 * @param yyscanner The scanner object.
 */
FILE *core_yyget_out  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyout;
}

/** Get the length of the current token.
 * @param yyscanner The scanner object.
 */
int core_yyget_leng  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yyleng;
}

/** Get the current token.
 * @param yyscanner The scanner object.
 */

char *core_yyget_text  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yytext;
}

/** Set the user-defined data. This data is never touched by the scanner.
 * @param user_defined The data to be associated with this scanner.
 * @param yyscanner The scanner object.
 */
void core_yyset_extra (YY_EXTRA_TYPE  user_defined , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyextra = user_defined ;
}

/** Set the current line number.
 * @param _line_number line number
 * @param yyscanner The scanner object.
 */
void core_yyset_lineno (int  _line_number , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* lineno is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "core_yyset_lineno called with no buffer" );
    
    yylineno = _line_number;
}

/** Set the current column.
 * @param _column_no column number
 * @param yyscanner The scanner object.
 */
void core_yyset_column (int  _column_no , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

        /* column is only valid if an input buffer exists. */
        if (! YY_CURRENT_BUFFER )
           YY_FATAL_ERROR( "core_yyset_column called with no buffer" );
    
    yycolumn = _column_no;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * @param yyscanner The scanner object.
 * @see core_yy_switch_to_buffer
 */
void core_yyset_in (FILE *  _in_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyin = _in_str ;
}

void core_yyset_out (FILE *  _out_str , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yyout = _out_str ;
}

int core_yyget_debug  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yy_flex_debug;
}

void core_yyset_debug (int  _bdebug , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yy_flex_debug = _bdebug ;
}

/* Accessor methods for yylval and yylloc */

YYSTYPE * core_yyget_lval  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylval;
}

void core_yyset_lval (YYSTYPE *  yylval_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylval = yylval_param;
}

YYLTYPE *core_yyget_lloc  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    return yylloc;
}
    
void core_yyset_lloc (YYLTYPE *  yylloc_param , yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    yylloc = yylloc_param;
}
    
/* User-visible API */

/* core_yylex_init is special because it creates the scanner itself, so it is
 * the ONLY reentrant function that doesn't take the scanner as the last argument.
 * That's why we explicitly handle the declaration, instead of using our macros.
 */

int core_yylex_init(yyscan_t* ptr_yy_globals)

{
    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }

    *ptr_yy_globals = (yyscan_t) core_yyalloc ( sizeof( struct yyguts_t ), NULL );

    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }

    /* By setting to 0xAA, we expose bugs in yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));

    return yy_init_globals ( *ptr_yy_globals );
}

/* core_yylex_init_extra has the same functionality as core_yylex_init, but follows the
 * convention of taking the scanner as the last argument. Note however, that
 * this is a *pointer* to a scanner, as it will be allocated by this call (and
 * is the reason, too, why this function also must handle its own declaration).
 * The user defined value in the first argument will be available to core_yyalloc in
 * the yyextra field.
 */

int core_yylex_init_extra(YY_EXTRA_TYPE yy_user_defined,yyscan_t* ptr_yy_globals )

{
    struct yyguts_t dummy_yyguts;

    core_yyset_extra (yy_user_defined, &dummy_yyguts);

    if (ptr_yy_globals == NULL){
        errno = EINVAL;
        return 1;
    }
	
    *ptr_yy_globals = (yyscan_t) core_yyalloc ( sizeof( struct yyguts_t ), &dummy_yyguts );
	
    if (*ptr_yy_globals == NULL){
        errno = ENOMEM;
        return 1;
    }
    
    /* By setting to 0xAA, we expose bugs in
    yy_init_globals. Leave at 0x00 for releases. */
    memset(*ptr_yy_globals,0x00,sizeof(struct yyguts_t));
    
    core_yyset_extra (yy_user_defined, *ptr_yy_globals);
    
    return yy_init_globals ( *ptr_yy_globals );
}

static int yy_init_globals (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
    /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from core_yylex_destroy(), so don't allocate here.
     */

    yyg->yy_buffer_stack = NULL;
    yyg->yy_buffer_stack_top = 0;
    yyg->yy_buffer_stack_max = 0;
    yyg->yy_c_buf_p = NULL;
    yyg->yy_init = 0;
    yyg->yy_start = 0;

    yyg->yy_start_stack_ptr = 0;
    yyg->yy_start_stack_depth = 0;
    yyg->yy_start_stack =  NULL;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * core_yylex_init()
     */
    return 0;
}

/* core_yylex_destroy is for both reentrant and non-reentrant scanners. */
int core_yylex_destroy  (yyscan_t yyscanner)
{
    struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;

    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		core_yy_delete_buffer(YY_CURRENT_BUFFER ,yyscanner );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		core_yypop_buffer_state(yyscanner);
	}

	/* Destroy the stack itself. */
	core_yyfree(yyg->yy_buffer_stack ,yyscanner);
	yyg->yy_buffer_stack = NULL;

    /* Destroy the start condition stack. */
        core_yyfree(yyg->yy_start_stack ,yyscanner );
        yyg->yy_start_stack = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * core_yylex() is called, initialization will occur. */
    yy_init_globals( yyscanner);

    /* Destroy the main struct (reentrant only). */
    core_yyfree ( yyscanner , yyscanner );
    yyscanner = NULL;
    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n , yyscan_t yyscanner)
{
	struct yyguts_t * yyg = (struct yyguts_t*)yyscanner;
	(void)yyg;

	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s , yyscan_t yyscanner)
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

#define YYTABLES_NAME "yytables"

#line 1112 "scan.l"



/* LCOV_EXCL_STOP */

/*
 * Arrange access to yyextra for subroutines of the main core_yylex() function.
 * We expect each subroutine to have a yyscanner parameter.  Rather than
 * use the yyget_xxx functions, which might or might not get inlined by the
 * compiler, we cheat just a bit and cast yyscanner to the right type.
 */
#undef yyextra
#define yyextra  (((struct yyguts_t *) yyscanner)->yyextra_r)

/* Likewise for a couple of other things we need. */
#undef yylloc
#define yylloc	(((struct yyguts_t *) yyscanner)->yylloc_r)
#undef yyleng
#define yyleng	(((struct yyguts_t *) yyscanner)->yyleng_r)


/*
 * scanner_errposition
 *		Report a lexer or grammar error cursor position, if possible.
 *
 * This is expected to be used within an ereport() call, or via an error
 * callback such as setup_scanner_errposition_callback().  The return value
 * is a dummy (always 0, in fact).
 *
 * Note that this can only be used for messages emitted during raw parsing
 * (essentially, scan.l, parser.c, and gram.y), since it requires the
 * yyscanner struct to still be available.
 */
int
scanner_errposition(int location, core_yyscan_t yyscanner)
{
	int			pos;

	if (location < 0)
		return 0;				/* no-op if location is unknown */

	/* Convert byte offset to character number */
	pos = pg_mbstrlen_with_len(yyextra->scanbuf, location) + 1;
	/* And pass it to the ereport mechanism */
	return errposition(pos);
}

/*
 * Error context callback for inserting scanner error location.
 *
 * Note that this will be called for *any* error occurring while the
 * callback is installed.  We avoid inserting an irrelevant error location
 * if the error is a query cancel --- are there any other important cases?
 */
static void
scb_error_callback(void *arg)
{
	ScannerCallbackState *scbstate = (ScannerCallbackState *) arg;

	if (geterrcode() != ERRCODE_QUERY_CANCELED)
		(void) scanner_errposition(scbstate->location, scbstate->yyscanner);
}

/*
 * setup_scanner_errposition_callback
 *		Arrange for non-scanner errors to report an error position
 *
 * Sometimes the scanner calls functions that aren't part of the scanner
 * subsystem and can't reasonably be passed the yyscanner pointer; yet
 * we would like any errors thrown in those functions to be tagged with an
 * error location.  Use this function to set up an error context stack
 * entry that will accomplish that.  Usage pattern:
 *
 *		declare a local variable "ScannerCallbackState scbstate"
 *		...
 *		setup_scanner_errposition_callback(&scbstate, yyscanner, location);
 *		call function that might throw error;
 *		cancel_scanner_errposition_callback(&scbstate);
 */
void
setup_scanner_errposition_callback(ScannerCallbackState *scbstate,
								   core_yyscan_t yyscanner,
								   int location)
{
	/* Setup error traceback support for ereport() */
	scbstate->yyscanner = yyscanner;
	scbstate->location = location;
	scbstate->errcallback.callback = scb_error_callback;
	scbstate->errcallback.arg = (void *) scbstate;
	scbstate->errcallback.previous = error_context_stack;
	error_context_stack = &scbstate->errcallback;
}

/*
 * Cancel a previously-set-up errposition callback.
 */
void
cancel_scanner_errposition_callback(ScannerCallbackState *scbstate)
{
	/* Pop the error context stack */
	error_context_stack = scbstate->errcallback.previous;
}

/*
 * scanner_yyerror
 *		Report a lexer or grammar error.
 *
 * The message's cursor position is whatever YYLLOC was last set to,
 * ie, the start of the current token if called within core_yylex(), or the
 * most recently lexed token if called from the grammar.
 * This is OK for syntax error messages from the Bison parser, because Bison
 * parsers report error as soon as the first unparsable token is reached.
 * Beware of using yyerror for other purposes, as the cursor position might
 * be misleading!
 */
void
scanner_yyerror(const char *message, core_yyscan_t yyscanner)
{
	const char *loc = yyextra->scanbuf + *yylloc;

	if (*loc == YY_END_OF_BUFFER_CHAR)
	{
		ereport(ERROR,
				(errcode(ERRCODE_SYNTAX_ERROR),
		/* translator: %s is typically the translation of "syntax error" */
				 errmsg("%s at end of input", _(message)),
				 lexer_errposition()));
	}
	else
	{
		ereport(ERROR,
				(errcode(ERRCODE_SYNTAX_ERROR),
		/* translator: first %s is typically the translation of "syntax error" */
				 errmsg("%s at or near \"%s\"", _(message), loc),
				 lexer_errposition()));
	}
}


/*
 * Called before any actual parsing is done
 */
core_yyscan_t
scanner_init(const char *str,
			 core_yy_extra_type *yyext,
			 const ScanKeywordList *keywordlist,
			 const uint16 *keyword_tokens)
{
	Size		slen = strlen(str);
	yyscan_t	scanner;

	if (core_yylex_init(&scanner) != 0)
		elog(ERROR, "core_yylex_init() failed: %m");

	core_yyset_extra(yyext, scanner);

	yyext->keywordlist = keywordlist;
	yyext->keyword_tokens = keyword_tokens;

	yyext->backslash_quote = backslash_quote;
	yyext->escape_string_warning = escape_string_warning;
	yyext->standard_conforming_strings = standard_conforming_strings;

	/*
	 * Make a scan buffer with special termination needed by flex.
	 */
	yyext->scanbuf = (char *) palloc(slen + 2);
	yyext->scanbuflen = slen;
	memcpy(yyext->scanbuf, str, slen);
	yyext->scanbuf[slen] = yyext->scanbuf[slen + 1] = YY_END_OF_BUFFER_CHAR;
	core_yy_scan_buffer(yyext->scanbuf,slen + 2,scanner);

	/* initialize literal buffer to a reasonable but expansible size */
	yyext->literalalloc = 1024;
	yyext->literalbuf = (char *) palloc(yyext->literalalloc);
	yyext->literallen = 0;

	return scanner;
}


/*
 * Called after parsing is done to clean up after scanner_init()
 */
void
scanner_finish(core_yyscan_t yyscanner)
{
	/*
	 * We don't bother to call core_yylex_destroy(), because all it would do is
	 * pfree a small amount of control storage.  It's cheaper to leak the
	 * storage until the parsing context is destroyed.  The amount of space
	 * involved is usually negligible compared to the output parse tree
	 * anyway.
	 *
	 * We do bother to pfree the scanbuf and literal buffer, but only if they
	 * represent a nontrivial amount of space.  The 8K cutoff is arbitrary.
	 */
	if (yyextra->scanbuflen >= 8192)
		pfree(yyextra->scanbuf);
	if (yyextra->literalalloc >= 8192)
		pfree(yyextra->literalbuf);
}


static void
addlit(char *ytext, int yleng, core_yyscan_t yyscanner)
{
	/* enlarge buffer if needed */
	if ((yyextra->literallen + yleng) >= yyextra->literalalloc)
	{
		yyextra->literalalloc = pg_nextpower2_32(yyextra->literallen + yleng + 1);
		yyextra->literalbuf = (char *) repalloc(yyextra->literalbuf,
												yyextra->literalalloc);
	}
	/* append new data */
	memcpy(yyextra->literalbuf + yyextra->literallen, ytext, yleng);
	yyextra->literallen += yleng;
}


static void
addlitchar(unsigned char ychar, core_yyscan_t yyscanner)
{
	/* enlarge buffer if needed */
	if ((yyextra->literallen + 1) >= yyextra->literalalloc)
	{
		yyextra->literalalloc *= 2;
		yyextra->literalbuf = (char *) repalloc(yyextra->literalbuf,
												yyextra->literalalloc);
	}
	/* append new data */
	yyextra->literalbuf[yyextra->literallen] = ychar;
	yyextra->literallen += 1;
}


/*
 * Create a palloc'd copy of literalbuf, adding a trailing null.
 */
static char *
litbufdup(core_yyscan_t yyscanner)
{
	int			llen = yyextra->literallen;
	char	   *new;

	new = palloc(llen + 1);
	memcpy(new, yyextra->literalbuf, llen);
	new[llen] = '\0';
	return new;
}

/*
 * Process {decinteger}, {hexinteger}, etc.  Note this will also do the right
 * thing with {numeric}, ie digits and a decimal point.
 */
static int
process_integer_literal(const char *token, YYSTYPE *lval, int base)
{
	ErrorSaveContext escontext = {T_ErrorSaveContext};
	int32		val;

	val = pg_strtoint32_safe(token, (Node *) &escontext);
	if (escontext.error_occurred)
	{
		/* integer too large (or contains decimal pt), treat it as a float */
		lval->str = pstrdup(token);
		return FCONST;
	}
	lval->ival = val;
	return ICONST;
}

static void
addunicode(pg_wchar c, core_yyscan_t yyscanner)
{
	ScannerCallbackState scbstate;
	char		buf[MAX_UNICODE_EQUIVALENT_STRING + 1];

	if (!is_valid_unicode_codepoint(c))
		yyerror("invalid Unicode escape value");

	/*
	 * We expect that pg_unicode_to_server() will complain about any
	 * unconvertible code point, so we don't have to set saw_non_ascii.
	 */
	setup_scanner_errposition_callback(&scbstate, yyscanner, *(yylloc));
	pg_unicode_to_server(c, (unsigned char *) buf);
	cancel_scanner_errposition_callback(&scbstate);
	addlit(buf, strlen(buf), yyscanner);
}

static unsigned char
unescape_single_char(unsigned char c, core_yyscan_t yyscanner)
{
	switch (c)
	{
		case 'b':
			return '\b';
		case 'f':
			return '\f';
		case 'n':
			return '\n';
		case 'r':
			return '\r';
		case 't':
			return '\t';
		case 'v':
			return '\v';
		default:
			/* check for backslash followed by non-7-bit-ASCII */
			if (c == '\0' || IS_HIGHBIT_SET(c))
				yyextra->saw_non_ascii = true;

			return c;
	}
}

static void
check_string_escape_warning(unsigned char ychar, core_yyscan_t yyscanner)
{
	if (ychar == '\'')
	{
		if (yyextra->warn_on_first_escape && yyextra->escape_string_warning)
			ereport(WARNING,
					(errcode(ERRCODE_NONSTANDARD_USE_OF_ESCAPE_CHARACTER),
					 errmsg("nonstandard use of \\' in a string literal"),
					 errhint("Use '' to write quotes in strings, or use the escape string syntax (E'...')."),
					 lexer_errposition()));
		yyextra->warn_on_first_escape = false;	/* warn only once per string */
	}
	else if (ychar == '\\')
	{
		if (yyextra->warn_on_first_escape && yyextra->escape_string_warning)
			ereport(WARNING,
					(errcode(ERRCODE_NONSTANDARD_USE_OF_ESCAPE_CHARACTER),
					 errmsg("nonstandard use of \\\\ in a string literal"),
					 errhint("Use the escape string syntax for backslashes, e.g., E'\\\\'."),
					 lexer_errposition()));
		yyextra->warn_on_first_escape = false;	/* warn only once per string */
	}
	else
		check_escape_warning(yyscanner);
}

static void
check_escape_warning(core_yyscan_t yyscanner)
{
	if (yyextra->warn_on_first_escape && yyextra->escape_string_warning)
		ereport(WARNING,
				(errcode(ERRCODE_NONSTANDARD_USE_OF_ESCAPE_CHARACTER),
				 errmsg("nonstandard use of escape in a string literal"),
		errhint("Use the escape string syntax for escapes, e.g., E'\\r\\n'."),
				 lexer_errposition()));
	yyextra->warn_on_first_escape = false;		/* warn only once per string */
}

/*
 * Interface functions to make flex use palloc() instead of malloc().
 * It'd be better to make these static, but flex insists otherwise.
 */

void *
core_yyalloc(yy_size_t bytes, core_yyscan_t yyscanner)
{
	return palloc(bytes);
}

void *
core_yyrealloc(void *ptr, yy_size_t bytes, core_yyscan_t yyscanner)
{
	if (ptr)
		return repalloc(ptr, bytes);
	else
		return palloc(bytes);
}

void
core_yyfree(void *ptr, core_yyscan_t yyscanner)
{
	if (ptr)
		pfree(ptr);
}

